C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Conall version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 CONALL 23JUNE1997
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Allocates space for Contour Arc Package within the common array.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C    Inputs:
C
C     OUTUNT  : FORTRAN UNIT NUMBER FOR OUTPUT DATA FILE
C     LENX    : MAXIMUM DIMENSION OF THE COMMON BLOCK ARRAY
C     IVIEW   : FLAG (ORIENTATION OF COVERAGE)
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C
C   Inputs/Outputs:
C
C     ISUM    : INDEX NUMBER TO COMMON BLOCK ARRAY FOR ALLOCATION
C             => 1 BEGINNING
C
C    Outputs:
C
C     MAXCOL  : MAXIMUM CELL MASK (Y-DIRECTION)
C     MAXROW  : MAXIMUM CELL MASK (X-DIRECTION)
C     MAXXND  : MAXIMUM CELL NODES (X-DIRECTION)
C     MAXYND  : MAXIMUM CELL NODES (Y-DIRECTION)
C     LCCNTR  : STARTING ARRAY INDEX FOR CONTOUR VALUES
C     LCXNOD  : STARTING ARRAY INDEX FOR CELL NODES (X-DIRECTION)
C     LCYNOD  : STARTING ARRAY INDEX FOR CELL NODES (Y-DIRECTION)
C     LCIBRM  : STARTING ARRAY INDEX FOR CELL BRANCHES
C     LCMBND  : STARTING ARRAY INDEX FOR CELL MASK
C
C     Program:
C
C     ISUM1   : INDEX NUMBER TO LAST COMMON BLOCK ARRAY FOR ALLOCATION
C
C-------------------------------------------------------------------------
      SUBROUTINE CONALL (
     I                   OUTUNT,
     I                   LENX,
     I                   IVIEW,NLAY,NROW,NCOL,
     B                   ISUM,
     O                   MAXCOL,MAXROW,MAXXND,MAXYND,
     O                   LCBUDT,LCCNTR,LCXNOD,
     O                   LCYNOD,LCIBRM,LCMBND,
     E                   *)
C-----------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      INTEGER
     &        OUTUNT,
     &        LENX,
     &        IVIEW,NLAY,NROW,NCOL,
     &        ISUM,
     &        MAXCOL,MAXROW,MAXXND,MAXYND,
     &        LCBUDT,LCCNTR,LCXNOD,
     &        LCYNOD,LCIBRM,LCMBND
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
C     ------------------------------------------------------------------
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(/10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          CONTOUR GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''             VERSION 6.0 23JUNE1997 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''               ALLOCATION MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C1----Calculate storage parameters NRCL
C
      NRCL=NROW*NCOL*NLAY
      ISP=ISUM-1
C
      IF(IVIEW.LE.0 .OR. IVIEW.GE.4) THEN
         MAXXND=NCOL
         MAXYND=NROW
         MAXCOL=NROW
         MAXROW=NCOL
      ELSE IF(IVIEW.EQ.1) THEN
         MAXXND=NCOL
         MAXYND=NLAY
         MAXCOL=NLAY
         MAXROW=NCOL
      ELSE IF(IVIEW.EQ.2) THEN
         MAXXND=NROW
         MAXYND=NLAY
         MAXCOL=NLAY
         MAXROW=NROW
      ELSE
         MAXNOD=NCOL*NROW
         MAXCOL=NLAY
         MAXROW=NCOL*NROW
      ENDIF
C
C4----Print Modtools operation parameters
C
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          CONTOUR -- CONTOUR GIS PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          VERSION 6.0 23JUNE1997 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
C
C5----Print Modtools common block listing
C
      WRITE(OUTUNT,'(//,1H1,36X,
     &             ''CONTOUR MESH PARAMETER LISTING            '',
     &             /10X,85(''-''))')
C
      WRITE(OUTUNT,'(10X,
     &             ''MAXIMUM NUMBER OF NODES IN X-DIRECTION        '',
     &             10X,I15,'' MAXXND'')')
     &          MAXXND
      WRITE(OUTUNT,'(10X,
     &             ''MAXIMUM NUMBER OF NODES IN Y-DIRECTION        '',
     &             10X,I15,'' MAXYND'')')
     &          MAXYND
      WRITE(OUTUNT,'(10X,
     &             ''MAXIMUM NUMBER OF NODES IN X-DIRECTION        '',
     &             10X,I15,'' MAXROW'')')
     &          MAXROW
      WRITE(OUTUNT,'(10X,
     &             ''MAXIMUM NUMBER OF NODES IN Y-DIRECTION        '',
     &             10X,I15,'' MAXCOL'')')
     &          MAXCOL
      WRITE(OUTUNT,'(10X,85(''-''))')
C
C3----Allocate space for arrays
C
      LCBUDT=ISUM
      ISUM=ISUM+NRCL
      LCCNTR=ISUM
      ISUM=ISUM+MAXCOL*MAXROW
      LCXNOD=ISUM
      ISUM=ISUM+MAXXND
      LCYNOD=ISUM
      ISUM=ISUM+MAXYND
      LCIBRM=ISUM
      ISUM=ISUM+MAXCOL*MAXROW
      LCMBND=ISUM
      ISUM=ISUM+MAXCOL*MAXROW
      ISUM1=ISUM-1
      ISP=ISUM1-ISP
C
C4----Print Modtools common block listing
C
      WRITE(OUTUNT,'(//,1H1,36X,
     &             ''CONTOUR COMMON BLOCK INDEX LISTING            '',
     &             /10X,85(''-''))')
C
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CONTOUR DATA          '',
     &             10X,I15,'' LCBUDT'')')
     &          LCBUDT
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CONTOUR VALUES        '',
     &             10X,I15,'' LCCNTR'')')
     &          LCCNTR
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR NODES FOR X-AXIS      '',
     &             10X,I15,'' LCXNOD'')')
     &          LCXNOD
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR NODES FOR Y-AXIS      '',
     &             10X,I15,'' LCYNOD'')')
     &          LCYNOD
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CELL FACES            '',
     &             10X,I15,'' LCIBRM'')')
     &          LCIBRM
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CELL ROW AND COLUMN   '',
     &             10X,I15,'' LCMBND'')')
     &          LCMBND
      WRITE(OUTUNT,'(10X,
     &             ''NUMBER OF ELEMENTS USED BY CONTOUR PACKAGE     '',
     &             10X,I15,''    ISP'')')
     &          ISP
      WRITE(OUTUNT,'(10X,
     &             ''TOTAL NUMBER OF ELEMENTS USED IN COMMON BLOCK  '',
     &             10X,I15,''  ISUM1'')')
     &          ISUM1
      WRITE(OUTUNT,'(10X,85(''-''))')
C
C3----Check amount of space used
C
      IF(ISUM1.GT.LENX) THEN
         WRITE(OUTUNT,'(//,
     &                ''    ***CELL ARRAY MUST BE DIMENSIONED '',
     &                ''LARGER*** ISUM '',I10,'' > LENX '',I10)')
     &             ISUM1,
     &             LENX
         WRITE(OUTUNT,'(//,
     &             '' Abnormal termination of Conall_Subroutine'')')
         WRITE (*,'(//,'' Cell array must be dimensioned larger ISUM '',
     &              I10,'' > LENX '',I10)')
     &           ISUM1,
     &           LENX
         WRITE(*,'(//,
     &             '' Abnormal termination of Conall_Subroutine'')')
         RETURN 1
      ENDIF
C
C4----Return
C
      RETURN
      END

C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Conrp1 version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 CONRP1 08SEPEMBER1999
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Reads an user specified files for cell_by_cell terms output by
C      the U.S. Geological Survey Modular Three-Dimensional Finite-Differences
C      Ground-Water Flow Model MODFLOW (McDonald and Harbaugh, 1988).
C      Also, this program can read 2D or 3D data that is formatted in the
C      same manner as the cell-by-cell terms.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C    Inputs:
C
C     OUTFIL  : OUTPUT FILE NAME DOCUMENTING CONRP1 OPERATIONS.
C     OUTUNT  : FORTRAN UNIT NUMBER FOR OUTPUT DATA FILE
C     CONFIL  : FILE CONTAINING THE CELL_BY_CELL TERMS
C     CONUNT  : FORTRAN UNIT NUMBER CONFIL FILE
C     LVLFIL  : FILE CONTAINING THE RECORDS FOR THE UTILITY READERS 
C     LVLUNT  : FORTRAN UNIT NUMBER FOR LVLFIL
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C
C    Outputs:
C
C     CONARY  : ARRAY FOR CELL-BY-CELL FLOW, BUDGET, HEAD TERMS
C
C     Program:
C
C     ANAME   : CHARACTER ARRAY (6,8) CONTAINING ARRAY NAMES
C
C-------------------------------------------------------------------------
      SUBROUTINE CONRP1 (
     I                   OUTFIL,OUTUNT,
     I                   CONFIL,CONUNT,
     I                   LVLFIL,LVLUNT,
     I                   MAXPMR,COVPMR,
     I                   NLAY,NROW,NCOL,
     O                   CONARY,
     E                   *)
C-----------------------------------------------------------------------
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      DIMENSION 
     &          COVPMR(MAXPMR),
     &          CONARY(NCOL*NROW*NLAY)
C
      CHARACTER*(*) 
     &             OUTFIL,
     &             CONFIL,
     &             LVLFIL
C
      INTEGER 
     &       OUTUNT,
     &       CONUNT,
     &       LVLUNT
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      CHARACTER*16 CONTXT(20)
C
      DATA CONTXT(1)  /'            HEAD'/
      DATA CONTXT(2)  /'        DRAWDOWN'/
      DATA CONTXT(3)  /'         STORAGE'/
      DATA CONTXT(4)  /'   RIVER LEAKAGE'/
      DATA CONTXT(5)  /'        RECHARGE'/
      DATA CONTXT(6)  /'           WELLS'/
      DATA CONTXT(7)  /'          DRAINS'/
      DATA CONTXT(8)  /' HEAD DEP BOUNDS'/
      DATA CONTXT(9)  /'              ET'/
      DATA CONTXT(10) /'  STREAM LEAKAGE'/
      DATA CONTXT(11) /'  STREAM FLOWOUT'/
      DATA CONTXT(12) /'INTERBED STORAGE'/
      DATA CONTXT(14) /'MISCELLANEO TERM'/
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                     Reading contour information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C0*********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(/)')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          CONTOUR GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''             VERSION 6.0 08SEPEMBER1999 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''               READ/PREPARE MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
CL----Set local variables
C
      MODFMT=INT(COVPMR(12)/100)
      IDCNTR=MOD(INT(COVPMR(12)),100)
      MODPER=INT(COVPMR(13))
      MODSTP=INT(COVPMR(14))
      NPER=INT(COVPMR(17))
      FLWCLL=COVPMR(16) 
      LOC=0
C
C1----Print message
C
      IF(NPER.EQ.0) THEN
         MODPER=1
         MODSTP=1
         WRITE(*,'(
     &          ''      .Reading steady-state '',
     &          ''cell-by-cell terms for Contour Package '')')
         WRITE(OUTUNT,'(
     &          ''      .Reading steady-state '',
     &          ''cell-by-cell terms for Contour Package '')')
      ELSE
         WRITE(*,'(
     &          ''      .Reading transient '',
     &          ''cell-by-cell terms for Contour Package '')')
         WRITE(*,'(
     &          ''      .. for Modflow stress period '',I10)')
     &                                                         MODPER
         WRITE(*,'(
     &          ''      .. for Modflow time step '',I10)')
     &                                                         MODSTP
         WRITE(OUTUNT,'(
     &          ''      .Reading transient '',
     &          ''cell-by-cell terms for Contour Package '')')
         WRITE(OUTUNT,'(
     &          ''      .. for Modflow stress period '',I10)')
     &                                                         MODPER
         WRITE(OUTUNT,'(
     &          ''      .. for Modflow time step '',I10)')
     &                                                         MODSTP
      ENDIF
C
C2---Read cell-by-cell terms
C 
      IF(MODFMT.EQ.1) THEN 
         WRITE(*,'( 
     &          ''      ..Reading Cell-By-Cell Head Terms from '', 
     &          ''Basic Package '')') 
         WRITE(OUTUNT,'( 
     &          ''      ..Reading Cell-By-Cell Head Terms from '', 
     &          ''Basic Package '')') 
      ELSE IF(MODFMT.EQ.2) THEN 
         WRITE(*,'( 
     &          ''      ..Reading Cell-By-Cell Drawdown Terms from '', 
     &          ''Basic Package '')') 
         WRITE(OUTUNT,'( 
     &          ''      ..Reading Cell-By-Cell Drawdown Terms from '', 
     &          ''Basic Package '')') 
      ELSE IF(MODFMT.EQ.3) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Storage Terms from '',
     &          ''Block-Centered Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Storage Terms from '',
     &          ''Block-Centered Package '')')
      ELSE IF(MODFMT.EQ.4) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''River Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''River Package '')')
      ELSE IF(MODFMT.EQ.5) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Recharge Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Recharge Package '')')
      ELSE IF(MODFMT.EQ.6) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Well Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Well Package '')')
      ELSE IF(MODFMT.EQ.7) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Drain Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Drain Package '')')
      ELSE IF(MODFMT.EQ.8) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''General Head Boundary Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''General Head Boundary Package '')')
      ELSE IF(MODFMT.EQ.9) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Evapotranspiration Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Evapotranspiration Package '')')
      ELSE IF(MODFMT.EQ.10) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Streamflow-Routing Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Flow Terms from '',
     &          ''Streamflow-Routing Package '')')
      ELSE IF(MODFMT.EQ.11) THEN
         WRITE(*,'(
     &          ''      ..Reading Cell-By-Cell Streamflow Terms  '',
     &          ''from Streamflow-Routing Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Cell-By-Cell Streamflow Terms '',
     &          ''from Streamflow-Routing Package '')')
      ELSE IF(MODFMT.EQ.12) THEN
         WRITE(*,'(
     &          ''      ..Reading Interbed-Storage Terms from '',
     &          ''Aquifer-System Compaction Package '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Interbed-Storage Terms from '',
     &          ''Aquifer-System Compaction Package '')')
      ELSE
         MODFMT=14
         WRITE(*,'(
     &          ''      ..Reading Miscellaneous Gridded Terms '')')
         WRITE(OUTUNT,'(
     &          ''      ..Reading Miscellaneous Gridded Terms '')')
      ENDIF
C
C1B----Check control file LVLFIL
C
       IF(LVLUNT.GT.0) THEN
          WRITE(*,'(
     &              ''      ..recorded in file '',A)')
     &              CONFIL (1:INDEX(CONFIL,' ')-1)
          WRITE(*,'(
     &              ''      ..on unit '',I10)')
     &                                                 CONUNT
          WRITE(*,'(
     &              ''      .Using control lines '')')
          WRITE(*,'(
     &              ''      ..recorded in file '',A)')
     &              LVLFIL (1:INDEX(LVLFIL,' ')-1)
          WRITE(OUTUNT,'(
     &              ''      ..recorded in file '',A)')
     &              CONFIL (1:INDEX(CONFIL,' ')-1)
          WRITE(OUTUNT,'(
     &              ''      ..on unit '',I10)')
     &                                                 CONUNT
          WRITE(OUTUNT,'(
     &              ''      .Using control lines '')')
          WRITE(OUTUNT,'(
     &              ''      ..recorded in file '',A)')
     &              LVLFIL (1:INDEX(LVLFIL,' ')-1)
       ELSE
          WRITE(*,'(
     &              ''      .Can not read cell_by_cell terms '',
     &              ''recorded in file '',A)')
     &              CONFIL (1:INDEX(CONFIL,' ')-1)
          WRITE(*,'(
     &              ''      ..on unit '',I10)')
     &                                                 CONUNT
          WRITE(*,'(
     &              ''      .Need file containing U2DREL control '',
     &              ''lines for format of cell-by-cell terms file'')') 
          WRITE(OUTUNT,'(
     &              ''      .Can not read cell_by_cell terms '',
     &              ''recorded in file '',A)')
     &              CONFIL (1:INDEX(CONFIL,' ')-1)
          WRITE(OUTUNT,'(
     &              ''      ..on unit '',I10)')
     &                                                 CONUNT
          WRITE(OUTUNT,'(
     &              ''      .Need file containing U2DREL control '',
     &              ''lines for format of cell-by-cell terms file'')') 
          GO TO 9999
       ENDIF
C
C2----Set contour array
C
      DO 200 KK=1,NLAY
      DO 200 JJ=1,NCOL
      DO 200 II=1,NROW 
         LOC=LOC+1
 200     CONARY(LOC)=FLWCLL
C
C3----Read 2-D array
C
      IF(IDCNTR.EQ.2) THEN
         CALL U2DARY (CONARY,CONTXT(MODFMT),NROW,NCOL,NLAY,
     &                CONFIL,CONUNT,LVLFIL,LVLUNT,OUTUNT,
     &                MODPER,MODSTP,
     E                *9999)
C
C4----Read 3-D array
C
      ELSE
         CALL U3DARY (CONARY,CONTXT(MODFMT),NROW,NCOL,NLAY,CONFIL,
     &                CONUNT,LVLFIL,LVLUNT,OUTUNT,MODPER,MODSTP,
     E                *9999)
      ENDIF
C
      GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9999 WRITE(*,
     &      '(//,'' Abnormal Termination of Conrp1_Subroutine'')')
      WRITE(OUTUNT,
     &      '(//,'' Abnormal Termination of Conrp1_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthcon version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHCON 01OCTOBER1999
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Generates an line coverage containing of lines of equal (contours)
C      cell-by-cell budget, flow, or head terms
C      output from the modular three-dimensional finite-difference
C      ground-water flow model (McDonald and Harbaugh, 1988).  This program
C      uses modified portions of the USGS computer code from CONTOUR.  
C      CONTOUR is "A Simple Contour Program for Gridded Data" documented in
C      Open-File Report 90-144 by Arlen W. Harbaugh (1990).
C
C      IVIEW
C           => 0 not used (mapview)
C           => 1 an user chosen row
C           => 2 an user chosen column
C           => 3 an user chosen particle (unavailable)
C           => 4 an user chosen layer
C           => 5 an user chosen ibound value (mapview)
C           => 6 uppermost active cells (mapview)
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C
C    Inputs:
C
C     CONCOV  : COVERAGE ROOT NAME
C     COVPMR  : COVERAGE PARAMETERS ARRAY (MAXPMR)
C     DELX    : ARRAY FOR CELL WIDTHS IN ROW/COLUMN/PARTICLE DIRECTION (NDELX)
C     CONBUD  : ARRAY FOR LAYER/UNIT CELL_BY_CELL HEADS
C     IBOUND  : ARRAY FOR IBOUND ARRAY (NCOL,NROW,NLAY)
C     OUTUNT  : FORTRAN UNIT WHERE OPERATIONAL OUTPUT AND ERRORS ARE RECORDED
C     IRWCL   : WHERE CROSS-SECTION TRANVERSE IS TAKEN
C     IVIEW   : FLAG (ORIENTATION OF COVERAGE)
C     LRWCL   : ARRAY INDICATING THE CELL'S ROW AND COLUMN (2,NDELX)
C     MAXATB  : MAXIMUM NUMBER OF ATTRIBUTES FOR EACH LINE
C                IN THE COVERAGE AAT FILE.
C     MAXPMR  : MAXIMUM NUMBER OF COVERAGE PARAMETERS
C     MAXPTS  : MAXIMUM NUMBER OF VERTICES IN A SINGLE ARC
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C     ZTOP    : ARRAY FOR LAYER/UNIT TOP ELEVATIONS
C     ZBOT    : ARRAY FOR LAYER/UNIT BOTTOM ELEVATIONS
C
C   Inputs/Outputs: None
C
C    Outputs: None
C
C-----------------------------------------------------------------------
      SUBROUTINE PTHCON (
     I                   OUTUNT,
     I                   CONCOV,
     I                   MAXPMR,
     I                   NLAY,NROW,NCOL,
     I                   DELX,COVPMR,DELZCB,
     I                   LRWCL,IBOUND,ZTOP,ZBOT,CONARY,
     I                   MAXROW,MAXCOL,MAXXND,MAXYND,
     I                   IBRMAP,MBOUND,CONBUD,XNODES,YNODES,
     E                   *)
C-----------------------------------------------------------------------
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      DIMENSION 
     1          COVPMR(MAXPMR),
     1          DELX(NCOL*NROW),
     1          DELZCB(NLAY),
     1          XNODES(MAXXND),
     1          YNODES(MAXYND),
     2          MBOUND(MAXROW,MAXCOL),
     2          IBRMAP(MAXROW,MAXCOL),
     3          CONBUD(MAXROW,MAXCOL),
     2          LRWCL(2,NCOL*NROW),
     3          IBOUND(NCOL,NROW,NLAY),
     3          ZTOP(NCOL,NROW,NLAY),
     3          ZBOT(NCOL,NROW,NLAY),
     3          CONARY(NCOL,NROW,NLAY)
C
      CHARACTER*(*) CONCOV
      INTEGER IRWCL,IVIEW,OUTUNT
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      PARAMETER (MAXFIL=4)
C
      REAL CONIBD,BOGUS
C
      CHARACTER*128 LABFIL,TMPCOV
      CHARACTER*80 FILES(MAXFIL),ADDFIL,INPFIL,TMPFIL
      CHARACTER*16 COVTYP,ARCCMD,ITEM,
     &             LAYITM,STRITM,RELITM,JONTYP
      CHARACTER*1 TYPITM
C
      INTEGER IOUT(MAXFIL)
C
      INTEGER 
     &        STRCOL,STRROW,STRCLL,
     &        FINCOL,FINROW,FINCLL,
     &        IROW,ICOL,ILAY,BADIBD,NUMDRY,NUMFLW,
     &        NUMCLL,
     &        DECIML,OUTPUT,WIDTH
C
      EXTERNAL OPEN_FILE,CLOSE_FILE,DELETE_FILE
C
      DATA FILES /'conitems','conitem','conarcs','arccmd'/
      DATA IOUT /96,97,98,99/
C
      DATA BOGUS /1.0E+30/
C
C     ------------------------------------------------------------------
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          CONTOUR GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''             VERSION 6.0 01OCTOBER1999 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''               GIS OUTPUT MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C1A----Set global variables
C
      DO 100 N=1,MAXROW
         DO 100 M=1,MAXCOL
            MBOUND(N,M)=0
  100 CONTINUE
C
C1B----Set local variables
C
      NARCS=0
      NLABS=0
      TMPCOV='tmp'
      YORGIN=0.0
      ZSTEP=COVPMR(1)
      XYSCALE=COVPMR(3)
      ZSCALE=COVPMR(4)
      ANGLE=COVPMR(5)
      XOGRID=COVPMR(6)
      YOGRID=COVPMR(7)
      IF(COVPMR(9).LE.0.0) COVPMR(9)=1.0
      HSCALE=12.0/COVPMR(9)
      IF(COVPMR(8).LE.0.0) COVPMR(8)=1.0
      VSCALE=HSCALE*COVPMR(8)
      IVIEW=INT(COVPMR(10))
      IRWCL=INT(COVPMR(11))
      DRYCLL=COVPMR(15)
      FLWCLL=COVPMR(16)
C
C1E----Error checking on local variables
C
      IF(ZSTEP.LE.0.0) THEN
         WRITE(*,'(''        ....Contour interval was set to 0.0 '',
     &             F10.3)') 
     &                ZSTEP
         WRITE(*,'(''        ....Check input parameters to Modtools'')')
         GOTO 9999
      ENDIF
C
C2----Delete and create files for attribute definitions, attribute value, 
C      and coverage arc data and tolerance/dangle values
C
      NSTAT=2
      ITALK=1
C
C2A----Delete/create files containing Arc/Info item definitions for
C      attribute files
C
      DO 200 N=1,MAXFIL
         CALL DELETE_FILE (FILES(N),*9999)
         CALL OPEN_FILE (IOUT(N),FILES(N),NSTAT,ITALK,*9999)
  200 CONTINUE
C
C2B----Compute attribute definitions
C
      ITEM='contour'
      WIDTH=10
      OUTPUT=10
      TYPITM='N'
      DECIML=2
C
      IF(ZSTEP-INT(ZSTEP).EQ.0.0) THEN
         TYPITM='I'
         DECIML=0
      ELSE 
         DECIML=0
 202     DECIML=DECIML+1
         DIFSTP=ZSTEP*(10**DECIML)
       IF(ZSTEP*(10**DECIML).LT.1.0) GO TO 202
      ENDIF
C
C2C----Write attribute definitions
C
      WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                   I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
      CALL CLOSE_FILE (FILES(1),*9999)
C
C3----Build mapview for single layer (iview=0,4)
C-----                  single ibound (iview=5)
C-----                  uppermost active layer (iview=6)
C
      IF(IVIEW.LE.0 .OR. IVIEW.GE.4) THEN
       IF(IVIEW.EQ.0 .OR. IVIEW.EQ.4) 
     &    WRITE(*,'(''      .Processing contour Information '',
     &              ''for layer '',I10,'' in mapview now...'')')
     &          IRWCL
       IF(IVIEW.EQ.5) 
     &    WRITE(*,'(''      .Processing contour Information '',
     &              ''for ibound '',I10,'' in mapview now...'')')
     &          IRWCL
       IF(IVIEW.EQ.6) 
     &    WRITE(*,'(''      .Processing contour Information '',
     &              ''for uppermost active cell in mapview now...'')')
C
C3A----Set local variables
C
         ZMAX=-9999999999.99
         ZMIN=-ZMAX
         NUMCLL=0
         YTOP=0.0
         NUMLAY=IRWCL
         NUMCOL=0
         NUMDRY=0
         NUMFLW=0
         NCELLS=0 
         BADIBD=0
C
C3H----Data header
C
         WRITE(OUTUNT,'(//,1H1,40X,
     &               '' CELL CONDITIONS FOR CONTOUR GIS PACKAGE'',
     &               /10X,85(''-''))')
         WRITE(OUTUNT,'(40X,
     &               ''       ROW'',
     &               ''    COLUMN'',
     &               ''     LAYER'',
     &               ''    IBOUND'',
     &               /10X,85(''-''))')
C
C3B----Compute node locations
C
         DO 300 ICOL=NCOL+1,NCOL+NROW
            NUMCOL=NUMCOL+1
            YWIDTH=DELX(ICOL)
            YCENTR=YTOP+YWIDTH/2.0
            YTOP=YTOP+YWIDTH
            XLEFT=0.0
            NUMROW=0
            DO 310 IROW=1,NCOL
               NUMROW=NUMROW+1
               XWIDTH=DELX(IROW)
               XCENTR=XLEFT+XWIDTH/2.0
               XLEFT=XLEFT+XWIDTH
               IBDCEL=0
             IF(IVIEW.EQ.0 .OR. IVIEW.EQ.4) THEN
                IBDCEL=ABS(IBOUND(NUMROW,NUMCOL,NUMLAY))
              IF(IBDCEL.NE.0) THEN
               IF(CONARY(NUMROW,NUMCOL,NUMLAY).EQ.DRYCLL) THEN
                  NUMDRY=NUMDRY+1
                  WRITE(OUTUNT,'(10X,
     &                  ''DRY CELL                      '',
     &                  4I10)')
     &                          NUMROW,
     &                          NUMCOL,
     &                          NUMLAY,
     &                          IBDCEL
                  IBDCEL=0
               ELSE IF(CONARY(NUMROW,NUMCOL,NUMLAY).EQ.FLWCLL) THEN
                  NUMFLW=NUMFLW+1
                  WRITE(OUTUNT,'(10X,
     &                  ''NOFLOW CELL                   '',
     &                  4I10)')
     &                          NUMROW,
     &                          NUMCOL,
     &                          NUMLAY,
     &                          IBDCEL
                  IBDCEL=0
               ELSE
                  NCELLS=NCELLS+1
               ENDIF
              ELSE
                BADIBD=BADIBD+1
                WRITE(OUTUNT,'(10X,
     &                  ''INACTIVE CELL                 '',
     &                  4I10)')
     &                          NUMROW,
     &                          NUMCOL,
     &                          NUMLAY,
     &                          IBDCEL
              ENDIF
             ELSE IF(IVIEW.EQ.5) THEN
                DO 320 ILAY=1,NLAY
                   IBDCEL=ABS(IBOUND(NUMROW,NUMCOL,ILAY))
                 IF(IBDCEL.EQ.IRWCL) THEN
                  IF(CONARY(NUMROW,NUMCOL,ILAY).EQ.DRYCLL) THEN
                     NUMDRY=NUMDRY+1
                     IBDCEL=0
                  ELSE IF(CONARY(NUMROW,NUMCOL,ILAY).EQ.FLWCLL) THEN
                     NUMFLW=NUMFLW+1
                     IBDCEL=0
                  ELSE
                    NUMLAY=ILAY
                    GO TO 322
                  ENDIF
                 ENDIF
  320           CONTINUE
  322           CONTINUE
                NCELLS=NCELLS+1
             ELSE
                DO 330 ILAY=1,NLAY
                   IBDCEL=ABS(IBOUND(NUMROW,NUMCOL,ILAY))
                 IF(IBDCEL.NE.0) THEN
                  IF(CONARY(NUMROW,NUMCOL,ILAY).EQ.DRYCLL) THEN
                     NUMDRY=NUMDRY+1
                     IBDCEL=0
                  ELSE IF(CONARY(NUMROW,NUMCOL,ILAY).EQ.FLWCLL) THEN
                     NUMFLW=NUMFLW+1
                     IBDCEL=0
                  ELSE
                    NCELLS=NCELLS+1
                    NUMLAY=ILAY
                    GO TO 332
                  ENDIF
                 ENDIF
  330           CONTINUE
  332           CONTINUE
             ENDIF
C
             IF(IBDCEL.EQ.0) THEN
                IUP=MBOUND(NUMROW,NUMCOL)/2
                IRIGHT=MBOUND(NUMROW,NUMCOL)-IUP*2
              IF(IUP.EQ.0) 
     &           MBOUND(NUMROW,NUMCOL)=MBOUND(NUMROW,NUMCOL)+2
              IF(IRIGHT.EQ.0) 
     &           MBOUND(NUMROW,NUMCOL)=MBOUND(NUMROW,NUMCOL)+1
              IF(NUMCOL.EQ.1) GO TO 312
                IDOWN=MBOUND(NUMROW,NUMCOL-1)/2
              IF(IDOWN.EQ.0) 
     &           MBOUND(NUMROW,NUMCOL-1)=MBOUND(NUMROW,NUMCOL-1)+2
  312         IF(NUMROW.EQ.1) GO TO 314
                ILEFT=MBOUND(NUMROW-1,NUMCOL)-
     &                MBOUND(NUMROW-1,NUMCOL)/2*2
              IF(ILEFT.EQ.0) 
     &           MBOUND(NUMROW-1,NUMCOL)=MBOUND(NUMROW-1,NUMCOL)+1
             ELSE
                MBOUND(NUMROW,NUMCOL)=0
             ENDIF
C
  314          CONCLL=CONARY(NUMROW,NUMCOL,NUMLAY)
             IF(IBDCEL.NE.0) THEN
              IF(CONCLL.GT.ZMAX) ZMAX=CONCLL
              IF(CONCLL.LT.ZMIN) ZMIN=CONCLL
             ENDIF
               CONBUD(NUMROW,NUMCOL)=CONCLL
               XNODES(NUMROW)=XCENTR
               YNODES(NUMCOL)=YCENTR
  310       CONTINUE
  300    CONTINUE
C
C4----Build vertical profile along row    (iview=1)
C-----                       along column (iview=2)
C-----                       along particle path (iview=3)
C
C
C4----Build arcs from elevation and row/column data
C
      ELSE IF(IVIEW.GT.0 .AND. IVIEW.LE.3) THEN
       IF(IVIEW.LE.1) THEN
          WRITE(*,'(''       .Processing vertical contour profile '',
     &              ''information along row '',I10)')
     &           IRWCL
       ELSE IF(IVIEW.EQ.2) THEN
          WRITE(*,'(''       .Processing vertical profile  '',
     &              ''information along column '',I10)')
     &           IRWCL
       ELSE
          WRITE(*,'(''       .Processing vertical profile '',
     &              ''information along particle '',I10)')
     &           IRWCL
       ENDIF
C
C4A----Set cell min/max and x-direction sum variables
C
         BADIBD=0
         BADTOP=0
         NUMDRY=0
         NUMFLW=0
         NUMCLL=0
         NCELLS=0
         ZMAX=-9999999999.99
         ZMIN=-ZMAX
         CLLMIN=COVPMR(MAXPMR)
C
C4H----Data header
C
         WRITE(OUTUNT,'(//,1H1,40X,
     &               '' CELL CONDITIONS FOR CONTOUR GIS PACKAGE'')')
         WRITE(OUTUNT,'(10X,85(''-''))')
         WRITE(OUTUNT,'(40X,
     &               ''       ROW'',
     &               ''    COLUMN'',
     &               ''     LAYER'',
     &               ''    IBOUND'')')
         WRITE(OUTUNT,'(10X,85(''-''))')
C
C4B----Set Loop index numcll
C
         IF(IVIEW.EQ.1) THEN
            STRCLL=1
            FINCLL=NCOL
         ELSE IF(IVIEW.EQ.2) THEN
            STRCLL=NCOL+1
            FINCLL=NCOL+NROW
         ELSE
            STRCLL=1
            FINCLL=IRWCL
         ENDIF
C
C4D---Loop to build arcs from elevation and row/column data
C
         DO 400 ILAY=1,NLAY
            XLEFT=0.0
            NUMROW=0
            NUMCLL=0
            NUMCOL=NLAY-ILAY+1
            DO 410 N=STRCLL,FINCLL
               NUMCLL=NUMCLL+1
               NUMROW=NUMROW+1
               XWIDTH=DELX(N)*HSCALE
               XRIGHT=XLEFT+XWIDTH
               HWIDTH=XWIDTH/2.0
               XCENTR=XLEFT+HWIDTH
               XLEFT=XRIGHT
C
             IF(IVIEW.LE.1) THEN
                IROW=IRWCL
                ICOL=NUMCLL
             ELSE IF(IVIEW.EQ.2) THEN
                IROW=NUMCLL
                ICOL=IRWCL
             ELSE
                ICOL=LRWCL(1,NUMCLL)
                IROW=LRWCL(2,NUMCLL)
             ENDIF
C
C4A----Set correct row/column
C
               TOPAVG=ZTOP(ICOL,IROW,ILAY)
               BOTAVG=ZBOT(ICOL,IROW,ILAY)
               IBDCEL=ABS(IBOUND(ICOL,IROW,ILAY))
               CONCLL=CONARY(ICOL,IROW,ILAY)
C
             IF(IBDCEL.NE.0) THEN
              IF(CONCLL.EQ.DRYCLL) THEN
                 NUMDRY=NUMDRY+1
                 WRITE(OUTUNT,'(10X,
     &                 ''DRY CELL                      '',
     &                 4I10,F9.3)')
     &                         IROW,
     &                         ICOL,
     &                         ILAY,
     &                         IBDCEL,
     &                         CONCLL
                 IBDCEL=0
              ELSE IF(CONCLL.EQ.FLWCLL) THEN
                 NUMFLW=NUMFLW+1
                 WRITE(OUTUNT,'(10X,
     &                 ''NOFLOW CELL                   '',
     &                 4I10,F9.3)')
     &                         IROW,
     &                         ICOL,
     &                         ILAY,
     &                         IBDCEL,
     &                         CONCLL
                 IBDCEL=0
              ELSE
                 NCELLS=NCELLS+1
              ENDIF
             ELSE
               BADIBD=BADIBD+1
               WRITE(OUTUNT,'(10X,
     &                 ''INACTIVE CELL                 '',
     &                 4I10,F9.3)')
     &                         IROW,
     &                         ICOL,
     &                         ILAY,
     &                         IBDCEL,
     &                         CONCLL
                IBDCEL=0
             ENDIF
C
             IF(IBDCEL.EQ.0) THEN
                IUP=MBOUND(NUMROW,NUMCOL)/2
                IRIGHT=MBOUND(NUMROW,NUMCOL) - IUP*2
              IF(IUP.EQ.0) 
     &           MBOUND(NUMROW,NUMCOL)=MBOUND(NUMROW,NUMCOL) + 2
              IF(IRIGHT.EQ.0) 
     &           MBOUND(NUMROW,NUMCOL)=MBOUND(NUMROW,NUMCOL) + 1
              IF(NUMCOL.EQ.1) GO TO 412
                IDOWN=MBOUND(NUMROW,NUMCOL-1)/2
              IF(IDOWN.EQ.0) 
     &           MBOUND(NUMROW,NUMCOL-1)=MBOUND(NUMROW,NUMCOL-1) + 2
  412         IF(NUMROW.EQ.1) GO TO 414
                ILEFT=MBOUND(NUMROW-1,NUMCOL)-
     &                MBOUND(NUMROW-1,NUMCOL)/2*2
              IF(ILEFT.EQ.0) 
     &           MBOUND(NUMROW-1,NUMCOL)=MBOUND(NUMROW-1,NUMCOL) + 1
             ENDIF
C
  414          YCENTR=TOPAVG-(TOPAVG-BOTAVG)*0.5
C
               YNODES(NUMCOL)=YCENTR*VSCALE-CLLMIN
               XNODES(NUMROW)=XCENTR
C
             IF(IBDCEL.NE.0) THEN
              IF(CONCLL.GT.ZMAX) ZMAX=CONCLL
              IF(CONCLL.LT.ZMIN) ZMIN=CONCLL
             ENDIF
                CONBUD(NUMROW,NUMCOL)=CONCLL
C
               WRITE(OUTUNT,'(10X,
     &                 ''ACTIVE CELL                   '',
     &                 4I5,3F10.3)')
     &                         IROW,
     &                         ICOL,
     &                         ILAY,
     &                         IBDCEL,
     &                         XNODES(NUMROW),
     &                         YNODES(NUMCOL),
     &                         CONCLL
  410       CONTINUE
  400    CONTINUE
         NUMCOL=NLAY
      ENDIF
C
      WRITE(OUTUNT,'(10X,85(''-''))')

C
C5---Compute contours
C
C
C5A---Compute minimum and maximum values
C
      CONMIN=ANINT(ZMIN/ZSTEP)*ZSTEP
      IF(ZMIN.GT.CONMIN) THEN
         ZMIN=CONMIN
      ELSE
         ZMIN=CONMIN-ZSTEP
      ENDIF
C
      CONMAX=ANINT(ZMAX/ZSTEP)*ZSTEP
      IF(ZMAX.LT.CONMAX) THEN
         ZMAX=CONMAX
      ELSE
         ZMAX=CONMAX+ZSTEP
      ENDIF
         WRITE(*,'(''        .Maximum '',G20.3,/,
     &             ''        ..Minimum  '',G20.3)') 
     &                ZMAX,
     &                ZMIN
C
C5B---Compute number of contour levels
C
        NLEVS=INT(ABS(ZMAX-ZMIN)/ZSTEP)
      IF(NLEVS.GT.0) THEN
         WRITE(*,'(''        ...Number of intervals is     '',
     &             I10,/,
     &             ''        ....Present contour interval  '',
     &             F10.3)') 
     &                NLEVS,
     &                ZSTEP
      ELSE
         WRITE(*,'(''        .Contour level too small'',
     &             '' number of intervals is zero '',
     &             ''        ..present contour interval  '',
     &             F10.3)') 
     &                ZSTEP
         GO TO 9999
      ENDIF
C
C5C---Messages to user
C
      IF(IVIEW.LE.0 .OR. IVIEW.EQ.4) THEN
         WRITE(*,'(''      .Contouring cell-by-cell terms '',
     &             ''for layer '',I10,'' now...'')')
     &          IRWCL
      ELSE IF(IVIEW.EQ.1) THEN
         WRITE(*,'(''      .Contouring cell-by-cell terms '',
     &             ''for row '',I10,'' now...'')')
     &          IRWCL
      ELSE IF(IVIEW.EQ.2) THEN
         WRITE(*,'(''      .Contouring cell-by-cell terms '',
     &             ''for column '',I10,'' now...'')')
     &          IRWCL
      ELSE IF(IVIEW.EQ.3) THEN
         WRITE(*,'(''      .Contouring cell-by-cell terms '',
     &             ''for particle '',I10,'' now...'')')
     &          IRWCL
      ELSE IF(IVIEW.EQ.5) THEN
         WRITE(*,'(''      .Contouring cell-by-cell terms '',
     &             ''for ibound '',I10,'' now...'')')
     &          IRWCL
      ELSE
         WRITE(*,'(''      .Contouring cell-by-cell terms '',
     &             ''for uppermost active cell now...'')')
      ENDIF
C
C5C---Compute contours
C
      DO 500 N=1,NLEVS
       IF(N.LE.1) THEN
          CONTUR=ZMIN
       ELSE
          CONTUR=ZMIN+FLOAT(N-1)*ZSTEP
       ENDIF
         DO 510 ICOL=1,NUMCOL
            DO 510 IROW=1,NUMROW
               CHNGR=CONTUR+CONTUR*10.E-5
             IF(CONTUR.EQ.0.0) CHNGR=1.E-20
             IF(CONBUD(IROW,ICOL).EQ.CONTUR) CONBUD(IROW,ICOL)=CHNGR
  510    CONTINUE
         CALL POINTS (
     &                NUMROW,NUMCOL,CONBUD,CONTUR,IBRMAP,
     &                XNODES,YNODES,MBOUND,1,NUMROW,
     &                1,NUMCOL,
     I                MAXPMR,COVPMR,
     I                IOUT(2),IOUT(3))
  500 CONTINUE
C
C6----Close-out arc coordinate file
C
      CALL CLOSE_FILE (FILES(2),*9999)
      WRITE(IOUT(3),'(''END'')')
      CALL CLOSE_FILE (FILES(3),*9999)
C
C7----Messages
C
C
C7A----Message to user
C
      WRITE(*,'(''      .Contour line coverage '',A,
     &          '' consists of '')')
     &        CONCOV (1:INDEX(CONCOV,' ')-1)
      WRITE(*,'(''      .'',I10,'' contour levels'')') NLEVS
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''contoured'')') NCELLS
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''ommited (ibound = 0)'')') BADIBD
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''ommited (dry)'')') NUMDRY
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''ommited (noflow)'')') NUMFLW
C
C7B----Message to operational output file
C
      WRITE(OUTUNT,'(//,''      .Contour line coverage '',
     &               A,'' consists of '')')
     &            CONCOV (1:INDEX(CONCOV,' ')-1)
      WRITE(OUTUNT,'(''      .'',I10,'' contour levels'')') NLEVS
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''contoured'')') NUMCLL
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''ommited (ibound = 0)'')') BADIBD
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''ommited (dry)'')') NUMDRY
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''ommited (noflow)'')') NUMFLW
C
C8----Arc Operations to coverage and attribute files
C
C
C8A---Kill old Coverage CONCOV
C
      ARCCMD='kill'
      WRITE(IOUT(4),'(A,1X,A)') 
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             CONCOV (1:INDEX(CONCOV,' ')-1)
C
C8B---Create Coverage CONCOV
C
      ARCCMD='create'
      WRITE(IOUT(4),'(A,1X,A)') 
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             CONCOV (1:INDEX(CONCOV,' ')-1)
C
C8C---Generate Coverage CONCOV (arcs only)
C
      ARCCMD='generate'
      INPFIL=FILES(3) (1:INDEX(FILES(3),' ')-1)
      COVTYP='lines'
      WRITE(IOUT(4),'(A,3(1X,A))') 
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             CONCOV (1:INDEX(CONCOV,' ')-1),
     &                             INPFIL (1:INDEX(INPFIL,' ')-1),
     &                             COVTYP (1:INDEX(COVTYP,' ')-1)
C
C8D----Build Coverage CONCOV
C
      ARCCMD='build'
      COVTYP='lines'
      WRITE(IOUT(4),'(A,2(1X,A))') 
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             CONCOV (1:INDEX(CONCOV,' ')-1),
     &                             COVTYP (1:INDEX(COVTYP,' ')-1)
C
C8E----Create attribute files and "add from" attributes
C
      ARCCMD='tables'
      TMPFIL=FILES(1) (1:INDEX(FILES(1),' ')-1)
      ADDFIL=FILES(2) (1:INDEX(FILES(2),' ')-1)
      WRITE(IOUT(4),'(A,2(1X,A))') 
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             TMPFIL (1:INDEX(TMPFIL,' ')-1),
     &                             ADDFIL (1:INDEX(ADDFIL,' ')-1)
C
C8F---Join attribute file label to Coverage XSCOV PAT file
C
      ARCCMD='joinitem'
      LABFIL=CONCOV (1:INDEX(CONCOV,' ')-1)//'.AAT'
      INPFIL=FILES(2) (1:INDEX(FILES(2),' ')-1)
      RELITM='$recno'
      STRITM=CONCOV (1:INDEX(CONCOV,' ')-1)//'-id'
      JONTYP='link'      
      WRITE(IOUT(4),'(A,6(1X,A))') 
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             LABFIL (1:INDEX(LABFIL,' ')-1),
     &                             INPFIL (1:INDEX(INPFIL,' ')-1),
     &                             LABFIL (1:INDEX(LABFIL,' ')-1),
     &                             RELITM (1:INDEX(RELITM,' ')-1),
     &                             STRITM (1:INDEX(STRITM,' ')-1),
     &                             JONTYP (1:INDEX(JONTYP,' ')-1)
      CALL CLOSE_FILE (FILES(4),*9999)
       GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9999 WRITE(*,
     &    '(//,'' Abnormal termination of Pthcon_Subroutine'')')
      WRITE(OUTUNT,
     &    '(//,'' Abnormal termination of Pthcon_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
      SUBROUTINE POINTS (
     I                   NX,NY,Z,CL,IBRMAP,XC,YC,IOUT,IXF,IXL,IYF,IYL,
     I                   MAXPMR,COVPMR,
     I                   AATUNT,ARCUNT)
C    *******************************************************************
C     THIS SUBROUTINE WILL CAUSE ONE CONTOUR LEVEL TO BE PLOTTED.
C     IT WILL GENERATE AS MANY CURVES AS REQUIRED FOR THAT LEVEL.
C     IT SCANS ALL NODES LOOKING FOR PLACES TO START A CURVE.  WHEN
C     A START IS FOUND, "FOLLOW" IS CALLED TO DRAW THE CURVE.  AFTER
C     "FOLLOW" COMPLETES, SCANNING CONTINUES -- ALL CPOSSIBLE CURVES
C     FOR THIS CONTOUR LEVEL WILL HAVE BEEN FOUND BY THE TIME ALL
C     NODES ARE SCANNED.
C
C         Modified to output contour coordinates into an Arc/Info
C          generate format for lines; output contour attributes which
C          later attached to the coverage AAT file; and output Arc/Info
C          instructions into a file called arccmd.  This file contains
C          commands for Arc/Info software to processing the contour 
C          coordinate file into a built arc coverage using the plot title
C          as the coverage name.
C                                         by Leonard L. Orzol 04/12/93
C         
C    *******************************************************************
      INTEGER IBRMAP, IOUT
      INTEGER AATUNT,ARCUNT
      DIMENSION Z(NX,NY),COVPMR(MAXPMR)
      DIMENSION IBRMAP(NX,NY),XC(NX),YC(NY),IOUT(NX,NY)
C
C-----INITIALIZE IBRMAP FOR EACH LEVEL-- THIS INDICATES WHICH BRANCHES
C-----SHOULDN'T BE DRAWN TO -- EITHER BECAUSE THE USER WANTS THEM BLANKED
C-----OUT OR BECAUSE A CONTOUR HAS ALREADY GONE THROUGH.
      DO 5 I=IXF,IXL
      DO 5 J=IYF,IYL
      IBRMAP(I,J) = IOUT(I,J)
      IBRMAP(I,J) = IOUT(I,J)
5     CONTINUE
      NC=0
C
C-----THIS LOOP FINDS STARTING POINTS
      DO 20 J=IYF,IYL-1
      DO 20 I=IXF,IXL-1
C
C-----CHECK IF A POINT IS ON THE HORIZONTAL BRANCH BETWEEN NODE
C-----I,J AND NODE I+1,J.
      IF (   CL  .LT.   Z(I,J)     .AND.  CL   .LT.   Z(I+1,J)  .OR.
     +       CL  .GT.   Z(I,J)     .AND.  CL   .GT.   Z(I+1,J)) GO TO 10
C
C-----POINT IS ON HORIZONTAL BRANCH
      IBRN=1
C
C-----IF POINT HAS BEEN PLOTTED - SKIP IT
      IRIGHT=IBRMAP(I,J)-IBRMAP(I,J)/2*2
      IF(IRIGHT.NE.0) GO TO 10
C
C-----DRAW THE CURVE
      CALL FOLLOW(NX,NY,Z,IBRMAP,XC,YC,I,J,IBRN,CL,IXF,IXL,IYF,IYL,
     I            MAXPMR,COVPMR,
     I            AATUNT,ARCUNT)
      NC=NC+1
C
C-----CURVE FOR THIS POINT COMPLETED - CONTINUE SCANNING
C
C-----CHECK IF A POINT IS ON THE VERTICAL BRANCH BETWEEN NODE
C-----I,J AND NODE I,J+1.
   10 IF (  CL   .LT.   Z(I,J)   .AND.    CL   .LT.   Z(I,J+1)  .OR.
     +      CL   .GT.   Z(I,J)   .AND.    CL   .GT.   Z(I,J+1)) GO TO 20
C
C-----POINT IS ON VERTICAL BRANCH
      IBRN=2
      IUP=IBRMAP(I,J)/2
      IF(IUP.NE.0) GO TO 20
      CALL FOLLOW(NX,NY,Z,IBRMAP,XC,YC,I,J,IBRN,CL,IXF,IXL,IYF,IYL,
     I            MAXPMR,COVPMR,
     I            AATUNT,ARCUNT)
      NC=NC+1
C
   20 CONTINUE
      RETURN
      END
      SUBROUTINE FOLLOW(NX,NY,Z,IBRMAP,XC,YC,L,M,IBRN,CL,IXF,IXL,
     1                  IYF,IYL,
     I                  MAXPMR,COVPMR,
     I                  AATUNT,ARCUNT)

C    *******************************************************************
C    This subroutine draws curves by connecting points on branches.  The
C    curve is constructed much as one might draw contours by hand.  To
C    continue the contour from a current branch, the surrounding
C    branches in the same general direction are scanned for the same
C    contour value.  If found, the contour is drawn to the new
C    branch.  Contours are not allowed to double back within the same
C    block of 4 branches because this is physically impossible and
C    would result in discontinuities in the contours.  Also, to avoid
C    the potential for 2 lines representing the same contour value
C    from crossing if it were to happen that all 4 branches of a
C    rectangle include the contour value, the 2 side branches in the
C    direction of the contour path are given drawing precedence over
C    the opposite branch.
C
C    Once a contour has been drawn to a given branch, there are
C    only 3 surrounding branches that the contour might continue to.
C    These 3 branches depend on the current direction of the contour
C    and the orientation of the current branch -- i.e either
C    horizonatl or vertical.  Based on which branch the curve has
C    come to and the direction that the curve is going, the order in
C    which surrounding branches are scanned to try to continue the
C    contour is shown below.  Note that when moving from the first
C    branch of a contour, it is necessary to scan all 6 directions
C    for the next branch because the direction has not been
C    established.
C
C                   CURRENT BRANCH IS HORIZONTAL (IBRN=1)
C    CONTOUR DIRECTION IS UP (IDIR=1)    CONTOUR DIRECTION IS DOWN (IDIR=-1)
C
C           ---3---
C          !       !
C          1       2
C          !       !
C          *---X---                                 *---X---
C                                                   !       !
C                                                   2       1
C                                                   !       !
C                                                    ---3---
C
C
C                          CURRENT BRANCH IS VERTICAL (IBRN=2)
C  CONTOUR DIRECTION IS LEFT (IDIR=-1)    CONTOUR DIRECTION IS RIGHT (IDIR=1)
C
C         ---2---                                    ---2---
C        !       !                                  !       !
C        3       X                                  X       3
C        !       !                                  !       !
C         ---1---*                                  *---1---
C
C         Modified to output contour coordinates into an Arc/Info
C          generate format for lines; output contour attributes which
C          later attached to the coverage AAT file; and output Arc/Info
C          instructions into a file called arccmd.  This file contains
C          commands for Arc/Info software to processing the contour 
C          coordinate file into a built arc coverage using the plot title
C          as the coverage name.
C                                         by Leonard L. Orzol 04/12/93
C         
C    *******************************************************************
      PARAMETER (MAXSEG=5000)
      INTEGER IBRMAP
      INTEGER AATUNT,ARCUNT
      DIMENSION XC(NX),YC(NY),IBRMAP(NX,NY),Z(NX,NY),COVPMR(MAXPMR)
      DIMENSION XPLT(0:MAXSEG), YPLT(0:MAXSEG)
      CHARACTER*20 LABEL
C
C-----LABEL CONTOURS EVERY MAXSEG POINTS.  XPLT AND YPLT MUST BE DIMENSIONED
C-----FROM 0 TO MAXSEG.  THE ZERO ELEMENT HOLDS THE START POINT.
      CONTUR=CL
      IBRNBG=IBRN
      IDIR=0
C
C-----FIND COORDINATES OF STARTING POINT AND MARK BRANCH AS OCCUPIED
      CALL COORDS (NX,NY,Z,XC,YC,L,M,IBRN,CL,XBG,YBG)
      IBRMAP(L,M)=IBRMAP(L,M)+IBRN
C
C-----LABEL THE START OF THE CONTOUR
C      CALL NUMCNV(CL,1,LABEL,NC)
C      CALL PLTSTR(XBG+.01,YBG+.01,.14,LABEL,NC)
C
C-----ENTER HERE TO GO BACK TO THE START OF THE CURVE AND TRY CONTINUING
C-----THE CURVE IN THE OTHER DIRECTION
1     I=L
      J=M
      XPLT(0)=XBG
      YPLT(0)=YBG
      NUMSEG=0
C
C-----ENTER HERE TO CONTINUE DRAWING AFTER THE START POINT AND AS LONG
C-----AS MORE POINTS CAN BE FOUND.
5     IF(IBRN.EQ.2) GO TO 50
C
C     CONTINUE FOR A POINT ON A HORIZONTAL BRANCH
C     GO TO 50 FOR A POINT ON A VERTICAL BRANCH
C
C
      IF(IDIR.GT.0) GO TO 25
      IF(J.EQ.IYF) GO TO 24
C
C-----SEARCH FOR A POINT ON THE 1ST OF 3 POSSIBLE BRANCHES GOING DOWN
      IF (  CL  .LT.   Z(I+1,J)  .AND.  CL  .LT.   Z(I+1,J-1)   .OR.
     +      CL  .GT.   Z(I+1,J)  .AND.  CL  .GT.   Z(I+1,J-1) ) GO TO 15
C-----THERE IS A POINT, SO SET PARAMETERS FOR THAT BRANCH
      IBRNNX=2
      INX=I+1
      JNX=J-1
      IDIRNX=1
      IDIRRV=1
C-----TEST TO SEE IF THE BRANCH ALREADY HAS A CONTOUR GOING THROUGH IT
C-----IF NOT, GO AND DRAW THE BRANCH TO THE POINT
      IF(IBRMAP(INX,JNX)/2 .EQ.0) GO TO 100
C-----IF THE BRANCH IS OCCUPIED ALREADY, THAT MIGHT MEAN THAT YOU'VE
C-----RETURNED NEAR TO THE START POINT AND NEED TO CLOSE THE CURVE.
C-----IF NOT THE 1ST BRANCH AND YOU'RE NEXT TO THE START POINT(L,M), GO
C-----AND CLOSE.  OTHERWISE CONTINUE LOOKING FOR A VALID BRANCH
C-----NEARBY.
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   15 IF (  CL  .LT.   Z(I,J-1)  .AND.  CL  .LT.   Z(I,J)       .OR.
     +      CL  .GT.   Z(I,J-1)  .AND.  CL  .GT.   Z(I,J)  ) GO TO 20
      IBRNNX=2
      INX=I
      JNX=J-1
      IDIRNX=-1
      IDIRRV=1
      IF(IBRMAP(INX,JNX)/2 .EQ.0) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   20 IF (  CL  .LT.   Z(I,J-1)  .AND.  CL  .LT.   Z(I+1,J-1)   .OR.
     +      CL  .GT.   Z(I,J-1)  .AND.  CL  .GT.   Z(I+1,J-1))  GO TO 24
      IBRNNX=1
      INX=I
      JNX=J-1
      IDIRNX=-1
      IDIRRV=1
      IF((IBRMAP(INX,JNX)-IBRMAP(INX,JNX)/2*2) .EQ. 0 ) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
24    IF(IDIR.NE.0) GO TO 80
25    IF(J.EQ.IYL) GO TO 80
C
C-----SEARCH UPWARD FROM HORIZONTAL BRANCH
      IF (  CL  .LT.   Z(I,J)    .AND.  CL  .LT.   Z(I,J+1)     .OR.
     +      CL  .GT.   Z(I,J)    .AND.  CL  .GT.   Z(I,J+1) ) GO TO 30
      IBRNNX=2
      INX=I
      JNX=J
      IDIRNX=-1
      IDIRRV=-1
      IF(IBRMAP(INX,JNX)/2 .EQ.0) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   30 IF (  CL  .LT.   Z(I+1,J)  .AND.  CL  .LT.   Z(I+1,J+1)   .OR.
     +      CL  .GT.   Z(I+1,J)  .AND.  CL  .GT.   Z(I+1,J+1) ) GO TO 35
      IBRNNX=2
      INX=I+1
      JNX=J
      IDIRNX=1
      IDIRRV=-1
      IF(IBRMAP(I+1,J)/2 .EQ.0) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   35 IF (  CL  .LT.   Z(I,J+1)  .AND.  CL  .LT.   Z(I+1,J+1)   .OR.
     +      CL  .GT.   Z(I,J+1)  .AND.  CL  .GT.   Z(I+1,J+1)) GO TO 80
      IBRNNX=1
      INX=I
      JNX=J+1
      IDIRNX=1
      IDIRRV=-1
      IF((IBRMAP(INX,JNX)-IBRMAP(INX,JNX)/2*2) .EQ. 0 ) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
C-----ALL POSSIBLE BRANCHES HAVE BEEN CHECKED WITHOUT FINDING ANY PATH.
C-----SO THE CURVE HAS DEAD-ENDED.
C-----GO BACK TO START OF THE CURVE AND TRY TO CONTINUE FROM THERE
      GO TO 80
C
C-----VERTICAL BRANCH
   50 IF(IDIR.GT.0) GO TO 65
      IF (I.EQ.IXF) GO TO 64
C
C-----SEARCH LEFT FROM A VERTICAL BRANCH
      IF (  CL  .LT.   Z(I-1,J)  .AND.  CL  .LT.   Z(I,J)       .OR.
     +      CL  .GT.   Z(I-1,J)  .AND.  CL  .GT.   Z(I,J)   ) GO TO 55
      IBRNNX=1
      INX=I-1
      JNX=J
      IDIRNX=-1
      IDIRRV=1
      IF((IBRMAP(INX,JNX)-IBRMAP(INX,JNX)/2*2) .EQ. 0 ) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   55 IF (  CL  .LT.   Z(I-1,J+1).AND.  CL  .LT.   Z(I,J+1)     .OR.
     +      CL  .GT.   Z(I-1,J+1).AND.  CL  .GT.   Z(I,J+1) ) GO TO 60
      IBRNNX=1
      INX=I-1
      JNX=J+1
      IDIRNX=1
      IDIRRV=1
      IF((IBRMAP(INX,JNX)-IBRMAP(INX,JNX)/2*2) .EQ. 0 ) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   60 IF (  CL  .LT.   Z(I-1,J)  .AND.  CL  .LT.   Z(I-1,J+1)   .OR.
     +      CL  .GT.   Z(I-1,J)  .AND.  CL  .GT.   Z(I-1,J+1) ) GO TO 64
      IBRNNX=2
      INX=I-1
      JNX=J
      IDIRNX=-1
      IDIRRV=1
      IF(IBRMAP(INX,JNX)/2*2 .EQ. 0 ) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   64 IF(IDIR.NE.0) GO TO 80
   65 IF(I.EQ.IXL) GO TO 80
C
C-----SEARCH RIGHT FROM A VERTICAL BRANCH
      IF (  CL  .LT.   Z(I,J)    .AND.  CL  .LT.   Z(I+1,J)     .OR.
     +      CL  .GT.   Z(I,J)    .AND.  CL  .GT.   Z(I+1,J)  ) GO TO 70
      IBRNNX=1
      INX=I
      JNX=J
      IDIRNX=-1
      IDIRRV=-1
      IF((IBRMAP(INX,JNX)-IBRMAP(INX,JNX)/2*2) .EQ. 0 ) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   70 IF (  CL  .LT.   Z(I,J+1)  .AND.  CL  .LT.   Z(I+1,J+1)   .OR.
     +      CL  .GT.   Z(I,J+1)  .AND.  CL  .GT.   Z(I+1,J+1) ) GO TO 75
      IBRNNX=1
      INX=I
      JNX=J+1
      IDIRNX=1
      IDIRRV=-1
      IF((IBRMAP(INX,JNX)-IBRMAP(INX,JNX)/2*2) .EQ. 0 ) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
   75 IF (  CL  .LT.   Z(I+1,J)  .AND.  CL  .LT.   Z(I+1,J+1)   .OR.
     +      CL  .GT.   Z(I+1,J)  .AND.  CL  .GT.   Z(I+1,J+1)) GO TO 80
      IBRNNX=2
      INX=I+1
      JNX=J
      IDIRNX=1
      IDIRRV=-1
      IF(IBRMAP(INX,JNX)/2*2 .EQ. 0 ) GO TO 100
      IF(INX.EQ.L.AND.JNX.EQ.M .AND. IBRNNX.EQ.IBRNBG) GO TO 90
C
C-----HAVE NOT BEEN ABLE TO FIND ANY PLACE TO GO FROM HERE
C-----CURVE HAS DEAD-ENDED -- GO BACK TO THE START OF IT AND TRY TO
C-----CONTINUE FROM THERE IN A NEW DIRECTION UNLESS THIS HAS ALREADY BEEN
C-----TRIED BEFORE
80    N=MOD(NUMSEG,MAXSEG)
      IF(N.GT.0) CALL PLTLIN (CONTUR,XPLT,YPLT,N+1,
     I                        MAXPMR,COVPMR,
     I                        AATUNT,ARCUNT)
      IF(NUMSEG.EQ.0) RETURN
      IBRN=IBRNBG
      IDIR=IDIRBG
      GO TO 1
C
C-----CLOSE THE CURVE
90    N=MOD(NUMSEG,MAXSEG)+1
      NUMSEG=NUMSEG+1
      XPLT(N)=XBG
      YPLT(N)=YBG
      CALL PLTLIN (CONTUR,XPLT,YPLT,N+1,
     I             MAXPMR,COVPMR,
     I             AATUNT,ARCUNT)
      RETURN
C
C-----PLOT A FOUND BRANCH
  100 CALL COORDS (NX,NY,Z,XC,YC,INX,JNX,IBRNNX,CL,XNX,YNX )
      N=MOD(NUMSEG,MAXSEG)+1
      NUMSEG=NUMSEG+1
      XPLT(N)=XNX
      YPLT(N)=YNX
      IF(N.NE.MAXSEG) GO TO 110
      CALL PLTLIN (CONTUR,XPLT,YPLT,MAXSEG+1,
     I             MAXPMR,COVPMR,
     I             AATUNT,ARCUNT)
C      CALL NUMCNV(CL,1,LABEL,NC)
C      CALL PLTSTR(XNX+.01,YNX+.01,.14,LABEL,NC)
      XPLT(0)=XNX
      YPLT(0)=YNX
C-----NOW SET THE BRANCH-OCCUPIED FLAG SO THAT A 2ND CONTOUR CAN'T
C-----GO TO THIS POINT
 110  IBRMAP(INX,JNX)=IBRMAP(INX,JNX)+IBRNNX
C-----ADVANCE POINTERS TO THE NEXT POINT
      I=INX
      J=JNX
      IF(NUMSEG.EQ.1) IDIRBG=IDIRRV
      IDIR=IDIRNX
      IBRN=IBRNNX
C
C-----GET NEXT POINT ON CURVE
      GO TO 5
      END
      SUBROUTINE COORDS (NX,NY,Z,XC,YC,I,J,IBRN,CL,XP,YP)
C    *******************************************************************
C    THIS SUBROUTINE FINDS THE COORDINATES OF A CONTOUR POINT ON A BRANCH.
C    LINEAR INTERPOLATION BETWEEN THE 2 NODES IS USED.
C    *******************************************************************
      DIMENSION Z(NX,NY)
      DIMENSION  XC(NX) , YC(NY)
C
      IF ( IBRN.EQ.2 ) GO TO 20
C
C-----HORIZONTAL BRANCH
   10 I2=I+1
      J2=J
      B=ABS(XC(I2)-XC(I))
      GO TO 30
C
C-----VERTICAL BRANCH
   20 I2=I
      J2=J+1
      B=ABS(YC(J2)-YC(J))
C
   30 A=ABS(CL-Z(I,J))
      C=ABS (Z(I2,J2)-Z(I,J))
      X=A*B/C
C
C
      IF ( IBRN.EQ.2 ) GO TO 50
C
C-----HORIZONTAL BRANCH
   40 XP=(XC(I)+X)
      YP=YC(J)
      RETURN
C
C-----VERTICAL BRANCH
   50 YP=(YC(J)+X)
      XP=XC(I)
      RETURN
      END
      SUBROUTINE PLTLIN (
     I                   CONTUR,
     I                   XCOORDS,YCOORDS,
     I                   NCOORD,
     I                   MAXPMR,COVPMR,
     I                   AATUNT,ARCUNT)
C-----------------------------------------------------------------------
C
C---VERSION 4.0 PLTLIN 13OCTOBER1999
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Writes contour attributes to files.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C
C    Inputs:
C
C     ARCUNT  : FORTRAN UNIT FOR ARC COORDINATE FILE
C     CONTUR  : VALUE OF CONTOUR ARC
C     NCOORD  : NUMBER OF COORDINATES IN EACH ARC
C     XCOORDS : ARRAY FOR X-COORDINATES (NCOORD)
C     YCOORDS : ARRAY FOR Y-COORDINATES (NCOORD)
C
C     Program: None
C
C
C .. History:
C
C      Leonard L. Orzol      04/21/92      Original Coding.
C                                          USGS WRD Portland, Or
C                                          503-251-3270
C                            04/12/93      Version 4.0
C      Leonard L. Orzol      05/16/94      Upgrade for version 5.0
C
C-------------------------------------------------------------------------
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C::::::::::::::::::::::::  GLOBAL_VARIABLES  :::::::::::::::::::::::::::::::::
C
      DIMENSION 
     1          COVPMR(MAXPMR),
     1          XCOORDS(NCOORD),
     1          YCOORDS(NCOORD)
C
      REAL 
     &     XCOORD,
     &     YCOORD
C
      INTEGER AATUNT,ARCUNT,ICONTUR
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  :::::::::::::::::::::::::::::::::
C
C
C     ------------------------------------------------------------------
C
C1----Set local variables
C
      XYSCALE=COVPMR(3)
      ZSCALE=COVPMR(4)
      ANGLE=COVPMR(5)
      XOGRID=COVPMR(6)
      YOGRID=COVPMR(7)
      IF(COVPMR(9).LE.0.0) COVPMR(9)=1.0
      HSCALE=12.0/COVPMR(9)
      IF(COVPMR(8).LE.0.0) COVPMR(8)=1.0
      VSCALE=HSCALE*COVPMR(8)
      IVIEW=INT(COVPMR(10))
      IRWCL=INT(COVPMR(11))
      ZSTEP=COVPMR(13)
C
C2----Write out arc attribute to file
C
      WRITE(AATUNT,'(F8.2,'','')')
     &                                 CONTUR
C
C3----Write out arc coordinates of particles to ARC file
C
      ICONTUR=INT(CONTUR)
C
C3A----Write out arc identifier to ARC file
C
      WRITE(ARCUNT,'(I10)') ICONTUR
C
C3B---Write out arc coordinates of particles to ARC file
C
      DO 300 I=1,NCOORD
         XCOORD=XCOORDS(I)*XYSCALE
       IF(IVIEW.LE.0 .OR. IVIEW.GE.4) THEN
          YCOORD=-YCOORDS(I)*XYSCALE
        IF(ANGLE.NE.0.0) THEN
           CALL ROTATE (
     I                  ANGLE,
     B                  XCOORD,YCOORD)
        ENDIF
         XCOORD=XCOORD+XOGRID
         YCOORD=YCOORD+YOGRID
      ELSE IF(IVIEW.EQ.1) THEN
         YCOORD=YCOORDS(I)
      ELSE IF(IVIEW.EQ.2) THEN
         YCOORD=YCOORDS(I)
      ELSE
         YCOORD=YCOORDS(I)
      ENDIF
         WRITE(ARCUNT,'(F20.10,'','',F20.10)')
     &                                             XCOORD,
     &                                             YCOORD
  300 CONTINUE
      WRITE(ARCUNT,'(''END'')')
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
