C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                Fileult version 2.0                 *************
C******************************************************************************
C**          Language: AML ARC Macro Language and Fortran 77                 **
C**          Program must be recompiled then bind with Arc50 libraries       **
C**             Primos
C**             Sun3, Sun4
C**             DG computers not yet
C**           The source code is available from below:
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol    89-90   USGS-WRD Portland OR  Version 2.0 Coding
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Purpose: Although this program has been used by the U.S. Geological Survey,
C*           no warranty, expressed or implied, is made by the USGS as to the
C*           accuracy and functioning of the program and related program
C*           material nor shall the fact of distribution constitute any such
C*           warranty, and no responsibility is assumed by the USGS in
C*           connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C<><><><><><><><><><><><><> FILE UTILITY SUBROUTINES <><><><><><><><><><><><>C
C
C---VERSION 2.0
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     A set of subroutines that handle opening; deleting; or closing files.
C
C    Subroutines:
C
C     OPEN_FILE     : Opens a file or checks file status for either direct
C                      or sequential access, formatted or unformatted,
C                      and old or new.
C     CLOSE_FILE    : Closes a file.
C     DELETE_FILE   : Closes and deletes a file.
C
C    Secondary Subroutines:
C
C     NONE          : 
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN, with ARC/INFO subroutine call version 5.01
C
C .. History:
C
C      Leonard L. Orzol      1989-98       Original Coding.
C                                          USGS WRD Portland, Or
C                                          Fts: 429-2256
C
C-------------------------------------------------------------------------
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
      SUBROUTINE OPEN_FILE (IU,FNAME,NSTAT,ITALK,*)
C-----------------------------------------------------------------------
C
C---VERSION 3.0 09JUNE1998 OPEN_FILE
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C  This routine either opens, creates, or inquires files.  The user can
C   specified the function of open_file as described below.
C
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: Fortran77
C
C
C    Inputs:
C
C  IU    = FORTRAN UNIT NUMBER OF FILE 
C          < 0 => UNFORMATTED FILE
C            0 => RETURN FORMAT STATUS (WHEN NSTAT=0 ONLY)
C          > 0 => FORMATTED FILE
C  FNAME = FILE NAME
C  NSTAT = STATUS OF FILE
C          DIRECT ACCESS ONLY
C           -4 => UNDETERMINED STATUS (MAY OR MAY NOT EXIST)
C                  IF IT DOES NOT EXIST, IT IS CREATED BY OPEN STATEMENT
C                  IF IT DOES EXIST, IT IS OPENED AS 'OLD' FILE
C           -3 => SCRATCH FILE (DELETED AUTOMATICALLY WHEN RUN ENDS)
C           -2 => NEW FILE
C           -1 => OLD FILE
C          FILE STATUS
C            0 => RETURN FILE STATUS FOR OPEN, FORMAT, FILE ACCESS
C          SEQUENTIAL ACCESS ONLY
C            1 => OLD FILE
C            2 => NEW FILE
C            3 => SCRATCH FILE (DELETED AUTOMATICALLY WHEN RUN ENDS)
C            4 => UNDETERMINED STATUS (MAY OR MAY NOT EXIST)
C                  IF IT DOES NOT EXIST, IT IS CREATED BY OPEN STATEMENT
C                  IF IT DOES EXIST, IT IS OPENED AS 'OLD' FILE
C
C  ITALK = FLAG INDICATING IF THERE IS INTERACTIVE DIALOGUE AT
C           TERMINAL
C
C           0 => THERE IS INTERACTIVE DIALOGUE
C           1 => THERE IS NOT INTERACTIVE DIALOGUE (BATCH MODE)
C
C    Outputs: WHEN INPUT 
C                    NSTAT => 0
C                    IU    => 0
C
C  IU    = FORMAT STATUS
C         99 => FORMATTED FILE
C          0 => UNDETERMINED STATUS
C        -99 => UNFORMATTED FILE
C       -999 => FILES DOES NOT EXIST
C  NSTAT = ACCESS STATUS OF FILE
C         99 => SEQUENTIAL ACCESS
C          0 => UNDETERMINED STATUS
C        -99 => DIRECT ACCESS
C       -999 => FILE DOES NOT EXIST
C  ITALK = OPEN STATUS OF FILE
C          99 => FILE IS OPEN
C         -99 => FILE IS CLOSED
C        -999 => FILE DOES NOT EXIST
C
C .. History:
C
C      Dave Pollack?        ??/??/??      Original Concept.
C               U.S. Geological Survey, Reston, Virginia
C
C      Leonard L. Orzol      03/13/90     Original Coding.
C                            12/18/90     Modified for Prime,Suns or DisII
C               U.S. Geological Survey, Portland, Oregon  Fts: 429-2256
C
C-------------------------------------------------------------------------
C
      CHARACTER*(*) FNAME
      CHARACTER*80 ACCSS,DRECT,FMT,SEQUENT,UNFMT
      INTEGER NSTAT,IU,ITALK,IERR
      LOGICAL*4 EXISTS,OPN
C************************************************************************C
C
C----Inquire on file
C
    2 INQUIRE (
     F         FILE=FNAME,
     I         IOSTAT=IERR,
     L         ERR=7777,
     E         EXIST=EXISTS,
     S         OPENED=OPN,
     T         ACCESS=ACCSS,
     A         SEQUENTIAL=SEQUENT,
     T         DIRECT=DRECT,
     U         FORMATTED=FMT,
     S         UNFORMATTED=UNFMT
     &         )
C
C0-----Return file parameters
C
      IF(NSTAT.EQ.0) THEN
C
C0A-----File existence status
C
       IF(EXISTS) THEN
          NSTAT=0
          IU=0
          ITALK=0
       ELSE
          NSTAT=-999
          IU=-999
          ITALK=-999
          RETURN
       ENDIF
C
C0B-----File open status
C
       IF(OPN) THEN
          ITALK=99
       ELSE
          ITALK=-99
       ENDIF
C
C0C-----File access status
C
       IF(SEQUENT.EQ.'YES') THEN
          NSTAT=99
       ELSE IF(SEQUENT.EQ.'NO') THEN
        IF(DRECT.EQ.'YES')  THEN
           NSTAT=-99
        ELSE
           NSTAT=0
        ENDIF
       ELSE
        IF(DRECT.EQ.'YES')  THEN
           NSTAT=-99
        ELSE
           NSTAT=0
        ENDIF
       ENDIF
C
C0C-----File record format status
C
       IF(FMT.EQ.'YES' .AND. UNFMT.EQ.'NO') THEN
          IU=99
       ELSE IF(FMT.EQ.'NO') THEN
        IF(UNFMT.EQ.'YES') THEN
           IU=-99
        ELSE
           IU=0
        ENDIF
       ELSE
        IF(UNFMT.EQ.'YES' .AND. FMT.EQ.'NO') THEN
           IU=-99
        ELSE
           IU=0
        ENDIF
       ENDIF
C
C0D-----Return file parameters
C
         RETURN
C
C1---OPEN AN EXISTING FILE
C
      ELSE IF(NSTAT.EQ.1 .OR. NSTAT.EQ.-1) THEN
C
C1A-----File open status
C
       IF(OPN) THEN
          GO TO 6666
C
C1B-----File exist status
C
       ELSE
        IF(.NOT.EXISTS) THEN
         IF(ITALK.GT.0) THEN
  104       WRITE(*,'(//,'' File does not exists '',A)')
     &             FNAME (1:INDEX(FNAME,' ')-1)
            WRITE(*,'(/,
     &           '' Enter the name of an existing file (<Cr>=Quit):'')')
            READ (*,'(A)',ERR=104) FNAME
          IF(FNAME.EQ.' ' .OR. FNAME.EQ.'') GO TO 9999
            GO TO 2
         ELSE
            WRITE(*,'(//,'' File does not exists '',A)')
     &             FNAME (1:INDEX(FNAME,' ')-1)
            GO TO 9999
         ENDIF
        ENDIF
       ENDIF
C
C1C-----File access status
C
C
C1CA-----Sequential access
C
       IF(SEQUENT.EQ.'YES') THEN
          ACCSS='SEQUENTIAL'
        IF(NSTAT.LT.0) THEN
           WRITE(*,'(/,'' File is direct access not sequential'')')
           NSTAT=-99
           GO TO 9999
        ENDIF
C
C1CB-----Direct access
C
       ELSE
        IF(DRECT.EQ.'YES') THEN
           ACCSS='DIRECT'
         IF(NSTAT.GT.0) THEN
            WRITE(*,'(/,'' File is sequential access not direct'')')
            NSTAT=99
            GO TO 9999
         ENDIF
        ELSE
           ACCSS='SEQUENTIAL'
           SEQUENT='YES'
           DRECT='NO'
        ENDIF
       ENDIF
C
C1D-----File format status
C
       IF(IU.LT.0) THEN
         IF(FMT.EQ.'YES' .AND. UNFMT.EQ.'NO') THEN
            WRITE(*,'(/,'' File is formatted not unformatted'')')
            IU=99
            GO TO 9999
         ENDIF
          FMT='UNFORMATTED'
          IU=-IU
       ELSE
         IF(UNFMT.EQ.'YES' .AND. FMT.EQ.'NO') THEN
            WRITE(*,'(/,'' File is unformatted not formatted'')')
            IU=-99
            GO TO 9999
         ENDIF
          FMT='FORMATTED'
       ENDIF
C
C1E-----Open file 
C
          OPEN (
     F          UNIT=IU,
     I          FILE=FNAME,
     L          STATUS='OLD',
     E          ACCESS=ACCSS,
     O          FORM=FMT,
     P          IOSTAT=IERR,
     E          ERR=8888
     N         )
          RETURN
C
C2-----Open An New File
C
      ELSE IF(NSTAT.EQ.2 .OR. NSTAT.EQ.-2) THEN
C
C2A-----File exists already
C
       IF(EXISTS) THEN
        IF(ITALK.GT.0) THEN
  202      WRITE(*,'(//,'' Already Exists '',A)')
     &            FNAME (1:INDEX(FNAME,' ')-1)
           WRITE(*,'(/,
     &           '' Enter the name of an new file (<Cr>=Quit):'')')
           READ (*,'(A)',ERR=202) FNAME
         IF(FNAME.EQ.' ') GO TO 9999
           GO TO 2
        ELSE
           WRITE(*,'(//,'' Already Exists '',A)')
     &                 FNAME (1:INDEX(FNAME,' ')-1)
           GO TO 9999
        ENDIF
C
C2B-----File access status
C
       ELSE
C
C2BA-----Sequential access
C
        IF(NSTAT.GT.0) THEN
           ACCSS='SEQUENTIAL'
C
C2BB-----Direct access
C
        ELSE
           ACCSS='DIRECT'
        ENDIF
C
C2C-----File format status
C
        IF(IU.LT.0) THEN
           FMT='UNFORMATTED'
           IU=-IU
        ELSE
           FMT='FORMATTED'
        ENDIF
       ENDIF
C
C2D-----Open file 
C
          OPEN (
     F          UNIT=IU,
     I          FILE=FNAME,
     L          STATUS='NEW',
     E          ACCESS=ACCSS,
     O          FORM=FMT,
     P          IOSTAT=IERR,
     E          ERR=8888
     N         )
         RETURN
C
C3-----Open An Scratch File
C
      ELSE IF(NSTAT.EQ.3 .OR. NSTAT.EQ.-3) THEN
C
C3A-----File exists already
C
       IF(EXISTS) THEN
        IF(ITALK.GT.0) THEN
  302      WRITE(*,'(//,'' Already Exists '',A)')
     &            FNAME (1:INDEX(FNAME,' ')-1)
           WRITE(*,'(/,
     &           '' Enter the name of an scratch file (<Cr>=Quit):'')')
           READ (*,'(A)',ERR=302) FNAME
        IF(FNAME.EQ.' ') GO TO 9999
           GO TO 2
        ENDIF
C
C3B-----File access status
C
       ELSE
C
C3BA-----Sequential access
C
        IF(NSTAT.GT.0) THEN
           ACCSS='SEQUENTIAL'
C
C3BB-----Direct access
C
        ELSE
           ACCSS='DIRECT'
        ENDIF
C
C3C-----File format status
C
        IF(IU.LT.0) THEN
           FMT='UNFORMATTED'
           IU=-IU
        ELSE
           FMT='FORMATTED'
        ENDIF
       ENDIF
C
C3D-----Open file 
C
          OPEN (
     F          UNIT=IU,
     L          STATUS='SCRATCH',
     E          ACCESS=ACCSS,
     O          FORM=FMT,
     P          IOSTAT=IERR,
     E          ERR=8888
     N         )
         RETURN
C
C4-----Open An Unknown Status File
C
      ELSE IF(NSTAT.EQ.4 .OR. NSTAT.EQ.-4) THEN
C
C4A-----File exists
C
       IF(EXISTS) THEN
C
C4AA-----Already open
C
        IF(OPN) THEN
           ITALK=99
C
C4AAA-----File sequential access
C
         IF(NSTAT.GT.0) THEN
            NSTAT=99
          IF(ACCSS.EQ.'DIRECT') THEN
             WRITE(*,'(/,'' File is direct access not sequential'')')
             NSTAT=-99
          ENDIF
C
C4AAB-----File direct access
C
         ELSE
            NSTAT=-99
          IF(ACCSS.EQ.'SEQUENTIAL') THEN
             NSTAT=99
             WRITE(*,'(/,'' File is sequential access not direct'')')
          ENDIF
         ENDIF
C
C4AAC-----File format status
C
         IF(IU.LT.0) THEN
            IU=-99
            FMT='UNFORMATTED'
          IF(FMT.EQ.'YES' .AND. UNFMT.EQ.'NO') THEN
             WRITE(*,'(/,'' File is formatted not unformatted'')')
             IU=99
          ENDIF
         ELSE
            IU=99
            FMT='FORMATTED'
          IF(UNFMT.EQ.'YES' .AND. FMT.EQ.'NO') THEN
             WRITE(*,'(/,'' File is unformatted not formatted'')')
             IU=-99
          ENDIF
         ENDIF
           GO TO 6666
C
C4AB-----Unopen
C
        ELSE
C
C4ABA-----File sequential access
C
         IF(NSTAT.GT.0) THEN
          IF(ACCSS.EQ.'DIRECT') THEN
             WRITE(*,'(/,'' File is direct access not sequential'')')
             GO TO 9999
          ENDIF
C
C4ABB-----Direct access
C
         ELSE
          IF(ACCSS.EQ.'SEQUENTIAL') THEN
             WRITE(*,'(/,'' File is sequential access not direct'')')
             GO TO 9999
          ENDIF
         ENDIF
C
C4ABC-----File format status
C
         IF(IU.LT.0) THEN
          IF(FMT.EQ.'NO' .AND. UNFMT.EQ.'NO') THEN
             WRITE(*,'(/,'' File is formatted not unformatted'')')
             GO TO 9999
          ENDIF
           IU=-IU
         ELSE
          IF(UNFMT.EQ.'YES' .AND. FMT.EQ.'NO') THEN
             WRITE(*,'(/,'' File is unformatted not formatted'')')
             GO TO 9999
          ENDIF
         ENDIF
C
C4ABD-----Open file 
C
          OPEN (IU,FILE=FNAME,STATUS='OLD',
     &          ACCESS=ACCSS,FORM=FMT,IOSTAT=IERR,ERR=8888)
          RETURN
        ENDIF
C
C4B-----File exist status
C
       ELSE
C
C4BA-----File sequential or direct access
C
        IF(NSTAT.GT.0) THEN
           ACCSS='SEQUENTIAL'
        ELSE
           ACCSS='DIRECT'
        ENDIF
C
C4BC-----File format status
C
        IF(IU.LT.0) THEN
           IU=-IU
           FMT='UNFORMATTED'
        ELSE
           FMT='FORMATTED'
        ENDIF
C
C4BD-----Open file 
C
          OPEN (UNIT=IU,FILE=FNAME,STATUS='NEW',
     &          ACCESS=ACCSS,FORM=FMT,IOSTAT=IERR,ERR=8888)
          RETURN
       ENDIF
C
C
C5-----Unknow Option
C
      ELSE
         WRITE(*,'(//,'' Poor choice for type of file'')')
         GO TO 9999
      END IF
C**********************************************************************C
C                       Report errors
C**********************************************************************C
 6666 WRITE(*,'(//,
     &   '' *********************__ERROR__*************************'')')
      WRITE(*,'('' File already open for file '',A,'' for unit'',I10)')
     &       FNAME (1:INDEX(FNAME,' ')-1),
     &       IU
      WRITE(*,'('' IOSTAT='',I10)')
     &       IERR
      WRITE(*,'(//,'' Abnormal Termination of Open_File_Subroutine'')')
      RETURN 1
C
 7777 WRITE(*,'(//,
     &   '' *********************__ERROR__*************************'')')
      WRITE(*,'('' Can not inquire on file '',A,'' for unit '',I10)')
     &       FNAME (1:INDEX(FNAME,' ')-1),
     &       IU
      WRITE(*,'('' IOSTAT='',I10)')
     &       IERR
      WRITE(*,'(//,'' Abnormal Termination of Open_File_Subroutine'')')
      RETURN 1
C
 8888 WRITE(*,'(//,
     &   '' *********************__ERROR__*************************'')')
      WRITE(*,'('' Can not open file '',A,'' on unit '',I10)')
     &       FNAME (1:INDEX(FNAME,' ')-1),
     &       IU
      WRITE(*,'('' IOSTAT='',I10)')
     &       IERR
C
 9999 WRITE(*,'(//,'' Abnormal Termination of Open_File_Subroutine'')')
      RETURN 1
C**********************************************************************C
 1000 RETURN
      END
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
      SUBROUTINE DELETE_FILE (FNAME,*)
C-----------------------------------------------------------------------
C
C---VERSION 2.0 12JUNE192 DELETE_FILE
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C  This routine deletes a single file.
C
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: Fortran77
C
C
C    Inputs:
C
C  FNAME = File Name
C
C .. History:
C
C      Leonard L. Orzol      03/13/90      Original Coding
C               USGS WRD Portland, Or Fts: 429-2256
C      Leonard L. Orzol      03/29/90      Improved Coding
C
C-------------------------------------------------------------------------
C
      CHARACTER*(*) FNAME
      INTEGER IERR
      INTEGER IU
      LOGICAL*4 EXISTS,OPN
C************************************************************************C
C
C1-----Inquire About Existing File
C
      INQUIRE (FILE=FNAME,IOSTAT=IERR,ERR=7777,
     &                              EXIST=EXISTS,OPENED=OPN,NUMBER=IU)
C
C1-----Existence of File
C
      IF(.NOT.EXISTS) THEN
C         WRITE(*,'(//,'' File does not exists '',A)')
C     &          FNAME (1:INDEX(FNAME,' ')-1)
         RETURN
      ELSE
       IF(OPN) THEN
          CLOSE (IU,STATUS='DELETE',ERR=8888,IOSTAT=IERR)
       ELSE
          IU=10
  2     INQUIRE (UNIT=IU,IOSTAT=IERR,ERR=7777,
     &                              EXIST=EXISTS,OPENED=OPN)
        IF(OPN) THEN
           IU=IU+1
           GO TO 2
        ENDIF
          OPEN (IU,FILE=FNAME,ERR=9999,IOSTAT=IERR)
          CLOSE (IU,STATUS='DELETE',ERR=8888,IOSTAT=IERR)
       ENDIF
          RETURN
      ENDIF
C**********************************************************************C
C                       Report errors
C**********************************************************************C
 7777 WRITE(*,'(//,
     &   '' *********************__ERROR__*************************'')')
      WRITE(*,'('' Can not inquire on file '',A,'' for unit '',I10)')
     &       FNAME (1:INDEX(FNAME,' ')-1),
     &       IU
      WRITE(*,'('' IOSTAT='',I10)')
     &       IERR
      WRITE(*,'(//,
     &          '' Abnormal Termination of Delete_File_Subroutine'')')
      RETURN 1
C
 8888 WRITE(*,'(//,
     &   '' *********************__ERROR__*************************'')')
      WRITE(*,'('' Can not close file '',A,'' on unit '',I10)')
     &       FNAME (1:INDEX(FNAME,' ')-1),
     &       IU
      WRITE(*,'('' IOSTAT='',I10)')
     &       IERR
C
 9999 WRITE(*,'(//,
     &          '' Abnormal Termination of Delete_File_Subroutine'')')
      RETURN 1
C**********************************************************************C
 1000 RETURN
      END
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
      SUBROUTINE CLOSE_FILE (FNAME,*)
C-----------------------------------------------------------------------
C
C---VERSION 2.0 12JUNE1992 CLOSE_FILE
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C  THIS ROUTINE CLOSES A SINGLE FILE.
C
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: Fortran77
C
C
C    Inputs:
C
C  FNAME = FILE NAME
C
C .. History:
C
C      Leonard L. Orzol      03/13/90      Original Coding
C               USGS WRD Portland, Or Fts: 429-2256
C
C-------------------------------------------------------------------------
C
      CHARACTER*80 FNAME
      INTEGER IERR
      LOGICAL EXISTS,OPN
C************************************************************************C
C
C1-----Inquire About Existing File
C
      INQUIRE (FILE=FNAME,IOSTAT=IERR,ERR=7777,
     &                              EXIST=EXISTS,OPENED=OPN,NUMBER=IU)
C
C1-----Existence of File
C
      IF(.NOT.EXISTS) THEN
         WRITE(*,'(//,'' System File '',A,'' does not exist'')')
     &          FNAME (1:INDEX(FNAME,' ')-1)
         RETURN
      ELSE
       IF(OPN) THEN
          CLOSE (IU,STATUS='KEEP',ERR=8888,IOSTAT=IERR)
       ENDIF
        RETURN
      ENDIF
C**********************************************************************C
C                       Report errors
C**********************************************************************C
 7777 WRITE(*,'(//,
     &   '' *********************__ERROR__*************************'')')
      WRITE(*,'('' Can not inquire on file '',A,'' for unit '',I10)')
     &       FNAME (1:INDEX(FNAME,' ')-1),
     &       IU
      WRITE(*,'('' IOSTAT='',I10)')
     &       IERR
      WRITE(*,'(//,'' Abnormal Termination of Close_File_Subroutine'')')
      RETURN 1
C
 8888 WRITE(*,'(//,
     &   '' *********************__ERROR__*************************'')')
      WRITE(*,'('' Can not close file '',A,'' on unit '',I10)')
     &       FNAME (1:INDEX(FNAME,' ')-1),
     &       IU
      WRITE(*,'('' IOSTAT='',I10)')
     &       IERR
C
 9999 WRITE(*,'(//,'' Abnormal Termination of Close_File_Subroutine'')')
      RETURN 1
C**********************************************************************C
 1000 RETURN
      END
