      PROGRAM MODPMT
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                            Modpmt                 **************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**           The source code is available from below:                       **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 1.0 MODPMT 24AUGUST2000
C
C::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     MODTOOLS is a replacement program for MODPATH-PLOT (Pollock, 1989)
C      that uses the results from the particle tracking program MODPATH 
C      (Pollock, 1989) to create Arc/Info coverages or Info files.  This  
C      replacement program does most options and plots that are available 
C      in MODPATH-PLOT.
C
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN, (standard FORTRAN77)
C
C
C    Inputs:
C
C      INSTR  ==  (Character*128) The command string passed from the
C                  Modtools.aml program that is parse into the following:
C                  coverage name, name file, and pmrfil file names.
C
C      Files:
C
C       COVER    : COVERAGE NAME
C       BASFIL   : MODPATH MAIN FILE CONTAINING MODELING PROBLEM INFORMATION
C       PMRFIL   : FILE COVERAGE INFORMATION
C
C    Outputs:  None
C
C     Program:
C
C      Variables:
C
C     BASUNT  : FORTRAN UNIT NUMBER FOR MODPATH MAIN FILE
C     COVER   : GIS OUTPUT NAME
C     COVFLG  : LOGICAL FLAG FOR COVERAGE PARAMETERS FILE
C             => TRUE READ PARAMETERS FROM PMRFIL FILE
C             => FALSE PROMPT USER FROM PARAMETERS AND WRITE TO PMRFIL FILE
C     ISUM    : INDEX NUMBER TO COMMON BLOCK ARRAY FOR ALLOCATION
C     ITALK   : FLAG FOR INTERACTIVE DIALOG
C             => 1 NON-INTERACTIVE DIALOG
C             => 0 INTERACTIVE DIALOG
C     LCCVPR  : STARTING ARRAY INDEX FOR COVERAGE PARAMETERS
C     MAXPMR  : MAXIMUM NUMBER OF COVERAGE PARAMETERS
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C     NSTAT   : STATUS OF FILE
C             => 1 OLD FILE
C             => 2 NEW FILE
C             => 3 SCRATCH FILE (DELETED AUTOMATICALLY WHEN RUN ENDS)
C             => 4 UNDETERMINED STATUS (MAY OR MAY NOT EXIST)
C                   IF IT DOES NOT EXIST, IT IS CREATED BY OPEN STATEMENT
C                   IF IT DOES EXIST, IT IS OPENED AS 'OLD' FILE
C     NUNIT   : FORTRAN UNIT NUMBER
C     OUTFIL  : MODTOOLS OPERATIONS FILE NAME
C             => MODTOOLS.OUT LISTS ALLOCATION SPACE, COVERAGE PARAMETERS,
C                 ARRAYS INFORMATION READ BY MODTOOLS DURING OPERATION
C     OUTUNT  : FORTRAN UNIT NUMBER FOR MODTOOLS OUTPUT LSTING FILE
C     STRDEX  : CHARACTER STRING INDEX
C
C-------------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
      PARAMETER (
     &           MAXPMR=30, 
     &           LENX=MAXPMR,
     &           MAXFIL=40,
     &           MAXPTS=100000)
C
      CHARACTER*128 ARCCMD,ARCCRS,INSTR,OUTSTR,PMRFIL,COVER,
     &              FILES(MAXFIL),XSCOV,
     &              OUTFIL,
     &              NAMFIL,
     &              BASFIL,
     &              TRMFIL,
     &              CTLFIL,
     &              ENDFIL,
     &              PTHFIL,
     &              TIMFIL,
     &              HEDFIL,
     &              HCLFIL,
     &              DDNFIL,
     &              DCLFIL,
     &              ARRFIL,
     &              ACLFIL,
     &              CONFIL,
     &              LVLFIL 
C
      INTEGER MODFLG,ICOVER,IVIEW,IRWCL,STRDEX,NUNITS(MAXFIL),
     &        MAXCOL,MAXROW,MAXXND,MAXYND,
     &        OUTUNT,
     &        NAMUNT,
     &        BASUNT,
     &        TRMUNT,
     &        CTLUNT,
     &        ENDUNT,
     &        PTHUNT,
     &        TIMUNT,
     &        HEDUNT,
     &        HCLUNT,
     &        DDNUNT,
     &        DCLUNT,
     &        ARRUNT,
     &        ACLUNT,
     &        CONUNT,
     &        LVLUNT
C
      LOGICAL COVFLG,FILFLG,EXISTS,OPN 
C
      COMMON /XCMN/ X(LENX)
C
      DATA ARCCMD,ARCCRS /'arccmd','arccrs'/
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       Modtools Version
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CH*********************************************************************C
      OUTUNT=81
      NSTAT=2
      ITALK=1
      OUTFIL='modtools.list'
      CALL DELETE_FILE (OUTFIL,*9998)
      CALL OPEN_FILE (OUTUNT,OUTFIL,NSTAT,ITALK,*9998)
C
CH----Print a message identifying the package
C
      WRITE(OUTUNT,'(1H0,10X,85(''*''))')
      WRITE(OUTUNT,'(40X,''U.S. GEOLOGICAL SURVEY '')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(35X,
     &               ''MODTOOLS -- MODPATH/MODFLOW GIS PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(40X,''VERSION 1.0 MODPMT 24AUGUST2000 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,''C*'',80(''=''),''*C'')')
      WRITE(OUTUNT,'(10X,''C*'',80('':''),''*C'')')
      WRITE(OUTUNT,'(10X,
     &               ''C* Purpose: Although this program has been '',
     &               ''used by the U.S. Geological Survey,'')')
      WRITE(OUTUNT,'(10X,
     &               ''C*           no warranty, expressed or '',
     &               ''implied, is made by the USGS as to the'')')
      WRITE(OUTUNT,'(10X,
     &               ''C*           accuracy and functioning of the '',
     &               ''program and related program'')')
      WRITE(OUTUNT,'(10X,
     &               ''C*           material nor shall the fact of '',
     &               ''distribution constitute any such'')')
      WRITE(OUTUNT,'(10X,
     &               ''C*           warranty, and no responsibility '',
     &               ''is assumed by the USGS in'')')
      WRITE(OUTUNT,'(10X,''C*           connection therewith.'')')
      WRITE(OUTUNT,'(10X,''C*'',80('' ''),''*C'')')
      WRITE(OUTUNT,'(10X,''C*'',80('':''),''*C'')')
      WRITE(OUTUNT,'(10X,''C*'',80(''=''),''*C'')')
C
CH----Display package to terminal screen
C
      WRITE(*,'(1X,79(''*''))')
      WRITE(*,'(30X,''U.S. GEOLOGICAL SURVEY '')')
      WRITE(*,'(1X,79(''-''))')
      WRITE(*,'(21X,''MODTOOLS -- MODPATH/MODFLOW GIS PACKAGE'')')
      WRITE(*,'(1X,79(''-''))')
      WRITE(*,'(30X,''VERSION 1.0 MODPMT 24AUGUST2000 '')')
      WRITE(*,'(1X,79(''-''))')
      WRITE(*,'(1X,''C*'',75(''=''),''*C'')')
      WRITE(*,'(1X,''C*'',75('':''),''*C'')')
      WRITE(*,'(1X,''C* Purpose: Although this program has been '',
     &             ''used by the U.S. Geological Survey,'')')
      WRITE(*,'(1X,''C*           no warranty, expressed or '',
     &             ''implied, is made by the USGS as to the'')')
      WRITE(*,'(1X,''C*           accuracy and functioning of the '',
     &             ''program and related program'')')
      WRITE(*,'(1X,''C*           material nor shall the fact of '',
     &             ''distribution constitute any such'')')
      WRITE(*,'(1X,''C*           warranty, and no responsibility '',
     &             ''is assumed by the USGS in'')')
      WRITE(*,'(1X,''C*           connection therewith.'')')
      WRITE(*,'(1X,''C*'',75('':''),''*C'')')
      WRITE(*,'(1X,''C*'',75('':''),''*C'')')
      WRITE(*,'(1X,''C*'',75(''=''),''*C'')')
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                 Parse Instr into Arguements
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C1*********************************************************************C
      INQUIRE (
     F         FILE=ARCCMD,
     I         IOSTAT=IERR,
     L         ERR=9999,
     E         EXIST=EXISTS,
     S         OPENED=OPN
     &         )
C
CP----Parse Modtools argument string
C
      IF(EXISTS) THEN
         WRITE(*,'('' .Parsing Modtools argument string...'')')
         NSTAT=1
         ITALK=1
         INCMD=80
         CALL OPEN_FILE (INCMD,ARCCMD,NSTAT,ITALK,*9998)
         READ(INCMD,'(A128)',ERR=9990,END=9991) INSTR
         CALL CLOSE_FILE (ARCCMD,*9998)
         CALL DELETE_FILE (ARCCMD,*9998)
C
C1A-----Parsing for Coverage name from Instr
C
         STRDEX=INDEX(INSTR,' ')
       IF(STRDEX.GT.12) THEN
          COVER=COVER (1:11)
       ELSE
          COVER=INSTR (1:STRDEX-1)
       ENDIF
         INSTR=INSTR (STRDEX+1:LEN(INSTR))
C
C1B-----Parsing for Problem definition file from Instr
C
         STRDEX=INDEX(INSTR,' ')
         NAMFIL=INSTR (1:STRDEX-1)
         INSTR=INSTR (STRDEX+1:LEN(INSTR))
C
C1C-----Parsing for Coverage parameter file from Instr
C
         COVFLG=.FALSE.
         STRDEX=INDEX(INSTR,' ')
       IF(STRDEX.GT.1) THEN
          PMRFIL=INSTR (1:STRDEX-1)
          INSTR=INSTR (STRDEX+1:LEN(INSTR))
          COVFLG=.TRUE.
        IF(PMRFIL.EQ.'#') THEN
           COVFLG=.FALSE.
           PMRFIL='modtools.out'
        ENDIF
       ELSE
          PMRFIL='modtools.out'
       ENDIF 
C 
CF----Question user 
C 
      ELSE 
         WRITE(*,'('' Enter the name of the GIS output that will '', 
     &             '' be created by MODTOOLS'')') 
         READ(*,'(A)',ERR=9999,END=9999) COVER 
       IF(INDEX(COVER,' ').EQ.1) GO TO 9999 
C 
  102    WRITE(*,'('' Enter the name of the MODTOOLS'', 
     &             '' NAME file'')') 
         READ(*,'(A)',ERR=9999,END=9999) NAMFIL 
       IF(INDEX(NAMFIL,' ').EQ.1) GO TO 9999 
         INQUIRE ( 
     F            FILE=NAMFIL, 
     I            IOSTAT=IERR, 
     L            ERR=9999, 
     E            EXIST=EXISTS, 
     S            OPENED=OPN 
     &           ) 
       IF(.NOT.EXISTS) THEN 
          WRITE(*,'('' MODTOOLS NAME file '',A,'' does not '', 
     &              ''exist'')') NAMFIL (1:INDEX(NAMFIL,' ')) 
          GO TO 102 
       ENDIF 
C 
  104    WRITE(*,'('' Enter the name of the optional'', 
     &             '' MODTOOLS batch file'')') 
         READ(*,'(A)',ERR=9999,END=9999) PMRFIL 
       IF(INDEX(PMRFIL,' ').LE.1) THEN 
          COVFLG=.FALSE. 
          PMRFIL='modtools.out' 
       ELSE 
          INQUIRE ( 
     F             FILE=PMRFIL, 
     I             IOSTAT=IERR, 
     L             ERR=9999, 
     E             EXIST=EXISTS, 
     S             OPENED=OPN 
     &            ) 
        IF(.NOT.EXISTS) THEN 
           WRITE(*,'('' MODTOOLS BATCH file '',A,'' does not '', 
     &               ''exist'')') PMRFIL (1:INDEX(PMRFIL,' ')) 
           GO TO 104 
        ENDIF 
          COVFLG=.TRUE. 
       ENDIF 
      ENDIF 
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       READ FILE NAMES FROM NAME FILE
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C2*********************************************************************C
      WRITE(*,'(
     &          '' ..Reading MODTOOLS Name file '',A)')
     &          NAMFIL (1:INDEX(NAMFIL,' ')-1)
      CALL PTHFLS (
     I             OUTFIL,OUTUNT,
     I             NAMFIL,NAMUNT,
     O             BASFIL,BASUNT,
     O             TRMFIL,TRMUNT,
     O             CTLFIL,CTLUNT,
     O             ENDFIL,ENDUNT,
     O             PTHFIL,PTHUNT,
     O             TIMFIL,TIMUNT,
     O             HEDFIL,HEDUNT,
     O             HCLFIL,HCLUNT,
     O             DDNFIL,DDNUNT,
     O             DCLFIL,DCLUNT,
     O             ARRFIL,ARRUNT,
     O             ACLFIL,ACLUNT,
     O             CONFIL,CONUNT,
     O             LVLFIL,LVLUNT,
     E             *9998)
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       BASIC PROBLEM DEFINITION
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C3*********************************************************************C
      WRITE(*,'('' ...Reading MODPATH main file '',
     &          ''and allocating space '')')
      CALL PTHBAS (
     I             OUTFIL,OUTUNT,
     I             BASFIL,BASUNT,
     O             NLAY,NROW,NCOL,NCBL,IGRID,NPER,
     O             HNOFLO,HDRY,
     E             *9998)
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       COVERAGE PARAMTERS OPERATIONS
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C4*********************************************************************C
      LCCVPR=1
      WRITE(*,'('' ....Prompting for coverage parameters...'')')
      CALL PTHPMT (
     I                OUTUNT,
     I                PMRFIL,COVER,
     I                MAXPMR,
     I                NROW,NCOL,NLAY,
     O                X(LCCVPR),
     E                *9998)
C
      CALL PTHLST (
     I             OUTFIL,OUTUNT,
     I             COVER,
     I             PMRFIL,
     I             NAMFIL,
     I             BASFIL,
     I             TRMFIL,
     I             ENDFIL,
     I             PTHFIL,
     I             TIMFIL,
     I             HEDFIL,
     I             HCLFIL,
     I             DDNFIL,
     I             DCLFIL,
     I             ARRFIL,
     I             ACLFIL,
     I             CONFIL,
     I             LVLFIL,
     I             MAXPMR,
     I             NROW,NCOL,NLAY,
     I             X(LCCVPR),
     E             *9998)
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       COVERAGE PARAMTERS OPERATIONS
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C4*********************************************************************C
       WRITE(*,'('' .Parsing Modtools argument string...'')')
       NSTAT=2
       ITALK=1
       CALL DELETE_FILE (ARCCMD,*9998)
       INCMD=80
       CALL OPEN_FILE (INCMD,ARCCMD,NSTAT,ITALK,*9998)
C
C1A-----Write arguments to arccmd file
C
       WRITE(INCMD,'(3A)',ERR=9990,END=9991) COVER,NAMFIL,PMRFIL
       CALL CLOSE_FILE (ARCCMD,*9998)
       GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  ERRORS WITHIN MODTOOLS PROGRAMS
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,
     &      '(//,'' Unable to read Modtools command string '',
     &      ''from file '',A)') 
     &      ARCCMD (1:INDEX(ARCCMD,' ')-1)
      WRITE(OUTUNT,
     &      '(//,'' Unable to read Modtools command string '',
     &      ''from file '',A)') 
     &      ARCCMD (1:INDEX(ARCCMD,' ')-1)
      GO TO 9998
 9991 WRITE(*,
     &      '(//,'' End-of-file; Missing Modtools command string '',
     &      ''in file '',A)')
     &      ARCCMD (1:INDEX(ARCCMD,' ')-1)
      WRITE(OUTUNT,
     &      '(//,'' End-of-file; Missing Modtools command string '',
     &      ''in file '',A)')
     &      ARCCMD (1:INDEX(ARCCMD,' ')-1)
 9998 CALL DELETE_FILE (ARCCMD,*9999)
      CALL DELETE_FILE (ARCCRS,*9999)
 9999 WRITE(*,
     &      '(//,'' Abnormal Termination of Modtools_Program'')')
      WRITE(OUTUNT,
     &      '(//,'' Abnormal Termination of Modtools_Program'')')
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  EXITING MODTOOLS PROGRAM
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 CALL CLOSE_FILE (OUTFIL,*1001)
 1001 STOP
      END
