C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthpmt version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHPMT 30AUGUST1999
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Prompts user for coverage and orientation information to construct
C      GIS output from the results of ground-water modeling program MODFLOW
C      and the particle tracking program MODPATH.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN77
C
C
C   Inputs:
C
C     OUTUNT  : FORTRAN UNIT NUMBER OF OPERATIONAL OUTPUT FILE
C     PMRFIL  : FILE CONTAINING COVERAGE ORIENTATION INFORMATION
C     COVER   : USER SPECIFIED COVERAGE NAME
C     MAXPMR  : NUMBER OF COVERAGE PARAMETERS
C     NROW    : NUMBER OF ROWS IN GRID
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C
C   Inputs/Outputs: None
C
C   Outputs:
C
C    Variables:
C
C     COVPMR  : COVERAGE PARAMETERS ARRAY (MAXPMR)
C
C     Program:
C
C     ANSWER : DUMMY CHARACTER HOLDING USER RESPONSES
C     CONVRT : DUMMY REAL HOLDING COVERAGE PARAMETERS
C     HSCALE : DUMMY REAL HOLDING HORIZONTAL MAPSCALE
C     IANSW  : DUMMY INTEGER HOLDING USER RESPONSES
C     IERROR : INTEGER HOLDING ERROR VALUE
C     MESAGE : DUMMY CHARACTER HOLDING FILE OUTPUT MESSAGES
C     VSCALE : DUMMY REAL HOLDING VERTICAL EXAGGERATION
C
C-------------------------------------------------------------------------
      SUBROUTINE PTHPMT (
     I                   OUTUNT,
     I                   PMRFIL,COVER,
     I                   MAXPMR,
     I                   NROW,NCOL,NLAY,
     O                   COVPMR,
     E                   *)
C-------------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C
C::::::::::::::::::::::::  GLOBAL_VARIABLES  :::::::::::::::::::::::::::
C
      DIMENSION 
     &          COVPMR(MAXPMR)
C
      CHARACTER*(*) COVER,PMRFIL
C
      INTEGER 
     &        OUTUNT,NCOL,NROW,NLAY
C
C:::::::::::::::::::::::::  PROGRAM_VARIABLES  :::::::::::::::::::::::::
C
      CHARACTER*80 ANSWER,MESAGE(30)
C
      REAL
     &    HNOFLO,HDRY
C
      INTEGER IOUT,NSTAT,ITALK,IERROR,NPER
C
      DATA IERROR /0/
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                 Prompt user for information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(//)')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          MODTOOLS GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''               VERSION 6.0 30AUGUST1999 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                   MENUING MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C1----Coverage characteristics
C
C
C1A----Set coverage parameters
C
 100  COVPMR(2)=0
      MESAGE(2)='NO COVERAGE'
      COVPMR(10)=0
      MESAGE(10)='NO ORIENTATION'
      IVIEW=-99
      NPER=INT(COVPMR(17))
C
C1B----Type of coverage
C
  102 IERROR=1
      WRITE(*,'(//,'' Select an option for creating '',
     &          ''a coverage or info file(s)'')')
      WRITE(*,'(''-------------------------------------------'',
     &          ''--------------------------'')')
      WRITE(*,'('' <cr> = Quit '')')
      WRITE(*,'(''    p = Pathline output'')')
      WRITE(*,'(''    e = Endpoint output'')')
      WRITE(*,'(''    t = Times-series output'')')
      WRITE(*,'(''    z = Zones of transport output'')')
      WRITE(*,'(''    g = Model grid output'')')
      WRITE(*,'(''    c = Contour output'')')
      WRITE(*,'(''    v = Velocity vectors output'')')
      WRITE(*,'(''    i = Cell values output '')')
      WRITE(*,'(''    h = Help'')')
      WRITE(*,'(/,''    Enter option:'')')
      READ(*,'(A)',ERR=104,END=9990) ANSWER
      IERROR=0
C
C1Q-----Quitting
C
 104  IF(ANSWER.EQ.' ') GO TO 9990
C
C1E-----Errors
C
      IF(IERROR.NE.0) THEN
         WRITE(*,'(//,'' Error reading option'')')
         GO TO 102
      ENDIF
C
C1H-----Help
C
      IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
 106     IERROR=1
         WRITE(*,'(//,'' Help for selecting an option for '',
     &                ''creating a coverage or info file(s)'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit '')')
         WRITE(*,'(''    p = Pathline output'')')
         WRITE(*,'(''    e = Endpoint output'')')
         WRITE(*,'(''    t = Times-series output'')')
         WRITE(*,'(''    z = Zones of Transport output'')')
         WRITE(*,'(''    g = Model grid output'')')
         WRITE(*,'(''    c = Contour output'')')
         WRITE(*,'(''    v = Velocity vectors output'')')
         WRITE(*,'(''    i = Cell values output '')')
         WRITE(*,'(''    q = Quit help'')')
         WRITE(*,'(/,''    Enter help letter:'')')
         READ(*,'(A)',ERR=108,END=9990) ANSWER
         IERROR=0
C
C1Hq-----Quitting
C
 108   IF(ANSWER.EQ.' ') GO TO 102
C
C1He-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading MODTOOLS option'')')
          GO TO 106
       ENDIF
C
C1Hq-----Quit help
C
       IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') THEN
          WRITE(*,'(//,'' Quiting help menu'')')
          GO TO 102
       ENDIF
C
C1Hr-----Help section
C
         WRITE(*,*) ' '
         WRITE(*,*) 'MODTOOLS needs to know what type of GIS output',
     &              ' will be created.'
         WRITE(*,*) ' '
       IF(ANSWER.EQ.'p') THEN
          WRITE(*,*) 'Response: =----->  p'
          WRITE(*,*) ' A line coverage is created from particle '
          WRITE(*,*) '  pathlines recorded in the PATHLINE file'
          WRITE(*,*) '  by MODPATH.'
          WRITE(*,*) ' The user must include the name of the output'
          WRITE(*,*) '  file in NAME file and use the word '
          WRITE(*,*) '  PATHLINE to identify this file in the list.'
        ELSE IF(ANSWER.EQ.'e') THEN
          WRITE(*,*) 'Response: =----->  e'
          WRITE(*,*) ' A point coverage is created from particle '
          WRITE(*,*) '  starting and ending locations recorded in the'
          WRITE(*,*) '  ENDPOINT file by MODPATH.'
          WRITE(*,*) ' The user must include the name of the output'
          WRITE(*,*) '  file in NAME file and use the word '
          WRITE(*,*) '  ENDPOINT to identify this file in the list.'
       ELSE IF(ANSWER.EQ.'t') THEN
          WRITE(*,*) 'Response: =----->  t'
          WRITE(*,*) ' A point coverage is created from particle '
          WRITE(*,*) '  time-series locations recorded in the TIMESERS'
          WRITE(*,*) '  file by MODPATH.'
          WRITE(*,*) ' The user must include the name of the output'
          WRITE(*,*) '  file in NAME file and use the word '
          WRITE(*,*) '  TIME-SERIES to identify this file in the list.'
       ELSE IF(ANSWER.EQ.'z') THEN
          WRITE(*,*) 'Response: =----->  z'
          WRITE(*,*) ' Two coverages are created from particle data'
          WRITE(*,*) '  recorded in the TIMESERS and ENDPOINT files'
          WRITE(*,*) '  by MODPATH for the backward-tracking option.'
          WRITE(*,*) '  A polygon coverage is delineated for the zones'
          WRITE(*,*) '  of transport for the user-specified '
          WRITE(*,*) '  orientation. A point coverage of the vertices'
          WRITE(*,*) '  from the selected particles used to construct'
          WRITE(*,*) '  the polygons. MODTOOLS associates'
          WRITE(*,*) '  characteristics from the selected particles'
          WRITE(*,*) '  to each vertices.'
          WRITE(*,*) ' The user must include the name of the output'
          WRITE(*,*) '  files in NAME file and use the words'
          WRITE(*,*) '  TIME-SERIES and ENDPOINT to identify these '
          WRITE(*,*) '  files in the list.'
       ELSE IF(ANSWER.EQ.'g') THEN
          WRITE(*,*) 'Response: =----->  g'
          WRITE(*,*) ' A polygon coverage is created from data arrays'
          WRITE(*,*) '  defining grid dimensions from the MAIN file'
          WRITE(*,*) '  input to MODPATH. The user can specify an '
          WRITE(*,*) '  orientation in mapview or along a row, column,'
          WRITE(*,*) '  or particle pathline.'
          WRITE(*,*) '  If the particle pathline option is used,'
          WRITE(*,*) '  the user must include the PATHLINE file in'
          WRITE(*,*) '  the NAME file.  Also, a pathline coverage'
          WRITE(*,*) '  will be created so both coverages can be'
          WRITE(*,*) '  displayed.'
       ELSE IF(ANSWER.EQ.'c') THEN
          WRITE(*,*) 'Response: =----->  c'
          WRITE(*,*) ' A contour coverage is created from data '
          WRITE(*,*) '  recorded in a file output by MODFLOW'
          WRITE(*,*) '  during a ground-water simulation. Also, the'
          WRITE(*,*) '  user can substitute any similarily formatted '
          WRITE(*,*) '  file.'
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  file in MODTOOLS name file and use the word '
          WRITE(*,*) '  CONTOUR or CONTOUR(BINARY) to identify this '
          WRITE(*,*) '  file in the list.  If the word CONTOUR is used,'
          WRITE(*,*) '  MODTOOLS needs another file which specifies'
          WRITE(*,*) '  the format of the values of the cell-by-cell'
          WRITE(*,*) '  terms.'
          WRITE(*,*) '  This format-control file is identified by'
          WRITE(*,*) '  using the word CONTOUR-CONTROL.  The '
          WRITE(*,*) '  format-control file is read by the U3DREL '
          WRITE(*,*) '  or U2DREL utility modules of MODFLOW or '
          WRITE(*,*) '  MODTOOLS [use intructions for the U2DREL '
          WRITE(*,*) '  module from MODFLOW manual for the construction'
          WRITE(*,*) '  of this file].'
       ELSE IF(ANSWER.EQ.'v') THEN
          WRITE(*,*) 'Response: =----->  v'
          WRITE(*,*) ' A flow direction line coverage is created from '
          WRITE(*,*) '  data recorded in the cell-by-cell head and flow'
          WRITE(*,*) '  terms output by MODFLOW during a ground-water'
          WRITE(*,*) '  simulation.'
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  file from the Block-Centered Package of MODFLOW'
          WRITE(*,*) '  in MODTOOLS name file and use the word'
          WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file '
          WRITE(*,*) '  in the list. If the word BUDGET(ASCII) is used,'
          WRITE(*,*) '  MODTOOLS needs another file which specifies the'
          WRITE(*,*) '  format of the values of the cell-by-cell  '
          WRITE(*,*) '  simulated flow. This format-control flow file '
          WRITE(*,*) '  is identified by using the word BUDGET-CONTROL.'
          WRITE(*,*) '  The format-control file is read by the U3DREL '
          WRITE(*,*) '  utility module of MODTOOLS [use intructions '
          WRITE(*,*) '  for the U2DREL module from MODFLOW manual for'
          WRITE(*,*) '  the construction of this file].'
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  head file in MODTOOLS name file and use the '
          WRITE(*,*) '  word HEAD or HEAD(BINARY) to identify this file'
          WRITE(*,*) '  in the list.  If the word HEAD is used, '
          WRITE(*,*) '  MODTOOLS needs another file which specifies '
          WRITE(*,*) '  the format of the values of the cell-by-cell  '
          WRITE(*,*) '  simulated head. This format-control head file '
          WRITE(*,*) '  is identified by using the word HEAD-CONTROL.'
          WRITE(*,*) '  The format-control file is read by the U2DREL '
          WRITE(*,*) '  utility module of MODFLOW [use intructions '
          WRITE(*,*) '  for the U2DREL module from MODFLOW manual for'
          WRITE(*,*) '  the construction of this file].'
       ELSE IF(ANSWER.EQ.'i') THEN
          WRITE(*,*) 'Response: =----->  i'
          WRITE(*,*) ' A info file(s) is created from the cell-by-cell'
          WRITE(*,*) '  terms recorded in an file output by'
          WRITE(*,*) '  MODFLOW during a ground-water simulation. '
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  file in MODTOOLS name file and use the word '
          WRITE(*,*) '  HEAD or HEAD(BINARY) for simulated head, or'
          WRITE(*,*) '  BUDGET for simulated terms from other packages'
          WRITE(*,*) '  of MODFLOW to identify this file in the list.'
          WRITE(*,*) ' If the word HEAD is used, MODTOOLS needs another'
          WRITE(*,*) '  file which specifies the format '
          WRITE(*,*) '  of the values of the cell-by-cell simulated '
          WRITE(*,*) '  head This format-control flow file is '
          WRITE(*,*) '  identified by using the word HEAD-CONTROL.'
          WRITE(*,*) '  The format-control file is read by the '
          WRITE(*,*) '  U2DREL module of MODFLOW [see MODFLOW manual'
          WRITE(*,*) '  for the construction of this file].'
          WRITE(*,*) ' If the user specifies a vertical profile'
          WRITE(*,*) '  orientation, the terms will be'
          WRITE(*,*) '  append as cell attributes to the vertical'
          WRITE(*,*) '  cell coverage which will be construction.'
       ELSE
          WRITE(*,*) ' '
          WRITE(*,*) ' =-----> Invalid Response <-----='
          WRITE(*,*) ' '
          GO TO 106
       ENDIF
         WRITE(*,*) 'Continue?'
         READ(*,'(A)') ANSWER
         GO TO 102
C
C1R-----Responses
C
      ELSE
       IF(ANSWER (1:1).EQ.'p') THEN
          WRITE(*,'('' ...Pathline GIS output selected'')')
          ICOVER=1
          COVPMR(2)=ICOVER
          MESAGE(2)='PATHLINE GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'e') THEN
          WRITE(*,'('' ...Endpoint GIS output selected'')')
          ICOVER=2
          COVPMR(2)=ICOVER
       ELSE IF(ANSWER (1:1).EQ.'t') THEN
          WRITE(*,'('' ...Time series GIS output selected'')')
          ICOVER=3
          COVPMR(2)=ICOVER
          MESAGE(2)='TIME-SERIES GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'z') THEN
          WRITE(*,'('' ...Zone_of_transport GIS output '',
     &              ''selected'')')
          ICOVER=4
          COVPMR(2)=ICOVER
          MESAGE(2)='ZONES_OF_TRANSPORT GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'g') THEN
          WRITE(*,'('' ...Model grid GIS output selected'')')
          ICOVER=5
          COVPMR(2)=ICOVER
          MESAGE(2)='MODEL GRID GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'c') THEN
          WRITE(*,'('' ...Contour GIS output selected'')')
          ICOVER=7
          COVPMR(2)=ICOVER
          MESAGE(2)='CONTOUR GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'v') THEN
          WRITE(*,'('' ...Velocity vectors GIS output selected'')')
          ICOVER=8
          COVPMR(2)=ICOVER
          MESAGE(2)='VELOCITY VECTORS GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'i') THEN
          WRITE(*,'('' ...Cell values GIS output selected'')')
          ICOVER=6
          COVPMR(2)=ICOVER
          MESAGE(2)='CELL VALUES OUTPUT'
       ELSE
          WRITE(*,'(//,'' Invalid response try again'')')
          GO TO 102
       ENDIF
      ENDIF
C
C2A-----Tracking mode of Modpath [Endpoint Analysis only]
C
 200    COVPMR(1)=0
        MESAGE(1)='NO MODPATH TRACKING OPTION NEEDED'
      IF(ICOVER.EQ.2) THEN
 202     IERROR=1
         WRITE(*,'(//,'' Select an option for creating a '',
     &             ''point coverage of '',/
     &             ''  starting or final particle locations'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    s = Mapview of starting locations '',
     &             ''(forward tracking)'')')
         WRITE(*,'(''    f = Mapview of final locations '',
     &             ''(forward tracking)'')')
         WRITE(*,'(''    e = Mapview of final locations '',
     &             ''(backward tracking)'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Options menu'')')
         WRITE(*,'(/,''    Enter tracking option:'')')
         READ(*,'(A)',ERR=204,END=9990) ANSWER
         IERROR=0
C
C2Q-----Quitting
C
 204   IF(ANSWER.EQ.' ') GO TO 9990
C
C2E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading tracking option'')')
          GO TO 202
       ENDIF
C
C2P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C2H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODPATH can be run using two tracking modes.'
          WRITE(*,*) ' '
          WRITE(*,*) 'Response: =----->  s'
          WRITE(*,*) ' Starting particle locations for a MODPATH'
          WRITE(*,*) '  simulation in the forward tracking mode'
          WRITE(*,*) '  which means particles traveled in the'
          WRITE(*,*) '  direction of the flow of ground-water'
          WRITE(*,*) '  towards discharge points.'
          WRITE(*,*) 'Response: =----->  f'
          WRITE(*,*) ' Final particle locations for a MODPATH'
          WRITE(*,*) '  simulation in the forward tracking mode'
          WRITE(*,*) '  which means particles traveled in the'
          WRITE(*,*) '  direction of the flow of ground-water'
          WRITE(*,*) '  towards discharge points.'
          WRITE(*,*) 'Response: =----->  e'
          WRITE(*,*) ' Final particle locations for a MODPATH'
          WRITE(*,*) '  simulation in the forward tracking mode'
          WRITE(*,*) '  which means particles traveled in the'
          WRITE(*,*) '  reverse direction of the flow of ground-water'
          WRITE(*,*) '  towards recharge points.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 202
C
C2R-----Responses
C
       ELSE
        IF(ANSWER (1:1).EQ.' ') THEN
           WRITE(*,'(//,'' Quitting Modtools now...'')')
           GO TO 9999
        ELSE IF(ANSWER (1:1).EQ.'s' .OR. ANSWER (1:1).EQ.'S') THEN
           MODFLG=1
           COVPMR(1)=MODFLG
           MESAGE(1)='FORWARD TRACKING FOR MODPATH'
           MESAGE(2)='STARTING PARTICLE COVERAGE (FORWARD TRACKING)'
        ELSE IF(ANSWER (1:1).EQ.'f' .OR. ANSWER (1:1).EQ.'F') THEN
           MODFLG=2
           COVPMR(1)=MODFLG
           MESAGE(1)='FORWARD TRACKING FOR MODPATH'
           MESAGE(2)='FINAL PARTICLE COVERAGE (FORWARD TRACKING)'
        ELSE IF(ANSWER (1:1).EQ.'e' .OR. ANSWER (1:1).EQ.'E') THEN
           MODFLG=3
           COVPMR(1)=2
           MESAGE(1)='BACKWARD TRACKING FOR MODPATH'
           MESAGE(2)='FINAL PARTICLE COVERAGE (BACKWARD TRACKING)'
        ELSE
           WRITE(*,'(//,'' Unavailable choice'')')
           GO TO 202
        ENDIF
       ENDIF
      ENDIF
C
C2O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 100
C
C2B-----Modflow cell-by-cell terms
C
      IF(ICOVER.EQ.6 .OR. ICOVER.EQ.7) THEN
  212    IERROR=1
         WRITE(*,'(//,
     &             '' Select the cell-by-cell terms from MODFLOW '')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''  hed = Head terms from Basic Package'')')
         WRITE(*,'(''  ddn = Drawdown terms from Basic Package'')')
         WRITE(*,'(''  bcf = Flow terms through cell faces '',
     &             ''from Block-Centered-Flow Package'')')
         WRITE(*,'(''  sto = Storage terms from '',
     &             ''Block-Centered-Flow Package'')')
         WRITE(*,'(''  riv = Flow terms from River Package'')')
         WRITE(*,'(''  rch = Flow terms from Recharge Package'')')
         WRITE(*,'(''  wel = Flow terms from Well Package'')')
         WRITE(*,'(''  drn = Flow terms from Drain Package'')')
         WRITE(*,'(''  ghb = Flow terms from '',
     &             ''General Head Boundary Package'')')
         WRITE(*,'(''  evt = Flow terms from '',
     &             ''Evapotranspiration Package'')')
         WRITE(*,'(''  str = Flow terms from '',
     &             ''Streamflow-Routing Package'')')
         WRITE(*,'(''  flo = Streamflow terms from '',
     &             ''Streamflow-Routing Package [flow]'')')
         WRITE(*,'(''  ibs = Storage terms from '',
     &             ''Interbed-Storage Package'')')
         WRITE(*,'(''  arr = Data array gridded like '',
     &             ''those of MODFLOW'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Options menu'')')
         WRITE(*,'(/,''    Enter cell-by-cell term selection:'')')
         READ(*,'(A)',ERR=214,END=9990) ANSWER
         IERROR=0
C
C2Q-----Quitting
C
 214   IF(ANSWER.EQ.' ') GO TO 9990
C
C2E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading tracking option'')')
          GO TO 212
       ENDIF
C
C2P-----Previous menu
C
       IF(ANSWER.EQ.'B' .OR. ANSWER.EQ.'b') THEN
          ANSWER='B'
C
C2H-----Help
C
       ELSE IF(ANSWER (1:3).EQ.'H  ' .OR. ANSWER (1:3).EQ.'h  ') THEN
  216     IERROR=1
          WRITE(*,'(//,
     &              '' Help for selecting of cell-by-cell terms '',
     &              ''from MODFLOW packages'')')
          WRITE(*,'(''-------------------------------------------'',
     &              ''--------------------------'')')
          WRITE(*,'('' <cr> = Quit help'')')
          WRITE(*,'(''  hed = Head terms from '',
     &              ''Basic Package'')')
          WRITE(*,'(''  ddn = Drawdown terms from '',
     &              ''Basic Package'')')
          WRITE(*,'(''  bcf = Terms for flow through '',
     &              ''cell faces from Block-Centered-Flow Package'')')
          WRITE(*,'(''  sto = Storage terms from '',
     &              ''Block-Centered-Flow Package'')')
          WRITE(*,'(''  riv = Flow terms from '',
     &              ''River Package [leakage]'')')
          WRITE(*,'(''  rch = Flow terms from '',
     &              ''Recharge Package'')')
          WRITE(*,'(''  wel = Flow terms from '',
     &              ''Well Package'')')
          WRITE(*,'(''  drn = Flow terms from '',
     &              ''Drain Package'')')
          WRITE(*,'(''  ghb = Flow terms from '',
     &              ''General Head Boundary Package'')')
          WRITE(*,'(''  evt = Flow terms from '',
     &              ''Evapotranspiration Package'')')
          WRITE(*,'(''  str = Flow terms from '',
     &              ''Streamflow-Routing Package'')')
          WRITE(*,'(''  flo = Streamflow terms from '',
     &              ''Streamflow-Routing Package [flow]'')')
          WRITE(*,'(''  ibs = Storage terms from '',
     &              ''Interbed-Storage Package'')')
          WRITE(*,'(''  arr = Miscellaneous model data that are '',
     &              '' gridded like the areal grid of MODFLOW'')')
          WRITE(*,'(''    q = Quit help'')')
          WRITE(*,'(/,''    Enter help selection:'')')
          READ(*,'(A)',ERR=218,END=9990) ANSWER
          IERROR=0
C
C2Hq-----Quitting
C
 218    IF(ANSWER (1:1).EQ.' ') GO TO 212
C
C2He-----Errors
C
        IF(IERROR.NE.0) THEN
           WRITE(*,'(//,'' Error reading help option'')')
           GO TO 216
        ENDIF
C
C2Hq-----Quit help
C
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') THEN
           ANSWER='Q'
C
C2Hr-----Help selection
C
        ELSE IF(ANSWER (1:3).EQ.'hed' .OR. ANSWER (1:3).EQ.'HED') THEN
           WRITE(*,*) 'Response: =-----> hed'
           WRITE(*,*) ' The cell-by-cell head terms are output by the'
           WRITE(*,*) '  Basic Package during a ground-water'
           WRITE(*,*) '  simulation.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  HEAD or HEAD(BINARY) to identify this file in'
           WRITE(*,*) '  the list.'
           WRITE(*,*) ' If the word HEAD is used, MODTOOLS'
           WRITE(*,*) '  needs another file which specifies the format '
           WRITE(*,*) '  of the values of the cell-by-cell simulated '
           WRITE(*,*) '  head. This format-control head file is '
           WRITE(*,*) '  identified by using the word HEAD-CONTROL.'
           WRITE(*,*) '  The format-control file is read by the U2DREL '
           WRITE(*,*) '  utility module of MODFLOW [use intructions '
           WRITE(*,*) '  for the U2DREL module from MODFLOW manual for'
           WRITE(*,*) '  the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, the head terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'ddn' .OR. ANSWER (1:3).EQ.'DDN') THEN
           WRITE(*,*) 'Response: =-----> ddn'
           WRITE(*,*) ' The cell-by-cell drawdown terms output from'
           WRITE(*,*) '  Basic Package during a ground-water'
           WRITE(*,*) '  simulation.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  DRAWDOWN or DRAWDOWN(BINARY) to identify this'
           WRITE(*,*) '  file in the list.'
           WRITE(*,*) ' If the word DRAWDOWN is used, MODTOOLS'
           WRITE(*,*) '  needs another file which specifies the format '
           WRITE(*,*) '  of the values of the cell-by-cell simulated '
           WRITE(*,*) '  head. This format-control head file is '
           WRITE(*,*) '  identified by using the word DRAWDOWN-CONTROL.'
           WRITE(*,*) '  The format-control file is read by the U2DREL '
           WRITE(*,*) '  utility module of MODFLOW [use intructions '
           WRITE(*,*) '  for the U2DREL module from MODFLOW manual for'
           WRITE(*,*) '  the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, the head terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'bcf' .OR. ANSWER (1:3).EQ.'BCF') THEN
           WRITE(*,*) 'Response: =-----> bcf'
           WRITE(*,*) ' The flow terms through cell faces output from'
           WRITE(*,*) '  Block-Centered-Flow Package. The terms are'
           WRITE(*,*) '  flow through the right, front, and lower'
           WRITE(*,*) '  faces.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'sto' .OR. ANSWER (1:3).EQ.'STO') THEN
           WRITE(*,*) 'Response: =-----> sto'
           WRITE(*,*) ' The cell-by-cell storage terms output from'
           WRITE(*,*) '  Block-Centered-Flow Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'riv' .OR. ANSWER (1:3).EQ.'RIV') THEN
           WRITE(*,*) 'Response: =-----> riv'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  River Package.  These values are the river'
           WRITE(*,*) '  leakage for each simulated river cell.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'rch' .OR. ANSWER (1:3).EQ.'RCH') THEN
           WRITE(*,*) 'Response: =-----> rch'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Recharge Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'wel' .OR. ANSWER (1:3).EQ.'WEL') THEN
           WRITE(*,*) 'Response: =-----> wel'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Well Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'drn' .OR. ANSWER (1:3).EQ.'DRN') THEN
           WRITE(*,*) 'Response: =-----> drn'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Drain Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'ghb' .OR. ANSWER (1:3).EQ.'GHB') THEN
           WRITE(*,*) 'Response: =-----> ghb'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  General Head Boundary Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'evt' .OR. ANSWER (1:3).EQ.'EVT') THEN
           WRITE(*,*) 'Response: =-----> evt'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Evapotranspiration Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'str' .OR. ANSWER (1:3).EQ.'STR') THEN
           WRITE(*,*) 'Response: =-----> str'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Streamflow-Routing Package.  These values are'
           WRITE(*,*) '  the cumulative sum of stream leakage for'
           WRITE(*,*) '  each simulated stream cell.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'flo' .OR. ANSWER (1:3).EQ.'FLO') THEN
           WRITE(*,*) 'Response: =-----> flo'
           WRITE(*,*) ' The cell-by-cell streamflow terms output from'
           WRITE(*,*) '  Streamflow-Routing Package.  These values are'
           WRITE(*,*) '  the cumulative sum of streamflow for'
           WRITE(*,*) '  each simulated stream cell.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'ibs' .OR. ANSWER (1:3).EQ.'IBS') THEN
           WRITE(*,*) 'Response: =-----> ibs'
           WRITE(*,*) ' The cell-by-cell interbed-storage terms output'
           WRITE(*,*) '  from Interbed-Storage Package.  These values'
           WRITE(*,*) '  are the volumetric rate of the interbed'
           WRITE(*,*) '  storage for each cell.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'arr' .OR. ANSWER (1:3).EQ.'arr') THEN
           WRITE(*,*) 'Response: =-----> arr'
           WRITE(*,*) ' Miscellaneous gridded model data that are in'
           WRITE(*,*) '  the binary (unformatted) or standard ASCII'
           WRITE(*,*) '  text formats like those of MODFLOW. These'
           WRITE(*,*) '  data must be gridded at the same scale as the'
           WRITE(*,*) '  areal grid of the MODFLOW model (that is,'
           WRITE(*,*) '  NROW x NCOL).'
           WRITE(*,*) ' The user must include the name of the array'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  ARRAY or ARRAY(BINARY) to identify this file'
           WRITE(*,*) '  in the list.'
           WRITE(*,*) ' MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the data array'
           WRITE(*,*) '  This format-control file is identified by '
           WRITE(*,*) '  using the word ARRAY-CONTROL.  '
           WRITE(*,*) '  The format-control file is read by either '
           WRITE(*,*) '  the U2DREL or U3DREL utility modules of '
           WRITE(*,*) '  MODFLOW or MODTOOLS [use intructions from '
           WRITE(*,*) '  MODFLOW manual for the construction of'
           WRITE(*,*) '  this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE
           WRITE(*,*) ' '
           WRITE(*,*) ' =-----> Invalid Response <-----='
           WRITE(*,*) ' '
           GO TO 216
        ENDIF
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 212
C
C2R-----Responses
C
       ELSE
        IF(ANSWER (1:1).EQ.' ') THEN
           WRITE(*,'(//,'' Quitting Modtools now...'')')
           GO TO 9999
        ELSE IF(ANSWER (1:3).EQ.'hed' .OR. ANSWER (1:3).EQ.'HED') THEN
           COVPMR(1)=1
           MODFLG=1
           WRITE(*,'('' ...Cell-by-cell head terms from Basic '', 
     &               ''Package'')')
           MESAGE(1)='CELL-BY-CELL HEAD TERMS FROM BAS PACKAGE'
           IDCNTR=2
        ELSE IF(ANSWER (1:3).EQ.'ddn' .OR. ANSWER (1:3).EQ.'DDN') THEN
           COVPMR(1)=2
           MODFLG=2
           WRITE(*,'('' ...Cell-by-cell drawdown terms from Basic '', 
     &               ''Package'')')
           MESAGE(1)='CELL-BY-CELL DRAWDOWN TERMS FROM BAS PACKAGE'
           IDCNTR=2
        ELSE IF(ANSWER (1:3).EQ.'bcf' .OR. ANSWER (1:3).EQ.'BCF') THEN
           COVPMR(1)=3
           MODFLG=3
           WRITE(*,'('' ...Cell face flow terms from Block-Centered'', 
     &               ''-Flow Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM BCF PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'sto' .OR. ANSWER (1:3).EQ.'STO') THEN
           COVPMR(1)=4
           MODFLG=4
           WRITE(*,'('' ...Storage terms from Block-Centered-Flow '', 
     &               ''Package'')')
           MESAGE(1)='CELL-BY-CELL STORAGE TERMS FROM BCF PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'riv' .OR. ANSWER (1:3).EQ.'RIV') THEN
           COVPMR(1)=5
           MODFLG=5
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''River Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM RIVER PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'rch' .OR. ANSWER (1:3).EQ.'RCH') THEN
           COVPMR(1)=6
           MODFLG=6
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Recharge Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM RECHARGE PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'wel' .OR. ANSWER (1:3).EQ.'WEL') THEN
           COVPMR(1)=7
           MODFLG=7
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Well Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM WELL PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'drn' .OR. ANSWER (1:3).EQ.'DRN') THEN
           COVPMR(1)=8
           MODFLG=8
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Drain Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM DRAIN PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'ghb' .OR. ANSWER (1:3).EQ.'GHB') THEN
           COVPMR(1)=9
           MODFLG=9
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''General Head Boundary Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM GHB PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'evt' .OR. ANSWER (1:3).EQ.'EVT') THEN
           COVPMR(1)=10
           MODFLG=10
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Evapotranspiration Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM EVT PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'str' .OR. ANSWER (1:3).EQ.'STR') THEN
           COVPMR(1)=11
           MODFLG=11
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Streamflow-Routing Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM STR PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'flo' .OR. ANSWER (1:3).EQ.'FLO') THEN
           COVPMR(1)=12
           MODFLG=12
           WRITE(*,'('' ...Streamflow terms from Streamflow-Routing '',
     &               ''Package'')')
           MESAGE(1)='CELL-BY-CELL STREAMFLOW TERMS FROM STR PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'ibs' .OR. ANSWER (1:3).EQ.'IBS') THEN
           COVPMR(1)=13
           MODFLG=13
           WRITE(*,'('' ...Interbed-Storage terms from '',
     &               ''Interbed-Storage Package'')')
           MESAGE(1)='CELL-BY-CELL STORAGE TERMS FROM IBS PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'arr' .OR. ANSWER (1:3).EQ.'ARR') THEN
           COVPMR(1)=14
           MODFLG=14
           WRITE(*,'('' ...Gridded array formatted like those '',
     &               ''of MODFLOW'')')
           MESAGE(1)='GRIDDED ARRAY LIKE THOSE OF MODFLOW'
           IDCNTR=0
        ELSE
           WRITE(*,'(//,'' Error Unavailable choice'')')
           GO TO 212
        ENDIF
       ENDIF
      ENDIF
C
C2O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 100
C
C3----Orientations
C
 300    IVIEW=0
        COVPMR(10)=0
        MESAGE(10)='MAPVIEW ORIENTATION'
      IF(ICOVER.NE.2) IVIEW=-99
C
C3A----Type of orientation
C
      IF(IVIEW.LE.-99) THEN
  302    IERROR=1
         WRITE(*,'(//,'' Select an orientation for the MODTOOLS'',
     &             '' GIS output'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
       IF(ICOVER.LE.5) THEN
          WRITE(*,'(''    m = Mapview'')')
       ELSE IF(ICOVER.EQ.6) THEN
          WRITE(*,'(''    m = Mapview, characteristics for '',
     &              ''all layers will be generated'')')
       ENDIF
       IF(ICOVER.GE.6) THEN
          WRITE(*,'(''    l = Mapview of a user-specified model '',
     &              ''layer'')')
          WRITE(*,'(''    i = Mapview of a user-specified model '',
     &              ''ibound value '')')
          WRITE(*,'(''    u = Mapview of uppermost active cells'')')
       ENDIF
         WRITE(*,'(''    r = Vertical profile view along a row'')')
         WRITE(*,'(''    c = Vertical profile view along a column '')')
       IF(ICOVER.EQ.1 .OR. ICOVER.EQ.5 .OR. ICOVER.EQ.6) THEN
          WRITE(*,'(''    p = Vertical profile view along a '',
     &             ''user-specified particle path'')')
       ENDIF
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Options menu'')')
         WRITE(*,'(/,''    Select an orientation:'')')
         READ(*,'(A)',ERR=304,END=9990) ANSWER
         IERROR=0
C
C3Q-----Quitting
C
 304   IF(ANSWER.EQ.' ') GO TO 9990
C
C3E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading orientation type'')')
          GO TO 302
       ENDIF
C
C3P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C3H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
 306      IERROR=1
          WRITE(*,'(//,'' Help for selecting an orientation'')')
          WRITE(*,'(//,''  for the MODTOOLS GIS output'')')
          WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
          WRITE(*,'('' <cr> = Quit help'')')
          WRITE(*,'(''    m = Mapview'')')
          WRITE(*,'(''    l = Mapview of a user-specified model '',
     &              ''layer'')')
          WRITE(*,'(''    i = Mapview of a user-specified model '',
     &              ''ibound value '')')
          WRITE(*,'(''    u = Mapview of uppermost active cells'')')
          WRITE(*,'(''    r = Vertical profile view along a row'')')
          WRITE(*,'(''    c = Vertical profile view along a column '')')
          WRITE(*,'(''    p = Vertical profile view along a '',
     &              ''user-specified particle path'')')
          WRITE(*,'(/,''    Enter help selection:'')')
          READ(*,'(A)',ERR=308,END=9990) ANSWER
          IERROR=0
C
C3Hq-----Quitting
C
 308    IF(ANSWER (1:1).EQ.' ') GO TO 302
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 302
C
C3He-----Errors
C
        IF(IERROR.NE.0) THEN
           WRITE(*,'(//,'' Error reading orientation type'')')
           GO TO 302
        ENDIF
C
C3Hr-----Help selection
C
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know what type of',
     &               ' orientation will be used.'
          WRITE(*,*) ' '
        IF(ANSWER (1:1).EQ.'m' .OR. ANSWER (1:1).EQ.'M') THEN
          WRITE(*,*) 'Response: =----->  m'
          WRITE(*,*) ' A mapview orientation along the x-y plane'
          WRITE(*,*) '  of the model grid used by MODPATH.'
          WRITE(*,*) '  For cell-by-cell terms, this selection'
          WRITE(*,*) '  results in an Info file containing values'
          WRITE(*,*) '  for cells in all layers'
        ELSE IF(ANSWER (1:1).EQ.'l' .OR. ANSWER (1:1).EQ.'L') THEN
          WRITE(*,*) 'Response: =----->  l'
          WRITE(*,*) ' A mapview orientation for the user-specified'
          WRITE(*,*) '  model grid layer used by MODPATH.  The user'
          WRITE(*,*) '  will be ask to specify a desired model layer.'
        ELSE IF(ANSWER (1:1).EQ.'i' .OR. ANSWER (1:1).EQ.'I') THEN
          WRITE(*,*) 'Response: =----->  i'
          WRITE(*,*) ' A mapview orientation for the user-specified'
          WRITE(*,*) '  ibound value used by MODPATH.  The user'
          WRITE(*,*) '  will be ask to specify a desired ibound value.'
        ELSE IF(ANSWER (1:1).EQ.'u' .OR. ANSWER (1:1).EQ.'U') THEN
          WRITE(*,*) 'Response: =----->  u'
          WRITE(*,*) ' A mapview orientation using the uppermost'
          WRITE(*,*) '  active cell in the model grid used by MODPATH.'
        ELSE IF(ANSWER (1:1).EQ.'r' .OR. ANSWER (1:1).EQ.'R') THEN
          WRITE(*,*) 'Response: =----->  r'
          WRITE(*,*) ' A vertical row orientation along the'
          WRITE(*,*) '  row direction of the model grid used by'
          WRITE(*,*) '  MODPATH.  The user will be ask to specify a'
          WRITE(*,*) '  desired row.'
        ELSE IF(ANSWER (1:1).EQ.'c' .OR. ANSWER (1:1).EQ.'C') THEN
          WRITE(*,*) 'Response: =----->  c'
          WRITE(*,*) ' A vertical column orientation along the'
          WRITE(*,*) '  column direction of the model grid used by'
          WRITE(*,*) '  MODPATH.  The user will be ask to specify a'
          WRITE(*,*) '  desired column.'
        ELSE IF(ANSWER (1:1).EQ.'p' .OR. ANSWER (1:1).EQ.'P') THEN
          WRITE(*,*) 'Response: =----->  p'
          WRITE(*,*) ' A particle pathline orientation along'
          WRITE(*,*) '  a particle pathline using data from the'
          WRITE(*,*) '  PATHLINE file output after a simulation by'
          WRITE(*,*) '  MODPATH.  The user will be ask to specify a'
          WRITE(*,*) '  desired particle id.'
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  file in MODTOOLS name file and use the word '
          WRITE(*,*) '  PATHLINE to identify this file in the list.'
       ELSE
          WRITE(*,*) ' '
          WRITE(*,*) ' =-----> Invalid Response <-----='
          WRITE(*,*) ' '
          GO TO 306
       ENDIF
         WRITE(*,*) 'Continue?'
         READ(*,'(A)') ANSWER
         GO TO 302
C
C3R-----Responses
C
       ELSE
        IF(ANSWER (1:1).EQ.' ') THEN
           WRITE(*,'(//,'' Quitting Modtools now...'')')
           GO TO 9999
        ELSE IF(ANSWER (1:1).EQ.'m' .OR. ANSWER (1:1).EQ.'M') THEN
           IVIEW=0
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Map view orientation'')')
           MESAGE(10)='MAPVIEW ORIENTATION'
           MESAGE(11)='UNUSED FOR MAPVIEW ORIENTATION'
        ELSE IF(ANSWER (1:1).EQ.'r' .OR. ANSWER (1:1).EQ.'R') THEN
           IVIEW=1
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Row vertical profile orientation'')')
           MESAGE(10)='ROW TRAVERSE ORIENTATION'
           MESAGE(11)='ROW; TRAVERSE ALONG ROW DIRECTION'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'c' .OR. ANSWER (1:1).EQ.'C') THEN
           IVIEW=2
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Column vertical profile orientation'')')
           MESAGE(10)='COLUMN TRAVERSE ORIENTATION'
           MESAGE(11)='COLUMN; TRAVERSE ALONG COLUMN DIRECTION'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'p' .OR. ANSWER (1:1).EQ.'P') THEN
           IVIEW=3
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Particle vertical profile orientation'')')
           MESAGE(10)='PARTICLE PATHLINE ORIENTATION'
           MESAGE(11)='PARTICLE; TRAVERSE ALONG PARTICLE DIRECTION'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'l' .OR. ANSWER (1:1).EQ.'L') THEN
           IVIEW=4
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Model layer orientation'')')
           MESAGE(10)='MODEL LAYER MAPVIEW ORIENTATION'
           MESAGE(11)='SINGLE MODEL LAYER MAPVIEW'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'i' .OR. ANSWER (1:1).EQ.'I') THEN
           IVIEW=5
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Model ibound value orientation'')')
           MESAGE(10)='MODEL IBOUND VALUE MAPVIEW ORIENTATION'
           MESAGE(11)='SINGLE MODEL IBOUND VALUE MAPVIEW'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'u' .OR. ANSWER (1:1).EQ.'U') THEN
           IVIEW=6
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Model all ibound values orientation'')')
           MESAGE(10)='MODEL ACTIVE IBOUND VALUES MAPVIEW ORIENTATION'
           MESAGE(11)='UPPERMOST ACTIVE MODEL IBOUND VALUES'
           IRWCL=99
        ELSE
           WRITE(*,'(//,'' Invalid response try again'')')
           GO TO 302
        ENDIF
       ENDIF
      ENDIF
C
C3O-----Back option
C
      IF(ANSWER (1:1).EQ.'B' .AND. ICOVER.EQ.2) GO TO 200
      IF(ANSWER (1:1).EQ.'B' .AND. ICOVER.EQ.6) GO TO 200
      IF(ANSWER (1:1).EQ.'B') GO TO 100
C
C4----Set X-Y conversion factor
C
 400   COVPMR(3)=1.0
       MESAGE(3)='NO X-Y CONVERSION FACTOR USED'
       IFLAG3=0
      IF(ICOVER.EQ.1) IFLAG3=1
      IF(ICOVER.EQ.2) IFLAG3=1
      IF(ICOVER.EQ.3) IFLAG3=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG3=1
      IF(ICOVER.EQ.5) IFLAG3=1
      IF(ICOVER.EQ.6 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG3=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG3=1
      IF(ICOVER.EQ.8) IFLAG3=1
C
C4A----X-Y conversion factor
C
      IF(IFLAG3.GT.0) THEN
  402    IERROR=1
         WRITE(*,'(//,
     &             '' X,Y coordinate conversion'')')
         WRITE(*,'(''  Select option to convert from model '',
     &             ''units to GIS length units.'')')
         WRITE(*,'(''   (Note: For vertical profile orientations,'',
     &             '' MODTOOLS requires'')')
         WRITE(*,'(''   coordinates in units of feet).'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    1 = Feet to meters'')')
         WRITE(*,'(''    2 = Meters to feet'')')
         WRITE(*,'(''    User-specified multiplication factor'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''    Enter option:'')')
         READ(*,'(A)',ERR=404,END=9990) ANSWER
         IERROR=0
C
C4Q-----Quitting
C
 404     IF(ANSWER.EQ.' ') GO TO 9990
C
C4E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading x,y conversion factor'')')
          GO TO 402
       ENDIF
C
C4P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C4H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to translate'
          WRITE(*,*) ' the particle or cell x-y coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should translate particle and '
          WRITE(*,*) ' cell coordinates into feet to ensure proper'
          WRITE(*,*) ' scaling, when using a vertical orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)',ERR=404) ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 402
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 402
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) ' The particle or cell x-y coordinates remain '
          WRITE(*,*) '  in MODPATH coordinate system. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)',ERR=404) ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 402
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 402
          WRITE(*,*) 'Response: =----->  1'
          WRITE(*,*) ' The particle or cell x-y coordinates are '
          WRITE(*,*) '  translated from feet to meters.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)',ERR=404) ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 402
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 402
          WRITE(*,*) 'Response: =----->  2'
          WRITE(*,*) ' The particle or cell x-y coordinates are '
          WRITE(*,*) '  translated from meters to feet.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 402
C
C4R-----Responses
C
       ELSE
          READ(ANSWER,*,ERR=404,END=9990) CONVRT
        IF(CONVRT.EQ.-999.0) THEN
           WRITE(*,'(//,'' Quitting Modtools now...'')')
           GO TO 9999
        ELSE IF(CONVRT.EQ.0.0) THEN
           COVPMR(3)=1.0
           MESAGE(3)='NO X-Y COORDINATE CONVERSION FACTOR'
        ELSE IF(CONVRT.EQ.1.0) THEN
           COVPMR(3)=0.3048
           MESAGE(3)='X-Y COORDINATES FROM FEET TO METERS'
        ELSE IF(CONVRT.EQ.2.0) THEN
           COVPMR(3)=3.28
           MESAGE(3)='X-Y COORDINATES FROM METERS TO FEET'
        ELSE IF(CONVRT.LT.0.0 .AND. CONVRT.NE.-999.0) THEN
          WRITE(*,'(//,'' Negative multiplier not valid'')')
          GO TO 402
        ELSE
           COVPMR(3)=CONVRT
           MESAGE(3)='USER SPECIFIED X-Y COORDINATE CONVERSION FACTOR'
        ENDIF
       ENDIF
      ENDIF
C
C4O-----Back option
C
      IF(ANSWER (1:1).EQ.'B' .AND. ICOVER.EQ.2) GO TO 200
      IF(ANSWER (1:1).EQ.'B') GO TO 300
C
C5------Z conversion factor
C
 500    COVPMR(4)=1.0
        MESAGE(4)='NO Z CONVERSION FACTOR USED'
        IFLAG4=0
      IF(ICOVER.EQ.1) IFLAG4=1
      IF(ICOVER.EQ.2) IFLAG4=1
      IF(ICOVER.EQ.3) IFLAG4=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG4=1
      IF(ICOVER.EQ.5) IFLAG4=1
      IF(ICOVER.EQ.6 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG4=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG4=1
      IF(ICOVER.EQ.8) IFLAG4=1
C
C5A------Set z conversion
C
      IF(IFLAG4.GT.0) THEN
  502    IERROR=1
         WRITE(*,'(//,'' Z coordinate conversion'')')
         WRITE(*,'(''  Select option to convert from model '',
     &             ''units to GIS length units.'')')
         WRITE(*,'(''   (Note: For vertical profile orientations,'',
     &             '' MODTOOLS requires'')')
         WRITE(*,'(''   coordinates in units of feet).'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    1 = Feet to meters'')')
         WRITE(*,'(''    2 = Meters to feet'')')
         WRITE(*,'(''    User-specified multiplication factor'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''    Enter option:'')')
         READ(*,'(A)',ERR=504,END=9990) ANSWER
         IERROR=0
C
C5Q-----Quitting
C
 504   IF(ANSWER.EQ.' ') GO TO 9990
C
C5E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading z conversion factor'')')
          GO TO 502
       ENDIF
C
C5P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C5H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to translate'
          WRITE(*,*) ' the particle or cell z coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should translate particle and '
          WRITE(*,*) ' cell coordinates into feet to ensure proper'
          WRITE(*,*) ' scaling, when using a vertical orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 502
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 502
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) 'The particle or cell z coordinates remain '
          WRITE(*,*) ' in MODPATH coordinate system. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 502
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 502
          WRITE(*,*) 'Response: =----->  1'
          WRITE(*,*) ' The particle or cell z coordinates are '
          WRITE(*,*) '  translated from feet to meters.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 502
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 502
          WRITE(*,*) 'Response: =----->  2'
          WRITE(*,*) ' The particle or cell z coordinates are '
          WRITE(*,*) '  translated from meters to feet.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 502
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 502
          GO TO 502
C
C5R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=504,END=9990) CONVRT
        IF(CONVRT.EQ.0.0) THEN
           COVPMR(4)=1.0
           MESAGE(4)='NO Z COORDINATE CONVERSION FACTOR'
        ELSE IF(CONVRT.EQ.1.0) THEN
           COVPMR(4)=0.3048
           MESAGE(4)='Z COORDINATES FROM FEET TO METERS'
        ELSE IF(CONVRT.EQ.2.0) THEN
           COVPMR(4)=3.28
           MESAGE(4)='Z COORDINATES FROM METERS TO FEET'
        ELSE
           COVPMR(4)=CONVRT
           MESAGE(4)='USER SPECIFIED Z COORDINATE CONVERSION FACTOR'
        ENDIF
       ENDIF
      ENDIF
C
C5O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 400
C
C6------Counterclockwise rotation angle
C
 600   COVPMR(5)=0.0
       MESAGE(5)='NO ROTATION AROUND MODFLOW ORIGIN'
       IFLAG5=0
      IF(ICOVER.EQ.1 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.2 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.3 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.5 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG5=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG5=1
C
C6A------Set counterclockwise rotation angle
C
      IF(IFLAG5.GT.0) THEN
 602     IERROR=1
         WRITE(*,'(//,'' Counterclockwise rotation angle '',
     &                ''around MODFLOW origin'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    User-specified rotation angle'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''   Enter clockwise rotation angle:'')')
         READ(*,'(A)',ERR=604,END=9990) ANSWER
         IERROR=0
C
C6Q-----Quitting
C
 604   IF(ANSWER.EQ.' ') GO TO 9990
C
C6H-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading rotation angle'')')
          GO TO 602
       ENDIF
C
C6P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C6H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to rotate'
          WRITE(*,*) ' the particle or cell x-y coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should rotate particle and '
          WRITE(*,*) ' cell coordinates to ensure proper'
          WRITE(*,*) ' alignment with the model grid system, when'
          WRITE(*,*) ' using a mapview orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 602
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 602
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) ' The particle or cell x-y coordinates are not '
          WRITE(*,*) '  rotated. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 602
C
C6R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=604,END=9990) COVPMR(5)
        IF(COVPMR(5).GT.0.) THEN
          MESAGE(5)='ANGLE COUNTERCLOCKWISE ROTATION '//
     &              'AROUND MODFLOW ORIGIN'
        ELSE IF(COVPMR(5).EQ.0.) THEN
          MESAGE(5)='NO ROTATION '//
     &              'AROUND MODFLOW ORIGIN'
        ELSE
          MESAGE(5)='ANGLE CLOCKWISE ROTATION '//
     &              'AROUND MODFLOW ORIGIN'
        ENDIF
       ENDIF
      ENDIF
C
C6O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 500
C
C7------Coverage x_origin
C
 700   COVPMR(6)=0.0
       MESAGE(6)='NO X ORIGIN FOR MODFLOW GRID'
       IFLAG6=0
      IF(ICOVER.EQ.1 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.2 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.3 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.5 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG6=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG6=1
C
C7A------Set x_origin
C
      IF(IFLAG6.GT.0) THEN
 702     IERROR=1
         WRITE(*,'(//,'' X-origin of MODFLOW grid'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    User-specified X-origin coordinate'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''   Enter x_origin:'')')
         READ(*,'(A)',ERR=704,END=9990) ANSWER
         IERROR=0
C
C7Q-----Quitting
C
 704   IF(ANSWER.EQ.' ') GO TO 9990
C
C7E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'('' Error reading x origin value '')')
          GO TO 702
       ENDIF
C
C7P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C7H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to translate'
          WRITE(*,*) ' the particle or cell x-y coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should translate particle and '
          WRITE(*,*) ' cell coordinates to ensure proper'
          WRITE(*,*) ' alignment with the model grid system, when'
          WRITE(*,*) ' using a mapview orientation.  The x origin is'
          WRITE(*,*) ' the upper left corner of cell row 1, column 1.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 702
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 702
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) ' The particle or cell x coordinates are not '
          WRITE(*,*) '  translated. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 702
C
C7R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=704,END=9990) COVPMR(6)
          MESAGE(6)='X ORIGIN OF MODFLOW GRID'
       ENDIF
      ENDIF
C
C7O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 600
C
C8------Coverage y_origin
C
 800    COVPMR(7)=0.0
        MESAGE(7)='NO Y ORIGIN FOR MODFLOW GRID'
        IFLAG7=0
      IF(ICOVER.EQ.1 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.2 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.3 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.5 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG7=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG7=1
C
C8A------Set y_origin
C
      IF(IFLAG7.GT.0) THEN
  802    IERROR=1
         WRITE(*,'(/,'' Y-origin of MODFLOW grid'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    User-specified Y-origin coordinate'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''   Enter y_origin: '')')
         READ(*,'(A)',ERR=804,END=9990) ANSWER
         IERROR=0
C
C8Q-----Quitting
C
 804   IF(ANSWER.EQ.' ') GO TO 9990
C
C8E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading y origin value'')')
          GO TO 802
       ENDIF
C
C8P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C8H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to translate'
          WRITE(*,*) ' the particle or cell x-y coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should translate particle and '
          WRITE(*,*) ' cell coordinates to ensure proper'
          WRITE(*,*) ' alignment with the model grid system, when'
          WRITE(*,*) ' using a mapview orientation.  The y origin is'
          WRITE(*,*) ' the upper left corner of cell row 1, column 1.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 802
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 802
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) ' The particle or cell y coordinates are not '
          WRITE(*,*) '  translated. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 802
C
C8R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=804,END=9990) COVPMR(7)
          MESAGE(7)='Y ORIGIN OF MODFLOW GRID'
       ENDIF
      ENDIF
C
C8O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 700
C
C9----Vertical Exaggeration
C
 900    COVPMR(8)=1.0
        MESAGE(8)='NO VERTICAL EXAGGERATION'
        IFLAG8=0
      IF(ICOVER.EQ.1 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.2 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.3 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.4 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.5 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.6 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
C
C9A----Set Exaggeration
C
      IF(IFLAG8.GT.0) THEN
  902    IERROR=1
         WRITE(*,'(//,'' Enter vertical exaggeration '')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified vertical exaggeration '',
     &             ''factor'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter vertical exaggeration '',
     &             ''1 foot = n feet:'')')
         READ(*,'(A)',ERR=904,END=9990) ANSWER
         IERROR=0
C
C9Q-----Quitting
C
 904   IF(ANSWER.EQ.' ') GO TO 9990
C
C9E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading vertical exaggeration'')')
          GO TO 902
       ENDIF
C
C9P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C9H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to exaggerate'
          WRITE(*,*) ' the particle or cell z coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: Also, the value for the horizontal scale'
          WRITE(*,*) ' will be used to ensure proper exaggeration,'
          WRITE(*,*) ' when using a vertical orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 902
C
C9R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=904,END=9990) VSCALE
        IF(VSCALE.LT.0.0) THEN
           WRITE(*,'(//,'' Invalid response'',F20.10)') VSCALE
           GO TO 902
        ELSE IF(VSCALE.EQ.0.0) THEN
           VSCALE=1.0
           WRITE(*,'('' ...Vertical Scale 1 foot = '',
     &               F20.10,'' feet'')')
     &             VSCALE
           COVPMR(8)=VSCALE
           MESAGE(8)='NO VERTICAL EXAGGERATION'
        ELSE
           WRITE(*,'('' ...Vertical Scale 1 foot = '',
     &               F20.10,'' feet'')')
     &             VSCALE
           COVPMR(8)=VSCALE
           MESAGE(8)='VERTICAL EXAGGERATION'
        ENDIF
       ENDIF
      ENDIF
C
C9O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 500
C
C10----Horizontal Scale
C
 1000   COVPMR(9)=1.0
        MESAGE(9)='NO HORIZONTAL MAPSCALE'
        IFLAG9=0
      IF(ICOVER.EQ.1 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.2 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.3 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.4 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.5 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.6 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
C
C10A----Set scale
C
      IF(IFLAG9.GT.0) THEN
 1002    IERROR=1
         WRITE(*,'(//,'' Enter horizontal mapscale'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified horizontal mapscale'')')
         WRITE(*,'(''    h = Help '')')
         WRITE(*,'(''    b = Back to Vertical Exaggeration menu'')')
         WRITE(*,'(//,'' Enter horizontal mapscale 1 foot = n feet:'')')
         READ(*,'(A)',ERR=1004,END=9990) ANSWER
         IERROR=0
C
C10Q-----Quitting
C
 1004  IF(ANSWER.EQ.' ') GO TO 9990
C
C10E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading horizontal mapscale'')')
          GO TO 1002
       ENDIF
C
C10P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C10H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to scale'
          WRITE(*,*) ' the particle or cell coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: To ensure proper scaling, translate'
          WRITE(*,*) ' particle or cell coordinates into feet,'
          WRITE(*,*) ' when using a vertical orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1002
C
C10R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1004,END=9990) HSCALE
        IF(HSCALE.LT.0.0) THEN
           WRITE(*,'(//,'' Invalid response'',F20.10)') HSCALE
           GO TO 1002
        ELSE IF(HSCALE.EQ.0.0) THEN
           HSCALE=1.0
           WRITE(*,'('' ...Horizontal Scale 1 foot = '',F20.10,
     &               '' feet'')')
     &             HSCALE
           COVPMR(9)=HSCALE
           MESAGE(9)='NO HORIZONTAL MAPSCALE'
        ELSE
           WRITE(*,'('' ...Horizontal Scale 1 foot = '',F20.10,
     &               '' feet'')')
     &             HSCALE
           COVPMR(9)=HSCALE
           MESAGE(9)='HORIZONTAL MAPSCALE'
        ENDIF
       ENDIF
      ENDIF
C
C10O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 900
C
C11----What row or column or particle or model layer or ibound value to draw
C
 1100 IRWCL=0
      MESAGE(11)='UNUSED FOR MAPVIEW ORIENTATION'
C
C11A----Set row or column or particle or model layer or ibound value
C
      IF(IVIEW.GE.1 .AND. IVIEW.LE.5) THEN
 1102    IERROR=1
       IF(IVIEW.LE.0) THEN
          WRITE(*,'(/,'' Enter number of layer to view '')')
          MESAGE(11)='LAYER'
       ELSE IF(IVIEW.EQ.1) THEN
          WRITE(*,'(/,'' Enter number of row to view '')')
          MESAGE(11)='ROW'
       ELSE IF(IVIEW.EQ.2) THEN
          WRITE(*,'(/,'' Enter number of column to view '')')
          MESAGE(11)='COLUMN'
       ELSE IF(IVIEW.EQ.3) THEN
          WRITE(*,'(/,'' Enter number of particle-id to view '')')
          MESAGE(11)='PARTICLE-ID'
       ELSE IF(IVIEW.EQ.4) THEN
          WRITE(*,'(/,'' Enter number of model layer to view '')')
          MESAGE(11)='LAYER'
       ELSE
          WRITE(*,'(/,'' Enter number of model ibound '',
     &              ''value to view'')')
          MESAGE(11)='IBOUND VALUE'
       ENDIF
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified selection'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''   Enter selection:'')')
         READ(*,'(A)',ERR=1102,END=9990) ANSWER
         IERROR=0
C
C11Q-----Quitting
C
 1104  IF(ANSWER.EQ.' ') GO TO 9990
C
C11E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error row or column or layer or '',
     &              ''particle number or ibound value invalid'')')
          GO TO 1102
       ENDIF
C
C11P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C11H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know what row, column,',
     &               ' particle, layer or ibound value will be used.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1102
C
C11R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1104,END=9990) IRWCL
          COVPMR(11)=IRWCL
         IF(IRWCL.LE.0) THEN
            WRITE(*,'(/,'' Invalid response must be greater than 0'')')
             GO TO 1102
         ELSE
          IF(IVIEW.EQ.0 .OR. IVIEW.EQ.4) THEN
           IF(IRWCL.GT.NLAY) THEN
              WRITE(*,'(/,'' Invalid response pick between 0 and '',
     &                  I10)')
     &                 NLAY
              GO TO 1102
           ELSE
              WRITE(*,'('' ...Mapview using layer '',I10)')
     &                IRWCL
           ENDIF
          ELSE IF(IVIEW.EQ.1) THEN
           IF(IRWCL.GT.NROW) THEN
              WRITE(*,'(/,'' Invalid response pick between 0 and '',
     &                  I10)')
     &                 NROW
              GO TO 1102
           ELSE
              WRITE(*,'('' ...Row vertical profile using row '',I10)')
     &                IRWCL
           ENDIF
          ELSE IF(IVIEW.EQ.2) THEN
           IF(IRWCL.GT.NCOL) THEN
              WRITE(*,'(/,'' Invalid response pick between 0 and '',
     &                  I10)')
     &                 NCOL
              GO TO 1102
           ELSE
              WRITE(*,'('' ...Column vertical profile using column '',
     &                  I10)')
     &                IRWCL
           ENDIF
          ELSE IF(IVIEW.EQ.3) THEN
             WRITE(*,'('' ...Particle vertical profile using '',
     &                 ''particle-id '',I10)')
     &               IRWCL
          ELSE
             WRITE(*,'('' ...Mapview using ibound = '',I10)')
     &               IRWCL
          ENDIF
        ENDIF
       ENDIF
      ENDIF
C
C11O-----Back option
C
      IF(ANSWER (1:1).EQ.'B' .AND. IVIEW.LE.0) GO TO 800
      IF(ANSWER (1:1).EQ.'B' .AND. IVIEW.GE.4) GO TO 800
      IF(ANSWER (1:1).EQ.'B') GO TO 1000
C
C12----Dimension of gridded data
C
       MODFLG=INT(COVPMR(1))
       COVPMR(12)=0
       MESAGE(12)='NO GRIDDED DATA'
       IFLAG12=0
      IF(ICOVER.EQ.7) THEN
         IDCNTR=2+100*MODFLG
         COVPMR(12)=IDCNTR
       IF(MODFLG.EQ.14) IFLAG12=1
      ENDIF
      IF(ICOVER.EQ.6 .AND. MODFLG.EQ.14) IFLAG12=1
C
C12A----Set dimension
C
      IF(IFLAG12.GT.0) THEN
 1202    IERROR=1
         WRITE(*,'(//,'' Enter dimension of the gridded model data'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    2 = Two-dimensional array'')')
         WRITE(*,'(''    3 = Three-dimensional array'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter dimension of gridded data:'')')
         READ(*,'(A)',ERR=1204,END=9990) ANSWER
         IERROR=0
C
C12Q-----Quitting
C
 1204  IF(ANSWER.EQ.' ') GO TO 9990
C
C12E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading '',
     &                ''dimension of gridded data'')')
          GO TO 1202
       ENDIF
C
C12H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know the format of the data'
          WRITE(*,*) ' array so the proper utility reading module'
          WRITE(*,*) ' will be used'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 1202
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 1202
          WRITE(*,*) 'Response: =----->  2'
          WRITE(*,*) ' Utility ULASAV of MODFLOW produces 2D'
          WRITE(*,*) '  data (records simulated head or drawdown'
          WRITE(*,*) '  for each layer with a character string header'
          WRITE(*,*) '  followed by the simulated values for that.'
          WRITE(*,*) '  layer). MODTOOLS will use the MODFLOW utility'
          WRITE(*,*) '  module U2DREL to read the gridded data'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 1202
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 1202
          WRITE(*,*) 'Response: =----->  3'
          WRITE(*,*) ' Utility UBUDSV of MODFLOW produces 3D'
          WRITE(*,*) '  data (records simulated cell budget or flow'
          WRITE(*,*) '  terms with a character string header followed'
          WRITE(*,*) '  by the terms for all layer).'
          WRITE(*,*) '  MODTOOLS will use the MODTOOLS utility'
          WRITE(*,*) '  module U3DREL to read the gridded data'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1202
C
C12R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1204,END=9990) IDCNTR
        IF(IDCNTR.LT.2 .AND. IDCNTR.GT.4 ) THEN
           WRITE(*,'(//,'' Invalid response'',I10)') IDCNTR
           GO TO 1202
        ELSE IF(IDCNTR.EQ.2) THEN
           IDCNTR=2+100*MODFLG
           WRITE(*,'('' ...2-D Data Array'')')
           COVPMR(12)=IDCNTR
           MESAGE(12)='2-D DATA ARRAY'
        ELSE
           IDCNTR=3+100*MODFLG
           WRITE(*,'('' ...3-D Data Array'')')
           COVPMR(12)=IDCNTR
           MESAGE(12)='3-D DATA ARRAY'
        ENDIF
       ENDIF
      ENDIF
C
C12O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C12A----Set flow-vector multiplier
C
      IF(ICOVER.EQ.8) THEN
 1206    IERROR=1
         WRITE(*,'(//,'' Enter scaling factor for length of '',
     &                ''flow vector'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    n > 0 - arithmetic scaling'')')
         WRITE(*,'(''    n = 0 - no scaling'')')
         WRITE(*,'(''    n < 0 - logarithmetic scaling'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter scaling factor:'')')
         READ(*,'(A)',ERR=1208,END=9990) ANSWER
         IERROR=0
C
C12Q-----Quitting
C
 1208  IF(ANSWER.EQ.' ') GO TO 9990
C
C12E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading scaling factor'')')
          GO TO 1206
       ENDIF
C
C12H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to scale ',
     &               'the length of flow vector'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1206
C
C12R-----Responses
C
       ELSE
          READ(ANSWER,*,ERR=1208,END=9990) VECSCL
        IF(VECSCL.LE.0.0) THEN
           WRITE(*,'(//,
     &               '' Logarithmetic scaling for length of ''
     &               ''velocity vectors'')')
           COVPMR(12)=VECSCL
           MESAGE(12)='LOGARITHMETIC SCALING'
        ELSE IF(VECSCL.EQ.0.0) THEN
           WRITE(*,'(//,
     &               '' Scaling factor set to one for length of ''
     &               ''velocity vectors'')')
           COVPMR(12)=VECSCL
           MESAGE(12)='SCALING FACTOR SET TO 1'
        ELSE
           WRITE(*,'(//,
     &               '' Arithmetic scaling for length of ''
     &               ''velocity vectors'')')
           COVPMR(12)=VECSCL
           MESAGE(12)='ARITHMETIC SCALING'
        ENDIF
       ENDIF
      ENDIF
C
C12O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C13----Contour interval
C
      COVPMR(13)=0
      MESAGE(13)='NO CONTOUR INTERVAL OR MODFLOW STRESS PERIOD'
C
C13A----Set interval
C
      IF(ICOVER.EQ.7) THEN
 1302    IERROR=1
         WRITE(*,'(//,'' Enter contour interval '')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified contour interval'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter contour interval:'')')
         READ(*,'(A)',ERR=1304,END=9990) ANSWER
         IERROR=0
C
C13Q-----Quitting
C
 1304  IF(ANSWER.EQ.' ') GO TO 9990
C
C13E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading contour interval'')')
          GO TO 1302
       ENDIF
C
C13H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know what contour ',
     &               'interval value will be used.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1302
C
C13R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1304,END=9990) CNTINT
        IF(CNTINT.LE.0.0) THEN
           WRITE(*,'(//,'' Invalid response'',F20.10)') CNTINT
           GO TO 1302
        ELSE
           WRITE(*,'('' ...Contour interval = '',F20.10)')
     &             CNTINT
           COVPMR(1)=CNTINT
           MESAGE(12)=MESAGE(1)
           MESAGE(1)='CONTOUR INTERVAL'
        ENDIF
       ENDIF
      ENDIF
C
C13O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C13A----MODFLOW stress period
C
        IFLAG13=0
      IF(ICOVER.EQ.6) IFLAG13=1
      IF(ICOVER.EQ.7) IFLAG13=1
      IF(ICOVER.EQ.8) IFLAG13=1
      IF(IFLAG13.GT.0) THEN
        COVPMR(13)=0
        MESAGE(13)='NO MODFLOW STRESS PERIOD'
      ENDIF
C
C13A---Set MODFLOW stress period
C
      IF(IFLAG13.GT.0 .AND. NPER.LE.0) THEN
         MODPER=1
         WRITE(*,'('' ...MODFLOW stress period = '',I10)')
     &             MODPER
         COVPMR(13)=MODPER
         MESAGE(13)='MODFLOW STRESS PERIOD'
      ELSE IF(IFLAG13.GT.0 .AND. NPER.GT.0) THEN
 1310    IERROR=1
         WRITE(*,'(//,'' Enter stress period number for '',
     &             ''the cell-by-cell terms'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified stress period'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter stress period number:'')')
         READ(*,'(A)',ERR=1312,END=9990) ANSWER
         IERROR=0
C
C13Q-----Quitting
C
 1312  IF(ANSWER.EQ.' ') GO TO 9990
C
C13E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading stress period'')')
          GO TO 1310
       ENDIF
C
C13H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know stress period number for ',
     &               ' the cell-by-cell terms'
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS uses this number to select the proper'
          WRITE(*,*) ' cell-by-cell terms output by MODFLOW at'
          WRITE(*,*) ' the specified stress period of '
          WRITE(*,*) ' a ground-water simulation'
          WRITE(*,*) 'MODFLOW outputs cell-by-cell terms for '
          WRITE(*,*) ' stress periods at time steps specified'
          WRITE(*,*) ' by the user.'
          READ(*,'(A)') ANSWER
          WRITE(*,*) 'Continue?'
          GO TO 1310
C
C13R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1312,END=9990) MODPER
        IF(MODPER.LT.0) THEN
           WRITE(*,'(//,'' Invalid response'',I10)') MODPER
           GO TO 1310
        ELSE
           WRITE(*,'('' ...Stress period = '',I10)')
     &             MODPER
           COVPMR(13)=MODPER
           MESAGE(13)='MODFLOW STRESS PERIOD'
        ENDIF
       ENDIF
      ENDIF
C
C13O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 300
C
C14---Degree interval
C
      COVPMR(14)=0
      MESAGE(14)='NO SECTORS FOR DELINEATING ZONES OF TRANSPORT'
      NUMARC=0
C
C14A---Set degree
C
      IF(ICOVER.EQ.4) THEN
 1402    IERROR=1
         WRITE(*,'(//,'' Enter number of sectors used to '',
     &                ''delineate zones of transport'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified number of sectors'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter number of sectors:'')')
         READ(*,'(A)',ERR=1404,END=9990) ANSWER
         IERROR=0
C
C14Q-----Quitting
C
 1404  IF(ANSWER.EQ.' ') GO TO 9990
C
C14E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading number of equal arcs'')')
          GO TO 1402
       ENDIF
C
C14H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know the number of equal',
     &               ' arcs will be used.'
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS uses this number to compute the'
          WRITE(*,*) ' vertices of a polygon which represents a'
          WRITE(*,*) ' specified time-of-travel in a MODPATH analysis'
          WRITE(*,*) ' using the time-series option. A computer'
          WRITE(*,*) ' algorithm calculates a point that is '
          WRITE(*,*) ' representative of a group of particles.'
          WRITE(*,*) ' The user should vary the number of equal arcs'
          WRITE(*,*) ' until the best results are obtained.'
          READ(*,'(A)') ANSWER
          WRITE(*,*) 'Continue?'
          GO TO 1402
C
C14R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1404,END=9990) NUMARC
        IF(NUMARC.LE.0.0) THEN
           WRITE(*,'(//,'' Invalid response'',I10)') NUMARC
           GO TO 1402
        ELSE
           WRITE(*,'('' ...Number of sectors = '',I10)')
     &             NUMARC
           COVPMR(14)=NUMARC
           MESAGE(14)='NUMBER OF SECTORS FOR DELINEATING ZOT'
        ENDIF
       ENDIF
      ENDIF
C
C14O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C14A---MODFLOW time step
C
        IFLAG14=0
      IF(ICOVER.EQ.6) IFLAG14=1
      IF(ICOVER.EQ.7) IFLAG14=1
      IF(ICOVER.EQ.8) IFLAG14=1
C
C14A---Set MODFLOW time step
C
      IF(IFLAG14.GT.0 .AND. NPER.EQ.0) THEN
         MODSTP=1
         WRITE(*,'('' ...MODFLOW time step = '',I10)')
     &             MODSTP
         COVPMR(14)=MODSTP
         MESAGE(14)='MODFLOW TIME STEP'
      ELSE IF(IFLAG14.GT.0 .AND. NPER.GT.0) THEN
 1406    IERROR=1
         WRITE(*,'(//,'' Enter MODFLOW time step number for '',
     &             ''cell-by-cell terms'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified time step'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter time step number:'')')
         READ(*,'(A)',ERR=1408,END=9990) ANSWER
         IERROR=0
C
C14Q-----Quitting
C
 1408  IF(ANSWER.EQ.' ') GO TO 9990
C
C14E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading MODFLOW time step'')')
          GO TO 1406
       ENDIF
C
C14H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know time step number for ',
     &               ' the cell-by-cell terms'
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS uses this number to select the proper'
          WRITE(*,*) ' cell-by-cell terms output by MODFLOW at'
          WRITE(*,*) ' specified time step in a stress period for '
          WRITE(*,*) ' a ground-water simulation'
          WRITE(*,*) 'MODFLOW outputs cell-by-cell terms for '
          WRITE(*,*) ' stress periods at time steps specified'
          WRITE(*,*) ' by the user.'
          READ(*,'(A)') ANSWER
          WRITE(*,*) 'Continue?'
          GO TO 1406
C
C14R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1408,END=9990) MODSTP
        IF(MODSTP.LT.0) THEN
           WRITE(*,'(//,'' Invalid response'',I10)') MODSTP
           GO TO 1406
        ELSE
           WRITE(*,'('' ...MODFLOW time step = '',I10)')
     &             MODSTP
           COVPMR(14)=MODSTP
           MESAGE(14)='MODFLOW TIME STEP'
        ENDIF
       ENDIF
      ENDIF
C
C15O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C15---Hydraulic head assigned to noflow cells
C
      MESAGE(15)='HYDRAULIC HEAD ASSIGNED TO NOFLOW CELLS'
      HNOFLO=COVPMR(15)
      WRITE(*,'('' ...Hydraulic head assigned to noflow cells = '',
     &              G20.10)')
     &             HNOFLO
C
C16---Hydraulic head assigned to dry cells
C
      MESAGE(16)='HYDRAULIC HEAD ASSIGNED TO DRY CELLS'
      HDRY=COVPMR(16)
      WRITE(*,'('' ...Hydraulic head assigned to dry cells = '',
     &              G20.10)')
     &             HDRY
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                     Output user information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
      WRITE(*,'(//,'' Writing coverage parameters now...'')')
      NSTAT=2
      ITALK=1
      IOUT=60
      CALL DELETE_FILE (PMRFIL,*9999)
      CALL OPEN_FILE (IOUT,PMRFIL,NSTAT,ITALK,*9999)
C
      IF(ICOVER.NE.7) THEN
         WRITE(IOUT,'(I15,1X,A80)') MODFLG,MESAGE(1)
      ELSE
         WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(1),MESAGE(1)
      ENDIF
C
       WRITE(IOUT,'(I15,1X,A80)') ICOVER,MESAGE(2)
        WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(3),MESAGE(3)
         WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(4),MESAGE(4)
          WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(5),MESAGE(5)
           WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(6),MESAGE(6)
            WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(7),MESAGE(7)
             WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(8),MESAGE(8)
              WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(9),MESAGE(9)
               WRITE(IOUT,'(I15,1X,A80)') IVIEW,MESAGE(10)
                WRITE(IOUT,'(I15,1X,A80)') IRWCL,MESAGE(11)
C
              IF(ICOVER.EQ.6) THEN
                 WRITE(IOUT,'(I15,1X,A80)') IDCNTR,MESAGE(1)
              ELSE IF(ICOVER.EQ.7) THEN
                 WRITE(IOUT,'(I15,1X,A80)') IDCNTR,MESAGE(12)
              ELSE
                 WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(12),MESAGE(12)
              ENDIF
C
              IF(ICOVER.GE.6) THEN
                 WRITE(IOUT,'(I15,1X,A80)') MODPER,MESAGE(13)
              ELSE
                 WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(13),MESAGE(13)
              ENDIF
C
               IF(ICOVER.EQ.4) THEN
                  WRITE(IOUT,'(I15,1X,A80)') NUMARC,MESAGE(14)
               ELSE
                  WRITE(IOUT,'(I15,1X,A80)') MODSTP,MESAGE(14)
               ENDIF
C
                    WRITE(IOUT,'(G15.5,1X,A80)') HNOFLO,MESAGE(15)
                     WRITE(IOUT,'(G15.5,1X,A80)') HDRY,MESAGE(16)
                      CALL CLOSE_FILE (PMRFIL,*9999)
                       GO TO 1001 
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                         Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,'(//,'' Quitting Modtools now...'')')
 9999 WRITE(*,'(//,'' Abnormal Terminal of Pth_Pmt_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1001 RETURN
      END
