C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Hedall version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 HEDALL 23JUNE1997
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Allocates space within the common array for cell-by-cell head terms
C      either polygon or line coverages and attributes.  These cell-by-cell
C      head terms were output by the Basic Package of the U.S. Geological 
C      Survey Modular Three-Dimensional Finite-Differences Ground-Water Flow 
C      model MODFLOW or MODFLOWARC (McDonald and Harbaugh, 1988; Orzol and 
C      McGrath, 1992).
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C    Inputs:
C
C     OUTUNT  : FORTRAN UNIT NUMBER FOR OUTPUT DATA FILE
C     LENX    : MAXIMUM DIMENSION OF THE COMMON BLOCK ARRAY
C     MAXATB  : MAXIMUM NUMBER OF ATTRIBUTES IN COVERAGE PAT OR AAT FILE
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C
C   Inputs/Outputs:
C
C     ISUM    : INDEX NUMBER TO COMMON BLOCK ARRAY FOR ALLOCATION
C             => 1+MAXPMR+MAXIND*MXINDS+MAXIND
C
C    Outputs:
C
C     LCHEAD  : STARTING ARRAY INDEX FOR HEAD ARRAY (NCOL,NROW,NLAY)
C
C     Program:
C
C     ISUM1   : INDEX NUMBER TO LAST COMMON BLOCK ARRAY FOR ALLOCATION
C
C-----------------------------------------------------------------------
      SUBROUTINE HEDALL (
     I                   HEDFIL,HEDUNT,
     I                   CTLFIL,CTLUNT,
     I                   OUTUNT,
     I                   LENX,
     I                   NLAY,NROW,NCOL,
     B                   ISUM,
     O                   LCHEAD,
     E                   *)
C-------------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      CHARACTER*(*) 
     &             HEDFIL,
     &             CTLFIL
C
      INTEGER 
     &        HEDUNT,
     &        CTLUNT,
     &        OUTUNT,
     &        LENX,
     &        NLAY,
     &        NROW,
     &        NCOL,
     &        ISUM,
     &        LCHEAD
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      CHARACTER*48 MESAGE
C
      INTEGER
     &       MAXCHR
C
      DATA 
     &     MAXCHR /48/
C     ------------------------------------------------------------------
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          CELL-BY-CELL HEAD/DRAWDOWN TERMS '',
     &               ''PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''               VERSION 6.0 23JUNE1997 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                 ALLOCATION MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C1----Calculate storage parameter NRCL
C
      NRCL=NROW*NCOL*NLAY
C
C2----Allocate space for arrays
C
      LCHEAD=ISUM
      ISUM=ISUM+NRCL
      ISUM1=ISUM-1
C
C3----Print Modtools operation parameters
C
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          CELL-BY-CELL HEAD PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          VERSION 6.0 23JUNE1997 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
C
C3A----Print head file
C
      IF(HEDUNT.LT.0) THEN
         MESAGE='CELL-BY-CELL HEAD FILE [BINARY FORMAT]'
         NUMCHR=INDEX(HEDFIL,' ')-1
       IF(NUMCHR.LT.0) THEN
          NUMCHR=1
          LENCHR=48
       ELSE IF(NUMCHR.GT.MAXCHR) THEN
          NUMCHR=NUMCHR-MAXCHR+1
          LENCHR=NUMCHR+MAXCHR-1
       ELSE
          LENCHR=NUMCHR
          NUMCHR=1
       ENDIF
         WRITE(OUTUNT,'(10X,
     &                      A50,
     &                      A30)')
     &                  MESAGE,
     &                  HEDFIL (NUMCHR:LENCHR)
      ELSE IF(HEDUNT.EQ.0) THEN
         MESAGE='NEED CELL-BY-CELL HEAD FILE'
         NUMCHR=INDEX(HEDFIL,' ')-1
       IF(NUMCHR.LT.0) THEN
          NUMCHR=1
          LENCHR=48
       ELSE IF(NUMCHR.GT.MAXCHR) THEN
          NUMCHR=NUMCHR-MAXCHR+1
          LENCHR=NUMCHR+MAXCHR-1
       ELSE
          LENCHR=NUMCHR
          NUMCHR=1
       ENDIF
         WRITE(*,'(10X,
     &                      A50,
     &                      A30)')
     &                 MESAGE,
     &                 HEDFIL (NUMCHR:LENCHR)
         WRITE(OUTUNT,'(10X,
     &                      A50,
     &                      A30)')
     &                 MESAGE,
     &                 HEDFIL (NUMCHR:LENCHR)
         GO TO 9999
      ELSE
         MESAGE='CELL-BY-CELL HEAD FILE [ASCII FORMAT]'
         NUMCHR=INDEX(HEDFIL,' ')-1
       IF(NUMCHR.LT.0) THEN
          NUMCHR=1
          LENCHR=48
       ELSE IF(NUMCHR.GT.MAXCHR) THEN
          NUMCHR=NUMCHR-MAXCHR+1
          LENCHR=NUMCHR+MAXCHR-1
       ELSE
          LENCHR=NUMCHR
          NUMCHR=1
       ENDIF
         WRITE(OUTUNT,'(10X,
     &                      A50,
     &                      A30)')
     &                 MESAGE,
     &                 HEDFIL (NUMCHR:LENCHR)
       IF(CTLUNT.EQ.0) THEN
          MESAGE='NEED U2DREL CONTROL FILE FOR READING'
          NUMCHR=INDEX(CTLFIL,' ')-1
        IF(NUMCHR.LT.0) THEN
           NUMCHR=1
           LENCHR=48
        ELSE IF(NUMCHR.GT.MAXCHR) THEN
           NUMCHR=NUMCHR-MAXCHR+1
           LENCHR=NUMCHR+MAXCHR-1
        ELSE
           LENCHR=NUMCHR
           NUMCHR=1
        ENDIF
          WRITE(*,'(10X,A50)')
     &                        MESAGE
          WRITE(OUTUNT,'(10X,A50)')
     &                             MESAGE
          GO TO 9999
       ELSE
          MESAGE='U2DREL CONTROL FILE FOR HEADS'
          NUMCHR=INDEX(CTLFIL,' ')-1
        IF(NUMCHR.LT.0) THEN
           NUMCHR=1
           LENCHR=48
        ELSE IF(NUMCHR.GT.MAXCHR) THEN
           NUMCHR=NUMCHR-MAXCHR+1
           LENCHR=NUMCHR+MAXCHR-1
        ELSE
           LENCHR=NUMCHR
           NUMCHR=1
        ENDIF
          WRITE(OUTUNT,'(10X,
     &                       A50,
     &                       A30)')
     &                  MESAGE,
     &                  CTLFIL (NUMCHR:LENCHR)
       ENDIF
      ENDIF
C
C3B----Print array allocation information
C
      ISP=NRCL
      WRITE(OUTUNT,'(10X,
     &             I8,1X,
     &             ''ELEMENTS IN COMMON BLOCK ARRAY USED '',
     &             ''FOR HEAD'')')
     &          ISP
C
      WRITE(OUTUNT,'(10X,
     &             I8,1X,
     &             '' ELEMENTS OF COMMON BLOCK ARRAY USED OUT OF '',
     &             I8)')
     &          ISUM1,LENX
C
      WRITE(OUTUNT,'(10X,85(''-''))')
C
C4----Check amount of space used
C
      IF(ISUM1.GT.LENX) THEN
         WRITE(OUTUNT,'(//,
     &                ''    ***CELL ARRAY MUST BE DIMENSIONED '',
     &                ''LARGER*** ISUM '',I10,'' > LENX '',I10)')
     &             ISUM1,
     &             LENX
         WRITE (*,'(//,'' Cell array must be dimensioned larger ISUM '',
     &              I10,'' > LENX '',I10)')
     &           ISUM1,
     &           LENX
      ENDIF
       GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9999 WRITE(*,
     &      '(//,'' Abnormal termination of Hedall_Subroutine'')')
      WRITE(OUTUNT,
     &      '(//,'' Abnormal termination of Hedall_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Hedrp1 version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 HEDRP1 30AUGUST1999
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Reads an user defined files for cell_by_cell head terms.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C    Inputs:
C
C     OUTFIL  : OUTPUT FILE NAME DOCUMENTING HEDRP1 OPERATIONS.
C     OUTUNT  : FORTRAN UNIT NUMBER FOR OUTPUT DATA FILE
C     HEDFIL  : FILE CONTAINING THE CELL-BY-CELL HEAD TERMS
C     HEDUNT  : FORTRAN UNIT NUMBER FOR CELL-BY-CELL HEAD TERMS
C     CTLFIL  : FILE CONTAINING THE CONTROL LINES
C     CTLUNT  : FORTRAN UNIT NUMBER FOR U2DREL CONTROL LINES
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C     NCOL    : NUMBER OF COLUMNS IN GRID
C
C    Outputs:
C
C     HEDBUD  : ARRAY FOR CELL_BY_CELL HEAD TERMS
C
C-------------------------------------------------------------------------
      SUBROUTINE HEDRP1 (
     I                   OUTFIL,OUTUNT,
     I                   HEDFIL,HEDUNT,
     I                   CTLFIL,CTLUNT,
     I                   NLAY,NROW,NCOL,
     I                   MAXPMR,
     I                   COVPMR,
     O                   HEDBUD,
     E                   *)
C-----------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      DIMENSION 
     &          COVPMR(MAXPMR),
     &          HEDBUD(NCOL*NROW*NLAY)
C
      CHARACTER*(*) OUTFIL,HEDFIL,CTLFIL
C
      INTEGER OUTUNT,HEDUNT,CTLUNT
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      CHARACTER*16 HEDTXT,TEXT,DDNTXT,MODTXT
      CHARACTER*24 ANAME(1)
C
      INTEGER CBCUNT,ICOL,IROW,ILAY,LAYER,KK,HEDFLG,MODPER,MODSTP
C
      DATA HEDTXT /'            HEAD'/
      DATA DDNTXT /'        DRAWDOWN'/
      DATA ANAME(1) /' COMPUTED HYDRAULIC HEAD'/
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                 Reading basic model problem information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C1*********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(//10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          CELL-BY-CELL HEAD/DRAWDOWN TERMS '',
     &               ''PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                 VERSION 6.0 30AUGUST1999 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                  READ/PREPARE MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C1L----Set local variables
C
      MODPER=INT(COVPMR(13))
      MODSTP=INT(COVPMR(14))
      NPER=INT(COVPMR(17))
      MODFLG=INT(COVPMR(1))
C
      IF(MODFLG.LT.2) THEN
         MODTXT='head'
         HEDTXT='            HEAD'
      ELSE
         MODTXT='drawdown'
         HEDTXT=DDNTXT
      ENDIF
C
      IF(NPER.EQ.0) THEN
         MODPER=1
         MODSTP=1
         WRITE(*,'(
     &             ''      .Reading steady-state cell_by_cell '',
     &             A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
         WRITE(OUTUNT,'(
     &             ''      .Reading steady-state cell_by_cell '',
     &             A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
      ELSE
         WRITE(*,'(
     &             ''      .Reading transient cell_by_cell '',
     &             A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
         WRITE(OUTUNT,'(
     &             ''      .Reading transient cell_by_cell '',
     &             A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
      ENDIF
C
C1---Unformatted cell-by-cell head terms
C
      IF(HEDUNT.LT.0) THEN
         WRITE(*,'(
     &             ''      ..reading unformatted cell_by_cell '',
     &             A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
         WRITE(OUTUNT,'(
     &             ''      ..reading unformatted cell_by_cell '',
     &             A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
C
C1A---Open unformatted file HEDFIL
C
         NSTAT=1
         ITALK=1
         CBCUNT=ABS(HEDUNT)
         OPEN(UNIT=ABS(HEDUNT),FILE=HEDFIL,ACCESS='SEQUENTIAL',
     &        FORM='UNFORMATTED') 
C         CALL OPEN_FILE (HEDUNT,HEDFIL,NSTAT,ITALK,*9999)
         WRITE(*,'(''      ..recorded in file '',A)')
     &             HEDFIL (1:INDEX(HEDFIL,' ')-1)
         WRITE(*,'(''      ..on unit '',I10)')
     &                                                CBCUNT
         WRITE(OUTUNT,'(''      ..recorded in file '',A)')
     &             HEDFIL (1:INDEX(HEDFIL,' ')-1)
         WRITE(OUTUNT,'(''      ..on unit '',I10)')
     &                                                CBCUNT
C
C1B---Loop to read from unformatted file HEDFIL
C
         HEDFLG=0
         DO 100 LAYER=1,NLAY
            KK=LAYER
            LOCSTR=1+(KK-1)*NCOL*NROW
            LOCEND=KK*NCOL*NROW
  102       READ(ABS(HEDUNT),ERR=9990,END=104)
     &                                       KSTP,
     &                                       KPER,
     &                                       PERTIM,
     &                                       TOTTIM,
     &                                       TEXT,
     &                                       ICOL,
     &                                       IROW,
     &                                       ILAY
          IF(TEXT.EQ.HEDTXT .AND.
     &       KPER.EQ.MODPER .AND. KSTP.EQ.MODSTP) THEN
             WRITE(*,'(
     &             ''      ....reading unformatted '',A,'' terms '',
     &             ''for layer '',I5)') 
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              KK
             WRITE(OUTUNT,'(
     &             ''      ....reading unformatted '',A,'' terms '',
     &             ''for layer '',I5)') 
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              KK
             HEDFLG=HEDFLG+1
             READ(CBCUNT,ERR=9991,END=9992) 
     &            (HEDBUD(LOC), LOC=LOCSTR,LOCEND)
             WRITE(OUTUNT,('(1X,///11X,A,'' FOR LAYER '',I4,/,
     &                       1X,'' READING BINARY ON UNIT '',I4)'))
     &             HEDTXT,KK,HEDUNT
            IF(HEDFLG.EQ.NLAY) GO TO 104
          ELSE
             READ(CBCUNT,ERR=9991,END=104) 
     &            (HEDBUD(LOC), LOC=LOCSTR,LOCEND)
             GO TO 102
          ENDIF
  100    CONTINUE
C
  104   IF(HEDFLG.LE.0) THEN
           WRITE(*,'(
     &              ''      ....Did not find cell_by_cell '',
     &              A,'' terms in file '',A)')
     &              MODTXT (1:INDEX(MODTXT,' ')-1),
     &              HEDFIL (1:INDEX(HEDFIL,' ')-1)
           WRITE(OUTUNT,'(
     &              ''      ....Did not find cell_by_cell '',
     &              A,'' terms in file '',A)')
     &              MODTXT (1:INDEX(MODTXT,' ')-1),
     &              HEDFIL (1:INDEX(HEDFIL,' ')-1)
        ENDIF
        IF(HEDFLG.LT.NLAY) THEN
           WRITE(*,'(
     &              ''      ....Warning:Did not find cell_by_cell '',
     &              A,'' terms for every layer'')')
     &              MODTXT (1:INDEX(MODTXT,' ')-1)
           WRITE(*,'(
     &              ''      .        or for proper stress '',
     &              ''period or time step'')')
           WRITE(*,'(
     &              ''      .  in file '',A)')
     &              HEDFIL (1:INDEX(HEDFIL,' ')-1)
           WRITE(OUTUNT,'(
     &              ''      ....Warning:Did not find cell_by_cell '',
     &              A,'' terms for every layer'')')
     &              MODTXT (1:INDEX(MODTXT,' ')-1)
           WRITE(OUTUNT,'(
     &              ''      .        or for proper stress '',
     &              ''period or time step'')')
           WRITE(OUTUNT,'(
     &              ''      .  in file '',A)')
     &              HEDFIL (1:INDEX(HEDFIL,' ')-1)
        ENDIF
C
C1C---Close unformatted file HEDFIL
C
         CALL CLOSE_FILE (HEDFIL,*9999)
         HEDUNT=-ABS(HEDUNT)
      IF(HEDFLG.LE.0) GO TO 9999
C
C2---Text formatted cell-by-cell head terms
C
      ELSE IF(HEDUNT.GT.0) THEN
         WRITE(*,'(
     &             ''      ..reading text formatted cell_by_cell '',
     &             A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
         WRITE(OUTUNT,'(
     &             ''      ..reading text formatted cell_by_cell '',
     &             A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
C
C2A----Open control file CTLFIL and text formatted file HEDFIL
C
       IF(CTLUNT.GT.0) THEN
          NSTAT=1
          ITALK=1
          CALL OPEN_FILE (CTLUNT,CTLFIL,NSTAT,ITALK,*9999)
          CALL OPEN_FILE (HEDUNT,HEDFIL,NSTAT,ITALK,*9999)
          WRITE(*,'(
     &              ''      ....recorded in file '',A)')
     &              HEDFIL (1:INDEX(HEDFIL,' ')-1)
          WRITE(*,'(
     &              ''      ....on unit '',I10)')
     &                                                 HEDUNT
          WRITE(*,'(
     &              ''      ..using control lines '')')
          WRITE(*,'(
     &              ''      ....recorded in file '',A)')
     &              CTLFIL (1:INDEX(CTLFIL,' ')-1)
          WRITE(OUTUNT,'(
     &              ''      ....recorded in file '',A)')
     &              HEDFIL (1:INDEX(HEDFIL,' ')-1)
          WRITE(OUTUNT,'(
     &              ''      ....on unit '',I10)')
     &                                                 HEDUNT
          WRITE(OUTUNT,'(
     &              ''      ..using control lines '')')
          WRITE(OUTUNT,'(
     &              ''      ..recorded in file '',A)')
     &              CTLFIL (1:INDEX(CTLFIL,' ')-1)
       ELSE
          WRITE(*,'(
     &              ''      ..Can not read text formatted '',
     &              ''cell_by_cell '',A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
          WRITE(*,'(
     &              ''      ....recorded in file '',A)')
     &              HEDFIL (1:INDEX(HEDFIL,' ')-1)
          WRITE(*,'(
     &              ''      ....on unit '',I10)')
     &                                                 HEDUNT
          WRITE(*,'(
     &              ''      ..Need file containing U2DREL control '',
     &              ''lines for format of cell-by-cell '',
     &              A,'' file'')') 
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
          WRITE(OUTUNT,'(
     &              ''      ..Can not read text formatted '',
     &              ''cell_by_cell '',A,'' terms '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
          WRITE(OUTUNT,'(
     &              ''      ....recorded in file '',A)')
     &              HEDFIL (1:INDEX(HEDFIL,' ')-1)
          WRITE(OUTUNT,'(
     &              ''      ....on unit '',I10)')
     &                                                 HEDUNT
          WRITE(OUTUNT,'(
     &              ''      ..Need file containing U2DREL control '',
     &              ''lines for format of cell-by-cell '',
     &              A,'' file'')') 
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
          CALL CLOSE_FILE (HEDFIL,*9999)
          GO TO 9999
       ENDIF
C
C2B---Loop to read from text formatted file HEDFIL
C
         DO 200 LAYER=1,NLAY
            KK=LAYER
            LOC=1+(KK-1)*NCOL*NROW
            CALL U2DREL (HEDBUD(LOC),ANAME(1),NROW,NCOL,KK,CTLUNT,
     &                   OUTUNT)
  200    CONTINUE
C
C2C---Close text formatted file HEDFIL
C
         CALL CLOSE_FILE (HEDFIL,*9999)
         CALL CLOSE_FILE (CTLFIL,*9999)
C
C3---Error no file containing cell-by-cell head terms
C
      ELSE
         WRITE(*,'(
     &             ''      ..No file containing cell_by_cell '',
     &             A,'' terms specified in MODTOOLS name file'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
         WRITE(OUTUNT,'(
     &             ''      ..No file containing cell_by_cell '',
     &             A,'' terms specified in MODTOOLS name file'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
         GO TO 9999
      ENDIF
        GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,'(//,
     &          '' Unable to read header line for layer '',I5,
     &          '' for head terms from file '',A)') 
     &          KK,
     &          HEDFIL (1:INDEX(HEDFIL,' ')-1)
      WRITE(OUTUNT,'(//,
     &          '' Unable to read header line for layer '',I5,
     &          '' for head terms from file '',A)') 
     &          KK,
     &          HEDFIL (1:INDEX(HEDFIL,' ')-1)
      GO TO 9998
 9991 WRITE(*,'(//,
     &          '' Unable to read values for '',
     &          ''head terms from file '',A)') 
     &          HEDFIL (1:INDEX(HEDFIL,' ')-1)
      WRITE(OUTUNT,'(//,
     &          '' Unable to read header line for '',
     &          ''head terms from file '',A)') 
     &          HEDFIL (1:INDEX(HEDFIL,' ')-1)
      GO TO 9998
 9992 WRITE(*,'(//,
     &          '' End-of-file; Unable to read values for '',
     &          ''head terms from file '',A)') 
     &          HEDFIL (1:INDEX(HEDFIL,' ')-1)
      WRITE(OUTUNT,'(//,
     &          '' End-of-file; Unable to read header line for '',
     &          ''head terms from file '',A)') 
     &          HEDFIL (1:INDEX(HEDFIL,' ')-1)
      GO TO 9998
 9998 CALL CLOSE_FILE (HEDFIL,*9999)
 9999 WRITE(*,
     &      '(//,'' Abnormal Termination of Hedrp1_Subroutine'')')
      WRITE(OUTUNT,
     &      '(//,'' Abnormal Termination of Hedrp1_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthhed version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHHED 30JUNE2000
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Generates a Info file HEDFIL using the cell-by-cell 
C      head terms that are output by the Basic package of the 
C      U.S. Geological Survey Modular Three-Dimensional Finite-Differences
C      Ground-Water Flow Model MODFLOW or MODFLOWARC (McDonald and Harbaugh, 
C      1988; Orzol and McGrath, 1992). 
C
C      IVIEW
C           => 0 a cell-by-cell head terms of all layers (mapview)
C              => (n,1) CELL ROWCOL (character representation of 
C                                    row and column)
C              => (n,2) CELL ROW
C              => (n,3) CELL COLUMN
C              => (n,3+NLAY) CELL_BY_CELL HEAD TERMS
C           => 1 a cell-by-cell head terms of an user chosen row
C              => (n,1) CELL ROWCOL (character representation of 
C                                    row and column)
C              => (n,2) CELL ROW
C              => (n,3) CELL COLUMN
C              => (n,4) CELL LAYER
C              => (n,5) CELL IBOUND VALUE
C              => (n,6) CELL TOP ELEVATION
C              => (n,7) CELL BOTTOM ELEVATION
C              => (n,8) CELL THICKNESS
C              => (n,9) CELL_BY_CELL HEAD TERMS
C           => 2 a cell-by-cell head terms of an user chosen column
C              => (n,1) CELL ROWCOL (character representation of 
C                                    row and column)
C              => (n,2) CELL ROW
C              => (n,3) CELL COLUMN
C              => (n,4) CELL LAYER
C              => (n,5) CELL IBOUND VALUE
C              => (n,6) CELL TOP ELEVATION
C              => (n,7) CELL BOTTOM ELEVATION
C              => (n,8) CELL THICKNESS
C              => (n,9) CELL_BY_CELL HEAD TERMS
C           => 3 a cell-by-cell head terms of an user chosen particle
C              => (n,1) CELL ROWCOL (character representation of 
C                                    row and column)
C              => (n,2) CELL ROW
C              => (n,3) CELL COLUMN
C              => (n,4) CELL LAYER
C              => (n,5) CELL IBOUND VALUE
C              => (n,6) CELL TOP ELEVATION
C              => (n,7) CELL BOTTOM ELEVATION
C              => (n,8) CELL THICKNESS
C              => (n,9) CELL_BY_CELL HEAD TERMS
C           => 4 a cell-by-cell head terms of an user chosen layer
C              => (n,1) CELL ROWCOL (character representation of 
C                                    row and column)
C              => (n,2) CELL ROW
C              => (n,3) CELL COLUMN
C              => (n,4) CELL LAYER
C              => (n,5) CELL IBOUND VALUE
C              => (n,6) CELL TOP ELEVATION
C              => (n,7) CELL BOTTOM ELEVATION
C              => (n,8) CELL THICKNESS
C              => (n,9) CELL_BY_CELL HEAD TERMS
C           => 5 a cell-by-cell head terms of an user chosen ibound value
C                 (this ibound value can be used to differentiate model
C                  layers into geological units)
C              => (n,1) CELL ROWCOL (character representation of 
C                                    row and column)
C              => (n,2) CELL ROW
C              => (n,3) CELL COLUMN
C              => (n,4) CELL LAYER
C              => (n,5) CELL IBOUND VALUE
C              => (n,6) CELL TOP ELEVATION
C              => (n,7) CELL BOTTOM ELEVATION
C              => (n,8) CELL THICKNESS
C              => (n,9) CELL_BY_CELL HEAD TERMS
C                       (these terms are computed as a summation of a weighted
C                         value based upon the saturated thickness of each 
C                         layer that has the chosen ibound value divided by
C                         the total saturated of this ibound value over all 
C                         layers times the cell-by-cell head term for 
C                         each layer)
C           => 6 a cell-by-cell head terms of uppermost active layer (mapview)
C              => (n,1) CELL POLYGON NUMBER
C              => (n,2) CELL ROWCOL (character representation of 
C                                    row and column)
C              => (n,3) CELL ROW
C              => (n,4) CELL COLUMN
C              => (n,5) CELL LAYER
C              => (n,6) CELL IBOUND VALUE
C              => (n,7) CELL TOP ELEVATION
C              => (n,8) CELL BOTTOM ELEVATION
C              => (n,9) CELL_BY_CELL HEAD TERMS
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C
C    Inputs:
C
C     OUTUNT  : FORTRAN UNIT WHERE OPERATIONAL OUTPUT AND ERRORS ARE RECORDED
C     HEDFIL  : COVERAGE ROOT NAME
C     MAXPMR  : MAXIMUM NUMBER OF COVERAGE PARAMETERS
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     COVPMR  : COVERAGE PARAMETERS ARRAY (MAXPMR)
C     LRWCL   : ARRAY INDICATING THE CELL'S ROW AND COLUMN (2,NDELX)
C     IBOUND  : ARRAY FOR IBOUND ARRAY (NCOL,NROW,NLAY)
C     ZTOP    : ARRAY FOR LAYER/UNIT TOP ELEVATIONS
C     ZBOT    : ARRAY FOR LAYER/UNIT BOTTOM ELEVATIONS
C     HEDTRM  : ARRAY FOR LAYER/UNIT CELL_BY_CELL HEADS
C
C   Inputs/Outputs: None
C
C    Outputs: None
C
C-----------------------------------------------------------------------
      SUBROUTINE PTHHED (
     I                   OUTUNT,
     I                   HEDFIL,
     I                   MAXPMR,
     I                   NLAY,NROW,NCOL,
     I                   COVPMR,DELZCB,
     I                   LRWCL,
     I                   IBOUND,ZTOP,ZBOT,
     I                   HEDTRM,
     E                   *)
C-----------------------------------------------------------------------
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      DIMENSION 
     1          COVPMR(MAXPMR),
     1          DELZCB(NLAY),
     2          LRWCL(2,NCOL*NROW),
     3          IBOUND(NCOL,NROW,NLAY),
     3          ZTOP(NCOL,NROW,NLAY),
     3          ZBOT(NCOL,NROW,NLAY),
     3          HEDTRM(NCOL,NROW,NLAY)
C
      CHARACTER*(*) HEDFIL
      INTEGER OUTUNT
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      PARAMETER (MAXFIL=3,
     &           MAXITM=5)
C
      REAL
     &     HEDDRY,HNOFLO,HEDIBD
C
      CHARACTER*128 LABFIL,FMTSTR
      CHARACTER*80 FILES(MAXFIL),ADDFIL,INPFIL,TMPFIL
      CHARACTER*16 MODTXT
      CHARACTER*16 COVTYP,ITEM,ITEMS(MAXITM),ARCCMD,ACTION,
     &             LAYITM,STRITM,RELITM,JONTYP
      CHARACTER*10 CHRLAY,CHRWCL,LAYFMT,ITMFMT
      CHARACTER*6 ITMTXT
      CHARACTER*1 TYPITM,TYPES(MAXITM)
C
      INTEGER DECIML,DECIMLS(MAXITM),IOUT(MAXFIL),ITMSTR,ITMFIN,
     &        OUTPUT,OUTPUTS(MAXITM),WIDTH,WIDTHS(MAXITM)
C
      INTEGER 
     &        IRWCL,IVIEW,
     &        IDPART,ICOLOR,TIMSTP,OLDSTP,
     &        STRCHR,STRCOL,STRROW,STRLAY,STRIBD,STRDEL,STRCLL,
     &        PRECOL,PREROW,PRELAY,PREIBD,
     &        FINCHR,FINCOL,FINROW,FINLAY,FINIBD,FINDEL,FINCLL,
     &        BADIBD,DRYCLL,NOFLOW,
     &        ROW,COLUMN,CELL,COVDEX,COL,ROWCOL,SEQNUM,
     &        NCELLS,
     &        NUMCOL,NUMROW,ILAY,
     &        IRWCOL
C
      EXTERNAL OPEN_FILE,CLOSE_FILE,DELETE_FILE
C
      DATA FILES /'headitems',
     &            'headitem',
     &            'arccmd'/
      DATA IOUT /91,92,93/
      DATA ITEMS /'SEQNUM','ROWCOL','ROW','COLUMN','LAYER_'/
      DATA DECIMLS /4*0, 3/
      DATA TYPES /'I','C',2*'I','F'/
      DATA WIDTHS /4*10,8/
      DATA OUTPUTS /4*10,16/
C
C     ------------------------------------------------------------------
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          CELL-BY-CELL HEAD/DRAWDOWN TERMS '',
     &               ''PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                VERSION 6.0 30JUNE2000 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                  GIS OUTPUT MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C1----Set local variables
C
      IVIEW=INT(COVPMR(10))
      IRWCL=INT(COVPMR(11))
      HNOFLO=COVPMR(15)
      HEDDRY=COVPMR(16)
      DEFHED=-99999999.999
      IF(HNOFLO.EQ.0.) HNOFLO=DEFHED
      IF(HEDDRY.EQ.0.) HEDDRY=DEFHED
      MODFLG=INT(COVPMR(1))
      MODFMT=MODFLG
C
      IF(MODFMT.EQ.1) THEN
         ITMTXT='HEDTRM'
         MODTXT='head'
      ELSE
         ITMTXT='DDNTRM'
         MODTXT='drawdown'
      ENDIF
C
         WRITE(*,'(
     &          ''      .Processing cell-by-cell ''
     &          A,'' terms from Basic Package '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
         WRITE(OUTUNT,'(
     &          ''      .Processing cell-by-cell ''
     &          A,'' terms from Basic Package '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
C
C2----Delete and create files for attribute definitions, attribute value, 
C      and coverage arc data and tolerance/dangle values
C
       NSTAT=2
        ITALK=1
      IF(IVIEW.LE.0 .OR. IVIEW.GE.4) 
     &   FILES(2) = HEDFIL(1:INDEX(HEDFIL,' ')-1)
C
C2A----Delete/create files containing Arc/Info item definitions for
C      attribute files
C
      DO 200 N=1,MAXFIL-1
         CALL DELETE_FILE (FILES(N),*9999)
         CALL OPEN_FILE (IOUT(N),FILES(N),NSTAT,ITALK,*9999)
  200 CONTINUE
C
C2B----Calculate rowcol attribute definition
C
      IF(NROW.LT.10) THEN
         LENROW=1
      ELSE IF(NROW.GT.9 .AND. NROW.LT.100) THEN
         LENROW=2
      ELSE IF(NROW.GT.99 .AND. NROW.LT.1000) THEN
         LENROW=3
      ELSE
         LENROW=4
      ENDIF
C
      IF(NCOL.LT.10) THEN
         LENCOL=1
      ELSE IF(NCOL.GT.9 .AND. NCOL.LT.100) THEN
         LENCOL=2
      ELSE IF(NCOL.GT.99 .AND. NCOL.LT.1000) THEN
         LENCOL=3
      ELSE
         LENCOL=4
      ENDIF
C
      IF(NLAY.LT.10) THEN
         LENLAY=1
      ELSE IF(NLAY.GT.9 .AND. NLAY.LT.100) THEN
         LENLAY=2
      ELSE IF(NLAY.GT.99 .AND. NLAY.LT.1000) THEN
         LENLAY=3
      ELSE
         LENLAY=4
      ENDIF
C
      WIDTHS(1)=LENROW+LENCOL
      OUTPUTS(1)=LENROW+LENCOL
      WIDTHS(2)=LENROW+LENCOL
      OUTPUTS(2)=LENROW+LENCOL
      WIDTHS(3)=LENROW
      OUTPUTS(3)=LENROW
      WIDTHS(4)=LENCOL
      OUTPUTS(4)=LENCOL
C
C2C----Write standard attribute definitions
C
      IF(IVIEW.LE.0 .OR. IVIEW.GE.4) THEN
         DO 210 K=1,4
            DECIML=DECIMLS(K)
            ITEM=ITEMS(K)
            OUTPUT=OUTPUTS(K)
            TYPITM=TYPES(K)
            WIDTH=WIDTHS(K)
            WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                      I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
  210    CONTINUE
C
C2Ca----Write attribute definitions IVIEW = all layers
C
        IF(IVIEW.LE.0) THEN
           DECIML=DECIMLS(MAXITM)
           ITEM=ITEMS(MAXITM)
           OUTPUT=OUTPUTS(MAXITM)
           TYPITM=TYPES(MAXITM)
           WIDTH=WIDTHS(MAXITM)
           DO 230 ILAY=1,NLAY
            IF(ILAY.LT.10) THEN
               WRITE(CHRLAY,'(I1)') ILAY
            ELSE IF(ILAY.GT.9 .AND. ILAY.LT.100) THEN
               WRITE(CHRLAY,'(I2)') ILAY
            ELSE IF(ILAY.GT.99 .AND. ILAY.LT.1000) THEN
               WRITE(CHRLAY,'(I3)') ILAY
            ELSE IF(ILAY.GT.999 .AND. ILAY.LT.1000) THEN
               WRITE(CHRLAY,'(I4)') ILAY
            ENDIF
              ITEM='LAYER_'//CHRLAY
              WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                        I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
  230      CONTINUE
C
C2Cb----Write attribute definitions IVIEW = single layer
C
        ELSE IF(IVIEW.EQ.4) THEN
           DECIML=DECIMLS(MAXITM)
           ITEM=ITEMS(MAXITM)
           OUTPUT=OUTPUTS(MAXITM)
           TYPITM=TYPES(MAXITM)
           WIDTH=WIDTHS(MAXITM)
           ILAY=IRWCL
         IF(ILAY.LT.10) THEN
            WRITE(CHRLAY,'(I1)') ILAY
         ELSE IF(ILAY.GT.9 .AND. ILAY.LT.100) THEN
            WRITE(CHRLAY,'(I2)') ILAY
         ELSE IF(ILAY.GT.99 .AND. ILAY.LT.1000) THEN
            WRITE(CHRLAY,'(I3)') ILAY
         ELSE IF(ILAY.GT.999 .AND. ILAY.LT.1000) THEN
            WRITE(CHRLAY,'(I4)') ILAY
         ENDIF
           ITEM='LAYER_'//CHRLAY
           WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                     I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
C
C2Cb----Write attribute definitions IVIEW = ibound value
C
        ELSE IF(IVIEW.EQ.5) THEN
           ITEM='IBOUND'
           DECIML=0
           OUTPUT=10
           TYPITM='I'
           WIDTH=10
           WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                     I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
C
           ITEM=ITMTXT
           DECIML=DECIMLS(MAXITM)
           OUTPUT=OUTPUTS(MAXITM)
           TYPITM=TYPES(MAXITM)
           WIDTH=WIDTHS(MAXITM)
           WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                     I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
C
C2Ca----Write attribute definitions IVIEW = uppermost active cell
C
        ELSE IF(IVIEW.EQ.6) THEN
           DECIML=DECIMLS(4)
           ITEM='LAYER'
           OUTPUT=LENLAY
           TYPITM=TYPES(4)
           WIDTH=LENLAY
           WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                     I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
           DECIML=DECIMLS(MAXITM)
           ITEM=ITEMS(MAXITM)
           OUTPUT=OUTPUTS(MAXITM)
           TYPITM=TYPES(MAXITM)
           WIDTH=WIDTHS(MAXITM)
           ITEM=ITMTXT
           WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                     I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
         ENDIF
          CALL CLOSE_FILE (FILES(1),*9999)
C
C2D----Write standard attribute definitions
C
      ELSE
         DECIML=0
         ITEM=HEDFIL (1:INDEX(HEDFIL,' ')-1)//'-id'
         OUTPUT=5
         TYPITM='B'
         WIDTH=4
         WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                   I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
         DECIML=DECIMLS(MAXITM)
         ITEM=ITEMS(MAXITM)
         OUTPUT=OUTPUTS(MAXITM)
         TYPITM=TYPES(MAXITM)
         WIDTH=WIDTHS(MAXITM)
         ITEM=ITMTXT
         WRITE(IOUT(1),'(A,'','',I2,'','',I2,'','',A1,'','',
     &                   I2,'',,,,,,,,,,'')')
     &                                    ITEM,
     &                                    WIDTH,
     &                                    OUTPUT,
     &                                    TYPITM,
     &                                    DECIML
         CALL CLOSE_FILE (FILES(1),*9999)
      ENDIF
C
C3----Build mapview for single layer (iview=0,4)
C
      IF(IVIEW.LE.0 .OR. IVIEW.EQ.4) THEN
       IF(IVIEW.LE.0) THEN
          WRITE(*,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms for '',
     &             I10,'' layers now...'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              NLAY
          WRITE(OUTUNT,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms for '',
     &             I10,'' layers now...'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              NLAY
       ELSE
          WRITE(*,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms for layer '',
     &             I10,'' now...'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              IRWCL
          WRITE(OUTUNT,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms for layer '',
     &             I10,'' now...'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              IRWCL
       ENDIF
C
C3H----Data header
C
         WRITE(OUTUNT,'(//,1H1,15X,
     &               '' CELLS WITH INVALID VALUES '',
     &               ''WILL HAVE HEAD/DRAWDOWN VALUES RESET TO '',
     &               F16.3,
     &               /10X,85(''-''))')
     &               DEFHED
         WRITE(OUTUNT,'(40X,
     &               ''       ROW'',
     &               ''    COLUMN'',
     &               ''     LAYER'',
     &               ''    IBOUND'',
     &               /10X,85(''-''))')
C
C3Cb----Grid head attributes
C
         NCELLS=0
         BADIBD=0
         DRYCLL=0
         NOFLOW=0
         MAXCLL=0
C
         DO 300 IROW=1,NROW
            DO 310 ICOL=1,NCOL
               NCELLS=NCELLS+1
               SEQNUM=(IROW-1)*NCOL+ICOL
               NUMCLL=(IROW-1)*NCOL+ICOL
               ROWCOL=IROW*(10**LENCOL)+ICOL
               WRITE(CHRWCL,'(I10)') ROWCOL
               FINCHR=10
               STRCHR=FINCHR-(LENROW+LENCOL-1)
C
C3Cc----Mapview all layers
C
             IF(IVIEW.LE.0) THEN
                DO 320 ILAY=1,NLAY
                   IBDCEL=ABS(IBOUND(ICOL,IROW,ILAY))
                   HEAD=HEDTRM(ICOL,IROW,ILAY)
                 IF(IBDCEL.EQ.0) THEN
                    BADIBD=BADIBD+1
                    WRITE(OUTUNT,'(10X,
     &                      ''IBOUND = 0                    '',
     &                      4I10)')
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL
                    HEDTRM(ICOL,IROW,ILAY)=HNOFLO
                    GO TO 320
                 ENDIF
                 IF(HEDTRM(ICOL,IROW,ILAY).EQ.HEDDRY) THEN
                    DRYCLL=DRYCLL+1
                    WRITE(OUTUNT,'(10X,
     &                      ''DRY CELL                      '',
     &                      4I10)')
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL
                    HEDTRM(ICOL,IROW,ILAY)=HNOFLO
                    GO TO 320
                 ENDIF
                 IF(HEDTRM(ICOL,IROW,ILAY).EQ.HNOFLO) THEN
                    NOFLOW=NOFLOW+1
                    WRITE(OUTUNT,'(10X,
     &                      ''NOFLOW CELL                   '',
     &                      4I10)')
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL
                    HEDTRM(ICOL,IROW,ILAY)=HNOFLO
                    GO TO 320
                 ENDIF
                 IF(HEAD.LT.DEFHED .OR. HEAD.GT.ABS(DEFHED)) THEN
                    MAXCLL=MAXCLL+1
                    WRITE(OUTUNT,'(10X,
     &                      ''HEAD EXCEEDED MAXIMUM HEAD    '',
     &                      4I10)')
     &                             IROW,
     &                             ICOL,
     &                             ILAY,
     &                             IBDCEL
                    HEDTRM(ICOL,IROW,ILAY)=HNOFLO
                    GO TO 320
                 ENDIF
  320           CONTINUE
C
                WRITE(IOUT(2),'(
     &                          I10,'','',
     &                          A,'','',
     &                          2(I10,'',''),
     &                          200(F16.3,'',''))')
     &                       SEQNUM,
     &                       CHRWCL (STRCHR:FINCHR),
     &                       IROW,
     &                       ICOL,
     &                       (HEDTRM(ICOL,IROW,ILAY), ILAY=1,NLAY)
C
C3Cd----Mapview user specified layer
C
              ELSE
                ILAY=IRWCL
                IBDCEL=ABS(IBOUND(ICOL,IROW,ILAY))
                HEAD=HEDTRM(ICOL,IROW,ILAY)
              IF(IBDCEL.EQ.0) THEN
                 BADIBD=BADIBD+1
                 WRITE(OUTUNT,'(10X,
     &                   ''IBOUND = 0                    '',
     &                   3I10,F10.3)')
     &                           IROW,
     &                           ICOL,
     &                           ILAY,
     &                           HEAD
                 HEAD=HNOFLO
                 GO TO 312
              ENDIF
              IF(HEAD.EQ.HEDDRY) THEN
                 DRYCLL=DRYCLL+1
                 WRITE(OUTUNT,'(10X,
     &                   ''DRY CELL                      '',
     &                   4I10)')
     &                           IROW,
     &                           ICOL,
     &                           ILAY,
     &                           IBDCEL
                 HEAD=HNOFLO
                 GO TO 312
              ENDIF
              IF(HEAD.EQ.HNOFLO) THEN
                 NOFLOW=NOFLOW+1
                 WRITE(OUTUNT,'(10X,
     &                   ''NOFLOW CELL                   '',
     &                   4I10)')
     &                           IROW,
     &                           ICOL,
     &                           ILAY,
     &                           IBDCEL
                 HEAD=HNOFLO
                 GO TO 312
              ENDIF
              IF(HEAD.LT.DEFHED .OR. HEAD.GT.ABS(DEFHED)) THEN
                 MAXCLL=MAXCLL+1
                 WRITE(OUTUNT,'(10X,
     &                   ''HEAD EXCEEDED MAXIMUM HEAD    '',
     &                   4I10)')
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
                 HEAD=HNOFLO
                 GO TO 312
             ENDIF
C
 312         WRITE(IOUT(2),'(
     &                          I10,'','',
     &                          A,'','',
     &                          2(I10,'',''),
     &                          F16.3,'','')')
     &                       SEQNUM,
     &                       CHRWCL (STRCHR:FINCHR),
     &                       IROW,
     &                       ICOL,
     &                       HEAD
              ENDIF
  310       CONTINUE
  300    CONTINUE
         WRITE(OUTUNT,'(10X,85(''-''))')
C
C4----Build cross-sectional view (iview=1,2,3)
C
      ELSE IF(IVIEW.GE.1 .AND. IVIEW.LE.3) THEN
       IF(IVIEW.EQ.1) THEN
          WRITE(*,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms along row '',
     &             I10,'' now...'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              IRWCL
       ELSE IF(IVIEW.EQ.2) THEN
          WRITE(*,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms along column '',
     &             I10,'' now...'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              IRWCL
       ELSE
          WRITE(*,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms along particle '',
     &             I10,'' now...'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              IRWCL
     &          IRWCL
       ENDIF
C
C4H----Data header
C
         WRITE(OUTUNT,'(//,1H1,15X,
     &               '' CELLS WITH INVALID VALUES '',
     &               ''WILL HAVE HEAD/DRAWDOWN VALUES RESET TO '',
     &               G21.8,
     &               /10X,85(''-''))')
     &               DEFHED
         WRITE(OUTUNT,'(10X,
     &               '' HEAD/DRAWDOWN    VALUES      '',
     &               ''       ROW'',
     &               ''    COLUMN'',
     &               ''     LAYER'',
     &               ''    IBOUND'')')
         WRITE(OUTUNT,'(10X,85(''-''))')
C
C4A----Set variables
C
         NCELLS=0
         BADIBD=0
         DRYCLL=0
         NOFLOW=0
         NUMCLL=0
         NUMCON=0
C
       IF(IVIEW.EQ.1) THEN
          STRCLL=1
          FINCLL=NCOL
       ELSE IF(IVIEW.EQ.2) THEN
          STRCLL=NCOL+1
          FINCLL=NCOL+NROW
       ELSE
          STRCLL=1
          FINCLL=IRWCL
       ENDIF
C
C4B----Loop to build cell arcs from head and row/column data
C
         DO 400 N=STRCLL,FINCLL
            NUMCLL=NUMCLL+1
          IF(IVIEW.LE.1) THEN
             IROW=IRWCL
             ICOL=NUMCLL
          ELSE IF(IVIEW.EQ.2) THEN
             IROW=NUMCLL
             ICOL=IRWCL
          ELSE
             ICOL=LRWCL(1,NUMCLL)
             IROW=LRWCL(2,NUMCLL)
          ENDIF
C
C4Ba----Write attributes of each cell and confining layer cells
C
            DO 410 ILAY=1,NLAY
               HEAD=HEDTRM(ICOL,IROW,ILAY)
               IBDCEL=ABS(IBOUND(ICOL,IROW,ILAY))
             IF(IBDCEL.EQ.0) THEN
                BADIBD=BADIBD+1
                WRITE(OUTUNT,'(10X,
     &                  ''IBOUND = 0                    '',
     &                  4I10)')
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
                HEAD=HNOFLO
                GO TO 410
             ENDIF
             IF(HEAD.EQ.HEDDRY) THEN
                DRYCLL=DRYCLL+1
                WRITE(OUTUNT,'(10X,
     &                  ''DRY CELL                      '',
     &                  4I10)')
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
                HEAD=HNOFLO
             ENDIF
             IF(HEAD.EQ.HNOFLO) THEN
                NOFLOW=NOFLOW+1
                WRITE(OUTUNT,'(10X,
     &                  ''NOFLOW CELL                   '',
     &                  4I10)')
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
                HEAD=HNOFLO
             ENDIF
             IF(HEAD.LT.DEFHED .OR. HEAD.GT.ABS(DEFHED)) THEN
                MAXCLL=MAXCLL+1
                WRITE(OUTUNT,'(10X,
     &                  ''HEAD EXCEEDED MAXIMUM HEAD    '',
     &                  4I10)')
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
                HEAD=HNOFLO
             ENDIF
C
               NCELLS=NCELLS+1
               WRITE(IOUT(2),'(I10,'','',
     &                          F16.3,'','')')
     &                       NCELLS,
     &                       HEAD
               WRITE(OUTUNT,'(10X,
     &                  F20.6,10X,
     &                  4I10)')
     &                          HEAD,
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
C
             IF(DELZCB(ILAY).GT.0.0) THEN
                NUMCON=NUMCON+1
                WRITE(OUTUNT,'(10X,
     &                  ''CONFINING LAYER CELL          '',
     &                  4I10)')
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
                NCELLS=NCELLS+1
                HEAD=HNOFLO
                WRITE(IOUT(2),'(I10,'','',
     &                          F16.3,'','')')
     &                       NCELLS,
     &                       HEAD
             ENDIF
  410       CONTINUE
  400    CONTINUE
         WRITE(OUTUNT,'(10X,85(''-''))')
C
C5----Build mapview for single ibound value (iview=5)
C
      ELSE IF(IVIEW.EQ.5) THEN
          WRITE(*,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms for ibound value '',
     &             I10,'' now...'')')
     &                             MODTXT (1:INDEX(MODTXT,' ')-1),
     &                             IRWCL
C
C5H---Data header
C
         WRITE(OUTUNT,'(//,1H1,15X,
     &               '' CELLS WITH INVALID VALUES '',
     &               ''WILL HAVE HEAD/DRAWDOWN VALUES RESET TO '',
     &               F16.3,
     &               /10X,85(''-''))')
     &               DEFHED
         WRITE(OUTUNT,'(40X,
     &               ''       ROW'',
     &               ''    COLUMN'',
     &               ''     LAYER'',
     &               ''    IBOUND'',
     &               /10X,85(''-''))')
C          WRITE(OUTUNT,'(//,1H1,20X,
C     &               '' CELL-BY-CELL HEAD/DRAWDOWN TERMS WITH '',
C     &               ''WITH SPECIFIED IBOUND VALUE '',I5,
C     &               /10X,85(''-''))')
C     &               IRWCL
C          WRITE(OUTUNT,'(20X,
C     &               ''       ROW'',
C     &               ''    COLUMN'',
C     &               ''     LAYER'',
C     &               ''      HYDRAULIC'',
C     &               ''     SATURATION'')')
C          WRITE(OUTUNT,'(20X,
C     &               ''          '',
C     &               ''          '',
C     &               ''          '',
C     &               ''           HEAD'',
C     &               ''         FACTOR'',
C     &               /10X,85(''-''))')
C
C5A----Grid label attributes
C
         LAYIBD=IRWCL
C
         DO 500 IROW=1,NROW
            DO 510 ICOL=1,NCOL
               SATIBD=0.0
               IBDFLG=0
               DO 520 ILAY=1,NLAY
                  IBDCEL=ABS(IBOUND(ICOL,IROW,ILAY))
                IF(IBDCEL.EQ.LAYIBD) THEN
                   IBDFLG=1
                   TOP=ZTOP(ICOL,IROW,ILAY)
                   BOT=ZBOT(ICOL,IROW,ILAY)
                   HEDIBD=HEDTRM(ICOL,IROW,ILAY)
                 IF(HEDTRM(ICOL,IROW,ILAY).EQ.HEDDRY) THEN
                    DRYCLL=DRYCLL+1
                    WRITE(OUTUNT,'(10X,
     &                      ''DRY CELL                      '',
     &                      4I10)')
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL
                    GO TO 520
                 ENDIF
                 IF(HEDTRM(ICOL,IROW,ILAY).EQ.HNOFLO) THEN
                    NOFLOW=NOFLOW+1
                    WRITE(OUTUNT,'(10X,
     &                      ''NOFLOW CELL                   '',
     &                      4I10)')
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL
                    GO TO 520
                 ENDIF
                 IF(HEDIBD.LT.DEFHED .OR. HEDIBD.GT.ABS(DEFHED)) THEN
                    MAXCLL=MAXCLL+1
                    WRITE(OUTUNT,'(10X,
     &                  ''HEAD EXCEEDED MAXIMUM HEAD    '',
     &                  4I10)')
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
                    GO TO 520
                 ENDIF
C
                 IF(HEDIBD.GE.TOP) THEN
                    SATCEL=TOP-BOT
                 ELSE
                  IF(HEDIBD.LE.BOT) THEN
                     SATCEL=0.0
                  ELSE
                     SATCEL=HEDIBD-BOT
                  ENDIF
                 ENDIF
                   SATIBD=SATIBD+SATCEL
                ENDIF
  520          CONTINUE
             IF(SATIBD.GT.0.0) THEN
                HEDIBD=0.0
                TOPIBD=-999999999999.99
                BOTIBD=-TOPIBD
                DO 530 ILAY=1,NLAY
                   IBDCEL=ABS(IBOUND(ICOL,IROW,ILAY))
                 IF(IBDCEL.EQ.LAYIBD) THEN
                    TOP=ZTOP(ICOL,IROW,ILAY)
                    BOT=ZBOT(ICOL,IROW,ILAY)
                    HEDFAC=(TOP-BOT)/SATIBD
                 IF(HEDTRM(ICOL,IROW,ILAY).EQ.HEDDRY) GO TO 530
                 IF(HEDTRM(ICOL,IROW,ILAY).EQ.HNOFLO) GO TO 530
                    HEDIBD=HEDIBD+HEDFAC*HEDTRM(ICOL,IROW,ILAY)
C                    WRITE(OUTUNT,'(20X,3I10,2F15.3)')
C     &                                         IROW,
C     &                                         ICOL,
C     &                                         ILAY,
C     &                                         HEDTRM(ICOL,IROW,ILAY),
C     &                                         SATIBD
                 ENDIF
  530           CONTINUE
C
                NCELLS=NCELLS+1
                SEQNUM=(IROW-1)*NCOL+ICOL
                NUMCLL=(IROW-1)*NCOL+ICOL
                ROWCOL=IROW*(10**LENCOL)+ICOL
                WRITE(CHRWCL,'(I10)') ROWCOL
                FINCHR=10
                STRCHR=FINCHR-(LENROW+LENCOL-1)
                WRITE(IOUT(2),'(
     &                          I10,'','',
     &                          A,'','',
     &                          3(I10,'',''),
     &                          F16.3,'','')')
     &                       SEQNUM,
     &                       CHRWCL (STRCHR:FINCHR),
     &                       IROW,
     &                       ICOL,
     &                       LAYIBD,
     &                       HEDIBD
             ELSE
                BASIBD=BADIBD+1
             ENDIF
  510       CONTINUE
  500    CONTINUE
         WRITE(OUTUNT,'(10X,85(''-''))')
C
C6----Build mapview for uppermost active cell (iview=6)
C
      ELSE
          WRITE(*,'(
     &             ''      .Processing cell-by-cell '',
     &             A,'' terms uppermost active cell now...'')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1)
C
C5H---Data header
C
         WRITE(OUTUNT,'(//,1H1,15X,
     &               '' CELL-BY-CELL HEAD/DRAWDOWN TERMS '',
     &               ''FOR UPPERMOST ACTIVE CELL'',
     &               /10X,85(''-''))')
         WRITE(OUTUNT,'(15X,
     &               '' CELLS WITH INVALID VALUES '',
     &               ''WILL HAVE HEAD/DRAWDOWN VALUES RESET TO '',
     &               F20.6,
     &               /10X,85(''-''))')
     &               DEFHED
         WRITE(OUTUNT,'(40X,
     &               ''       ROW'',
     &               ''    COLUMN'',
     &               ''     LAYER'',
     &               ''    IBOUND'',
     &               /10X,85(''-''))')
C
C6A----Grid cell attributes
C
         DO 600 IROW=1,NROW
            DO 610 ICOL=1,NCOL
               NCELLS=NCELLS+1
               DO 620 ILAY=1,NLAY
                  IBDCEL=ABS(IBOUND(ICOL,IROW,ILAY))
                   HEAD=HEDTRM(ICOL,IROW,ILAY)
                IF(IBDCEL.NE.0) THEN
                 IF(HEAD.EQ.HEDDRY) THEN
                    DRYCLL=DRYCLL+1
                    WRITE(OUTUNT,'(10X,
     &                      ''DRY CELL                      '',
     &                      4I10)')
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL
                    GO TO 620
                 ENDIF
                 IF(HEAD.EQ.HNOFLO) THEN
                    NOFLOW=NOFLOW+1
                    WRITE(OUTUNT,'(10X,
     &                      ''NOFLOW CELL                   '',
     &                      4I10)')
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL
                    GO TO 620
                 ENDIF
                 IF(HEAD.LT.DEFHED .OR. HEAD.GT.ABS(DEFHED)) THEN
                    MAXCLL=MAXCLL+1
                    WRITE(OUTUNT,'(10X,
     &                  ''HEAD EXCEEDED MAXIMUM HEAD    '',
     &                  4I10)')
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          IBDCEL
                    GO TO 620
                 ENDIF
C
                   SEQNUM=(IROW-1)*NCOL+ICOL
                   NUMCLL=(IROW-1)*NCOL+ICOL
                   ROWCOL=IROW*(10**LENCOL)+ICOL
                   WRITE(CHRWCL,'(I10)') ROWCOL
                   FINCHR=10
                   STRCHR=FINCHR-(LENROW+LENCOL-1)
                   WRITE(IOUT(2),'(
     &                             I10,'','',
     &                             A,'','',
     &                             3(I10,'',''),
     &                             F16.3,'','')')
     &                          SEQNUM,
     &                          CHRWCL (STRCHR:FINCHR),
     &                          IROW,
     &                          ICOL,
     &                          ILAY,
     &                          HEDTRM(ICOL,IROW,ILAY)
C
                    WRITE(OUTUNT,'(10X,
     &                      ''HEAD '',
     &                      F25.6,
     &                      4I10)')
     &                          HEDTRM(ICOL,IROW,ILAY),
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL

                   GO TO 610
                ELSE
                    WRITE(OUTUNT,'(10X,
     &                      ''INACTIVE CELL                 '',
     &                      4I10)')
     &                              IROW,
     &                              ICOL,
     &                              ILAY,
     &                              IBDCEL
                ENDIF
  620          CONTINUE
  610       CONTINUE
  600    CONTINUE
         WRITE(OUTUNT,'(10X,85(''-''))')
      ENDIF
C
C7----Close attribute files
C
      CALL CLOSE_FILE (FILES(2),*9999)
C
C8----Messages
C
C
C8A----Message to user
C
      WRITE(*,'(
     &          ''      .Cell-by-cell '',
     &          A,'' term file '',A,
     &          '' consists of '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              HEDFIL (1:INDEX(HEDFIL,' ')-1)
      WRITE(*,'(''      .'',I10,'' cells'')') NCELLS
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''ommited (ibound = 0)'')') BADIBD
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''ommited (dry)'')') DRYCLL
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''ommited (noflow)'')') NOFLOW
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''ommited (head exceed maximum)'')') MAXCLL
      WRITE(*,'(''      .'',I10,'' cells were '',
     &          ''in confining layer'')') NUMCON
C
C8B----Message to operational output file
C
      WRITE(OUTUNT,'(
     &          ''      .Cell-by-cell '',
     &          A,'' term file '',A,
     &          '' consists of '')')
     &                              MODTXT (1:INDEX(MODTXT,' ')-1),
     &                              HEDFIL (1:INDEX(HEDFIL,' ')-1)
      WRITE(OUTUNT,'(''      .'',I10,'' cells'')') NCELLS
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''ommited (ibound = 0)'')') BADIBD
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''ommited (dry)'')') DRYCLL
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''ommited (noflow)'')') NOFLOW
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''ommited (head exceed maximum)'')') MAXCLL
      WRITE(OUTUNT,'(''      .'',I10,'' cells were '',
     &          ''in confining layer'')') NUMCON
C
C9----Arc Operations to coverage and attribute files
C
      IF(IVIEW.NE.3) THEN
         CALL DELETE_FILE (FILES(MAXFIL),*9999)
         CALL OPEN_FILE (IOUT(MAXFIL),FILES(MAXFIL),NSTAT,ITALK,*9999)
      ELSE
         FILES(1)='arccmd.old'
         CALL DELETE_FILE (FILES(1),*9999)
         FILES(MAXFIL)='arccmd'
         CALL OPEN_FILE (IOUT(MAXFIL),FILES(1),NSTAT,ITALK,*9999)
         DO 900 N=1,100
            READ(IOUT(MAXFIL),'(A)',END=902) ARCCMD
            WRITE(IOUT(1),'(A)') ARCCMD
  900    CONTINUE
  902    CALL CLOSE_FILE (FILES(MAXFIL),*9999)
         CALL DELETE_FILE (FILES(MAXFIL),*9999)
         CALL OPEN_FILE (IOUT(MAXFIL),FILES(MAXFIL),NSTAT,ITALK,*9999)
         CALL CLOSE_FILE (FILES(1),*9999)
         CALL OPEN_FILE (IOUT(1),FILES(1),NSTAT,ITALK,*9999)
         DO 910 N=1,100
            READ(IOUT(1),'(A)',END=912) ARCCMD
            WRITE(IOUT(MAXFIL),'(A)') ARCCMD
  910    CONTINUE
  912    CALL CLOSE_FILE (FILES(1),*9999)
         CALL DELETE_FILE (FILES(1),*9999)
      ENDIF
C
C9A----Create attribute files and "add from" attributes
C
      IF(IVIEW.LE.0 .OR. IVIEW.GE.4) THEN
         ARCCMD='tables'
         TMPFIL=FILES(1) (1:INDEX(FILES(1),' ')-1)
         ADDFIL=FILES(2) (1:INDEX(FILES(2),' ')-1)
         WRITE(IOUT(MAXFIL),'(A,2(1X,A))')
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             TMPFIL (1:INDEX(TMPFIL,' ')-1),
     &                             ADDFIL (1:INDEX(ADDFIL,' ')-1)
C
C9B---Join attribute files (if needed)
C
      ELSE
         ARCCMD='tables'
         TMPFIL=FILES(1) (1:INDEX(FILES(1),' ')-1)
         ADDFIL=FILES(2) (1:INDEX(FILES(2),' ')-1)
         ACTION='kill'
         WRITE(IOUT(MAXFIL),'(A,3(1X,A))')
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             TMPFIL (1:INDEX(TMPFIL,' ')-1),
     &                             ADDFIL (1:INDEX(ADDFIL,' ')-1),
     &                             ACTION (1:INDEX(ACTION,' ')-1)
         ARCCMD='joinitem'
         LABFIL=HEDFIL (1:INDEX(HEDFIL,' ')-1)//'.pat'
         INPFIL=FILES(2) (1:INDEX(FILES(2),' ')-1)
         RELITM=HEDFIL (1:INDEX(HEDFIL,' ')-1)//'-id'
         STRITM='thick'
         JONTYP='linear'
         WRITE(IOUT(MAXFIL),'(A,6(1X,A))')
     &                             ARCCMD (1:INDEX(ARCCMD,' ')-1),
     &                             LABFIL (1:INDEX(LABFIL,' ')-1),
     &                             INPFIL (1:INDEX(INPFIL,' ')-1),
     &                             LABFIL (1:INDEX(LABFIL,' ')-1),
     &                             RELITM (1:INDEX(RELITM,' ')-1),
     &                             STRITM (1:INDEX(STRITM,' ')-1),
     &                             JONTYP (1:INDEX(JONTYP,' ')-1)
      ENDIF
      CALL CLOSE_FILE (FILES(MAXFIL),*9999)
       GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,'(//,'' Exceed maximum number of unique ibound values '',
     &          '' > '',I10)') 
     &        MAXIBD
 9999 WRITE(*,
     &    '(//,'' Abnormal termination of Pthhed_Subroutine'')')
      WRITE(OUTUNT,
     &    '(//,'' Abnormal termination of Pthhed_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
