      PROGRAM MODTOOLS
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************               Modtools version 6.0                **************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**           The source code is available from below:                       **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 MODTOOLS 03OCTOBER1999
C
C::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     MODTOOLS is a replacement program for MODPATH-PLOT (Pollock, 1989)
C      that uses the results from the particle tracking program MODPATH 
C      (Pollock, 1989) to create Arc/Info coverages or Info files.  This  
C      replacement program does most options and plots that are available 
C      in MODPATH-PLOT.
C
C     The usage of the MODTOOLS program is documented in 
C      Orzol, L.L., 1997, Users' guide for MODTOOLS: Computer Programs for 
C       translating data of MODFLOW and MODPATH into Geographic
C       Information System files, U.S. Geological Survey Open-File Report
C       97-240, 86 p.
C
C
C     ADDITIONALLY, MODTOOLS generates a database of 40 to 70 particle 
C      characteristics such as particle velocities along the x,y, and z axes,
C      starting position information (row, column, and layer), finishing
C      position information (row, column, and layer), and many others.
C
C     ALSO, MODTOOLS generates coverages or Info files using the 
C      cell-by-cell flow terms that are output by the different 
C      packages of the U.S. Geological Survey Modular Three-Dimensional 
C      Finite-Differences Ground-Water Flow Model MODFLOW (McDonald and 
C      Harbaugh, 1988). These packages are:
C                         (1) River [RIV1];
C                         (2) Evapotranspiration [EVT1];
C                         (3) Well [WEL1];
C                         (4) Recharge [RCH1];
C                         (5) Drain [DRN1];
C                         (6) General-Head boundary [GHB1];
C                         (7) Block-Centered [BCF1, BCF2, or BCF3]
C                         (8) Streamflow-Routing (Pudric, 1989).
C
C     ALSO, MODTOOLS generates coverages using the cell-by-cell flow terms
C      of Block-Centered Package (constant_heads, flow_front_face, 
C      flow_lower_face, and flow_right_face).
C
C     ALSO, MODTOOLS generates coverages using the head terms
C      from the Basic Package.
C
C     ALSO, MODTOOLS generates contour coverages using the 
C      cell-by-cell flow, drawdown, and head terms output by the different 
C      packages of the U.S. Geological Survey Modular Three-Dimensional 
C      Finite-Differences Ground-Water Flow Model MODFLOW
C      (McDonald and Harbaugh, 1988).
C
C      Coverages that are generated: 
C
C    Pathlines of the simulated particles (line topology)
C      (a) mapviews of pathlines,
C      (b) vertical profiles along row,
C      (c) vertical profiles along column,
C      (d) vertical profiles along user specified particle pathline;
C
C    Starting/Finishing points of the simulated particles (point topology)
C      (a) mapviews of starting and finishing;
C
C    Time-series points of the simulated particles (point topology)
C      (a) mapviews of time-series points,
C      (b) vertical profiles along row,
C      (c) vertical profiles along column;
C
C    Profiles of model-grid geometry (polygon topology)
C      (a) vertical profiles along row,
C      (b) vertical profiles along column,
C     *(c) vertical profiles along user specified particle pathline;
C
C   *Cell_by_cell flow terms (Info file)
C      (a) mapview
C      (b) vertical profiles along row,
C      (c) vertical profiles along column,
C      (d) vertical profiles along user specified particle pathline;
C
C   *Cell_by_cell head and drawdown terms (Info file)
C      (a) mapview
C      (b) vertical profiles along row,
C      (c) vertical profiles along column,
C      (d) vertical profiles along user specified particle pathline;
C
C    Contour (polygon topology)
C      (a) mapview 
C      (b) vertical profiles along row,
C      (c) vertical profiles along column,
C      (d) vertical profiles along user specified particle pathline; 
C           [unavailable]
C
C   *--not available using MODPATH-PLOT
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN, (standard FORTRAN77)
C
C
C    Inputs:
C
C      INSTR  ==  (Character*128) The command string passed from the
C                  Modtools.aml program that is parse into the following:
C                  coverage name, name file, and pmrfil file names.
C
C      Files:
C
C       COVER    : COVERAGE NAME
C       BASFIL   : MODPATH MAIN FILE CONTAINING MODELING PROBLEM INFORMATION
C       PMRFIL   : FILE COVERAGE INFORMATION
C
C    Outputs:  None
C
C     Program:
C
C      Variables:
C
C     BASUNT  : FORTRAN UNIT NUMBER FOR MODPATH MAIN FILE
C     TRMFIL  : MODFLOW BLOCK CENTERED PACKAGE OUTPUT [BINARY FORMAT]
C     TRMUNT  : FORTRAN UNIT NUMBER FOR CELL-BY-CELL FLOW TERM FILE
C     TRMUNT  : FORTRAN UNIT NUMBER FOR INPUT MODFLOW PACKAGE
C     ENDFIL  : MODPATH ENDPOINT FILE
C     ENDUNT  : FORTRAN UNIT NUMBER FOR MODPATH ENDPOINT FILE
C     COVFLG  : LOGICAL FLAG FOR COVERAGE PARAMETERS FILE
C             => TRUE READ PARAMETERS FROM PMRFIL FILE
C             => FALSE PROMPT USER FROM PARAMETERS AND WRITE TO PMRFIL FILE
C     HEDFIL  : MODFLOW CELL-BY-CELL HEAD TERM FILE
C     HEDUNT  : FORTRAN UNIT NUMBER FOR INPUT BASIC_PACKAGE_HEADS FILE
C     ICOVER  : FLAG (TYPE OF COVERAGE)
C     IGRID   : GRID GEOMETRY CODE
C             => 0 VARYING THICKNESS MODEL LAYERS
C                   AND(OR) NONHORIZONTAL LAYERS
C             => 1 TRUE RECTANGLAR 3-D GRID (UNIFORM THICKNESS MODEL LAYERS)
C     ISUM    : INDEX NUMBER TO COMMON BLOCK ARRAY FOR ALLOCATION
C     ITALK   : FLAG FOR INTERACTIVE DIALOG
C             => 1 NON-INTERACTIVE DIALOG
C             => 0 INTERACTIVE DIALOG
C     IVIEW   : FLAG (ORIENTATION OF COVERAGE)
C             => 0 MAPVIEW
C             => 1 ROW VERTICAL PROFILE
C             => 2 COLUMN VERTICAL PROFILE
C             => 3 PARTICLE-ID VERTICAL PROFILE
C             => 4 MODEL LAYER MAPVIEW
C             => 5 MODEL IBOUND VALUE MAPVIEW
C             => 6 UPPERMOST ACTIVE CELL MAPVIEW
C     LAYCON  : INTEGER FLAG FOR LAYER ONE TYPE
C     LCATRB  : STARTING ARRAY INDEX FOR ATTRIBUTE TABLE (ARCS,LABELS)
C     LCCHDB  : STARTING ARRAY INDEX FOR CELL_BY_CELL CONSTANT_HEAD TERMS
C     LCCVPR  : STARTING ARRAY INDEX FOR COVERAGE PARAMETERS
C     LCDELX  : STARTING ARRAY INDEX FOR CELL WIDTHS IN ROW/COLUMN/PARTICLE
C                DIRECTION
C     LCDELZ  : STARTING ARRAY INDEX FOR NUMBER MODEL LAYERS/UNITS
C     LCDZCB  : STARTING ARRAY INDEX FOR CONFINING LAYERS/UNITS
C     LCFRFB  : STARTING ARRAY INDEX FOR CELL_BY_CELL FLOW_RIGHT_FACE FLUX
C     LCFFFB  : STARTING ARRAY INDEX FOR CELL_BY_CELL FLOW_FRONT_FACE FLUX
C     LCFLFB  : STARTING ARRAY INDEX FOR CELL_BY_CELL FLOW_LOWER_FACE FLUX
C     LCHEAD  : STARTING ARRAY INDEX FOR CELL_BY_CELL HEADS
C     LCIBOU  : STARTING ARRAY INDEX FOR IBOUND ARRAY
C     LCNCRD  : STARTING ARRAY INDEX FOR NUMBER OF COORDINATES IN EACH ARC
C     LCRWCL  : STARTING ARRAY INDEX FOR THE CELL'S ROW OR COLUMN
C     LCZBOT  : STARTING ARRAY INDEX FOR LAYER/UNIT BOTTOM ELEVATIONS
C     LCZTOP  : STARTING ARRAY INDEX FOR LAYER/UNIT TOP ELEVATIONS
C     LCPORO  : STARTING ARRAY INDEX FOR POROSITY
C     MAXATB  : MAXIMUM NUMBER OF ATTRIBUTES IN PARTICLE ATTRIBUTE TABLE
C     MAXPMR  : MAXIMUM NUMBER OF COVERAGE PARAMETERS
C     MAXPTS  : MAXIMUM NUMBER OF PARTICLE POSITIONS
C     MODFLG  : FLAG (MODPATH TRACKING MODE AND FORMAT)
C     NCBL    : NUMBER OF QUASI-3D CONFINING LAYERS
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NDELX   : NUMBER OF CELL WIDTHS IN ROW/COLUMN/PARTICLE DIRECTION
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C     NSTAT   : STATUS OF FILE
C             => 1 OLD FILE
C             => 2 NEW FILE
C             => 3 SCRATCH FILE (DELETED AUTOMATICALLY WHEN RUN ENDS)
C             => 4 UNDETERMINED STATUS (MAY OR MAY NOT EXIST)
C                   IF IT DOES NOT EXIST, IT IS CREATED BY OPEN STATEMENT
C                   IF IT DOES EXIST, IT IS OPENED AS 'OLD' FILE
C     NUNIT   : FORTRAN UNIT NUMBER
C     OUTFIL  : MODTOOLS OPERATIONS FILE NAME
C             => MODTOOLS.OUT LISTS ALLOCATION SPACE, COVERAGE PARAMETERS,
C                 ARRAYS INFORMATION READ BY MODTOOLS DURING OPERATION
C     OUTUNT  : FORTRAN UNIT NUMBER FOR MODTOOLS OUTPUT LSTING FILE
C     STRDEX  : CHARACTER STRING INDEX
C     XSCOV   : VERTICAL PROFILE COVERAGE NAME OF MODEL CELLS
C
C-------------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
      PARAMETER (LENX=100000000,
     &           MAXATB=70,
     &           MAXFIL=40,
     &           MAXPMR=30, 
     &           MAXPTS=100000)
C
      CHARACTER*128 ARCCMD,ARCCRS,INSTR,OUTSTR,PMRFIL,COVER,
     &              FILES(MAXFIL),XSCOV,
     &              OUTFIL,
     &              NAMFIL,
     &              BASFIL,
     &              TRMFIL,
     &              CTLFIL,
     &              ENDFIL,
     &              PTHFIL,
     &              TIMFIL,
     &              HEDFIL,
     &              HCLFIL,
     &              DDNFIL,
     &              DCLFIL,
     &              ARRFIL,
     &              ACLFIL,
     &              CONFIL,
     &              LVLFIL 
C
      INTEGER MODFLG,ICOVER,IVIEW,IRWCL,STRDEX,NUNITS(MAXFIL),
     &        MAXCOL,MAXROW,MAXXND,MAXYND,
     &        OUTUNT,
     &        NAMUNT,
     &        BASUNT,
     &        TRMUNT,
     &        CTLUNT,
     &        ENDUNT,
     &        PTHUNT,
     &        TIMUNT,
     &        HEDUNT,
     &        HCLUNT,
     &        DDNUNT,
     &        DCLUNT,
     &        ARRUNT,
     &        ACLUNT,
     &        CONUNT,
     &        LVLUNT
C
      LOGICAL COVFLG,FILFLG,EXISTS,OPN 
C
      COMMON /XCMN/ X(LENX)
C
      DATA ARCCMD,ARCCRS /'arccmd','arccrs'/
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       Modtools Version
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CH*********************************************************************C
      OUTUNT=81
      NSTAT=2
      ITALK=1
      OUTFIL='modtools.list'
      CALL DELETE_FILE (OUTFIL,*9998)
      CALL OPEN_FILE (OUTUNT,OUTFIL,NSTAT,ITALK,*9998)
C
CH----Print a message identifying the package
C
      WRITE(OUTUNT,'(1H0,10X,85(''*''))')
      WRITE(OUTUNT,'(40X,''U.S. GEOLOGICAL SURVEY '')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(35X,
     &               ''MODTOOLS -- MODPATH/MODFLOW GIS PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(40X,''VERSION 6.0 03OCTOBER1999 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,''C*'',80(''=''),''*C'')')
      WRITE(OUTUNT,'(10X,''C*'',80('':''),''*C'')')
      WRITE(OUTUNT,'(10X,
     &               ''C* Purpose: Although this program has been '',
     &               ''used by the U.S. Geological Survey,'')')
      WRITE(OUTUNT,'(10X,
     &               ''C*           no warranty, expressed or '',
     &               ''implied, is made by the USGS as to the'')')
      WRITE(OUTUNT,'(10X,
     &               ''C*           accuracy and functioning of the '',
     &               ''program and related program'')')
      WRITE(OUTUNT,'(10X,
     &               ''C*           material nor shall the fact of '',
     &               ''distribution constitute any such'')')
      WRITE(OUTUNT,'(10X,
     &               ''C*           warranty, and no responsibility '',
     &               ''is assumed by the USGS in'')')
      WRITE(OUTUNT,'(10X,''C*           connection therewith.'')')
      WRITE(OUTUNT,'(10X,''C*'',80('' ''),''*C'')')
      WRITE(OUTUNT,'(10X,''C*'',80('':''),''*C'')')
      WRITE(OUTUNT,'(10X,''C*'',80(''=''),''*C'')')
C
CH----Display package to terminal screen
C
      WRITE(*,'(1X,79(''*''))')
      WRITE(*,'(30X,''U.S. GEOLOGICAL SURVEY '')')
      WRITE(*,'(1X,79(''-''))')
      WRITE(*,'(21X,''MODTOOLS -- MODPATH/MODFLOW GIS PACKAGE'')')
      WRITE(*,'(1X,79(''-''))')
      WRITE(*,'(30X,''VERSION 6.0 03OCTOBER1999 '')')
      WRITE(*,'(1X,79(''-''))')
      WRITE(*,'(1X,''C*'',75(''=''),''*C'')')
      WRITE(*,'(1X,''C*'',75('':''),''*C'')')
      WRITE(*,'(1X,''C* Purpose: Although this program has been '',
     &             ''used by the U.S. Geological Survey,'')')
      WRITE(*,'(1X,''C*           no warranty, expressed or '',
     &             ''implied, is made by the USGS as to the'')')
      WRITE(*,'(1X,''C*           accuracy and functioning of the '',
     &             ''program and related program'')')
      WRITE(*,'(1X,''C*           material nor shall the fact of '',
     &             ''distribution constitute any such'')')
      WRITE(*,'(1X,''C*           warranty, and no responsibility '',
     &             ''is assumed by the USGS in'')')
      WRITE(*,'(1X,''C*           connection therewith.'')')
      WRITE(*,'(1X,''C*'',75('':''),''*C'')')
      WRITE(*,'(1X,''C*'',75('':''),''*C'')')
      WRITE(*,'(1X,''C*'',75(''=''),''*C'')')
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                 Parse Instr into Arguements
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C1*********************************************************************C
      INQUIRE (
     F         FILE=ARCCMD,
     I         IOSTAT=IERR,
     L         ERR=9999,
     E         EXIST=EXISTS,
     S         OPENED=OPN
     &         )
C
CP----Parse Modtools argument string
C
      IF(EXISTS) THEN
         WRITE(*,'('' .Parsing Modtools argument string...'')')
         NSTAT=1
         ITALK=1
         INCMD=80
         CALL OPEN_FILE (INCMD,ARCCMD,NSTAT,ITALK,*9998)
         READ(INCMD,'(A128)',ERR=9990,END=9991) INSTR
         CALL CLOSE_FILE (ARCCMD,*9998)
         CALL DELETE_FILE (ARCCMD,*9998)
C
C1A-----Parsing for Coverage name from Instr
C
         STRDEX=INDEX(INSTR,' ')
       IF(STRDEX.GT.12) THEN
          COVER=COVER (1:11)
       ELSE
          COVER=INSTR (1:STRDEX-1)
       ENDIF
         INSTR=INSTR (STRDEX+1:LEN(INSTR))
C
C1B-----Parsing for Problem definition file from Instr
C
         STRDEX=INDEX(INSTR,' ')
         NAMFIL=INSTR (1:STRDEX-1)
         INSTR=INSTR (STRDEX+1:LEN(INSTR))
C
C1C-----Parsing for Coverage parameter file from Instr
C
         COVFLG=.FALSE.
         STRDEX=INDEX(INSTR,' ')
       IF(STRDEX.GT.1) THEN
          PMRFIL=INSTR (1:STRDEX-1)
          INSTR=INSTR (STRDEX+1:LEN(INSTR))
          COVFLG=.TRUE.
        IF(PMRFIL.EQ.'#') THEN
           COVFLG=.FALSE.
           PMRFIL='modtools.out'
        ENDIF
       ELSE
          PMRFIL='modtools.out'
       ENDIF 
C 
CF----Question user 
C 
      ELSE 
         WRITE(*,'('' Enter the name of the GIS output that will '', 
     &             '' be created by MODTOOLS'')') 
         READ(*,'(A)',ERR=9999,END=9999) COVER 
       IF(INDEX(COVER,' ').EQ.1) GO TO 9999 
C 
  102    WRITE(*,'('' Enter the name of the MODTOOLS'', 
     &             '' NAME file'')') 
         READ(*,'(A)',ERR=9999,END=9999) NAMFIL 
       IF(INDEX(NAMFIL,' ').EQ.1) GO TO 9999 
         INQUIRE ( 
     F            FILE=NAMFIL, 
     I            IOSTAT=IERR, 
     L            ERR=9999, 
     E            EXIST=EXISTS, 
     S            OPENED=OPN 
     &           ) 
       IF(.NOT.EXISTS) THEN 
          WRITE(*,'('' MODTOOLS NAME file '',A,'' does not '', 
     &              ''exist'')') NAMFIL (1:INDEX(NAMFIL,' ')) 
          GO TO 102 
       ENDIF 
C 
  104    WRITE(*,'('' Enter the name of the optional'', 
     &             '' MODTOOLS batch file'')') 
         READ(*,'(A)',ERR=9999,END=9999) PMRFIL 
       IF(INDEX(PMRFIL,' ').LE.1) THEN 
          COVFLG=.FALSE. 
          PMRFIL='modtools.out' 
       ELSE 
          INQUIRE ( 
     F             FILE=PMRFIL, 
     I             IOSTAT=IERR, 
     L             ERR=9999, 
     E             EXIST=EXISTS, 
     S             OPENED=OPN 
     &            ) 
        IF(.NOT.EXISTS) THEN 
           WRITE(*,'('' MODTOOLS BATCH file '',A,'' does not '', 
     &               ''exist'')') PMRFIL (1:INDEX(PMRFIL,' ')) 
           GO TO 104 
        ENDIF 
          COVFLG=.TRUE. 
       ENDIF 
      ENDIF 
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       READ FILE NAMES FROM NAME FILE
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C2*********************************************************************C
      WRITE(*,'(
     &          '' ..Reading MODTOOLS Name file '',A)')
     &          NAMFIL (1:INDEX(NAMFIL,' ')-1)
      CALL PTHFLS (
     I             OUTFIL,OUTUNT,
     I             NAMFIL,NAMUNT,
     O             BASFIL,BASUNT,
     O             TRMFIL,TRMUNT,
     O             CTLFIL,CTLUNT,
     O             ENDFIL,ENDUNT,
     O             PTHFIL,PTHUNT,
     O             TIMFIL,TIMUNT,
     O             HEDFIL,HEDUNT,
     O             HCLFIL,HCLUNT,
     O             DDNFIL,DDNUNT,
     O             DCLFIL,DCLUNT,
     O             ARRFIL,ARRUNT,
     O             ACLFIL,ACLUNT,
     O             CONFIL,CONUNT,
     O             LVLFIL,LVLUNT,
     E             *9998)
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       BASIC PROBLEM DEFINITION
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C3*********************************************************************C
      WRITE(*,'('' ...Reading MODPATH main file '',
     &          ''and allocating space '')')
      CALL PTHBAS (
     I             OUTFIL,OUTUNT,
     I             BASFIL,BASUNT,
     O             NLAY,NROW,NCOL,NCBL,IGRID,NPER,
     O             HNOFLO,HDRY,
     E             *9998)
C
      LCCVPR=1
      ISUM=LCCVPR+MAXPMR
      X(15)=HNOFLO
      X(16)=HDRY
      X(17)=INT(NPER)
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       COVERAGE PARAMTERS OPERATIONS
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C4*********************************************************************C
      IF(COVFLG) THEN
         WRITE(*,'('' ....Reading coverage parameters...'')')
         CALL PTHPMR (
     I                OUTUNT,
     I                PMRFIL,
     I                MAXPMR,
     I                NROW,NCOL,NLAY,
     O                X(LCCVPR),
     E                *9998)
      ELSE
         WRITE(*,'('' ....Prompting for coverage parameters...'')')
         CALL PTHPMT (
     I                OUTUNT,
     I                PMRFIL,COVER,
     I                MAXPMR,
     I                NROW,NCOL,NLAY,
     O                X(LCCVPR),
     E                *9998)
      ENDIF
C
      MODFLG=INT(X(1))
      ICOVER=INT(X(2))
      IVIEW=INT(X(10))
C
      CALL PTHLST (
     I             OUTFIL,OUTUNT,
     I             COVER,
     I             PMRFIL,
     I             NAMFIL,
     I             BASFIL,
     I             TRMFIL,
     I             ENDFIL,
     I             PTHFIL,
     I             TIMFIL,
     I             HEDFIL,
     I             HCLFIL,
     I             DDNFIL,
     I             DCLFIL,
     I             ARRFIL,
     I             ACLFIL,
     I             CONFIL,
     I             LVLFIL,
     I             MAXPMR,
     I             NROW,NCOL,NLAY,
     I             X(LCCVPR),
     E             *9998)
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       ALLOCATE OPERATIONS
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C5*********************************************************************C
      IF(ICOVER.LE.1) THEN
         WRITE(*,'('' .....Allocating space for '',
     &             ''pathline coverage...'')')
         CALL LNSALL (
     I                OUTUNT,
     I                LENX,
     I                MAXATB,MAXPTS,
     B                ISUM,
     O                LCATRB,
     E                *9998)
      ENDIF
C
      IF(ICOVER.EQ.2) THEN
         WRITE(*,'('' .....Allocating space for '',
     &             ''ending/starting point coverage'')')
         CALL ENDALL (
     I                OUTUNT,
     I                LENX,
     I                MAXATB,MAXPTS,
     B                ISUM,
     O                LCATRB,
     E                *9998)
      ENDIF
C
      IF(ICOVER.EQ.3) THEN
         WRITE(*,'('' .....Allocating space for '',
     &             ''time-series point coverage'')')
         CALL TIMALL (
     I                OUTUNT,
     I                LENX,
     I                MAXATB,MAXPTS,
     B                ISUM,
     O                LCATRB,
     E                *9998)
      ENDIF
C
      IF(ICOVER.EQ.4) THEN
         WRITE(*,'('' .....Allocating space for '',
     &             ''Zones_of_transport coverage'')')
         CALL ZOTALL (
     I                OUTUNT,
     I                LENX,
     I                MAXATB,MAXPTS,
     B                ISUM,
     O                LCATRB,
     E                *9998)
      ENDIF
C
      IF(ICOVER.EQ.6) THEN
       IF(MODFLG.LT.2) THEN
          WRITE(*,'('' .....Allocating space for '',
     &              ''cell-by-cell head terms...'')')
          CALL HEDALL (
     I                 HEDFIL,HEDUNT,
     I                 HCLFIL,HCLUNT,
     I                 OUTUNT,
     I                 LENX,
     I                 NLAY,NROW,NCOL,
     B                 ISUM,
     O                 LCHEAD,
     E                 *9998)
       ELSE IF(MODFLG.LT.3) THEN
          WRITE(*,'('' .....Allocating space for '',
     &              ''cell-by-cell drawdown terms...'')')
          CALL HEDALL (
     I                 DDNFIL,DDNUNT,
     I                 DCLFIL,DCLUNT,
     I                 OUTUNT,
     I                 LENX,
     I                 NLAY,NROW,NCOL,
     B                 ISUM,
     O                 LCHEAD,
     E                 *9998)
       ELSE IF(MODFLG.EQ.3) THEN
          WRITE(*,'('' .....Allocating space for '',
     &              ''cell-by-cell flow terms...'')')
          CALL CBCALL (
     I                 OUTUNT,
     I                 LENX,
     I                 NLAY,NROW,NCOL,
     B                 ISUM,
     O                 LCCHDB,LCFFFB,LCFLFB,LCFRFB,
     E                 *9998)
       ELSE IF(MODFLG.EQ.14) THEN
          WRITE(*,'('' .....Allocating space for '',
     &              ''miscellaneous gridded terms...'')')
          CALL ARRALL (
     I                 OUTUNT,
     I                 LENX,
     I                 NLAY,NROW,NCOL,
     B                 ISUM,
     O                 LCBUDT,
     E                 *9998)
       ELSE 
          WRITE(*,'('' .....Allocating space for '',
     &              ''cell-by-cell budget terms...'')')
          CALL BUDALL (
     I                 OUTUNT,
     I                 LENX,
     I                 NLAY,NROW,NCOL,
     B                 ISUM,
     O                 LCBUDT,
     E                 *9998)
        ENDIF
       ENDIF
C
      IF(ICOVER.EQ.7) THEN
         WRITE(*,'('' .....Allocating space for '',
     &             ''contour terms...'')')
         CALL CONALL (
     I                OUTUNT,
     I                LENX,
     I                IVIEW,NLAY,NROW,NCOL,
     B                ISUM,
     O                MAXCOL,MAXROW,MAXXND,MAXYND,
     O                LCBUDT,LCCNTR,LCXNOD,
     O                LCYNOD,LCIBRM,LCMBND,
     E                *9998)
       ENDIF
C
      IF(ICOVER.EQ.8) THEN
         WRITE(*,'('' .....Allocating space for '',
     &             ''cell-by-cell flow vector terms...'')')
         CALL VELALL (
     I                OUTUNT,
     I                LENX,
     I                NLAY,NROW,NCOL,
     I                MAXATB,MAXPTS,MAXCEL,
     B                ISUM,
     O                LCCHDB,LCFFFB,LCFLFB,LCFRFB,
     O                LCHEAD,
     O                LCATRB,
     E                *9998)
      ENDIF
C
      WRITE(*,'('' .....Allocating space for '',
     &          ''Modpath Main terms...'')')
      CALL PTHALL (
     I             OUTUNT,
     I             LENX,
     I             MAXPMR,
     I             NLAY,NROW,NCOL,NCBL,IGRID,
     I             NPER,HNOFLO,HDRY,
     B             ISUM,
     O             LCCVPR,LAYCON,LCDELX,LCDELZ,LCDZCB,
     O             LCIBOU,LCRWCL,LCZBOT,LCZTOP,LCPORO,
     E             *9998)
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       DATA OPERATIONS
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C7*********************************************************************C
      WRITE(*,'('' ....Reading data arrays...'')')
      CALL PTHRP1 (
     I             OUTFIL,OUTUNT,
     I             BASFIL,BASUNT,
     I             HEDFIL,HEDUNT,
     I             HCLFIL,HCLUNT,
     I             ICOVER,IVIEW,
     I             NLAY,NROW,NCOL,NCBL,IGRID,
     I             MAXPMR,X(LCCVPR),
     O             X(LAYCON),
     O             X(LCDELX),X(LCDELZ),X(LCDZCB),
     O             X(LCIBOU),X(LCZBOT),X(LCZTOP),
     O             X(LCPORO),
     E             *9998)
C
C---Zones_Of_Transport
C
      IF(ICOVER.EQ.4) THEN
         CALL ZOTRP1 (
     I                OUTUNT,
     I                TIMFIL,TIMUNT,
     I                ENDFIL,ENDUNT,
     I                MAXATB,MAXPTS,MAXPMR,
     I                NLAY,NROW,NCOL,
     I                X(LCCVPR),
     O                X(LCATRB),
     E                *9998)
      ENDIF
C
C---Cell-By-Cell Terms output from Modflow simulations
C
      IF(ICOVER.EQ.6) THEN
       IF(MODFLG.EQ.1) THEN
          CALL HEDRP1 (
     I                 OUTFIL,OUTUNT,
     I                 HEDFIL,HEDUNT,
     I                 HCLFIL,HCLUNT,
     I                 NLAY,NROW,NCOL,
     I                 MAXPMR,
     I                 X(LCCVPR),
     O                 X(LCHEAD),
     E                 *9998)
       ELSE IF(MODFLG.EQ.2) THEN
          CALL HEDRP1 (
     I                 OUTFIL,OUTUNT,
     I                 DDNFIL,DDNUNT,
     I                 DCLFIL,DCLUNT,
     I                 NLAY,NROW,NCOL,
     I                 MAXPMR,
     I                 X(LCCVPR),
     O                 X(LCHEAD),
     E                 *9998)
       ELSE IF(MODFLG.EQ.3) THEN
          CALL CBCRP1 (
     I                 OUTFIL,OUTUNT,
     I                 TRMFIL,TRMUNT,
     I                 CTLFIL,CTLUNT,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),
     O                 X(LCCHDB),X(LCFFFB),X(LCFLFB),X(LCFRFB),
     E                 *9998)
       ELSE IF(MODFLG.EQ.14) THEN
          CALL ARRRP1 (
     I                 OUTFIL,OUTUNT,
     I                 ARRFIL,ARRUNT,
     I                 ACLFIL,ACLUNT,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),
     O                 X(LCBUDT),
     E                 *9998)
       ELSE
          CALL BUDRP1 (
     I                 OUTFIL,OUTUNT,
     I                 TRMFIL,TRMUNT,
     I                 CTLFIL,CTLUNT,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),
     O                 X(LCBUDT),
     E                 *9998)
       ENDIF
      ENDIF
C
C---Contour gridded arrays
C
      IF(ICOVER.EQ.7) THEN
         CALL CONRP1 (
     I                OUTFIL,OUTUNT,
     I                CONFIL,CONUNT,
     I                LVLFIL,LVLUNT,
     I                MAXPMR,X(LCCVPR),
     I                NLAY,NROW,NCOL,
     O                X(LCBUDT),
     E                *9998)
      ENDIF
C
C---Modflow velocity vector coverage
C
      IF(ICOVER.EQ.8) THEN
         CALL HEDRP1 (
     I                OUTFIL,OUTUNT,
     I                HEDFIL,HEDUNT,
     I                HCLFIL,HCLUNT,
     I                NLAY,NROW,NCOL,
     I                MAXPMR,
     I                X(LCCVPR),
     O                X(LCHEAD),
     E                *9998)
         CALL CBCRP1 (
     I                OUTFIL,OUTUNT,
     I                TRMFIL,TRMUNT,
     I                CTLFIL,CTLUNT,
     I                MAXPMR,
     I                NLAY,NROW,NCOL,
     I                X(LCCVPR),
     O                X(LCCHDB),X(LCFFFB),X(LCFLFB),X(LCFRFB),
     E                *9998)
      ENDIF
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                         Modtools Operations
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C8*********************************************************************C
C
C8A---Particle Pathlines
C
      IF(ICOVER.EQ.1) THEN
       IF(IVIEW.NE.3) THEN
        IF(IVIEW.NE.0) THEN
           XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
           WRITE(*,'('' .....Creating Vertical Profile Cell '',A,
     &               ''  coverage...'')')
     &            XSCOV (1:INDEX(XSCOV,' ')-1)
           CALL PTHCRS (
     I                  OUTUNT,
     I                  XSCOV,
     I                  MAXPMR,
     I                  NLAY,NROW,NCOL,
     I                  X(LCDELX),X(LCCVPR),
     I                  X(LCRWCL),
     I                  X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                  X(LCDELZ),X(LCDZCB),
     E                  *9998)
        ENDIF
         WRITE(*,'('' .....Creating Particle Pathline '',A,
     &             '' coverage...'')')
     &           COVER (1:INDEX(COVER,' ')-1)
         CALL PTHLNS (
     I                OUTUNT,
     I                PTHFIL,PTHUNT,
     I                COVER,
     I                MAXATB,MAXPMR,MAXPTS,
     I                NLAY,NROW,NCOL,
     I                X(LCDELX),X(LCCVPR),
     I                X(LCIBOU),
     O                X(LCATRB),
     E                *9998)
       ELSE
          WRITE(*,'('' .....Creating Vertical Profile Particle '',A,
     &              '' coverage...'')')
     &            COVER (1:INDEX(COVER,' ')-1)
          CALL PTHPRT (
     I                 OUTUNT,
     I                 PTHFIL,PTHUNT,
     I                 COVER,
     I                 MAXATB,MAXPMR,MAXPTS,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),
     I                 X(LCIBOU),X(LCZBOT),
     O                 X(LCDELX),X(LCRWCL),
     O                 X(LCATRB),
     E                 *9998)
          XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
          WRITE(*,'('' .....Creating Vertical Profile Cell '',A,
     &              ''  coverage...'')')
          CALL PTHCRS (
     I                 OUTUNT,
     I                 XSCOV,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ENDIF
C
C8B---Particle Endpoints
C
      ELSE IF(ICOVER.EQ.2) THEN
         WRITE(*,'('' .....Creating Particle Endpoint '',A,
     &             '' Mapview coverage...'')')
     &           COVER (1:INDEX(COVER,' ')-1)
         CALL PTHEND (
     I                OUTUNT,
     I                ENDFIL,ENDUNT,
     I                COVER,
     I                MAXPMR,
     I                NLAY,NROW,NCOL,
     I                X(LCDELX),X(LCCVPR),
     I                X(LCIBOU),
     E                *9998)
C
C8C---Particle Time Series
C
      ELSE IF(ICOVER.EQ.3) THEN
       IF(IVIEW.GT.0 .AND. IVIEW.LT.3) THEN
           XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
           WRITE(*,'('' .....Creating Vertical Profile Cell '',A,
     &               ''  coverage...'')')
     &            XSCOV (1:INDEX(XSCOV,' ')-1)
          CALL PTHCRS (
     I                 OUTUNT,
     I                 XSCOV,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ELSE
          WRITE(*,'('' .....Creating Particle Time-series '',A,
     &              '' coverage...'')')
     &           COVER (1:INDEX(COVER,' ')-1)
       ENDIF
         CALL PTHTIM (
     I                OUTUNT,
     I                TIMFIL,TIMUNT,
     I                COVER,
     I                MAXATB,MAXPMR,MAXPTS,
     I                NLAY,NROW,NCOL,
     I                X(LCDELX),X(LCCVPR),
     I                X(LCIBOU),
     O                X(LCATRB),
     E                *9998)
       IF(IVIEW.GT.0 .AND. IVIEW.LT.3) THEN
          XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
          CALL PTHCRS (
     I                 OUTUNT,
     I                 XSCOV,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ENDIF
C
C8F---Zones_Of_Transport
C
      ELSE IF(ICOVER.EQ.4) THEN
       IF(IVIEW.LE.0) THEN
          WRITE(*,'('' .....Creating ZOT '',A,
     &              '' Mapview coverage...'')')
     &           COVER (1:INDEX(COVER,' ')-1)
       ELSE 
        IF(IVIEW.EQ.1) THEN
           WRITE(*,'('' .....Creating ZOT '',A,
     &               '' Row vertical profile coverage...'')')
     &            COVER (1:INDEX(COVER,' ')-1)
        ELSE IF(IVIEW.EQ.2) THEN
           WRITE(*,'('' .....Creating ZOT '',A,
     &               '' Column vertical profile coverage...'')')
     &            COVER (1:INDEX(COVER,' ')-1)
        ELSE
           WRITE(*,'('' .....No Vertical Particle Profile '',
     &               ''ZOT coverage availble yet'')')
           GO TO 9999
        ENDIF
          XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
          CALL PTHNOR (
     I                 OUTUNT,
     I                 XSCOV,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ENDIF
         CALL PTHZOT (
     I                OUTUNT,
     I                TIMFIL,TIMUNT,
     I                COVER,
     I                MAXATB,MAXPMR,MAXPTS,
     I                NLAY,NROW,NCOL,
     I                X(LCDELX),X(LCCVPR),
     I                X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                X(LCDELZ),X(LCDZCB),
     O                X(LCATRB),
     E                *9998)
C
C8E---Model Grid
C
      ELSE IF(ICOVER.EQ.5) THEN
         WRITE(*,'('' .....Creating model grid '',A,
     &             '' coverage...'')')
     &           COVER (1:INDEX(COVER,' ')-1)
       IF(IVIEW.GE.1 .AND. IVIEW.LE.2) THEN
          CALL PTHCRS (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ELSE IF(IVIEW.EQ.3) THEN
          WRITE(*,'('' .....Creating vertical particle profile '',
     &              ''coverage for cell-by-cell flow terms'')')
          CALL PTHPRT (
     I                 OUTUNT,
     I                 PTHFIL,PTHUNT,
     I                 COVER,
     I                 MAXATB,MAXPMR,MAXPTS,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),
     I                 X(LCIBOU),X(LCZBOT),
     O                 X(LCDELX),X(LCRWCL),
     O                 X(LCATRB),
     E                 *9998)
          XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
          CALL PTHCRS (
     I                 OUTUNT,
     I                 XSCOV,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ELSE
         CALL PTHGRD (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCIBOU),
     E                 *9998)
       ENDIF
C
C8G---Cell-By-Cell Terms output from Modflow simulations
C
      ELSE IF(ICOVER.EQ.6) THEN
       IF(IVIEW.LE.0) THEN
          WRITE(*,'('' .....Creating Cell-By-Cell Terms '',
     &              ''Info File '',A)')
     &           COVER (1:INDEX(COVER,' ')-1)
       ELSE IF(IVIEW.EQ.1) THEN
          WRITE(*,'('' .....Creating vertical row profile '',
     &              ''coverage for cell-by-cell terms'')')
          CALL PTHCRS (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ELSE IF(IVIEW.EQ.2) THEN
          WRITE(*,'('' .....Creating vertical column profile '',
     &              ''coverage for cell-by-cell terms'')')
          CALL PTHCRS (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ELSE IF(IVIEW.EQ.3) THEN
          WRITE(*,'('' .....Creating vertical particle profile '',
     &              ''coverage for cell-by-cell terms'')')
          XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
          CALL PTHPRT (
     I                 OUTUNT,
     I                 PTHFIL,PTHUNT,
     I                 COVER,
     I                 MAXATB,MAXPMR,MAXPTS,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),
     I                 X(LCIBOU),X(LCZBOT),
     O                 X(LCDELX),X(LCRWCL),
     O                 X(LCATRB),
     E                 *9998)
          COVER=COVER (1:INDEX(COVER,' ')-1)//'xs'
          CALL PTHCRS (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ELSE IF(IVIEW.EQ.4) THEN
          WRITE(*,'('' .....Creating Single Model Layer of '',
     &              ''Cell-By-Cell Terms Info File '',A)')
     &           COVER (1:INDEX(COVER,' ')-1)
       ELSE IF(IVIEW.EQ.5) THEN
          WRITE(*,'('' .....Creating Specified Ibound Value of '',
     &              ''Cell-By-Cell Terms Info File '',A)')
     &           COVER (1:INDEX(COVER,' ')-1)
       ELSE
          WRITE(*,'('' .....Creating Uppermost Active Cell of '',
     &              ''Cell-By-Cell Terms Info File '',A)')
     &           COVER (1:INDEX(COVER,' ')-1)
       ENDIF
       IF(MODFLG.LE.2) THEN
          CALL PTHHED (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),X(LCDZCB),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),X(LCHEAD),
     E                 *9998)
       ELSE IF(MODFLG.EQ.3) THEN
         CALL PTHCBC (
     I                OUTUNT,
     I                COVER,
     I                MAXPMR,
     I                NLAY,NROW,NCOL,
     I                X(LCCVPR),X(LCDZCB),
     I                X(LCRWCL),
     I                X(LCIBOU),
     I                X(LCCHDB),X(LCFRFB),X(LCFFFB),X(LCFLFB),
     E                *9998)
       ELSE IF(MODFLG.EQ.14) THEN
          CALL PTHARR (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),X(LCDZCB),
     I                 X(LCRWCL),
     I                 X(LCIBOU),
     I                 X(LCBUDT),
     E                 *9998)
       ELSE 
          CALL PTHBUD (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),X(LCDZCB),
     I                 X(LCRWCL),
     I                 X(LCIBOU),
     I                 X(LCBUDT),
     E                 *9998)
       ENDIF
C
C8J---Contour gridded arrays
C
      ELSE IF(ICOVER.EQ.7) THEN
       IF(IVIEW.LE.0 .OR. IVIEW.EQ.4) THEN
          WRITE(*,'('' .....Creating Mapview Single Model Layer '',
     &              ''Contour Coverage '',A)')
     &           COVER (1:INDEX(COVER,' ')-1)
       ELSE IF(IVIEW.GE.1 .AND. IVIEW.LE.2) THEN
        IF(IVIEW.LE.1) THEN
           WRITE(*,'('' .....Creating Vertical Row Profile '',
     &               ''Contour coverage '',A)')
     &            COVER (1:INDEX(COVER,' ')-1)
        ELSE
           WRITE(*,'('' .....Creating Vertical Column Profile '',
     &               ''Contour coverage '',A)')
     &            COVER (1:INDEX(COVER,' ')-1)
        ENDIF
          XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
          CALL PTHNOR (
     I                 OUTUNT,
     I                 XSCOV,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ELSE IF(IVIEW.EQ.3) THEN
          WRITE(*,'('' .....No Vertical Particle Profile '',
     &               ''Contour coverage availble'')')
           GO TO 9999
       ELSE IF(IVIEW.EQ.5) THEN
          WRITE(*,'('' .....Creating Mapview Specified Ibound Value '',
     &              ''Contour Coverage '',A)')
     &           COVER (1:INDEX(COVER,' ')-1)
       ELSE
          WRITE(*,'('' .....Creating Uppermost Active Cell of '',
     &              ''Cell-By-Cell Flow Terms Info File '',A)')
     &           COVER (1:INDEX(COVER,' ')-1)
       ENDIF
          CALL PTHCON (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),X(LCDZCB),
     I                 X(LCRWCL),X(LCIBOU),
     I                 X(LCZTOP),X(LCZBOT),X(LCBUDT),
     I                 MAXROW,MAXCOL,MAXXND,MAXYND,
     I                 X(LCIBRM),X(LCMBND),X(LCCNTR),
     I                 X(LCXNOD),X(LCYNOD),
     E                 *9998)
C
C8K---Modflow velocity vector coverage
C
      ELSE IF(ICOVER.EQ.8) THEN
       IF(IVIEW.LT.1 .OR. IVIEW.GE.4) THEN
        IF(IVIEW.LT.1 .OR. IVIEW.EQ.4) THEN
           WRITE(*,'('' .....Creating Mapview for Specified '',
     &               ''Layer Velocity Vector coverage '',A)')
     &            COVER (1:INDEX(COVER,' ')-1)
        ELSE IF(IVIEW.EQ.5) THEN
           WRITE(*,'('' .....Creating Mapview for Specified '',
     &               ''IBOUND Velocity Vector coverage '',A)')
     &            COVER (1:INDEX(COVER,' ')-1)
        ELSE
           WRITE(*,'('' .....Creating Mapview for Uppermost '',
     &               ''Active Cell Velocity Vector coverage '',A)')
     &            COVER (1:INDEX(COVER,' ')-1)
        ENDIF
       ELSE
        IF(IVIEW.LE.1) THEN
           WRITE(*,'('' .....Creating Vertical Row Profile '',
     &               ''Velocity Vector coverage '',A)')
     &            COVER (1:INDEX(COVER,' ')-1)
        ELSE IF(IVIEW.EQ.2) THEN
           WRITE(*,'('' .....Creating Vertical Column Profile '',
     &               ''Velocity Vector coverage '',A)')
     &            COVER (1:INDEX(COVER,' ')-1)
        ELSE
           WRITE(*,'('' .....No Vertical Particle Profile '',
     &               ''Velocity Vector coverage availble yet'')')
           WRITE(OUTUNT,'('' .....No Vertical Particle Profile '',
     &               ''Velocity Vector coverage availble yet'')')
           GO TO 9999
        ENDIF
          XSCOV=COVER (1:INDEX(COVER,' ')-1)//'xs'
          CALL PTHCRS (
     I                 OUTUNT,
     I                 XSCOV,
     I                 MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCDELX),X(LCCVPR),
     I                 X(LCRWCL),
     I                 X(LCIBOU),X(LCZTOP),X(LCZBOT),
     I                 X(LCDELZ),X(LCDZCB),
     E                 *9998)
       ENDIF
          CALL PTHVEL (
     I                 OUTUNT,
     I                 COVER,
     I                 MAXCEL,MAXPMR,
     I                 NLAY,NROW,NCOL,
     I                 X(LCCVPR),X(LAYCON),
     I                 X(LCDELX),X(LCDELZ),X(LCDZCB),
     I                 X(LCRWCL),
     I                 X(LCIBOU),
     I                 X(LCFRFB),X(LCFFFB),X(LCFLFB),
     I                 X(LCHEAD),X(LCZTOP),X(LCZBOT),
     O                 X(LCATRB),X(LCPORO),
     E                 *9998)
      ENDIF
       GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  ERRORS WITHIN MODTOOLS PROGRAMS
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,
     &      '(//,'' Unable to read Modtools command string '',
     &      ''from file '',A)') 
     &      ARCCMD (1:INDEX(ARCCMD,' ')-1)
      WRITE(OUTUNT,
     &      '(//,'' Unable to read Modtools command string '',
     &      ''from file '',A)') 
     &      ARCCMD (1:INDEX(ARCCMD,' ')-1)
      GO TO 9998
 9991 WRITE(*,
     &      '(//,'' End-of-file; Missing Modtools command string '',
     &      ''in file '',A)')
     &      ARCCMD (1:INDEX(ARCCMD,' ')-1)
      WRITE(OUTUNT,
     &      '(//,'' End-of-file; Missing Modtools command string '',
     &      ''in file '',A)')
     &      ARCCMD (1:INDEX(ARCCMD,' ')-1)
 9998 CALL DELETE_FILE (ARCCMD,*9999)
      CALL DELETE_FILE (ARCCRS,*9999)
 9999 WRITE(*,
     &      '(//,'' Abnormal Termination of Modtools_Program'')')
      WRITE(OUTUNT,
     &      '(//,'' Abnormal Termination of Modtools_Program'')')
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  EXITING MODTOOLS PROGRAM
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 CALL CLOSE_FILE (OUTFIL,*1001)
 1001 STOP
      END
