C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthfls version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHFLS 11JUNE1998 
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Reads an user defined name file NAMFIL for filenames for the operation
C      of Modtools.  This file can be the same one used by MODPATH (the
C      file containing the unit number and filenames).  MODTOOLS uses
C      the utility modules from MODFLOW (McDonald and Harbaugh, 1988)
C      or MODFLOWARC (Orzol and McGrath, 1991) to read input data
C      array information.  
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C    Inputs:
C
C     OUTFIL  : FILENAME OF THE MODTOOLS.OUT
C     NAMFIL  : FILENAME OF THE NAME FILE USED BY MODTOOLS
C     NAMUNT  : FORTRAN UNIT NUMBER FOR NAME FILE
C     OUTUNT  : FORTRAN UNIT NUMBER FOR OUTPUT FILENAME MODTOOLS.OUT
C
C    Outputs:
C
C     BASFIL  : MODPATH MAIN FILE
C     BASUNT  : FORTRAN UNIT NUMBER FOR MODPATH MAIN FILE
C     TRMFIL  : MODFLOW CELL-BY-CELL TERM FILE
C     TRMUNT  : FORTRAN UNIT NUMBER FOR MODFLOW CELL-BY-CELL TERM FILE
C     ENDFIL  : MODPATH ENDPOINT FILE
C     ENDUNT  : FORTRAN UNIT NUMBER FOR MODPATH ENDPOINT FILE
C     PTHFIL  : MODPATH PATHLINE FILE
C     PTHUNT  : FORTRAN UNIT NUMBER FOR MODPATH PATHLINE FILE
C     TIMFIL  : MODPATH TIME-SERIES FILE
C     TIMUNT  : FORTRAN UNIT NUMBER FOR MODPATH TIME-SERIES FILE
C     HEDFIL  : MODFLOW CELL-BY-CELL HEAD TERM FILE
C     HEDUNT  : FORTRAN UNIT NUMBER FOR MODFLOW CELL-BY-CELL HEAD TERM FILE
C     DDNFIL  : MODFLOW CELL-BY-CELL DRAWDOWN TERM FILE
C     DDNUNT  : FORTRAN UNIT NUMBER FOR MODFLOW CELL-BY-CELL DRAWDOWN TERM FILE
C     CONFIL  : MODFLOW FILE CELL-BY-CELL TERMS TO BE CONTOURED
C     CONUNT  : FORTRAN UNIT NUMBER FOR CELL-BY-CELL CONTOUR TERMS FILE
C     LVLFIL  : CONTROL RECORD LINES FOR 2D OR 3D CELL-BY-CELL TERMS
C     LVLUNT  : FORTRAN UNIT NUMBER FOR CONTROL RECORD LINES
C
C-------------------------------------------------------------------------
      SUBROUTINE PTHFLS (
     I                   OUTFIL,OUTUNT,
     I                   NAMFIL,NAMUNT,
     O                   BASFIL,BASUNT,
     O                   TRMFIL,TRMUNT,
     O                   CTLFIL,CTLUNT,
     O                   ENDFIL,ENDUNT,
     O                   PTHFIL,PTHUNT,
     O                   TIMFIL,TIMUNT,
     O                   HEDFIL,HEDUNT,
     O                   HCLFIL,HCLUNT,
     O                   DDNFIL,DDNUNT,
     O                   DCLFIL,DCLUNT,
     O                   ARRFIL,ARRUNT,
     O                   ACLFIL,ACLUNT,
     O                   CONFIL,CONUNT,
     O                   LVLFIL,LVLUNT,
     E                   *)
C-----------------------------------------------------------------------
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C::::::::::::::::::::::::  GLOBAL_VARIABLES  :::::::::::::::::::::::::::
C
      CHARACTER*(*) OUTFIL,
     &              NAMFIL,
     &              BASFIL,
     &              TRMFIL,
     &              CTLFIL,
     &              ENDFIL,
     &              PTHFIL,
     &              TIMFIL,
     &              HEDFIL,
     &              HCLFIL,
     &              DDNFIL,
     &              DCLFIL,
     &              CONFIL,
     &              LVLFIL,
     &              ARRFIL,
     &              ACLFIL
C
      INTEGER
     &              MAXFIL,
     &              OUTUNT,
     &              NAMUNT,
     &              BASUNT,
     &              TRMUNT,
     &              CTLUNT,
     &              ENDUNT,
     &              PTHUNT,
     &              TIMUNT,
     &              HEDUNT,
     &              HCLUNT,
     &              DDNUNT,
     &              DCLUNT,
     &              CONUNT,
     &              LVLUNT,
     &              ARRUNT,
     &              ACLUNT
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      CHARACTER*128 BUFFER
      CHARACTER*80  FILNAM
      CHARACTER*30  FNAME
C
      INTEGER
     &        FILUNT,
     &        OPNFLG,
     &        STRCOL,
     &        FINCOL,
     &        NUMCOL
C
C     ------------------------------------------------------------------
C
C1----Set local variables
C
      MAXFIL=100
      BASUNT=0
      BASFIL='NONE'
      TRMUNT=0
      TRMFIL='NONE'
      CTLUNT=0
      CTLFIL='NONE'
      ENDUNT=0
      ENDFIL='NONE'
      PTHUNT=0
      PTHFIL='NONE'
      TIMUNT=0
      TIMFIL='NONE' 
      HEDUNT=0
      HEDFIL='NONE'
      HCLUNT=0
      HCLFIL='NONE'
      DDNUNT=0
      DDNFIL='NONE'
      DCLUNT=0
      DCLFIL='NONE'
      CONUNT=0
      CONFIL='NONE'
      LVLUNT=0
      LVLFIL='NONE'
      ARRUNT=0
      ARRFIL='NONE'
      ACLUNT=0
      ACLFIL='NONE'
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C          Read MODTOOLS name file for filenames and unit numbers
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(/10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          MODTOOLS GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''              VERSION 6.0 11JUNE1998 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                FILE READER MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C0---Open Modtools name file
C
      NAMUNT=80
      NSTAT=1
      ITALK=1
      CALL OPEN_FILE (NAMUNT,NAMFIL,NSTAT,ITALK,*9998)
C
C1---Write Modtools name file system heading
C
      WRITE(OUTUNT,101) 
  101 FORMAT(//,41X,'MODTOOLS NAME FILE LIST',
     &       /,10X,85('-'))
      WRITE(OUTUNT,103) 
 103  FORMAT(
     &       25X,'  PACKAGES',
     &       40X,'  FILENAME',
     &       '   FORTRAN',
     &       /,85X,'      UNIT',
     &       /,85X,'    NUMBER',
     &       /,10X,85('-'))
      MAXCHR=50
      NFILES=0
C
C2----Loop to read and write filenames and fortran unit numbers
C
      DO 200 I=1,100
         OPNFLG=1
         READ(NAMUNT,'(A)',ERR=9990,END=302) BUFFER
       IF(BUFFER.EQ.' ') GO TO 200
C
C2----Read term name
C
         BUFFER(LEN(BUFFER):LEN(BUFFER))=' '
         NUMCOL=1
  204  IF(BUFFER(NUMCOL:NUMCOL).NE.' ' .AND. 
     &    BUFFER(NUMCOL:NUMCOL).NE.',' .AND.
     &    BUFFER(NUMCOL:NUMCOL).NE.'''') THEN
          STRCOL=NUMCOL
       ELSE
          NUMCOL=NUMCOL+1
          GO TO 204
       ENDIF
         NUMCOL=NUMCOL+1
  206  IF(BUFFER(NUMCOL:NUMCOL).EQ.' ' .OR. 
     &    BUFFER(NUMCOL:NUMCOL).EQ.',' .OR.
     &    BUFFER(NUMCOL:NUMCOL).EQ.'''') THEN
          FINCOL=NUMCOL
       ELSE
          NUMCOL=NUMCOL+1
        IF(NUMCOL.GT.LEN(BUFFER)) GO TO 9992
          GO TO 206
       ENDIF
         FNAME=BUFFER (STRCOL:FINCOL-1)
C         READ(BUFFER (STRCOL:FINCOL-1),*,ERR=9992) FNAME
C
C2----Read unit number
C
         BUFFER=BUFFER(FINCOL:LEN(BUFFER))
         NUMCOL=1
  208  IF(BUFFER(NUMCOL:NUMCOL).NE.' ' .AND. 
     &    BUFFER(NUMCOL:NUMCOL).NE.',' .AND.
     &    BUFFER(NUMCOL:NUMCOL).NE.'''') THEN
          STRCOL=NUMCOL
       ELSE
          NUMCOL=NUMCOL+1
          GO TO 208
       ENDIF
  210  IF(BUFFER(NUMCOL:NUMCOL).EQ.' ' .OR. 
     &    BUFFER(NUMCOL:NUMCOL).EQ.',' .OR.
     &    BUFFER(NUMCOL:NUMCOL).EQ.'''') THEN
          FINCOL=NUMCOL
       ELSE
          NUMCOL=NUMCOL+1
        IF(NUMCOL.GT.LEN(BUFFER)) GO TO 9993
          GO TO 210
       ENDIF
         READ(BUFFER (STRCOL:FINCOL-1),*,ERR=9993) FILUNT
C
C2----Read filename including path
C
         BUFFER=BUFFER(FINCOL:LEN(BUFFER))
         NUMCOL=1
  212  IF(BUFFER(NUMCOL:NUMCOL).NE.' ' .AND. 
     &    BUFFER(NUMCOL:NUMCOL).NE.',' .AND.
     &    BUFFER(NUMCOL:NUMCOL).NE.'''') THEN
          STRCOL=NUMCOL
       ELSE
          NUMCOL=NUMCOL+1
          GO TO 212
       ENDIF
  214  IF(BUFFER(NUMCOL:NUMCOL).EQ.' ' .OR. 
     &    BUFFER(NUMCOL:NUMCOL).EQ.',' .OR.
     &    BUFFER(NUMCOL:NUMCOL).EQ.'''') THEN
          FINCOL=NUMCOL
       ELSE
          NUMCOL=NUMCOL+1
        IF(NUMCOL.GT.LEN(BUFFER)) GO TO 9994
          GO TO 214
       ENDIF
         FILNAM=BUFFER (STRCOL:FINCOL-1)
C
         NUMCHR=INDEX(FILNAM,' ')-1
       IF(NUMCHR.LT.0) THEN
          NUMCHR=1
          LENCHR=50
       ELSE IF(NUMCHR.GT.MAXCHR) THEN
          NUMCHR=NUMCHR-MAXCHR+1
          LENCHR=NUMCHR+MAXCHR-1
       ELSE
          LENCHR=NUMCHR
          NUMCHR=1
       ENDIF
C
C2A-Modtools Main file
C
       IF((INDEX(FNAME,'MAIN').NE.0) .OR.
     &    (INDEX(FNAME,'main').NE.0) .OR.
     &    (INDEX(FNAME,'Main').NE.0)) THEN
           OPNFLG=0
           FNAME='MODPATH MAIN'
           BASUNT=FILUNT
           BASFIL=FILNAM
C
C2A-MODFLOW Flow Control file [lines for U3DREL utility]
C
       ELSE IF((INDEX(FNAME,'BUDGET-CONTROL').NE.0) .OR.
     &         (INDEX(FNAME,'Budget-Control').NE.0) .OR.
     &         (INDEX(FNAME,'Budget-control').NE.0) .OR.
     &         (INDEX(FNAME,'budget-control').NE.0)) THEN
           OPNFLG=0
           FNAME='CBC Terms Control Records File'
           CTLUNT=FILUNT
           CTLFIL=FILNAM
C
C2A-MODFLOW Binary file output by Block-Centered Package
C
       ELSE IF((INDEX(FNAME,'BUDGET(ASCII)').NE.0) .OR.
     &         (INDEX(FNAME,'Budget(Ascii)').NE.0) .OR.
     &         (INDEX(FNAME,'Budget(ascii)').NE.0) .OR.
     &         (INDEX(FNAME,'budget(ascii)').NE.0)) THEN
           OPNFLG=0
           FNAME='ASCII Cell-By-Cell Flow Terms'
           TRMUNT=ABS(FILUNT)
           TRMFIL=FILNAM
C
C2A-MODFLOW Binary file output by Block-Centered Package
C
       ELSE IF((INDEX(FNAME,'BUDGET').NE.0) .OR.
     &         (INDEX(FNAME,'Budget').NE.0) .OR.
     &         (INDEX(FNAME,'budget').NE.0)) THEN
           OPNFLG=0
           FNAME='Binary Cell-By-Cell Flow Terms'
           TRMUNT=-ABS(FILUNT)
           TRMFIL=FILNAM
C
C2A-MODFLOW Hydraulic Head Control file [lines for U2DREL utility]
C
       ELSE IF((INDEX(FNAME,'HEAD-CONTROL').NE.0) .OR.
     &         (INDEX(FNAME,'head-control').NE.0) .OR.
     &         (INDEX(FNAME,'Head-Control').NE.0)) THEN
           OPNFLG=0
           FNAME='Head Control Records File'
           HCLUNT=FILUNT
           HCLFIL=FILNAM
C
C2A-MODFLOW Hydraulic Head file [Binary FORMAT]
C
       ELSE IF((INDEX(FNAME,'HEAD(BINARY)').NE.0) .OR.
     &         (INDEX(FNAME,'Head(Binary)').NE.0) .OR.
     &         (INDEX(FNAME,'Head(binary)').NE.0) .OR.
     &         (INDEX(FNAME,'head(binary)').NE.0)) THEN
           OPNFLG=0
           FNAME='Binary Cell-By-Cell Head Terms'
           HEDUNT=-ABS(FILUNT)
           HEDFIL=FILNAM
C
C2A-MODFLOW Hydraulic Head Text file [ASCII FORMAT]
C
       ELSE IF((INDEX(FNAME,'HEAD').NE.0) .OR.
     &         (INDEX(FNAME,'head').NE.0) .OR.
     &         (INDEX(FNAME,'Head').NE.0)) THEN
           OPNFLG=0
           FNAME='ASCII Cell-By-Cell Head Terms File'
           HEDUNT=ABS(FILUNT)
           HEDFIL=FILNAM
C
C2A-MODFLOW Drawdown Control file [lines for U2DREL utility]
C
       ELSE IF((INDEX(FNAME,'DRAWDOWN-CONTROL').NE.0) .OR.
     &         (INDEX(FNAME,'drawdown-control').NE.0) .OR.
     &         (INDEX(FNAME,'Drawdown-Control').NE.0)) THEN
           OPNFLG=0
           FNAME='Drawdown Control Records File'
           DCLUNT=FILUNT
           DCLFIL=FILNAM
C
C2A-MODFLOW Drawdown file [Binary FORMAT]
C
       ELSE IF((INDEX(FNAME,'DRAWDOWN(BINARY)').NE.0) .OR.
     &         (INDEX(FNAME,'drawdown(binary)').NE.0) .OR.
     &         (INDEX(FNAME,'Drawdown(Binary)').NE.0)) THEN
           OPNFLG=0
           FNAME='Binary Cell-By-Cell Drawdown Terms'
           DDNUNT=-ABS(FILUNT)
           DDNFIL=FILNAM
C
C2A-MODFLOW Drawdown Text file [ASCII FORMAT]
C
       ELSE IF((INDEX(FNAME,'DRAWDOWN').NE.0) .OR.
     &         (INDEX(FNAME,'drawdown').NE.0) .OR.
     &         (INDEX(FNAME,'Drawdown').NE.0)) THEN
           OPNFLG=0
           FNAME='ASCII Cell-By-Cell Drawdown Terms File'
           DDNUNT=ABS(FILUNT)
           DDNFIL=FILNAM
C
C2A-Contour MODFLOW Cell-by-Cell Terms [Binary FORMAT]
C
       ELSE IF((INDEX(FNAME,'CONTOUR-DATA(BINARY)').NE.0) .OR.
     &         (INDEX(FNAME,'contour-data(binary)').NE.0) .OR.
     &         (INDEX(FNAME,'Contour-Data(Binary)').NE.0)) THEN
           OPNFLG=0
           FNAME='Contour 2D or 3D Terms File'
           CONUNT=-ABS(FILUNT)
           CONFIL=FILNAM
C
C2A-Contour MODFLOW Cell-by-Cell Terms [ASCII FORMAT]
C
       ELSE IF((INDEX(FNAME,'CONTOUR-DATA').NE.0) .OR.
     &         (INDEX(FNAME,'contour-data').NE.0) .OR.
     &         (INDEX(FNAME,'Contour-Data').NE.0)) THEN
           OPNFLG=0
           FNAME='Contour 2D or 3D Terms File'
           CONUNT=FILUNT
           CONFIL=FILNAM
C
C2A-Contour record lines [lines for U2DREL and U3DREL utilities]
C
       ELSE IF((INDEX(FNAME,'CONTOUR-CONTROL').NE.0) .OR.
     &         (INDEX(FNAME,'contour-control').NE.0) .OR.
     &         (INDEX(FNAME,'Contour-Control').NE.0)) THEN
           OPNFLG=0
           FNAME='Contour Control Records File'
           LVLUNT=FILUNT
           LVLFIL=FILNAM
C
C2A-Miscellaneous record lines [lines for U2DREL and U3DREL utilities]
C
       ELSE IF((INDEX(FNAME,'ARRAY-CONTROL').NE.0) .OR.
     &         (INDEX(FNAME,'array-control').NE.0) .OR.
     &         (INDEX(FNAME,'Array-Control').NE.0)) THEN
           OPNFLG=0
           FNAME='Miscellaneous Control Records File'
           ACLUNT=FILUNT
           ACLFIL=FILNAM
C
C2A-Miscellaneous Cell-by-Cell Terms [Binary FORMAT]
C
       ELSE IF((INDEX(FNAME,'ARRAY(BINARY)').NE.0) .OR.
     &         (INDEX(FNAME,'array(binary)').NE.0) .OR.
     &         (INDEX(FNAME,'Array(Binary)').NE.0)) THEN
           OPNFLG=0
           FNAME='Miscellaneous Gridded Terms File'
           ARRUNT=-ABS(FILUNT)
           ARRFIL=FILNAM
C
C2A-Miscellaneous Cell-by-Cell Terms [ASCII FORMAT]
C
       ELSE IF((INDEX(FNAME,'ARRAY').NE.0) .OR.
     &         (INDEX(FNAME,'array').NE.0) .OR.
     &         (INDEX(FNAME,'Array').NE.0)) THEN
           OPNFLG=0
           FNAME='Miscellaneous Gridded Terms File'
           ARRUNT=ABS(FILUNT)
           ARRFIL=FILNAM
C
C2A-MODPATH Pathline file
C
       ELSE IF((INDEX(FNAME,'PATHLINE').NE.0) .OR.
     &         (INDEX(FNAME,'pathline').NE.0) .OR.
     &         (INDEX(FNAME,'Pathline').NE.0)) THEN
           OPNFLG=0
           FNAME='Pathline File'
           PTHUNT=FILUNT
           PTHFIL=FILNAM
C
C2A-MODPATH Endpoint file
C
       ELSE IF((INDEX(FNAME,'ENDPOINT').NE.0) .OR.
     &         (INDEX(FNAME,'endpoint').NE.0) .OR.
     &         (INDEX(FNAME,'Endpoint').NE.0)) THEN
           OPNFLG=0
           FNAME='Endpoint File'
           ENDUNT=FILUNT
           ENDFIL=FILNAM
C
C2A-MODPATH Time-Series file
C
       ELSE IF((INDEX(FNAME,'TIME-SERIES').NE.0) .OR.
     &         (INDEX(FNAME,'time-series').NE.0) .OR.
     &         (INDEX(FNAME,'Time-Series').NE.0)) THEN
           OPNFLG=0
           FNAME='Time-Series File'
           TIMUNT=FILUNT
           TIMFIL=FILNAM
C
C2A-Other FILES
C
       ELSE
          OPNFLG=1
          FNAME=FNAME
       ENDIF
C
C2A-Print FORTRAN unit numbers
C
           WRITE(OUTUNT,'(10X,A30,A50,I5)')
     &     FNAME,
     &     FILNAM (NUMCHR:LENCHR),
     &     FILUNT
C
C2A--Fortran Unit Numbers [Needed by Modtools]
C          
       IF(FILUNT.NE.80 .AND. FILUNT.NE.81) THEN
          NSTAT=1
          ITALK=1
        IF(OPNFLG.NE.0) CALL OPEN_FILE (FILUNT,FILNAM,NSTAT,ITALK,*9998)
       ELSE
          WRITE(*,'(//,
     &          '' File '',A,'' is being opened on unit number '',I10)')
     &            FILNAM (1:INDEX(FILNAM,' ')-1),FILUNT
          WRITE(*,'('' Fortran unit number 80 and 81 have '',
     &              ''reserved for use by Modtools'')')
          GO TO 9998
       ENDIF
  200 CONTINUE
C
C3----Finish Modtools filename heading
C
  302   WRITE(OUTUNT,'(10X,85(''-''))')
      IF(BASUNT.LE.0) THEN
         WRITE(OUTUNT,'(10X,
     &               ''******* MISSING MODTOOLS MAIN FILE ********'')')
         GO TO 9991
      ELSE
         CALL CLOSE_FILE (NAMFIL,*9998)
         GO TO 1000
      ENDIF
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,'(//,
     &          '' Unable to read from file '',A)') 
     &                                    NAMFIL (1:INDEX(NAMFIL,' ')-1)
      WRITE(OUTUNT,'(//,
     &          '' Unable to read from file '',A)') 
     &                                    NAMFIL (1:INDEX(NAMFIL,' ')-1)
      GO TO 9998
 9991 WRITE(*,'(//,
     &          '' End-of-file; Missing filenames in file '',A)')
     &                                    NAMFIL (1:INDEX(NAMFIL,' ')-1)
      GO TO 9998
 9992 WRITE(*,'(//,
     &          '' Unable to read type of data file in file '',A)')
     &                                    NAMFIL (1:INDEX(NAMFIL,' ')-1)
      GO TO 9998
 9993 WRITE(*,'(//,
     &          '' Unable to read unit number in file '',A)')
     &                                    NAMFIL (1:INDEX(NAMFIL,' ')-1)
      GO TO 9998
 9994 WRITE(*,'(//,
     &          '' Unable to file name in file '',A)')
     &                                    NAMFIL (1:INDEX(NAMFIL,' ')-1)
      GO TO 9998
 9998 CALL CLOSE_FILE (NAMFIL,*9999)
 9999 WRITE(*,'(//,'' Abnormal Termination of Pthfls_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthbas version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHBAS 23JUNE1997
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Reads the user defined file MAIN for model problem information and
C      array information.  The arrays needed by Modtools are the same 
C      ones input to MODPATH:
C       NCOL,NROW, etc (Data item 1), 
C       Options line (Data item 2), 
C       LAYCON (Data item 3), 
C       NCON (Data item 4), 
C       DELR or DELC (Data item 5), 
C       DELZ, DELZCB, or ZBL1 (Data item 6)
C       ZTOP and ZBOT (Data item 7)
C       IBOUND (Data item 8),
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C    Inputs:
C
C     OUTUNT  : FORTRAN UNIT NUMBER FOR OUTPUT FILENAME MODTOOLS.LIST
C     FILOUT  : FILENAME OF THE MODTOOLS.LIST
C     BASFIL  : FILE NAME OF INPUT MODEL DATA
C     BASUNT  : FORTRAN UNIT NUMBER FOR INPUT DATA FILE
C
C    Outputs:
C
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NCBL    : NUMBER OF QUASI-3D CONFINING LAYERS
C     IGRID   : GRID GEOMETRY CODE
C             => 0 VARYING THICKNESS MODEL LAYERS
C                   AND(OR) NONHORIZONTAL LAYERS
C             => 1 TRUE RECTANGLAR 3-D GRID (UNIFORM THICKNESS MODEL LAYERS)
C     HNOFLO  : MODFLOW NO FLOW HEAD VALUE
C     HDRY    : MODFLOW DRY HEAD VALUE
C
C     Program:
C
C     VARNAM  : DUMMY CHARACTER STRING HOLDING VARIABLE NAME
C
C-------------------------------------------------------------------------
      SUBROUTINE PTHBAS (
     I                   OUTFIL,OUTUNT,
     I                   BASFIL,BASUNT,
     O                   NLAY,NROW,NCOL,NCBL,IGRID,NPER,
     O                   HNOFLO,HDRY,
     E                   *)
C-----------------------------------------------------------------------
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      CHARACTER*(*) OUTFIL,
     &              BASFIL
C
      INTEGER OUTUNT,
     &        BASUNT,
     &        NLAY,
     &        NROW,
     &        NCOL,
     &        NCBL,
     &        IGRID,
     &        NPER
C
       REAL HNOFLO,
     &      HDRY
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      CHARACTER*128 BUFFER
      CHARACTER*80 VARNAM
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                 Read model problem definition information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(/)')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          MODTOOLS GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''              VERSION 6.0 23JUNE1997 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''              MAIN FILE READER MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(/)')
C
C0---Set 
C
      NPER=0
      MAXSIZ=0
      HNOFLO=1.0E30
      HDRY=1.0E30
C
C0---Open MODPATH main file
C
      NSTAT=1
      ITALK=1
      CALL OPEN_FILE (BASUNT,BASFIL,NSTAT,ITALK,*9998)
C
C1----Read model problem information
C
      VARNAM='MODPATH_ROW_COLUMN_DATA'
      READ(BASUNT,'(A)',ERR=9990,END=9991) 
     &                                    BUFFER
      READ(BUFFER,*,ERR=9990,END=9991) 
     &                                               NCOL,
     &                                               NROW,
     &                                               NLAY,
     &                                               NCBL,
     &                                               IGRID,
     &                                               NPER,
     &                                               MAXSIZ,
     &                                               HNOFLO,
     &                                               HDRY
      CALL CLOSE_FILE (BASFIL,*9998)
C
C2----Print Modtools operation parameters
C
      WRITE(OUTUNT,'(/)')
      WRITE(OUTUNT,'(1H1,36X,
     &             ''MODEL DIMENSION AND PARAMETER LIST'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(/)')
C
      WRITE(OUTUNT,'(10X,
     &             ''NUMBER OF MODEL LAYERS                         '',
     &             10X,I15,'' NLAY'')')
     &          NLAY
      WRITE(OUTUNT,'(10X,
     &             ''NUMBER OF MODEL ROWS                           '',
     &             10X,I15,'' NROW'')')
     &          NROW 
      WRITE(OUTUNT,'(10X,
     &             ''NUMBER OF MODEL COLUMNS                        '',
     &             10X,I15,'' NCOL'')')
     &          NCOL
      WRITE(OUTUNT,'(10X,
     &             ''QUASI-3D CONFINING FLAG                        '',
     &             10X,I15,'' NCBL'')')
     &          NCBL
      WRITE(OUTUNT,'(10X,
     &             ''GRID GEOMETRY CODE                             '',
     &             10X,I15,'' IGRID'')')
     &          IGRID
      IF(NPER.EQ.0) THEN
         WRITE(OUTUNT,'(10X,
     &             ''STEADY-STATE GROUND-WATER SIMULATION           '',
     &             10X,I15,'' NPER'')')
     &          NPER
      ELSE
         WRITE(OUTUNT,'(10X,
     &             ''TRANSIENT GROUND-WATER SIMULATION              '',
     &             10X,I15,'' NPER'')')
     &          NPER
      ENDIF
      WRITE(OUTUNT,'(10X,
     &             ''MODFLOW HEAD VALUE FOR NO FLOW CELLS           '',
     &             10X,G15.5,'' HNOFLO'')')
     &          HNOFLO
      WRITE(OUTUNT,'(10X,
     &             ''MODFLOW HEAD VALUE FOR DRY CELLS               '',
     &             10X,G15.5,'' HDRY'')')
     &          HDRY
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(/)')
       GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,'(//,
     &          '' Unable to read '',A,'' from file '',A)') 
     &          VARNAM,BASFIL (1:INDEX(BASFIL,' ')-1)
      WRITE(OUTUNT,'(//,
     &          '' Unable to read '',A,'' from file '',A)') 
     &          VARNAM,BASFIL (1:INDEX(BASFIL,' ')-1)
      GO TO 9998
 9991 WRITE(*,'(//,
     &          '' End-of-file; Unable to read '',A,
     &          '' from file '',A)') 
     &          VARNAM,BASFIL (1:INDEX(BASFIL,' ')-1)
      WRITE(*,'(//,
     &          '' End-of-file; Unable to read '',A,
     &          '' from file '',A)') 
     &          VARNAM,BASFIL (1:INDEX(BASFIL,' ')-1)
 9998 CALL CLOSE_FILE (BASFIL,*9999)
 9999 WRITE(*,'(//,'' Abnormal Termination of Pthbas_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthall version 6.0                **************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHALL 04OCTOBER1999
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Allocates space within the common array.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C    Inputs:
C
C     OUTUNT  : FORTRAN UNIT NUMBER FOR MODTOOLS OUTPUT LSTING FILE
C     IGRID   : GRID GEOMETRY CODE
C             => 0 VARYING THICKNESS MODEL LAYERS
C                   AND(OR) NONHORIZONTAL LAYERS
C             => 1 TRUE RECTANGLAR 3-D GRID (UNIFORM THICKNESS MODEL LAYERS)
C     LENX    : MAXIMUM DIMENSION OF THE COMMON BLOCK ARRAY
C     MAXPMR  : MAXIMUM NUMBER OF COVERAGE PARAMETERS
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C     IOUT    : FORTRAN UNIT NUMBER
C
C   Inputs/Outputs:
C
C     ISUM    : INDEX NUMBER TO COMMON BLOCK ARRAY FOR ALLOCATION
C             => 1 BEGINNING
C
C    Outputs:
C
C     LCCVPR  : STARTING ARRAY INDEX FOR COVERAGE PARAMETERS
C     LAYCON  : STARTING ARRAY INDEX FOR LAYER TYPE CODES
C     LCDELX  : STARTING ARRAY INDEX FOR CELL WIDTHS IN ROW/COLUMN/PARTICLE
C                DIRECTION
C     LCDELZ  : STARTING ARRAY INDEX FOR NUMBER MODEL LAYERS/UNITS
C     LCDZCB  : STARTING ARRAY INDEX FOR CONFINING LAYERS/UNITS
C     LCIBOU  : STARTING ARRAY INDEX FOR IBOUND ARRAY
C     LCRWCL  : STARTING ARRAY INDEX FOR THE CELL'S ROW OR COLUMN
C     LCZBOT  : STARTING ARRAY INDEX FOR CELL BOTTOM ELEVATIONS
C     LCZTOP  : STARTING ARRAY INDEX FOR CELL TOP ELEVATIONS
C     LCPORO  : STARTING ARRAY INDEX FOR CELL POROSITY
C
C     Program:
C
C     ISUM1   : INDEX NUMBER TO LAST COMMON BLOCK ARRAY FOR ALLOCATION
C
C-----------------------------------------------------------------------
      SUBROUTINE PTHALL (
     I                   OUTUNT,
     I                   LENX,
     I                   MAXPMR,
     I                   NLAY,NROW,NCOL,NCBL,IGRID,NPER,
     I                   HNOFLO,HDRY,
     B                   ISUM,
     O                   LCCVPR,LAYCON,LCDELX,LCDELZ,LCDZCB,
     O                   LCIBOU,LCRWCL,LCZBOT,LCZTOP,LCPORO,
     E                   *)
C-------------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      REAL
     &     HNOFLO,HDRY
C
      INTEGER
     &        OUTUNT,
     &        LENX,
     &        NLAY,NROW,NCOL,NCBL,IGRID,NPER,
     &        ISUM,
     O        LCCVPR,LAYCON,LCDELX,LCDELZ,LCDZCB,
     O        LCIBOU,LCRWCL,LCZBOT,LCZTOP,LCPORO
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
C     ------------------------------------------------------------------
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(/)')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          MODTOOLS GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''              VERSION 6.0 04OCTOBER1999 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                 ALLOCATION MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(/)')
C
C1----Calculate storage parameters NRCL and NZDIM
C
      NRCL=NROW*NCOL*NLAY
C
      IF(IGRID.GT.0) THEN
         NZDIM=NRCL
      ELSE
         NZDIM=NRCL
      ENDIF
C
C2----Allocate space for arrays
C
      LAYCON=ISUM
      ISUM=ISUM+NLAY
      LCDELX=ISUM
      ISUM=ISUM+NCOL*NROW
      LCDELZ=ISUM
      ISUM=ISUM+NLAY
      LCDZCB=ISUM
      ISUM=ISUM+NLAY
      LCIBOU=ISUM
      ISUM=ISUM+NRCL
      LCRWCL=ISUM
      ISUM=ISUM+2*NCOL*NROW
      LCZBOT=ISUM
      ISUM=ISUM+NZDIM
      LCZTOP=ISUM
      ISUM=ISUM+NRCL
      LCPORO=ISUM
      ISUM=ISUM+NZDIM
      ISUM1=ISUM-1
C
C3----Print Modtools operation parameters
C
      WRITE(OUTUNT,'(/)')
      WRITE(OUTUNT,'(1H1,36X,
     &             ''MODTOOLS OPERATION PARAMETERS LIST'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(/)')
C
      WRITE(OUTUNT,'(10X,
     &             ''MAXIMUM DIMENSION OF THE COMMON BLOCK ARRAY    '',
     &             10X,I15,'' LENX'')')
     &          LENX
      WRITE(OUTUNT,'(10X,
     &             ''ELEMENTS IN THE COMMON BLOCK ARRAY USED        '',
     &             10X,I15,'' ISUM'')')
     &          ISUM1
      WRITE(OUTUNT,'(10X,
     &             ''MAXIMUM NUMBER OF COVERAGE PARAMETERS          '',
     &             10X,I15,'' MAXPMR'')')
     &          MAXPMR
C
      WRITE(OUTUNT,'(10X,
     &             ''NUMBER OF MODEL LAYERS                         '',
     &             10X,I15,'' NLAY'')')
     &          NLAY
      WRITE(OUTUNT,'(10X,
     &             ''NUMBER OF MODEL ROWS                           '',
     &             10X,I15,'' NROW'')')
     &          NROW 
      WRITE(OUTUNT,'(10X,
     &             ''NUMBER OF MODEL COLUMNS                        '',
     &             10X,I15,'' NCOL'')')
     &          NCOL
      WRITE(OUTUNT,'(10X,
     &             ''QUASI-3D CONFINING FLAG                        '',
     &             10X,I15,'' NCBL'')')
     &          NCBL
      WRITE(OUTUNT,'(10X,
     &             ''GRID GEOMETRY CODE                             '',
     &             10X,I15,'' IGRID'')')
     &          IGRID
      IF(NPER.EQ.0) THEN
         WRITE(OUTUNT,'(10X,
     &             ''STEADY-STATE GROUND-WATER SIMULATION           '',
     &             10X,I15,'' NPER'')')
     &          NPER
      ELSE
         WRITE(OUTUNT,'(10X,
     &             ''TRANSIENT GROUND-WATER SIMULATION              '',
     &             10X,I15,'' NPER'')')
     &          NPER
      ENDIF
      WRITE(OUTUNT,'(10X,
     &             ''MODFLOW HEAD VALUE FOR NO FLOW CELLS           '',
     &             10X,G15.5,'' HNOFLO'')')
     &          HNOFLO
      WRITE(OUTUNT,'(10X,
     &             ''MODFLOW HEAD VALUE FOR DRY CELLS               '',
     &             10X,G15.5,'' HDRY'')')
     &          HDRY
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(/)')
C
C4----Check amount of space used
C
      IF(ISUM1.GT.LENX) THEN
         WRITE(OUTUNT,'(//,
     &                ''    ***CELL ARRAY MUST BE DIMENSIONED '',
     &                ''LARGER*** ISUM '',I10,'' > LENX '',I10)')
     &             ISUM1,
     &             LENX
         WRITE (*,'(//,'' Cell array must be dimensioned larger ISUM '',
     &              I10,'' > LENX '',I10)')
     &           ISUM1,
     &           LENX
         WRITE(OUTUNT,'(//,
     &             '' Abnormal termination of Pthall_Subroutine'')')
         WRITE (*,'(//,'' Cell array must be dimensioned larger ISUM '',
     &              I10,'' > LENX '',I10)')
     &           ISUM1,
     &           LENX
         WRITE(*,'(//,
     &             '' Abnormal termination of Pthall_Subroutine'')')
         RETURN 1
      ENDIF
C
C5----Print Modtools common block listing
C
      WRITE(OUTUNT,'(/)')
      WRITE(OUTUNT,'(1H1,36X,
     &             ''MODTOOLS COMMON BLOCK INDEX LISTING          '')')
      WRITE(OUTUNT,'(10X,85(''-''))')
C
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR COVERAGE PARAMETERS   '',
     &             10X,I15,'' LCCVPR'')')
     &          LCCVPR
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR LAYER TYPE CODES      '',
     &             10X,I15,'' LAYCON'')')
     &          LAYCON
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CELL WIDTHS           '',
     &             10X,I15,'' LCDELX'')')
     &          LCDELX
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR MODEL LAYERS/UNITS    '',
     &             10X,I15,'' LCDELZ'')')
     &          LCDELZ
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CONFINING LAYERS      '',
     &             10X,I15,'' LCDZCB'')')
     &          LCDZCB
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR IBOUND ARRAY          '',
     &             10X,I15,'' LCIBOU'')')
     &          LCIBOU
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CELL ROW AND COLUMN   '',
     &             10X,I15,'' LCRWCL'')')
     &          LCRWCL
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CELL BOTTOM ELEVATION '',
     &             10X,I15,'' LCZBOT'')')
     &          LCZBOT
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR CELL TOP ELEVATION    '',
     &             10X,I15,'' LCZTOP'')')
     &          LCZTOP
      WRITE(OUTUNT,'(10X,
     &             ''STARTING ARRAY INDEX FOR POROSITY TERMS        '',
     &             10X,I15,'' LCPORO'')')
     &          LCPORO
      WRITE(OUTUNT,'(10X,
     &             ''TOTAL NUMBER OF ELEMENTS USED IN COMMON BLOCK  '',
     &             10X,I15,'' ISUM1'')')
     &          ISUM1
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(/)')
C
C6----Return
C
      RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthpmr version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHPMR 12NOVEMBER1997
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Reads information specifying what type of coverage
C      to generate, the scaling in the horizontal and vertical, and
C      other pertinent information.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C   Inputs:
C
C     FILNAM  : FILE CONTAINING COVERAGE ORIENTATION INFORMATION
C     MAXPMR  : MAXIMUM NUMBER OF COVERAGE PARAMETERS
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C
C   Outputs:
C
C     COVPMR  : COVERAGE PARAMETERS ARRAY (MAXPMR)

C-------------------------------------------------------------------------
      SUBROUTINE PTHPMR (
     I                   OUTUNT,
     I                   FILNAM,
     I                   MAXPMR,
     I                   NROW,NCOL,NLAY,
     O                   COVPMR,
     E                   *)
C-----------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      DIMENSION 
     &          COVPMR(MAXPMR)
C
      CHARACTER*(*) FILNAM
      CHARACTER*80 VARNAM
C
      INTEGER OUTUNT,NCOL,NROW,NLAY
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                 Prompt user for information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          MODTOOLS GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''               VERSION 6.0 12NOVEMBER1997 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                  BATCH FILE MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C1----Open coverage parameter file
C
      INCOV=60
      NSTAT=1
      ITALK=1
      CALL OPEN_FILE (INCOV,FILNAM,NSTAT,ITALK,*9999)
C
C2----Read MODPATH mode of operation
C
      VARNAM='1st line -->MODPATH Tracking Mode'
       READ(INCOV,*,ERR=9990,END=9991) CNTINT
C
C3----Read coverage type
C
       VARNAM='2nd line -->MODTOOLS Options'
        READ(INCOV,*,ERR=9990,END=9991) ICOVER
         COVPMR(2)=ICOVER
C
      IF(ICOVER.NE.7) THEN
         MODFLG=INT(CNTINT)
         COVPMR(1)=MODFLG
      ELSE
         COVPMR(1)=CNTINT
      ENDIF
C
C4----Read view orientation informatiom
C
      DO 400 N=3,9
         VARNAM='COVPMR  '
         WRITE(VARNAM (7:8),'(I2)') N
         READ(INCOV,*,ERR=9990,END=9991) COVPMR(N)
  400 CONTINUE
C
      IF(COVPMR(3).LE.0.0) COVPMR(3)=1.0
       IF(COVPMR(4).LE.0.0) COVPMR(4)=1.0
        IF(COVPMR(8).LE.0.0) COVPMR(8)=1.0
         IF(COVPMR(9).LE.0.0) COVPMR(9)=1.0
C
C5----Read view orientation informatiom
C
      VARNAM='10th line -->MODTOOLS orientation'
       READ(INCOV,*,ERR=9990,END=9991) IVIEW
        COVPMR(10)=IVIEW
C
C7----Read tranverse informatiom
C
      VARNAM='11th line -->Row,Column,layer,etc'
       READ(INCOV,*,ERR=9990,END=9991) IRWCL
        COVPMR(11)=IRWCL
C
C8----Read tranverse informatiom
C
      IF(ICOVER.NE.8) THEN
         VARNAM='12th line -->Array dimension'
         READ(INCOV,*,ERR=9990,END=9991) IDCNTR
         COVPMR(12)=IDCNTR
      ELSE
         VARNAM='12th line -->Velocity vector scaling'
         READ(INCOV,*,ERR=9990,END=9991) VECTOR
         COVPMR(12)=VECTOR
      ENDIF
C
C9----Read contour interval informatiom
C
      IF(ICOVER.EQ.7) THEN
         VARNAM='13th line -->Contour interval'
         READ(INCOV,*,ERR=9990,END=1000) MODPER
         COVPMR(13)=MODPER
      ELSE
         VARNAM='13th line -->MODFLOW stress period'
         READ(INCOV,*,ERR=9990,END=1000) MODPER
         COVPMR(13)=MODPER
      ENDIF
C
C10---Read number of equal arcs informatiom
C
      IF(ICOVER.NE.6) THEN
         VARNAM='14th line -->Number of arcs'
         READ(INCOV,*,ERR=9990,END=1000) NUMARC
         COVPMR(14)=NUMARC
      ELSE
         VARNAM='14th line -->MODFLOW time step'
         READ(INCOV,*,ERR=9990,END=1000) MODSTP
         COVPMR(14)=MODSTP
      ENDIF
C
C11----Read hydraulic head for dry cells informatiom
C
      VARNAM='15th line -->Head value for dry cells'
       READ(INCOV,*,ERR=9990,END=1000) DRYCLL
        COVPMR(15)=DRYCLL
C
C12----Read hydraulic head for noflow cells informatiom
C
      VARNAM='16th line -->Head value for noflow cells'
       READ(INCOV,*,ERR=9990,END=1000) FLWCLL
        COVPMR(16)=FLWCLL
         GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,'(//,'' Unable to read '',A)') 
     &                                      VARNAM
      WRITE(*,'(//,'' from file '',A)') 
     &                                 FILNAM (1:INDEX(FILNAM,' ')-1)
      WRITE(OUTUNT,'(//,'' Unable to read '',A)') 
     &                                      VARNAM
      WRITE(OUTUNT,'(//,'' from file '',A)') 
     &                                 FILNAM (1:INDEX(FILNAM,' ')-1)
      GO TO 9998
 9991 WRITE(*,'(//,'' End-of-file; Unable to find '',A)')
     &        VARNAM
      WRITE(*,'(//,'' in file '',A)')
     &                               FILNAM (1:INDEX(FILNAM,' ')-1)
      WRITE(OUTUNT,'(//,'' End-of-file; Unable to find '',A)')
     &        VARNAM
      WRITE(OUTUNT,'(//,'' in file '',A)')
     &                               FILNAM (1:INDEX(FILNAM,' ')-1)
 9998 CALL CLOSE_FILE (FILNAM,*9999)
 9999 WRITE(*,'(//,'' Abnormal Termination of Pthpmr_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 CALL CLOSE_FILE (FILNAM,*9999)
      RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthpmt version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHPMT 30AUGUST1999
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Prompts user for coverage and orientation information to construct
C      GIS output from the results of ground-water modeling program MODFLOW
C      and the particle tracking program MODPATH.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN77
C
C
C   Inputs:
C
C     OUTUNT  : FORTRAN UNIT NUMBER OF OPERATIONAL OUTPUT FILE
C     PMRFIL  : FILE CONTAINING COVERAGE ORIENTATION INFORMATION
C     COVER   : USER SPECIFIED COVERAGE NAME
C     MAXPMR  : NUMBER OF COVERAGE PARAMETERS
C     NROW    : NUMBER OF ROWS IN GRID
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C
C   Inputs/Outputs: None
C
C   Outputs:
C
C    Variables:
C
C     COVPMR  : COVERAGE PARAMETERS ARRAY (MAXPMR)
C
C     Program:
C
C     ANSWER : DUMMY CHARACTER HOLDING USER RESPONSES
C     CONVRT : DUMMY REAL HOLDING COVERAGE PARAMETERS
C     HSCALE : DUMMY REAL HOLDING HORIZONTAL MAPSCALE
C     IANSW  : DUMMY INTEGER HOLDING USER RESPONSES
C     IERROR : INTEGER HOLDING ERROR VALUE
C     MESAGE : DUMMY CHARACTER HOLDING FILE OUTPUT MESSAGES
C     VSCALE : DUMMY REAL HOLDING VERTICAL EXAGGERATION
C
C-------------------------------------------------------------------------
      SUBROUTINE PTHPMT (
     I                   OUTUNT,
     I                   PMRFIL,COVER,
     I                   MAXPMR,
     I                   NROW,NCOL,NLAY,
     O                   COVPMR,
     E                   *)
C-------------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C
C::::::::::::::::::::::::  GLOBAL_VARIABLES  :::::::::::::::::::::::::::
C
      DIMENSION 
     &          COVPMR(MAXPMR)
C
      CHARACTER*(*) COVER,PMRFIL
C
      INTEGER 
     &        OUTUNT,NCOL,NROW,NLAY
C
C:::::::::::::::::::::::::  PROGRAM_VARIABLES  :::::::::::::::::::::::::
C
      CHARACTER*80 ANSWER,MESAGE(30)
C
      REAL
     &    HNOFLO,HDRY
C
      INTEGER IOUT,NSTAT,ITALK,IERROR,NPER
C
      DATA IERROR /0/
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                 Prompt user for information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(//)')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          MODTOOLS GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''               VERSION 6.0 30AUGUST1999 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                   MENUING MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C1----Coverage characteristics
C
C
C1A----Set coverage parameters
C
 100  COVPMR(2)=0
      MESAGE(2)='NO COVERAGE'
      COVPMR(10)=0
      MESAGE(10)='NO ORIENTATION'
      IVIEW=-99
      NPER=INT(COVPMR(17))
C
C1B----Type of coverage
C
  102 IERROR=1
      WRITE(*,'(//,'' Select an option for creating '',
     &          ''a coverage or info file(s)'')')
      WRITE(*,'(''-------------------------------------------'',
     &          ''--------------------------'')')
      WRITE(*,'('' <cr> = Quit '')')
      WRITE(*,'(''    p = Pathline output'')')
      WRITE(*,'(''    e = Endpoint output'')')
      WRITE(*,'(''    t = Times-series output'')')
      WRITE(*,'(''    z = Zones of transport output'')')
      WRITE(*,'(''    g = Model grid output'')')
      WRITE(*,'(''    c = Contour output'')')
      WRITE(*,'(''    v = Velocity vectors output'')')
      WRITE(*,'(''    i = Cell values output '')')
      WRITE(*,'(''    h = Help'')')
      WRITE(*,'(/,''    Enter option:'')')
      READ(*,'(A)',ERR=104,END=9990) ANSWER
      IERROR=0
C
C1Q-----Quitting
C
 104  IF(ANSWER.EQ.' ') GO TO 9990
C
C1E-----Errors
C
      IF(IERROR.NE.0) THEN
         WRITE(*,'(//,'' Error reading option'')')
         GO TO 102
      ENDIF
C
C1H-----Help
C
      IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
 106     IERROR=1
         WRITE(*,'(//,'' Help for selecting an option for '',
     &                ''creating a coverage or info file(s)'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit '')')
         WRITE(*,'(''    p = Pathline output'')')
         WRITE(*,'(''    e = Endpoint output'')')
         WRITE(*,'(''    t = Times-series output'')')
         WRITE(*,'(''    z = Zones of Transport output'')')
         WRITE(*,'(''    g = Model grid output'')')
         WRITE(*,'(''    c = Contour output'')')
         WRITE(*,'(''    v = Velocity vectors output'')')
         WRITE(*,'(''    i = Cell values output '')')
         WRITE(*,'(''    q = Quit help'')')
         WRITE(*,'(/,''    Enter help letter:'')')
         READ(*,'(A)',ERR=108,END=9990) ANSWER
         IERROR=0
C
C1Hq-----Quitting
C
 108   IF(ANSWER.EQ.' ') GO TO 102
C
C1He-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading MODTOOLS option'')')
          GO TO 106
       ENDIF
C
C1Hq-----Quit help
C
       IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') THEN
          WRITE(*,'(//,'' Quiting help menu'')')
          GO TO 102
       ENDIF
C
C1Hr-----Help section
C
         WRITE(*,*) ' '
         WRITE(*,*) 'MODTOOLS needs to know what type of GIS output',
     &              ' will be created.'
         WRITE(*,*) ' '
       IF(ANSWER.EQ.'p') THEN
          WRITE(*,*) 'Response: =----->  p'
          WRITE(*,*) ' A line coverage is created from particle '
          WRITE(*,*) '  pathlines recorded in the PATHLINE file'
          WRITE(*,*) '  by MODPATH.'
          WRITE(*,*) ' The user must include the name of the output'
          WRITE(*,*) '  file in NAME file and use the word '
          WRITE(*,*) '  PATHLINE to identify this file in the list.'
        ELSE IF(ANSWER.EQ.'e') THEN
          WRITE(*,*) 'Response: =----->  e'
          WRITE(*,*) ' A point coverage is created from particle '
          WRITE(*,*) '  starting and ending locations recorded in the'
          WRITE(*,*) '  ENDPOINT file by MODPATH.'
          WRITE(*,*) ' The user must include the name of the output'
          WRITE(*,*) '  file in NAME file and use the word '
          WRITE(*,*) '  ENDPOINT to identify this file in the list.'
       ELSE IF(ANSWER.EQ.'t') THEN
          WRITE(*,*) 'Response: =----->  t'
          WRITE(*,*) ' A point coverage is created from particle '
          WRITE(*,*) '  time-series locations recorded in the TIMESERS'
          WRITE(*,*) '  file by MODPATH.'
          WRITE(*,*) ' The user must include the name of the output'
          WRITE(*,*) '  file in NAME file and use the word '
          WRITE(*,*) '  TIME-SERIES to identify this file in the list.'
       ELSE IF(ANSWER.EQ.'z') THEN
          WRITE(*,*) 'Response: =----->  z'
          WRITE(*,*) ' Two coverages are created from particle data'
          WRITE(*,*) '  recorded in the TIMESERS and ENDPOINT files'
          WRITE(*,*) '  by MODPATH for the backward-tracking option.'
          WRITE(*,*) '  A polygon coverage is delineated for the zones'
          WRITE(*,*) '  of transport for the user-specified '
          WRITE(*,*) '  orientation. A point coverage of the vertices'
          WRITE(*,*) '  from the selected particles used to construct'
          WRITE(*,*) '  the polygons. MODTOOLS associates'
          WRITE(*,*) '  characteristics from the selected particles'
          WRITE(*,*) '  to each vertices.'
          WRITE(*,*) ' The user must include the name of the output'
          WRITE(*,*) '  files in NAME file and use the words'
          WRITE(*,*) '  TIME-SERIES and ENDPOINT to identify these '
          WRITE(*,*) '  files in the list.'
       ELSE IF(ANSWER.EQ.'g') THEN
          WRITE(*,*) 'Response: =----->  g'
          WRITE(*,*) ' A polygon coverage is created from data arrays'
          WRITE(*,*) '  defining grid dimensions from the MAIN file'
          WRITE(*,*) '  input to MODPATH. The user can specify an '
          WRITE(*,*) '  orientation in mapview or along a row, column,'
          WRITE(*,*) '  or particle pathline.'
          WRITE(*,*) '  If the particle pathline option is used,'
          WRITE(*,*) '  the user must include the PATHLINE file in'
          WRITE(*,*) '  the NAME file.  Also, a pathline coverage'
          WRITE(*,*) '  will be created so both coverages can be'
          WRITE(*,*) '  displayed.'
       ELSE IF(ANSWER.EQ.'c') THEN
          WRITE(*,*) 'Response: =----->  c'
          WRITE(*,*) ' A contour coverage is created from data '
          WRITE(*,*) '  recorded in a file output by MODFLOW'
          WRITE(*,*) '  during a ground-water simulation. Also, the'
          WRITE(*,*) '  user can substitute any similarily formatted '
          WRITE(*,*) '  file.'
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  file in MODTOOLS name file and use the word '
          WRITE(*,*) '  CONTOUR or CONTOUR(BINARY) to identify this '
          WRITE(*,*) '  file in the list.  If the word CONTOUR is used,'
          WRITE(*,*) '  MODTOOLS needs another file which specifies'
          WRITE(*,*) '  the format of the values of the cell-by-cell'
          WRITE(*,*) '  terms.'
          WRITE(*,*) '  This format-control file is identified by'
          WRITE(*,*) '  using the word CONTOUR-CONTROL.  The '
          WRITE(*,*) '  format-control file is read by the U3DREL '
          WRITE(*,*) '  or U2DREL utility modules of MODFLOW or '
          WRITE(*,*) '  MODTOOLS [use intructions for the U2DREL '
          WRITE(*,*) '  module from MODFLOW manual for the construction'
          WRITE(*,*) '  of this file].'
       ELSE IF(ANSWER.EQ.'v') THEN
          WRITE(*,*) 'Response: =----->  v'
          WRITE(*,*) ' A flow direction line coverage is created from '
          WRITE(*,*) '  data recorded in the cell-by-cell head and flow'
          WRITE(*,*) '  terms output by MODFLOW during a ground-water'
          WRITE(*,*) '  simulation.'
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  file from the Block-Centered Package of MODFLOW'
          WRITE(*,*) '  in MODTOOLS name file and use the word'
          WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file '
          WRITE(*,*) '  in the list. If the word BUDGET(ASCII) is used,'
          WRITE(*,*) '  MODTOOLS needs another file which specifies the'
          WRITE(*,*) '  format of the values of the cell-by-cell  '
          WRITE(*,*) '  simulated flow. This format-control flow file '
          WRITE(*,*) '  is identified by using the word BUDGET-CONTROL.'
          WRITE(*,*) '  The format-control file is read by the U3DREL '
          WRITE(*,*) '  utility module of MODTOOLS [use intructions '
          WRITE(*,*) '  for the U2DREL module from MODFLOW manual for'
          WRITE(*,*) '  the construction of this file].'
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  head file in MODTOOLS name file and use the '
          WRITE(*,*) '  word HEAD or HEAD(BINARY) to identify this file'
          WRITE(*,*) '  in the list.  If the word HEAD is used, '
          WRITE(*,*) '  MODTOOLS needs another file which specifies '
          WRITE(*,*) '  the format of the values of the cell-by-cell  '
          WRITE(*,*) '  simulated head. This format-control head file '
          WRITE(*,*) '  is identified by using the word HEAD-CONTROL.'
          WRITE(*,*) '  The format-control file is read by the U2DREL '
          WRITE(*,*) '  utility module of MODFLOW [use intructions '
          WRITE(*,*) '  for the U2DREL module from MODFLOW manual for'
          WRITE(*,*) '  the construction of this file].'
       ELSE IF(ANSWER.EQ.'i') THEN
          WRITE(*,*) 'Response: =----->  i'
          WRITE(*,*) ' A info file(s) is created from the cell-by-cell'
          WRITE(*,*) '  terms recorded in an file output by'
          WRITE(*,*) '  MODFLOW during a ground-water simulation. '
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  file in MODTOOLS name file and use the word '
          WRITE(*,*) '  HEAD or HEAD(BINARY) for simulated head, or'
          WRITE(*,*) '  BUDGET for simulated terms from other packages'
          WRITE(*,*) '  of MODFLOW to identify this file in the list.'
          WRITE(*,*) ' If the word HEAD is used, MODTOOLS needs another'
          WRITE(*,*) '  file which specifies the format '
          WRITE(*,*) '  of the values of the cell-by-cell simulated '
          WRITE(*,*) '  head This format-control flow file is '
          WRITE(*,*) '  identified by using the word HEAD-CONTROL.'
          WRITE(*,*) '  The format-control file is read by the '
          WRITE(*,*) '  U2DREL module of MODFLOW [see MODFLOW manual'
          WRITE(*,*) '  for the construction of this file].'
          WRITE(*,*) ' If the user specifies a vertical profile'
          WRITE(*,*) '  orientation, the terms will be'
          WRITE(*,*) '  append as cell attributes to the vertical'
          WRITE(*,*) '  cell coverage which will be construction.'
       ELSE
          WRITE(*,*) ' '
          WRITE(*,*) ' =-----> Invalid Response <-----='
          WRITE(*,*) ' '
          GO TO 106
       ENDIF
         WRITE(*,*) 'Continue?'
         READ(*,'(A)') ANSWER
         GO TO 102
C
C1R-----Responses
C
      ELSE
       IF(ANSWER (1:1).EQ.'p') THEN
          WRITE(*,'('' ...Pathline GIS output selected'')')
          ICOVER=1
          COVPMR(2)=ICOVER
          MESAGE(2)='PATHLINE GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'e') THEN
          WRITE(*,'('' ...Endpoint GIS output selected'')')
          ICOVER=2
          COVPMR(2)=ICOVER
       ELSE IF(ANSWER (1:1).EQ.'t') THEN
          WRITE(*,'('' ...Time series GIS output selected'')')
          ICOVER=3
          COVPMR(2)=ICOVER
          MESAGE(2)='TIME-SERIES GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'z') THEN
          WRITE(*,'('' ...Zone_of_transport GIS output '',
     &              ''selected'')')
          ICOVER=4
          COVPMR(2)=ICOVER
          MESAGE(2)='ZONES_OF_TRANSPORT GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'g') THEN
          WRITE(*,'('' ...Model grid GIS output selected'')')
          ICOVER=5
          COVPMR(2)=ICOVER
          MESAGE(2)='MODEL GRID GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'c') THEN
          WRITE(*,'('' ...Contour GIS output selected'')')
          ICOVER=7
          COVPMR(2)=ICOVER
          MESAGE(2)='CONTOUR GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'v') THEN
          WRITE(*,'('' ...Velocity vectors GIS output selected'')')
          ICOVER=8
          COVPMR(2)=ICOVER
          MESAGE(2)='VELOCITY VECTORS GIS OUTPUT'
       ELSE IF(ANSWER (1:1).EQ.'i') THEN
          WRITE(*,'('' ...Cell values GIS output selected'')')
          ICOVER=6
          COVPMR(2)=ICOVER
          MESAGE(2)='CELL VALUES OUTPUT'
       ELSE
          WRITE(*,'(//,'' Invalid response try again'')')
          GO TO 102
       ENDIF
      ENDIF
C
C2A-----Tracking mode of Modpath [Endpoint Analysis only]
C
 200    COVPMR(1)=0
        MESAGE(1)='NO MODPATH TRACKING OPTION NEEDED'
      IF(ICOVER.EQ.2) THEN
 202     IERROR=1
         WRITE(*,'(//,'' Select an option for creating a '',
     &             ''point coverage of '',/
     &             ''  starting or final particle locations'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    s = Mapview of starting locations '',
     &             ''(forward tracking)'')')
         WRITE(*,'(''    f = Mapview of final locations '',
     &             ''(forward tracking)'')')
         WRITE(*,'(''    e = Mapview of final locations '',
     &             ''(backward tracking)'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Options menu'')')
         WRITE(*,'(/,''    Enter tracking option:'')')
         READ(*,'(A)',ERR=204,END=9990) ANSWER
         IERROR=0
C
C2Q-----Quitting
C
 204   IF(ANSWER.EQ.' ') GO TO 9990
C
C2E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading tracking option'')')
          GO TO 202
       ENDIF
C
C2P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C2H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODPATH can be run using two tracking modes.'
          WRITE(*,*) ' '
          WRITE(*,*) 'Response: =----->  s'
          WRITE(*,*) ' Starting particle locations for a MODPATH'
          WRITE(*,*) '  simulation in the forward tracking mode'
          WRITE(*,*) '  which means particles traveled in the'
          WRITE(*,*) '  direction of the flow of ground-water'
          WRITE(*,*) '  towards discharge points.'
          WRITE(*,*) 'Response: =----->  f'
          WRITE(*,*) ' Final particle locations for a MODPATH'
          WRITE(*,*) '  simulation in the forward tracking mode'
          WRITE(*,*) '  which means particles traveled in the'
          WRITE(*,*) '  direction of the flow of ground-water'
          WRITE(*,*) '  towards discharge points.'
          WRITE(*,*) 'Response: =----->  e'
          WRITE(*,*) ' Final particle locations for a MODPATH'
          WRITE(*,*) '  simulation in the forward tracking mode'
          WRITE(*,*) '  which means particles traveled in the'
          WRITE(*,*) '  reverse direction of the flow of ground-water'
          WRITE(*,*) '  towards recharge points.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 202
C
C2R-----Responses
C
       ELSE
        IF(ANSWER (1:1).EQ.' ') THEN
           WRITE(*,'(//,'' Quitting Modtools now...'')')
           GO TO 9999
        ELSE IF(ANSWER (1:1).EQ.'s' .OR. ANSWER (1:1).EQ.'S') THEN
           MODFLG=1
           COVPMR(1)=MODFLG
           MESAGE(1)='FORWARD TRACKING FOR MODPATH'
           MESAGE(2)='STARTING PARTICLE COVERAGE (FORWARD TRACKING)'
        ELSE IF(ANSWER (1:1).EQ.'f' .OR. ANSWER (1:1).EQ.'F') THEN
           MODFLG=2
           COVPMR(1)=MODFLG
           MESAGE(1)='FORWARD TRACKING FOR MODPATH'
           MESAGE(2)='FINAL PARTICLE COVERAGE (FORWARD TRACKING)'
        ELSE IF(ANSWER (1:1).EQ.'e' .OR. ANSWER (1:1).EQ.'E') THEN
           MODFLG=3
           COVPMR(1)=2
           MESAGE(1)='BACKWARD TRACKING FOR MODPATH'
           MESAGE(2)='FINAL PARTICLE COVERAGE (BACKWARD TRACKING)'
        ELSE
           WRITE(*,'(//,'' Unavailable choice'')')
           GO TO 202
        ENDIF
       ENDIF
      ENDIF
C
C2O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 100
C
C2B-----Modflow cell-by-cell terms
C
      IF(ICOVER.EQ.6 .OR. ICOVER.EQ.7) THEN
  212    IERROR=1
         WRITE(*,'(//,
     &             '' Select the cell-by-cell terms from MODFLOW '')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''  hed = Head terms from Basic Package'')')
         WRITE(*,'(''  ddn = Drawdown terms from Basic Package'')')
         WRITE(*,'(''  bcf = Flow terms through cell faces '',
     &             ''from Block-Centered-Flow Package'')')
         WRITE(*,'(''  sto = Storage terms from '',
     &             ''Block-Centered-Flow Package'')')
         WRITE(*,'(''  riv = Flow terms from River Package'')')
         WRITE(*,'(''  rch = Flow terms from Recharge Package'')')
         WRITE(*,'(''  wel = Flow terms from Well Package'')')
         WRITE(*,'(''  drn = Flow terms from Drain Package'')')
         WRITE(*,'(''  ghb = Flow terms from '',
     &             ''General Head Boundary Package'')')
         WRITE(*,'(''  evt = Flow terms from '',
     &             ''Evapotranspiration Package'')')
         WRITE(*,'(''  str = Flow terms from '',
     &             ''Streamflow-Routing Package'')')
         WRITE(*,'(''  flo = Streamflow terms from '',
     &             ''Streamflow-Routing Package [flow]'')')
         WRITE(*,'(''  ibs = Storage terms from '',
     &             ''Interbed-Storage Package'')')
         WRITE(*,'(''  arr = Data array gridded like '',
     &             ''those of MODFLOW'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Options menu'')')
         WRITE(*,'(/,''    Enter cell-by-cell term selection:'')')
         READ(*,'(A)',ERR=214,END=9990) ANSWER
         IERROR=0
C
C2Q-----Quitting
C
 214   IF(ANSWER.EQ.' ') GO TO 9990
C
C2E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading tracking option'')')
          GO TO 212
       ENDIF
C
C2P-----Previous menu
C
       IF(ANSWER.EQ.'B' .OR. ANSWER.EQ.'b') THEN
          ANSWER='B'
C
C2H-----Help
C
       ELSE IF(ANSWER (1:3).EQ.'H  ' .OR. ANSWER (1:3).EQ.'h  ') THEN
  216     IERROR=1
          WRITE(*,'(//,
     &              '' Help for selecting of cell-by-cell terms '',
     &              ''from MODFLOW packages'')')
          WRITE(*,'(''-------------------------------------------'',
     &              ''--------------------------'')')
          WRITE(*,'('' <cr> = Quit help'')')
          WRITE(*,'(''  hed = Head terms from '',
     &              ''Basic Package'')')
          WRITE(*,'(''  ddn = Drawdown terms from '',
     &              ''Basic Package'')')
          WRITE(*,'(''  bcf = Terms for flow through '',
     &              ''cell faces from Block-Centered-Flow Package'')')
          WRITE(*,'(''  sto = Storage terms from '',
     &              ''Block-Centered-Flow Package'')')
          WRITE(*,'(''  riv = Flow terms from '',
     &              ''River Package [leakage]'')')
          WRITE(*,'(''  rch = Flow terms from '',
     &              ''Recharge Package'')')
          WRITE(*,'(''  wel = Flow terms from '',
     &              ''Well Package'')')
          WRITE(*,'(''  drn = Flow terms from '',
     &              ''Drain Package'')')
          WRITE(*,'(''  ghb = Flow terms from '',
     &              ''General Head Boundary Package'')')
          WRITE(*,'(''  evt = Flow terms from '',
     &              ''Evapotranspiration Package'')')
          WRITE(*,'(''  str = Flow terms from '',
     &              ''Streamflow-Routing Package'')')
          WRITE(*,'(''  flo = Streamflow terms from '',
     &              ''Streamflow-Routing Package [flow]'')')
          WRITE(*,'(''  ibs = Storage terms from '',
     &              ''Interbed-Storage Package'')')
          WRITE(*,'(''  arr = Miscellaneous model data that are '',
     &              '' gridded like the areal grid of MODFLOW'')')
          WRITE(*,'(''    q = Quit help'')')
          WRITE(*,'(/,''    Enter help selection:'')')
          READ(*,'(A)',ERR=218,END=9990) ANSWER
          IERROR=0
C
C2Hq-----Quitting
C
 218    IF(ANSWER (1:1).EQ.' ') GO TO 212
C
C2He-----Errors
C
        IF(IERROR.NE.0) THEN
           WRITE(*,'(//,'' Error reading help option'')')
           GO TO 216
        ENDIF
C
C2Hq-----Quit help
C
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') THEN
           ANSWER='Q'
C
C2Hr-----Help selection
C
        ELSE IF(ANSWER (1:3).EQ.'hed' .OR. ANSWER (1:3).EQ.'HED') THEN
           WRITE(*,*) 'Response: =-----> hed'
           WRITE(*,*) ' The cell-by-cell head terms are output by the'
           WRITE(*,*) '  Basic Package during a ground-water'
           WRITE(*,*) '  simulation.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  HEAD or HEAD(BINARY) to identify this file in'
           WRITE(*,*) '  the list.'
           WRITE(*,*) ' If the word HEAD is used, MODTOOLS'
           WRITE(*,*) '  needs another file which specifies the format '
           WRITE(*,*) '  of the values of the cell-by-cell simulated '
           WRITE(*,*) '  head. This format-control head file is '
           WRITE(*,*) '  identified by using the word HEAD-CONTROL.'
           WRITE(*,*) '  The format-control file is read by the U2DREL '
           WRITE(*,*) '  utility module of MODFLOW [use intructions '
           WRITE(*,*) '  for the U2DREL module from MODFLOW manual for'
           WRITE(*,*) '  the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, the head terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'ddn' .OR. ANSWER (1:3).EQ.'DDN') THEN
           WRITE(*,*) 'Response: =-----> ddn'
           WRITE(*,*) ' The cell-by-cell drawdown terms output from'
           WRITE(*,*) '  Basic Package during a ground-water'
           WRITE(*,*) '  simulation.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  DRAWDOWN or DRAWDOWN(BINARY) to identify this'
           WRITE(*,*) '  file in the list.'
           WRITE(*,*) ' If the word DRAWDOWN is used, MODTOOLS'
           WRITE(*,*) '  needs another file which specifies the format '
           WRITE(*,*) '  of the values of the cell-by-cell simulated '
           WRITE(*,*) '  head. This format-control head file is '
           WRITE(*,*) '  identified by using the word DRAWDOWN-CONTROL.'
           WRITE(*,*) '  The format-control file is read by the U2DREL '
           WRITE(*,*) '  utility module of MODFLOW [use intructions '
           WRITE(*,*) '  for the U2DREL module from MODFLOW manual for'
           WRITE(*,*) '  the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, the head terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'bcf' .OR. ANSWER (1:3).EQ.'BCF') THEN
           WRITE(*,*) 'Response: =-----> bcf'
           WRITE(*,*) ' The flow terms through cell faces output from'
           WRITE(*,*) '  Block-Centered-Flow Package. The terms are'
           WRITE(*,*) '  flow through the right, front, and lower'
           WRITE(*,*) '  faces.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'sto' .OR. ANSWER (1:3).EQ.'STO') THEN
           WRITE(*,*) 'Response: =-----> sto'
           WRITE(*,*) ' The cell-by-cell storage terms output from'
           WRITE(*,*) '  Block-Centered-Flow Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'riv' .OR. ANSWER (1:3).EQ.'RIV') THEN
           WRITE(*,*) 'Response: =-----> riv'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  River Package.  These values are the river'
           WRITE(*,*) '  leakage for each simulated river cell.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'rch' .OR. ANSWER (1:3).EQ.'RCH') THEN
           WRITE(*,*) 'Response: =-----> rch'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Recharge Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'wel' .OR. ANSWER (1:3).EQ.'WEL') THEN
           WRITE(*,*) 'Response: =-----> wel'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Well Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'drn' .OR. ANSWER (1:3).EQ.'DRN') THEN
           WRITE(*,*) 'Response: =-----> drn'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Drain Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'ghb' .OR. ANSWER (1:3).EQ.'GHB') THEN
           WRITE(*,*) 'Response: =-----> ghb'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  General Head Boundary Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'evt' .OR. ANSWER (1:3).EQ.'EVT') THEN
           WRITE(*,*) 'Response: =-----> evt'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Evapotranspiration Package.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'str' .OR. ANSWER (1:3).EQ.'STR') THEN
           WRITE(*,*) 'Response: =-----> str'
           WRITE(*,*) ' The cell-by-cell flow terms output from'
           WRITE(*,*) '  Streamflow-Routing Package.  These values are'
           WRITE(*,*) '  the cumulative sum of stream leakage for'
           WRITE(*,*) '  each simulated stream cell.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'flo' .OR. ANSWER (1:3).EQ.'FLO') THEN
           WRITE(*,*) 'Response: =-----> flo'
           WRITE(*,*) ' The cell-by-cell streamflow terms output from'
           WRITE(*,*) '  Streamflow-Routing Package.  These values are'
           WRITE(*,*) '  the cumulative sum of streamflow for'
           WRITE(*,*) '  each simulated stream cell.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'ibs' .OR. ANSWER (1:3).EQ.'IBS') THEN
           WRITE(*,*) 'Response: =-----> ibs'
           WRITE(*,*) ' The cell-by-cell interbed-storage terms output'
           WRITE(*,*) '  from Interbed-Storage Package.  These values'
           WRITE(*,*) '  are the volumetric rate of the interbed'
           WRITE(*,*) '  storage for each cell.'
           WRITE(*,*) ' The user must include the name of the output'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  BUDGET or BUDGET(ASCII) to identify this file'
           WRITE(*,*) '  in the list. '
           WRITE(*,*) ' If the word BUDGET(ASCII) is used,'
           WRITE(*,*) '  MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the simulated'
           WRITE(*,*) '  cell-by-cell terms. This format-control budget'
           WRITE(*,*) '  file is identified by using the word '
           WRITE(*,*) '  BUDGET-CONTROL.  The format-control file is '
           WRITE(*,*) '  read by the U3DREL utility module of '
           WRITE(*,*) '  MODTOOLS [use intructions from MODTOOLS '
           WRITE(*,*) '  manual for the construction of this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE IF(ANSWER (1:3).EQ.'arr' .OR. ANSWER (1:3).EQ.'arr') THEN
           WRITE(*,*) 'Response: =-----> arr'
           WRITE(*,*) ' Miscellaneous gridded model data that are in'
           WRITE(*,*) '  the binary (unformatted) or standard ASCII'
           WRITE(*,*) '  text formats like those of MODFLOW. These'
           WRITE(*,*) '  data must be gridded at the same scale as the'
           WRITE(*,*) '  areal grid of the MODFLOW model (that is,'
           WRITE(*,*) '  NROW x NCOL).'
           WRITE(*,*) ' The user must include the name of the array'
           WRITE(*,*) '  file in MODTOOLS name file and use the word '
           WRITE(*,*) '  ARRAY or ARRAY(BINARY) to identify this file'
           WRITE(*,*) '  in the list.'
           WRITE(*,*) ' MODTOOLS needs another file which specifies'
           WRITE(*,*) '  the format of the values of the data array'
           WRITE(*,*) '  This format-control file is identified by '
           WRITE(*,*) '  using the word ARRAY-CONTROL.  '
           WRITE(*,*) '  The format-control file is read by either '
           WRITE(*,*) '  the U2DREL or U3DREL utility modules of '
           WRITE(*,*) '  MODFLOW or MODTOOLS [use intructions from '
           WRITE(*,*) '  MODFLOW manual for the construction of'
           WRITE(*,*) '  this file].'
           WRITE(*,*) ' If the user specifies a vertical profile'
           WRITE(*,*) '  orientation, these terms will be'
           WRITE(*,*) '  append as cell attributes to the vertical'
           WRITE(*,*) '  cell coverage which will be construction.'
        ELSE
           WRITE(*,*) ' '
           WRITE(*,*) ' =-----> Invalid Response <-----='
           WRITE(*,*) ' '
           GO TO 216
        ENDIF
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 212
C
C2R-----Responses
C
       ELSE
        IF(ANSWER (1:1).EQ.' ') THEN
           WRITE(*,'(//,'' Quitting Modtools now...'')')
           GO TO 9999
        ELSE IF(ANSWER (1:3).EQ.'hed' .OR. ANSWER (1:3).EQ.'HED') THEN
           COVPMR(1)=1
           MODFLG=1
           WRITE(*,'('' ...Cell-by-cell head terms from Basic '', 
     &               ''Package'')')
           MESAGE(1)='CELL-BY-CELL HEAD TERMS FROM BAS PACKAGE'
           IDCNTR=2
        ELSE IF(ANSWER (1:3).EQ.'ddn' .OR. ANSWER (1:3).EQ.'DDN') THEN
           COVPMR(1)=2
           MODFLG=2
           WRITE(*,'('' ...Cell-by-cell drawdown terms from Basic '', 
     &               ''Package'')')
           MESAGE(1)='CELL-BY-CELL DRAWDOWN TERMS FROM BAS PACKAGE'
           IDCNTR=2
        ELSE IF(ANSWER (1:3).EQ.'bcf' .OR. ANSWER (1:3).EQ.'BCF') THEN
           COVPMR(1)=3
           MODFLG=3
           WRITE(*,'('' ...Cell face flow terms from Block-Centered'', 
     &               ''-Flow Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM BCF PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'sto' .OR. ANSWER (1:3).EQ.'STO') THEN
           COVPMR(1)=4
           MODFLG=4
           WRITE(*,'('' ...Storage terms from Block-Centered-Flow '', 
     &               ''Package'')')
           MESAGE(1)='CELL-BY-CELL STORAGE TERMS FROM BCF PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'riv' .OR. ANSWER (1:3).EQ.'RIV') THEN
           COVPMR(1)=5
           MODFLG=5
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''River Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM RIVER PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'rch' .OR. ANSWER (1:3).EQ.'RCH') THEN
           COVPMR(1)=6
           MODFLG=6
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Recharge Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM RECHARGE PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'wel' .OR. ANSWER (1:3).EQ.'WEL') THEN
           COVPMR(1)=7
           MODFLG=7
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Well Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM WELL PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'drn' .OR. ANSWER (1:3).EQ.'DRN') THEN
           COVPMR(1)=8
           MODFLG=8
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Drain Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM DRAIN PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'ghb' .OR. ANSWER (1:3).EQ.'GHB') THEN
           COVPMR(1)=9
           MODFLG=9
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''General Head Boundary Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM GHB PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'evt' .OR. ANSWER (1:3).EQ.'EVT') THEN
           COVPMR(1)=10
           MODFLG=10
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Evapotranspiration Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM EVT PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'str' .OR. ANSWER (1:3).EQ.'STR') THEN
           COVPMR(1)=11
           MODFLG=11
           WRITE(*,'('' ...Cell-by-cell terms from '',
     &               ''Streamflow-Routing Package'')')
           MESAGE(1)='CELL-BY-CELL FLOW TERMS FROM STR PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'flo' .OR. ANSWER (1:3).EQ.'FLO') THEN
           COVPMR(1)=12
           MODFLG=12
           WRITE(*,'('' ...Streamflow terms from Streamflow-Routing '',
     &               ''Package'')')
           MESAGE(1)='CELL-BY-CELL STREAMFLOW TERMS FROM STR PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'ibs' .OR. ANSWER (1:3).EQ.'IBS') THEN
           COVPMR(1)=13
           MODFLG=13
           WRITE(*,'('' ...Interbed-Storage terms from '',
     &               ''Interbed-Storage Package'')')
           MESAGE(1)='CELL-BY-CELL STORAGE TERMS FROM IBS PACKAGE'
           IDCNTR=3
        ELSE IF(ANSWER (1:3).EQ.'arr' .OR. ANSWER (1:3).EQ.'ARR') THEN
           COVPMR(1)=14
           MODFLG=14
           WRITE(*,'('' ...Gridded array formatted like those '',
     &               ''of MODFLOW'')')
           MESAGE(1)='GRIDDED ARRAY LIKE THOSE OF MODFLOW'
           IDCNTR=0
        ELSE
           WRITE(*,'(//,'' Error Unavailable choice'')')
           GO TO 212
        ENDIF
       ENDIF
      ENDIF
C
C2O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 100
C
C3----Orientations
C
 300    IVIEW=0
        COVPMR(10)=0
        MESAGE(10)='MAPVIEW ORIENTATION'
      IF(ICOVER.NE.2) IVIEW=-99
C
C3A----Type of orientation
C
      IF(IVIEW.LE.-99) THEN
  302    IERROR=1
         WRITE(*,'(//,'' Select an orientation for the MODTOOLS'',
     &             '' GIS output'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
       IF(ICOVER.LE.5) THEN
          WRITE(*,'(''    m = Mapview'')')
       ELSE IF(ICOVER.EQ.6) THEN
          WRITE(*,'(''    m = Mapview, characteristics for '',
     &              ''all layers will be generated'')')
       ENDIF
       IF(ICOVER.GE.6) THEN
          WRITE(*,'(''    l = Mapview of a user-specified model '',
     &              ''layer'')')
          WRITE(*,'(''    i = Mapview of a user-specified model '',
     &              ''ibound value '')')
          WRITE(*,'(''    u = Mapview of uppermost active cells'')')
       ENDIF
         WRITE(*,'(''    r = Vertical profile view along a row'')')
         WRITE(*,'(''    c = Vertical profile view along a column '')')
       IF(ICOVER.EQ.1 .OR. ICOVER.EQ.5 .OR. ICOVER.EQ.6) THEN
          WRITE(*,'(''    p = Vertical profile view along a '',
     &             ''user-specified particle path'')')
       ENDIF
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Options menu'')')
         WRITE(*,'(/,''    Select an orientation:'')')
         READ(*,'(A)',ERR=304,END=9990) ANSWER
         IERROR=0
C
C3Q-----Quitting
C
 304   IF(ANSWER.EQ.' ') GO TO 9990
C
C3E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading orientation type'')')
          GO TO 302
       ENDIF
C
C3P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C3H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
 306      IERROR=1
          WRITE(*,'(//,'' Help for selecting an orientation'')')
          WRITE(*,'(//,''  for the MODTOOLS GIS output'')')
          WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
          WRITE(*,'('' <cr> = Quit help'')')
          WRITE(*,'(''    m = Mapview'')')
          WRITE(*,'(''    l = Mapview of a user-specified model '',
     &              ''layer'')')
          WRITE(*,'(''    i = Mapview of a user-specified model '',
     &              ''ibound value '')')
          WRITE(*,'(''    u = Mapview of uppermost active cells'')')
          WRITE(*,'(''    r = Vertical profile view along a row'')')
          WRITE(*,'(''    c = Vertical profile view along a column '')')
          WRITE(*,'(''    p = Vertical profile view along a '',
     &              ''user-specified particle path'')')
          WRITE(*,'(/,''    Enter help selection:'')')
          READ(*,'(A)',ERR=308,END=9990) ANSWER
          IERROR=0
C
C3Hq-----Quitting
C
 308    IF(ANSWER (1:1).EQ.' ') GO TO 302
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 302
C
C3He-----Errors
C
        IF(IERROR.NE.0) THEN
           WRITE(*,'(//,'' Error reading orientation type'')')
           GO TO 302
        ENDIF
C
C3Hr-----Help selection
C
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know what type of',
     &               ' orientation will be used.'
          WRITE(*,*) ' '
        IF(ANSWER (1:1).EQ.'m' .OR. ANSWER (1:1).EQ.'M') THEN
          WRITE(*,*) 'Response: =----->  m'
          WRITE(*,*) ' A mapview orientation along the x-y plane'
          WRITE(*,*) '  of the model grid used by MODPATH.'
          WRITE(*,*) '  For cell-by-cell terms, this selection'
          WRITE(*,*) '  results in an Info file containing values'
          WRITE(*,*) '  for cells in all layers'
        ELSE IF(ANSWER (1:1).EQ.'l' .OR. ANSWER (1:1).EQ.'L') THEN
          WRITE(*,*) 'Response: =----->  l'
          WRITE(*,*) ' A mapview orientation for the user-specified'
          WRITE(*,*) '  model grid layer used by MODPATH.  The user'
          WRITE(*,*) '  will be ask to specify a desired model layer.'
        ELSE IF(ANSWER (1:1).EQ.'i' .OR. ANSWER (1:1).EQ.'I') THEN
          WRITE(*,*) 'Response: =----->  i'
          WRITE(*,*) ' A mapview orientation for the user-specified'
          WRITE(*,*) '  ibound value used by MODPATH.  The user'
          WRITE(*,*) '  will be ask to specify a desired ibound value.'
        ELSE IF(ANSWER (1:1).EQ.'u' .OR. ANSWER (1:1).EQ.'U') THEN
          WRITE(*,*) 'Response: =----->  u'
          WRITE(*,*) ' A mapview orientation using the uppermost'
          WRITE(*,*) '  active cell in the model grid used by MODPATH.'
        ELSE IF(ANSWER (1:1).EQ.'r' .OR. ANSWER (1:1).EQ.'R') THEN
          WRITE(*,*) 'Response: =----->  r'
          WRITE(*,*) ' A vertical row orientation along the'
          WRITE(*,*) '  row direction of the model grid used by'
          WRITE(*,*) '  MODPATH.  The user will be ask to specify a'
          WRITE(*,*) '  desired row.'
        ELSE IF(ANSWER (1:1).EQ.'c' .OR. ANSWER (1:1).EQ.'C') THEN
          WRITE(*,*) 'Response: =----->  c'
          WRITE(*,*) ' A vertical column orientation along the'
          WRITE(*,*) '  column direction of the model grid used by'
          WRITE(*,*) '  MODPATH.  The user will be ask to specify a'
          WRITE(*,*) '  desired column.'
        ELSE IF(ANSWER (1:1).EQ.'p' .OR. ANSWER (1:1).EQ.'P') THEN
          WRITE(*,*) 'Response: =----->  p'
          WRITE(*,*) ' A particle pathline orientation along'
          WRITE(*,*) '  a particle pathline using data from the'
          WRITE(*,*) '  PATHLINE file output after a simulation by'
          WRITE(*,*) '  MODPATH.  The user will be ask to specify a'
          WRITE(*,*) '  desired particle id.'
          WRITE(*,*) '  The user must include the name of the output'
          WRITE(*,*) '  file in MODTOOLS name file and use the word '
          WRITE(*,*) '  PATHLINE to identify this file in the list.'
       ELSE
          WRITE(*,*) ' '
          WRITE(*,*) ' =-----> Invalid Response <-----='
          WRITE(*,*) ' '
          GO TO 306
       ENDIF
         WRITE(*,*) 'Continue?'
         READ(*,'(A)') ANSWER
         GO TO 302
C
C3R-----Responses
C
       ELSE
        IF(ANSWER (1:1).EQ.' ') THEN
           WRITE(*,'(//,'' Quitting Modtools now...'')')
           GO TO 9999
        ELSE IF(ANSWER (1:1).EQ.'m' .OR. ANSWER (1:1).EQ.'M') THEN
           IVIEW=0
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Map view orientation'')')
           MESAGE(10)='MAPVIEW ORIENTATION'
           MESAGE(11)='UNUSED FOR MAPVIEW ORIENTATION'
        ELSE IF(ANSWER (1:1).EQ.'r' .OR. ANSWER (1:1).EQ.'R') THEN
           IVIEW=1
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Row vertical profile orientation'')')
           MESAGE(10)='ROW TRAVERSE ORIENTATION'
           MESAGE(11)='ROW; TRAVERSE ALONG ROW DIRECTION'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'c' .OR. ANSWER (1:1).EQ.'C') THEN
           IVIEW=2
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Column vertical profile orientation'')')
           MESAGE(10)='COLUMN TRAVERSE ORIENTATION'
           MESAGE(11)='COLUMN; TRAVERSE ALONG COLUMN DIRECTION'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'p' .OR. ANSWER (1:1).EQ.'P') THEN
           IVIEW=3
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Particle vertical profile orientation'')')
           MESAGE(10)='PARTICLE PATHLINE ORIENTATION'
           MESAGE(11)='PARTICLE; TRAVERSE ALONG PARTICLE DIRECTION'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'l' .OR. ANSWER (1:1).EQ.'L') THEN
           IVIEW=4
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Model layer orientation'')')
           MESAGE(10)='MODEL LAYER MAPVIEW ORIENTATION'
           MESAGE(11)='SINGLE MODEL LAYER MAPVIEW'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'i' .OR. ANSWER (1:1).EQ.'I') THEN
           IVIEW=5
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Model ibound value orientation'')')
           MESAGE(10)='MODEL IBOUND VALUE MAPVIEW ORIENTATION'
           MESAGE(11)='SINGLE MODEL IBOUND VALUE MAPVIEW'
           IRWCL=-99
        ELSE IF(ANSWER (1:1).EQ.'u' .OR. ANSWER (1:1).EQ.'U') THEN
           IVIEW=6
           COVPMR(10)=IVIEW
           WRITE(*,'('' ...Model all ibound values orientation'')')
           MESAGE(10)='MODEL ACTIVE IBOUND VALUES MAPVIEW ORIENTATION'
           MESAGE(11)='UPPERMOST ACTIVE MODEL IBOUND VALUES'
           IRWCL=99
        ELSE
           WRITE(*,'(//,'' Invalid response try again'')')
           GO TO 302
        ENDIF
       ENDIF
      ENDIF
C
C3O-----Back option
C
      IF(ANSWER (1:1).EQ.'B' .AND. ICOVER.EQ.2) GO TO 200
      IF(ANSWER (1:1).EQ.'B' .AND. ICOVER.EQ.6) GO TO 200
      IF(ANSWER (1:1).EQ.'B') GO TO 100
C
C4----Set X-Y conversion factor
C
 400   COVPMR(3)=1.0
       MESAGE(3)='NO X-Y CONVERSION FACTOR USED'
       IFLAG3=0
      IF(ICOVER.EQ.1) IFLAG3=1
      IF(ICOVER.EQ.2) IFLAG3=1
      IF(ICOVER.EQ.3) IFLAG3=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG3=1
      IF(ICOVER.EQ.5) IFLAG3=1
      IF(ICOVER.EQ.6 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG3=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG3=1
      IF(ICOVER.EQ.8) IFLAG3=1
C
C4A----X-Y conversion factor
C
      IF(IFLAG3.GT.0) THEN
  402    IERROR=1
         WRITE(*,'(//,
     &             '' X,Y coordinate conversion'')')
         WRITE(*,'(''  Select option to convert from model '',
     &             ''units to GIS length units.'')')
         WRITE(*,'(''   (Note: For vertical profile orientations,'',
     &             '' MODTOOLS requires'')')
         WRITE(*,'(''   coordinates in units of feet).'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    1 = Feet to meters'')')
         WRITE(*,'(''    2 = Meters to feet'')')
         WRITE(*,'(''    User-specified multiplication factor'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''    Enter option:'')')
         READ(*,'(A)',ERR=404,END=9990) ANSWER
         IERROR=0
C
C4Q-----Quitting
C
 404     IF(ANSWER.EQ.' ') GO TO 9990
C
C4E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading x,y conversion factor'')')
          GO TO 402
       ENDIF
C
C4P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C4H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to translate'
          WRITE(*,*) ' the particle or cell x-y coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should translate particle and '
          WRITE(*,*) ' cell coordinates into feet to ensure proper'
          WRITE(*,*) ' scaling, when using a vertical orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)',ERR=404) ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 402
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 402
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) ' The particle or cell x-y coordinates remain '
          WRITE(*,*) '  in MODPATH coordinate system. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)',ERR=404) ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 402
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 402
          WRITE(*,*) 'Response: =----->  1'
          WRITE(*,*) ' The particle or cell x-y coordinates are '
          WRITE(*,*) '  translated from feet to meters.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)',ERR=404) ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 402
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 402
          WRITE(*,*) 'Response: =----->  2'
          WRITE(*,*) ' The particle or cell x-y coordinates are '
          WRITE(*,*) '  translated from meters to feet.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 402
C
C4R-----Responses
C
       ELSE
          READ(ANSWER,*,ERR=404,END=9990) CONVRT
        IF(CONVRT.EQ.-999.0) THEN
           WRITE(*,'(//,'' Quitting Modtools now...'')')
           GO TO 9999
        ELSE IF(CONVRT.EQ.0.0) THEN
           COVPMR(3)=1.0
           MESAGE(3)='NO X-Y COORDINATE CONVERSION FACTOR'
        ELSE IF(CONVRT.EQ.1.0) THEN
           COVPMR(3)=0.3048
           MESAGE(3)='X-Y COORDINATES FROM FEET TO METERS'
        ELSE IF(CONVRT.EQ.2.0) THEN
           COVPMR(3)=3.28
           MESAGE(3)='X-Y COORDINATES FROM METERS TO FEET'
        ELSE IF(CONVRT.LT.0.0 .AND. CONVRT.NE.-999.0) THEN
          WRITE(*,'(//,'' Negative multiplier not valid'')')
          GO TO 402
        ELSE
           COVPMR(3)=CONVRT
           MESAGE(3)='USER SPECIFIED X-Y COORDINATE CONVERSION FACTOR'
        ENDIF
       ENDIF
      ENDIF
C
C4O-----Back option
C
      IF(ANSWER (1:1).EQ.'B' .AND. ICOVER.EQ.2) GO TO 200
      IF(ANSWER (1:1).EQ.'B') GO TO 300
C
C5------Z conversion factor
C
 500    COVPMR(4)=1.0
        MESAGE(4)='NO Z CONVERSION FACTOR USED'
        IFLAG4=0
      IF(ICOVER.EQ.1) IFLAG4=1
      IF(ICOVER.EQ.2) IFLAG4=1
      IF(ICOVER.EQ.3) IFLAG4=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG4=1
      IF(ICOVER.EQ.5) IFLAG4=1
      IF(ICOVER.EQ.6 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG4=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG4=1
      IF(ICOVER.EQ.8) IFLAG4=1
C
C5A------Set z conversion
C
      IF(IFLAG4.GT.0) THEN
  502    IERROR=1
         WRITE(*,'(//,'' Z coordinate conversion'')')
         WRITE(*,'(''  Select option to convert from model '',
     &             ''units to GIS length units.'')')
         WRITE(*,'(''   (Note: For vertical profile orientations,'',
     &             '' MODTOOLS requires'')')
         WRITE(*,'(''   coordinates in units of feet).'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    1 = Feet to meters'')')
         WRITE(*,'(''    2 = Meters to feet'')')
         WRITE(*,'(''    User-specified multiplication factor'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''    Enter option:'')')
         READ(*,'(A)',ERR=504,END=9990) ANSWER
         IERROR=0
C
C5Q-----Quitting
C
 504   IF(ANSWER.EQ.' ') GO TO 9990
C
C5E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading z conversion factor'')')
          GO TO 502
       ENDIF
C
C5P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C5H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to translate'
          WRITE(*,*) ' the particle or cell z coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should translate particle and '
          WRITE(*,*) ' cell coordinates into feet to ensure proper'
          WRITE(*,*) ' scaling, when using a vertical orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 502
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 502
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) 'The particle or cell z coordinates remain '
          WRITE(*,*) ' in MODPATH coordinate system. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 502
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 502
          WRITE(*,*) 'Response: =----->  1'
          WRITE(*,*) ' The particle or cell z coordinates are '
          WRITE(*,*) '  translated from feet to meters.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 502
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 502
          WRITE(*,*) 'Response: =----->  2'
          WRITE(*,*) ' The particle or cell z coordinates are '
          WRITE(*,*) '  translated from meters to feet.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 502
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 502
          GO TO 502
C
C5R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=504,END=9990) CONVRT
        IF(CONVRT.EQ.0.0) THEN
           COVPMR(4)=1.0
           MESAGE(4)='NO Z COORDINATE CONVERSION FACTOR'
        ELSE IF(CONVRT.EQ.1.0) THEN
           COVPMR(4)=0.3048
           MESAGE(4)='Z COORDINATES FROM FEET TO METERS'
        ELSE IF(CONVRT.EQ.2.0) THEN
           COVPMR(4)=3.28
           MESAGE(4)='Z COORDINATES FROM METERS TO FEET'
        ELSE
           COVPMR(4)=CONVRT
           MESAGE(4)='USER SPECIFIED Z COORDINATE CONVERSION FACTOR'
        ENDIF
       ENDIF
      ENDIF
C
C5O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 400
C
C6------Counterclockwise rotation angle
C
 600   COVPMR(5)=0.0
       MESAGE(5)='NO ROTATION AROUND MODFLOW ORIGIN'
       IFLAG5=0
      IF(ICOVER.EQ.1 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.2 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.3 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.5 .AND. IVIEW.EQ.0) IFLAG5=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG5=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG5=1
C
C6A------Set counterclockwise rotation angle
C
      IF(IFLAG5.GT.0) THEN
 602     IERROR=1
         WRITE(*,'(//,'' Counterclockwise rotation angle '',
     &                ''around MODFLOW origin'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    User-specified rotation angle'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''   Enter clockwise rotation angle:'')')
         READ(*,'(A)',ERR=604,END=9990) ANSWER
         IERROR=0
C
C6Q-----Quitting
C
 604   IF(ANSWER.EQ.' ') GO TO 9990
C
C6H-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading rotation angle'')')
          GO TO 602
       ENDIF
C
C6P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C6H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to rotate'
          WRITE(*,*) ' the particle or cell x-y coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should rotate particle and '
          WRITE(*,*) ' cell coordinates to ensure proper'
          WRITE(*,*) ' alignment with the model grid system, when'
          WRITE(*,*) ' using a mapview orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 602
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 602
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) ' The particle or cell x-y coordinates are not '
          WRITE(*,*) '  rotated. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 602
C
C6R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=604,END=9990) COVPMR(5)
        IF(COVPMR(5).GT.0.) THEN
          MESAGE(5)='ANGLE COUNTERCLOCKWISE ROTATION '//
     &              'AROUND MODFLOW ORIGIN'
        ELSE IF(COVPMR(5).EQ.0.) THEN
          MESAGE(5)='NO ROTATION '//
     &              'AROUND MODFLOW ORIGIN'
        ELSE
          MESAGE(5)='ANGLE CLOCKWISE ROTATION '//
     &              'AROUND MODFLOW ORIGIN'
        ENDIF
       ENDIF
      ENDIF
C
C6O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 500
C
C7------Coverage x_origin
C
 700   COVPMR(6)=0.0
       MESAGE(6)='NO X ORIGIN FOR MODFLOW GRID'
       IFLAG6=0
      IF(ICOVER.EQ.1 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.2 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.3 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.5 .AND. IVIEW.EQ.0) IFLAG6=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG6=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG6=1
C
C7A------Set x_origin
C
      IF(IFLAG6.GT.0) THEN
 702     IERROR=1
         WRITE(*,'(//,'' X-origin of MODFLOW grid'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    User-specified X-origin coordinate'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''   Enter x_origin:'')')
         READ(*,'(A)',ERR=704,END=9990) ANSWER
         IERROR=0
C
C7Q-----Quitting
C
 704   IF(ANSWER.EQ.' ') GO TO 9990
C
C7E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'('' Error reading x origin value '')')
          GO TO 702
       ENDIF
C
C7P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C7H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to translate'
          WRITE(*,*) ' the particle or cell x-y coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should translate particle and '
          WRITE(*,*) ' cell coordinates to ensure proper'
          WRITE(*,*) ' alignment with the model grid system, when'
          WRITE(*,*) ' using a mapview orientation.  The x origin is'
          WRITE(*,*) ' the upper left corner of cell row 1, column 1.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 702
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 702
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) ' The particle or cell x coordinates are not '
          WRITE(*,*) '  translated. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 702
C
C7R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=704,END=9990) COVPMR(6)
          MESAGE(6)='X ORIGIN OF MODFLOW GRID'
       ENDIF
      ENDIF
C
C7O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 600
C
C8------Coverage y_origin
C
 800    COVPMR(7)=0.0
        MESAGE(7)='NO Y ORIGIN FOR MODFLOW GRID'
        IFLAG7=0
      IF(ICOVER.EQ.1 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.2 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.3 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.4 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.5 .AND. IVIEW.EQ.0) IFLAG7=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG7=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.LT.1 .OR. IVIEW.GT.3)) IFLAG7=1
C
C8A------Set y_origin
C
      IF(IFLAG7.GT.0) THEN
  802    IERROR=1
         WRITE(*,'(/,'' Y-origin of MODFLOW grid'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    0 = None'')')
         WRITE(*,'(''    User-specified Y-origin coordinate'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''   Enter y_origin: '')')
         READ(*,'(A)',ERR=804,END=9990) ANSWER
         IERROR=0
C
C8Q-----Quitting
C
 804   IF(ANSWER.EQ.' ') GO TO 9990
C
C8E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error reading y origin value'')')
          GO TO 802
       ENDIF
C
C8P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C8H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to translate'
          WRITE(*,*) ' the particle or cell x-y coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: The user should translate particle and '
          WRITE(*,*) ' cell coordinates to ensure proper'
          WRITE(*,*) ' alignment with the model grid system, when'
          WRITE(*,*) ' using a mapview orientation.  The y origin is'
          WRITE(*,*) ' the upper left corner of cell row 1, column 1.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 802
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 802
          WRITE(*,*) 'Response: =----->  0'
          WRITE(*,*) ' The particle or cell y coordinates are not '
          WRITE(*,*) '  translated. '
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 802
C
C8R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=804,END=9990) COVPMR(7)
          MESAGE(7)='Y ORIGIN OF MODFLOW GRID'
       ENDIF
      ENDIF
C
C8O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 700
C
C9----Vertical Exaggeration
C
 900    COVPMR(8)=1.0
        MESAGE(8)='NO VERTICAL EXAGGERATION'
        IFLAG8=0
      IF(ICOVER.EQ.1 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.2 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.3 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.4 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.5 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.6 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG8=1
C
C9A----Set Exaggeration
C
      IF(IFLAG8.GT.0) THEN
  902    IERROR=1
         WRITE(*,'(//,'' Enter vertical exaggeration '')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified vertical exaggeration '',
     &             ''factor'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter vertical exaggeration '',
     &             ''1 foot = n feet:'')')
         READ(*,'(A)',ERR=904,END=9990) ANSWER
         IERROR=0
C
C9Q-----Quitting
C
 904   IF(ANSWER.EQ.' ') GO TO 9990
C
C9E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading vertical exaggeration'')')
          GO TO 902
       ENDIF
C
C9P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C9H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to exaggerate'
          WRITE(*,*) ' the particle or cell z coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: Also, the value for the horizontal scale'
          WRITE(*,*) ' will be used to ensure proper exaggeration,'
          WRITE(*,*) ' when using a vertical orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 902
C
C9R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=904,END=9990) VSCALE
        IF(VSCALE.LT.0.0) THEN
           WRITE(*,'(//,'' Invalid response'',F20.10)') VSCALE
           GO TO 902
        ELSE IF(VSCALE.EQ.0.0) THEN
           VSCALE=1.0
           WRITE(*,'('' ...Vertical Scale 1 foot = '',
     &               F20.10,'' feet'')')
     &             VSCALE
           COVPMR(8)=VSCALE
           MESAGE(8)='NO VERTICAL EXAGGERATION'
        ELSE
           WRITE(*,'('' ...Vertical Scale 1 foot = '',
     &               F20.10,'' feet'')')
     &             VSCALE
           COVPMR(8)=VSCALE
           MESAGE(8)='VERTICAL EXAGGERATION'
        ENDIF
       ENDIF
      ENDIF
C
C9O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 500
C
C10----Horizontal Scale
C
 1000   COVPMR(9)=1.0
        MESAGE(9)='NO HORIZONTAL MAPSCALE'
        IFLAG9=0
      IF(ICOVER.EQ.1 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.2 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.3 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.4 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.5 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.6 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.7 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
      IF(ICOVER.EQ.8 .AND. (IVIEW.GE.1 .AND. IVIEW.LE.3)) IFLAG9=1
C
C10A----Set scale
C
      IF(IFLAG9.GT.0) THEN
 1002    IERROR=1
         WRITE(*,'(//,'' Enter horizontal mapscale'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified horizontal mapscale'')')
         WRITE(*,'(''    h = Help '')')
         WRITE(*,'(''    b = Back to Vertical Exaggeration menu'')')
         WRITE(*,'(//,'' Enter horizontal mapscale 1 foot = n feet:'')')
         READ(*,'(A)',ERR=1004,END=9990) ANSWER
         IERROR=0
C
C10Q-----Quitting
C
 1004  IF(ANSWER.EQ.' ') GO TO 9990
C
C10E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading horizontal mapscale'')')
          GO TO 1002
       ENDIF
C
C10P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C10H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to scale'
          WRITE(*,*) ' the particle or cell coordinates from the '
          WRITE(*,*) ' MODPATH system to the user specified system.'
          WRITE(*,*) 'Hint: To ensure proper scaling, translate'
          WRITE(*,*) ' particle or cell coordinates into feet,'
          WRITE(*,*) ' when using a vertical orientation.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1002
C
C10R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1004,END=9990) HSCALE
        IF(HSCALE.LT.0.0) THEN
           WRITE(*,'(//,'' Invalid response'',F20.10)') HSCALE
           GO TO 1002
        ELSE IF(HSCALE.EQ.0.0) THEN
           HSCALE=1.0
           WRITE(*,'('' ...Horizontal Scale 1 foot = '',F20.10,
     &               '' feet'')')
     &             HSCALE
           COVPMR(9)=HSCALE
           MESAGE(9)='NO HORIZONTAL MAPSCALE'
        ELSE
           WRITE(*,'('' ...Horizontal Scale 1 foot = '',F20.10,
     &               '' feet'')')
     &             HSCALE
           COVPMR(9)=HSCALE
           MESAGE(9)='HORIZONTAL MAPSCALE'
        ENDIF
       ENDIF
      ENDIF
C
C10O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 900
C
C11----What row or column or particle or model layer or ibound value to draw
C
 1100 IRWCL=0
      MESAGE(11)='UNUSED FOR MAPVIEW ORIENTATION'
C
C11A----Set row or column or particle or model layer or ibound value
C
      IF(IVIEW.GE.1 .AND. IVIEW.LE.5) THEN
 1102    IERROR=1
       IF(IVIEW.LE.0) THEN
          WRITE(*,'(/,'' Enter number of layer to view '')')
          MESAGE(11)='LAYER'
       ELSE IF(IVIEW.EQ.1) THEN
          WRITE(*,'(/,'' Enter number of row to view '')')
          MESAGE(11)='ROW'
       ELSE IF(IVIEW.EQ.2) THEN
          WRITE(*,'(/,'' Enter number of column to view '')')
          MESAGE(11)='COLUMN'
       ELSE IF(IVIEW.EQ.3) THEN
          WRITE(*,'(/,'' Enter number of particle-id to view '')')
          MESAGE(11)='PARTICLE-ID'
       ELSE IF(IVIEW.EQ.4) THEN
          WRITE(*,'(/,'' Enter number of model layer to view '')')
          MESAGE(11)='LAYER'
       ELSE
          WRITE(*,'(/,'' Enter number of model ibound '',
     &              ''value to view'')')
          MESAGE(11)='IBOUND VALUE'
       ENDIF
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified selection'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(/,''   Enter selection:'')')
         READ(*,'(A)',ERR=1102,END=9990) ANSWER
         IERROR=0
C
C11Q-----Quitting
C
 1104  IF(ANSWER.EQ.' ') GO TO 9990
C
C11E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(//,'' Error row or column or layer or '',
     &              ''particle number or ibound value invalid'')')
          GO TO 1102
       ENDIF
C
C11P-----Previous menu
C
       IF(ANSWER (1:1).EQ.'B' .OR. ANSWER (1:1).EQ.'b') THEN
          ANSWER='B'
C
C11H-----Help
C
       ELSE IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know what row, column,',
     &               ' particle, layer or ibound value will be used.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1102
C
C11R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1104,END=9990) IRWCL
          COVPMR(11)=IRWCL
         IF(IRWCL.LE.0) THEN
            WRITE(*,'(/,'' Invalid response must be greater than 0'')')
             GO TO 1102
         ELSE
          IF(IVIEW.EQ.0 .OR. IVIEW.EQ.4) THEN
           IF(IRWCL.GT.NLAY) THEN
              WRITE(*,'(/,'' Invalid response pick between 0 and '',
     &                  I10)')
     &                 NLAY
              GO TO 1102
           ELSE
              WRITE(*,'('' ...Mapview using layer '',I10)')
     &                IRWCL
           ENDIF
          ELSE IF(IVIEW.EQ.1) THEN
           IF(IRWCL.GT.NROW) THEN
              WRITE(*,'(/,'' Invalid response pick between 0 and '',
     &                  I10)')
     &                 NROW
              GO TO 1102
           ELSE
              WRITE(*,'('' ...Row vertical profile using row '',I10)')
     &                IRWCL
           ENDIF
          ELSE IF(IVIEW.EQ.2) THEN
           IF(IRWCL.GT.NCOL) THEN
              WRITE(*,'(/,'' Invalid response pick between 0 and '',
     &                  I10)')
     &                 NCOL
              GO TO 1102
           ELSE
              WRITE(*,'('' ...Column vertical profile using column '',
     &                  I10)')
     &                IRWCL
           ENDIF
          ELSE IF(IVIEW.EQ.3) THEN
             WRITE(*,'('' ...Particle vertical profile using '',
     &                 ''particle-id '',I10)')
     &               IRWCL
          ELSE
             WRITE(*,'('' ...Mapview using ibound = '',I10)')
     &               IRWCL
          ENDIF
        ENDIF
       ENDIF
      ENDIF
C
C11O-----Back option
C
      IF(ANSWER (1:1).EQ.'B' .AND. IVIEW.LE.0) GO TO 800
      IF(ANSWER (1:1).EQ.'B' .AND. IVIEW.GE.4) GO TO 800
      IF(ANSWER (1:1).EQ.'B') GO TO 1000
C
C12----Dimension of gridded data
C
       MODFLG=INT(COVPMR(1))
       COVPMR(12)=0
       MESAGE(12)='NO GRIDDED DATA'
       IFLAG12=0
      IF(ICOVER.EQ.7) THEN
         IDCNTR=2+100*MODFLG
         COVPMR(12)=IDCNTR
       IF(MODFLG.EQ.14) IFLAG12=1
      ENDIF
      IF(ICOVER.EQ.6 .AND. MODFLG.EQ.14) IFLAG12=1
C
C12A----Set dimension
C
      IF(IFLAG12.GT.0) THEN
 1202    IERROR=1
         WRITE(*,'(//,'' Enter dimension of the gridded model data'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    2 = Two-dimensional array'')')
         WRITE(*,'(''    3 = Three-dimensional array'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter dimension of gridded data:'')')
         READ(*,'(A)',ERR=1204,END=9990) ANSWER
         IERROR=0
C
C12Q-----Quitting
C
 1204  IF(ANSWER.EQ.' ') GO TO 9990
C
C12E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading '',
     &                ''dimension of gridded data'')')
          GO TO 1202
       ENDIF
C
C12H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know the format of the data'
          WRITE(*,*) ' array so the proper utility reading module'
          WRITE(*,*) ' will be used'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 1202
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 1202
          WRITE(*,*) 'Response: =----->  2'
          WRITE(*,*) ' Utility ULASAV of MODFLOW produces 2D'
          WRITE(*,*) '  data (records simulated head or drawdown'
          WRITE(*,*) '  for each layer with a character string header'
          WRITE(*,*) '  followed by the simulated values for that.'
          WRITE(*,*) '  layer). MODTOOLS will use the MODFLOW utility'
          WRITE(*,*) '  module U2DREL to read the gridded data'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
        IF(ANSWER (1:1).EQ.'Q' .OR. ANSWER (1:1).EQ.'q') GO TO 1202
        IF(ANSWER (1:1).EQ.'N' .OR. ANSWER (1:1).EQ.'n') GO TO 1202
          WRITE(*,*) 'Response: =----->  3'
          WRITE(*,*) ' Utility UBUDSV of MODFLOW produces 3D'
          WRITE(*,*) '  data (records simulated cell budget or flow'
          WRITE(*,*) '  terms with a character string header followed'
          WRITE(*,*) '  by the terms for all layer).'
          WRITE(*,*) '  MODTOOLS will use the MODTOOLS utility'
          WRITE(*,*) '  module U3DREL to read the gridded data'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1202
C
C12R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1204,END=9990) IDCNTR
        IF(IDCNTR.LT.2 .AND. IDCNTR.GT.4 ) THEN
           WRITE(*,'(//,'' Invalid response'',I10)') IDCNTR
           GO TO 1202
        ELSE IF(IDCNTR.EQ.2) THEN
           IDCNTR=2+100*MODFLG
           WRITE(*,'('' ...2-D Data Array'')')
           COVPMR(12)=IDCNTR
           MESAGE(12)='2-D DATA ARRAY'
        ELSE
           IDCNTR=3+100*MODFLG
           WRITE(*,'('' ...3-D Data Array'')')
           COVPMR(12)=IDCNTR
           MESAGE(12)='3-D DATA ARRAY'
        ENDIF
       ENDIF
      ENDIF
C
C12O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C12A----Set flow-vector multiplier
C
      IF(ICOVER.EQ.8) THEN
 1206    IERROR=1
         WRITE(*,'(//,'' Enter scaling factor for length of '',
     &                ''flow vector'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    n > 0 - arithmetic scaling'')')
         WRITE(*,'(''    n = 0 - no scaling'')')
         WRITE(*,'(''    n < 0 - logarithmetic scaling'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter scaling factor:'')')
         READ(*,'(A)',ERR=1208,END=9990) ANSWER
         IERROR=0
C
C12Q-----Quitting
C
 1208  IF(ANSWER.EQ.' ') GO TO 9990
C
C12E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading scaling factor'')')
          GO TO 1206
       ENDIF
C
C12H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know how to scale ',
     &               'the length of flow vector'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1206
C
C12R-----Responses
C
       ELSE
          READ(ANSWER,*,ERR=1208,END=9990) VECSCL
        IF(VECSCL.LE.0.0) THEN
           WRITE(*,'(//,
     &               '' Logarithmetic scaling for length of ''
     &               ''velocity vectors'')')
           COVPMR(12)=VECSCL
           MESAGE(12)='LOGARITHMETIC SCALING'
        ELSE IF(VECSCL.EQ.0.0) THEN
           WRITE(*,'(//,
     &               '' Scaling factor set to one for length of ''
     &               ''velocity vectors'')')
           COVPMR(12)=VECSCL
           MESAGE(12)='SCALING FACTOR SET TO 1'
        ELSE
           WRITE(*,'(//,
     &               '' Arithmetic scaling for length of ''
     &               ''velocity vectors'')')
           COVPMR(12)=VECSCL
           MESAGE(12)='ARITHMETIC SCALING'
        ENDIF
       ENDIF
      ENDIF
C
C12O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C13----Contour interval
C
      COVPMR(13)=0
      MESAGE(13)='NO CONTOUR INTERVAL OR MODFLOW STRESS PERIOD'
C
C13A----Set interval
C
      IF(ICOVER.EQ.7) THEN
 1302    IERROR=1
         WRITE(*,'(//,'' Enter contour interval '')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified contour interval'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter contour interval:'')')
         READ(*,'(A)',ERR=1304,END=9990) ANSWER
         IERROR=0
C
C13Q-----Quitting
C
 1304  IF(ANSWER.EQ.' ') GO TO 9990
C
C13E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading contour interval'')')
          GO TO 1302
       ENDIF
C
C13H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know what contour ',
     &               'interval value will be used.'
          WRITE(*,*) 'Continue?'
          READ(*,'(A)') ANSWER
          GO TO 1302
C
C13R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1304,END=9990) CNTINT
        IF(CNTINT.LE.0.0) THEN
           WRITE(*,'(//,'' Invalid response'',F20.10)') CNTINT
           GO TO 1302
        ELSE
           WRITE(*,'('' ...Contour interval = '',F20.10)')
     &             CNTINT
           COVPMR(1)=CNTINT
           MESAGE(12)=MESAGE(1)
           MESAGE(1)='CONTOUR INTERVAL'
        ENDIF
       ENDIF
      ENDIF
C
C13O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C13A----MODFLOW stress period
C
        IFLAG13=0
      IF(ICOVER.EQ.6) IFLAG13=1
      IF(ICOVER.EQ.7) IFLAG13=1
      IF(ICOVER.EQ.8) IFLAG13=1
      IF(IFLAG13.GT.0) THEN
        COVPMR(13)=0
        MESAGE(13)='NO MODFLOW STRESS PERIOD'
      ENDIF
C
C13A---Set MODFLOW stress period
C
      IF(IFLAG13.GT.0 .AND. NPER.LE.0) THEN
         MODPER=1
         WRITE(*,'('' ...MODFLOW stress period = '',I10)')
     &             MODPER
         COVPMR(13)=MODPER
         MESAGE(13)='MODFLOW STRESS PERIOD'
      ELSE IF(IFLAG13.GT.0 .AND. NPER.GT.0) THEN
 1310    IERROR=1
         WRITE(*,'(//,'' Enter stress period number for '',
     &             ''the cell-by-cell terms'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified stress period'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter stress period number:'')')
         READ(*,'(A)',ERR=1312,END=9990) ANSWER
         IERROR=0
C
C13Q-----Quitting
C
 1312  IF(ANSWER.EQ.' ') GO TO 9990
C
C13E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading stress period'')')
          GO TO 1310
       ENDIF
C
C13H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know stress period number for ',
     &               ' the cell-by-cell terms'
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS uses this number to select the proper'
          WRITE(*,*) ' cell-by-cell terms output by MODFLOW at'
          WRITE(*,*) ' the specified stress period of '
          WRITE(*,*) ' a ground-water simulation'
          WRITE(*,*) 'MODFLOW outputs cell-by-cell terms for '
          WRITE(*,*) ' stress periods at time steps specified'
          WRITE(*,*) ' by the user.'
          READ(*,'(A)') ANSWER
          WRITE(*,*) 'Continue?'
          GO TO 1310
C
C13R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1312,END=9990) MODPER
        IF(MODPER.LT.0) THEN
           WRITE(*,'(//,'' Invalid response'',I10)') MODPER
           GO TO 1310
        ELSE
           WRITE(*,'('' ...Stress period = '',I10)')
     &             MODPER
           COVPMR(13)=MODPER
           MESAGE(13)='MODFLOW STRESS PERIOD'
        ENDIF
       ENDIF
      ENDIF
C
C13O-----Back option
C
      IF(ANSWER (1:1).EQ.'B') GO TO 300
C
C14---Degree interval
C
      COVPMR(14)=0
      MESAGE(14)='NO SECTORS FOR DELINEATING ZONES OF TRANSPORT'
      NUMARC=0
C
C14A---Set degree
C
      IF(ICOVER.EQ.4) THEN
 1402    IERROR=1
         WRITE(*,'(//,'' Enter number of sectors used to '',
     &                ''delineate zones of transport'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified number of sectors'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter number of sectors:'')')
         READ(*,'(A)',ERR=1404,END=9990) ANSWER
         IERROR=0
C
C14Q-----Quitting
C
 1404  IF(ANSWER.EQ.' ') GO TO 9990
C
C14E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading number of equal arcs'')')
          GO TO 1402
       ENDIF
C
C14H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know the number of equal',
     &               ' arcs will be used.'
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS uses this number to compute the'
          WRITE(*,*) ' vertices of a polygon which represents a'
          WRITE(*,*) ' specified time-of-travel in a MODPATH analysis'
          WRITE(*,*) ' using the time-series option. A computer'
          WRITE(*,*) ' algorithm calculates a point that is '
          WRITE(*,*) ' representative of a group of particles.'
          WRITE(*,*) ' The user should vary the number of equal arcs'
          WRITE(*,*) ' until the best results are obtained.'
          READ(*,'(A)') ANSWER
          WRITE(*,*) 'Continue?'
          GO TO 1402
C
C14R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1404,END=9990) NUMARC
        IF(NUMARC.LE.0.0) THEN
           WRITE(*,'(//,'' Invalid response'',I10)') NUMARC
           GO TO 1402
        ELSE
           WRITE(*,'('' ...Number of sectors = '',I10)')
     &             NUMARC
           COVPMR(14)=NUMARC
           MESAGE(14)='NUMBER OF SECTORS FOR DELINEATING ZOT'
        ENDIF
       ENDIF
      ENDIF
C
C14O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C14A---MODFLOW time step
C
        IFLAG14=0
      IF(ICOVER.EQ.6) IFLAG14=1
      IF(ICOVER.EQ.7) IFLAG14=1
      IF(ICOVER.EQ.8) IFLAG14=1
C
C14A---Set MODFLOW time step
C
      IF(IFLAG14.GT.0 .AND. NPER.EQ.0) THEN
         MODSTP=1
         WRITE(*,'('' ...MODFLOW time step = '',I10)')
     &             MODSTP
         COVPMR(14)=MODSTP
         MESAGE(14)='MODFLOW TIME STEP'
      ELSE IF(IFLAG14.GT.0 .AND. NPER.GT.0) THEN
 1406    IERROR=1
         WRITE(*,'(//,'' Enter MODFLOW time step number for '',
     &             ''cell-by-cell terms'')')
         WRITE(*,'(''-------------------------------------------'',
     &             ''--------------------------'')')
         WRITE(*,'('' <cr> = Quit'')')
         WRITE(*,'(''    User-specified time step'')')
         WRITE(*,'(''    h = Help'')')
         WRITE(*,'(''    b = Back to MODTOOLS Orientation menu'')')
         WRITE(*,'(//,'' Enter time step number:'')')
         READ(*,'(A)',ERR=1408,END=9990) ANSWER
         IERROR=0
C
C14Q-----Quitting
C
 1408  IF(ANSWER.EQ.' ') GO TO 9990
C
C14E-----Errors
C
       IF(IERROR.NE.0) THEN
          WRITE(*,'(/,'' Error in reading MODFLOW time step'')')
          GO TO 1406
       ENDIF
C
C14H-----Help
C
       IF(ANSWER (1:1).EQ.'H' .OR. ANSWER (1:1).EQ.'h') THEN
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS needs to know time step number for ',
     &               ' the cell-by-cell terms'
          WRITE(*,*) ' '
          WRITE(*,*) 'MODTOOLS uses this number to select the proper'
          WRITE(*,*) ' cell-by-cell terms output by MODFLOW at'
          WRITE(*,*) ' specified time step in a stress period for '
          WRITE(*,*) ' a ground-water simulation'
          WRITE(*,*) 'MODFLOW outputs cell-by-cell terms for '
          WRITE(*,*) ' stress periods at time steps specified'
          WRITE(*,*) ' by the user.'
          READ(*,'(A)') ANSWER
          WRITE(*,*) 'Continue?'
          GO TO 1406
C
C14R-----Responses
C
       ELSE
          IERROR=1
          READ(ANSWER,*,ERR=1408,END=9990) MODSTP
        IF(MODSTP.LT.0) THEN
           WRITE(*,'(//,'' Invalid response'',I10)') MODSTP
           GO TO 1406
        ELSE
           WRITE(*,'('' ...MODFLOW time step = '',I10)')
     &             MODSTP
           COVPMR(14)=MODSTP
           MESAGE(14)='MODFLOW TIME STEP'
        ENDIF
       ENDIF
      ENDIF
C
C15O-----Back option
C
      IF(ANSWER (1:1).EQ.'b' .OR. ANSWER (1:1).EQ.'B') GO TO 300
C
C15---Hydraulic head assigned to noflow cells
C
      MESAGE(15)='HYDRAULIC HEAD ASSIGNED TO NOFLOW CELLS'
      HNOFLO=COVPMR(15)
      WRITE(*,'('' ...Hydraulic head assigned to noflow cells = '',
     &              G20.10)')
     &             HNOFLO
C
C16---Hydraulic head assigned to dry cells
C
      MESAGE(16)='HYDRAULIC HEAD ASSIGNED TO DRY CELLS'
      HDRY=COVPMR(16)
      WRITE(*,'('' ...Hydraulic head assigned to dry cells = '',
     &              G20.10)')
     &             HDRY
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                     Output user information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
      WRITE(*,'(//,'' Writing coverage parameters now...'')')
      NSTAT=2
      ITALK=1
      IOUT=60
      CALL DELETE_FILE (PMRFIL,*9999)
      CALL OPEN_FILE (IOUT,PMRFIL,NSTAT,ITALK,*9999)
C
      IF(ICOVER.NE.7) THEN
         WRITE(IOUT,'(I15,1X,A80)') MODFLG,MESAGE(1)
      ELSE
         WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(1),MESAGE(1)
      ENDIF
C
       WRITE(IOUT,'(I15,1X,A80)') ICOVER,MESAGE(2)
        WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(3),MESAGE(3)
         WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(4),MESAGE(4)
          WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(5),MESAGE(5)
           WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(6),MESAGE(6)
            WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(7),MESAGE(7)
             WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(8),MESAGE(8)
              WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(9),MESAGE(9)
               WRITE(IOUT,'(I15,1X,A80)') IVIEW,MESAGE(10)
                WRITE(IOUT,'(I15,1X,A80)') IRWCL,MESAGE(11)
C
              IF(ICOVER.EQ.6) THEN
                 WRITE(IOUT,'(I15,1X,A80)') IDCNTR,MESAGE(1)
              ELSE IF(ICOVER.EQ.7) THEN
                 WRITE(IOUT,'(I15,1X,A80)') IDCNTR,MESAGE(12)
              ELSE
                 WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(12),MESAGE(12)
              ENDIF
C
              IF(ICOVER.GE.6) THEN
                 WRITE(IOUT,'(I15,1X,A80)') MODPER,MESAGE(13)
              ELSE
                 WRITE(IOUT,'(F15.5,1X,A80)') COVPMR(13),MESAGE(13)
              ENDIF
C
               IF(ICOVER.EQ.4) THEN
                  WRITE(IOUT,'(I15,1X,A80)') NUMARC,MESAGE(14)
               ELSE
                  WRITE(IOUT,'(I15,1X,A80)') MODSTP,MESAGE(14)
               ENDIF
C
                    WRITE(IOUT,'(G15.5,1X,A80)') HNOFLO,MESAGE(15)
                     WRITE(IOUT,'(G15.5,1X,A80)') HDRY,MESAGE(16)
                      CALL CLOSE_FILE (PMRFIL,*9999)
                       GO TO 1001 
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                         Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,'(//,'' Quitting Modtools now...'')')
 9999 WRITE(*,'(//,'' Abnormal Terminal of Pth_Pmt_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1001 RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthlst version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHLST 30AUGUST1999
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Lists Modtools and coverage orientation information to file OUTFIL.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C
C   Inputs:
C
C     COVPMR  : COVERAGE PARAMETERS ARRAY (MAXPMR)
C     OUTUNT  : FORTRAN UNIT WHERE OPERATIONAL OUTPUT AND ERRORS ARE RECORDED
C     MAXPMR  : NUMBER OF COVERAGE PARAMETERS
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C
C-----------------------------------------------------------------------
      SUBROUTINE PTHLST (
     I                   OUTFIL,OUTUNT,
     I                   COVER,
     I                   PMRFIL,
     I                   FLWFIL,
     I                   BASFIL,
     I                   TRMFIL,
     I                   ENDFIL,
     I                   PTHFIL,
     I                   TIMFIL,
     I                   HEDFIL,
     I                   HCLFIL,
     I                   DDNFIL,
     I                   DCLFIL,
     I                   ARRFIL,
     I                   ACLFIL,
     I                   CONFIL,
     I                   LVLFIL,
     I                   MAXPMR,
     I                   NROW,NCOL,NLAY,
     I                   COVPMR,
     E                   *)
C
C-------------------------------------------------------------------------
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      DIMENSION 
     &          COVPMR(MAXPMR)
C
      CHARACTER*(*) 
     &             OUTFIL,
     &             COVER,
     &             PMRFIL,
     &             FLWFIL,
     &             BASFIL,
     &             TRMFIL,
     &             ENDFIL,
     &             PTHFIL,
     &             TIMFIL,
     &             HEDFIL,HCLFIL,
     &             DDNFIL,DCLFIL,
     &             ARRFIL,ACLFIL,
     &             CONFIL,LVLFIL
C
      INTEGER OUTUNT
C
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      CHARACTER*128 MODFIL,XSCOV
      CHARACTER*48 MESAGE
C
      INTEGER
     &       MAXCHR
C
      DATA 
     &     MAXCHR /48/
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                     Write Modtools information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          MODTOOLS GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''               VERSION 6.0 30AUGUST1999 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''                   LISTING MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
C0A----Set argument parameters
C
      MODFLG=INT(COVPMR(1))
      ICOVER=INT(COVPMR(2))
      XYSCALE=COVPMR(3)
      ZSCALE=COVPMR(4)
      ANGLE=COVPMR(5)
      XOGRID=COVPMR(6)
      YOGRID=COVPMR(7)
      VSCALE=COVPMR(8)
      HSCALE=COVPMR(9)
      IVIEW=INT(COVPMR(10))
      IRWCL=INT(COVPMR(11))
      IF(ICOVER.EQ.7 .OR.ICOVER.EQ.6) THEN
         IDARAY=MOD(INT(COVPMR(12)),100)
         MODFLG=INT(COVPMR(12))/100
      ELSE IF(ICOVER.NE.8) THEN
         IDARAY=INT(COVPMR(12))
      ELSE
         VECTOR=COVPMR(12)
      ENDIF
      IF(ICOVER.LT.6) THEN
         CNTINT=COVPMR(13)
      ELSE
         MODPER=INT(COVPMR(13))
      ENDIF
      IF(ICOVER.LT.6) THEN
         NUMARC=INT(COVPMR(14))
      ELSE
         MODSTP=INT(COVPMR(14))
      ENDIF
      HNOFLO=COVPMR(15)
      HDRY=COVPMR(16)
      MODFMT=INT(COVPMR(MAXPMR-4))
C
C1----Write Modtools argument list
C
      WRITE(OUTUNT,'(//,42X,''MODTOOLS ARGUMENT LIST'',
     &             /,10X,85(''-''))')
C
C1A----Write Modtools coverage or info file name
C
      IF(ICOVER.LE.1) THEN
         MODFIL=PTHFIL
         MESAGE='PATHLINE COVERAGE'
       IF(IVIEW.EQ.3) MESAGE='SINGLE PARTICLE PATHLINE COVERAGE'
      ELSE IF(ICOVER.EQ.2) THEN
         MODFIL=ENDFIL
       IF(MODFLG.LE.1) MESAGE='STARTING ENDPOINT COVERAGE'
       IF(MODFLG.EQ.2) MESAGE='FINAL ENDPOINT COVERAGE'
       IF(MODFLG.GE.3) MESAGE='FINAL ENDPOINT COVERAGE'
      ELSE IF(ICOVER.EQ.3) THEN
         MODFIL=TIMFIL
         MESAGE='TIME-SERIES COVERAGE'
      ELSE IF(ICOVER.EQ.4) THEN
         MODFIL=TIMFIL
         MESAGE='ZONES OF TRANSPORT AREA COVERAGE'
      ELSE IF(ICOVER.EQ.5) THEN
         MODFIL=BASFIL
       IF(IVIEW.EQ.0) MESAGE='MAPVIEW MODEL GRID COVERAGE'
       IF(IVIEW.EQ.1) MESAGE='ROW MODEL GRID COVERAGE'
       IF(IVIEW.EQ.2) MESAGE='COLUMN MODEL GRID COVERAGE'
       IF(IVIEW.EQ.3) MESAGE='PARTICLE PATHLINE MODEL GRID COVERAGE'
      ELSE IF(ICOVER.EQ.6) THEN
       IF(MODFLG.LT.2) THEN
          MODFIL=HEDFIL
          MESAGE='HEAD TERM INFO FILE'
       ELSE IF(MODFLG.LT.3) THEN
          MODFIL=DDNFIL
          MESAGE='DRAWDOWN TERM INFO FILE'
       ELSE IF(MODFLG.EQ.14) THEN
          MODFIL=ARRFIL
          MESAGE='MISCELLANEOUS TERM INFO FILE'
       ELSE
          MODFIL=TRMFIL
          MESAGE='CELL-BY-CELL TERM INFO FILE'
       ENDIF
      ELSE IF(ICOVER.EQ.7) THEN
         MODFIL=CONFIL
         MESAGE='CONTOUR COVERAGE'
      ELSE IF(ICOVER.EQ.8) THEN
         MODFIL=COVER
         MESAGE='FLOW VECTOR COVERAGE'
      ELSE
         MODFIL='NONE'
         MESAGE='NONE'
      ENDIF
C
        NUMCHR=INDEX(COVER,' ')-1
      IF(NUMCHR.LT.0) THEN
         NUMCHR=1
         LENCHR=48
      ELSE IF(NUMCHR.GT.MAXCHR) THEN
         NUMCHR=NUMCHR-MAXCHR+1
         LENCHR=NUMCHR+MAXCHR-1
      ELSE
         LENCHR=NUMCHR
         NUMCHR=1
      ENDIF
      WRITE(OUTUNT,'(10X,
     &                   A50,
     &                   A30)')
     &              MESAGE,
     &              COVER (NUMCHR:LENCHR)
C
C1B----Cell Coverage needed
C
        MESAGE='CROSS-SECTION COVERAGE NAME'
      IF(IVIEW.LT.1 .OR. IVIEW.GT.3) THEN
         XSCOV='NONE'
      ELSE
         XSCOV=COVER (1:INDEX(COVER,' ')-1)//'XS'
      ENDIF
C
        NUMCHR=INDEX(XSCOV,' ')-1
      IF(NUMCHR.LT.0) THEN
         NUMCHR=1
         LENCHR=48
      ELSE IF(NUMCHR.GT.MAXCHR) THEN
         NUMCHR=NUMCHR-MAXCHR+1
         LENCHR=NUMCHR+MAXCHR-1
      ELSE
         LENCHR=NUMCHR
         NUMCHR=1
      ENDIF
      WRITE(OUTUNT,'(10X,
     &                   A50,
     &                   A30)')
     &              MESAGE,
     &              XSCOV (NUMCHR:LENCHR)
C
C1C----MODPATH Main file
C
       MESAGE='MODPATH MAIN FILE NAME'
        NUMCHR=INDEX(BASFIL,' ')-1
      IF(NUMCHR.LT.0) THEN
         NUMCHR=1
         LENCHR=48
      ELSE IF(NUMCHR.GT.MAXCHR) THEN
         NUMCHR=NUMCHR-MAXCHR+1
         LENCHR=NUMCHR+MAXCHR-1
      ELSE
         LENCHR=NUMCHR
         NUMCHR=1
      ENDIF
      WRITE(OUTUNT,'(10X,
     &                   A50,
     &                   A30)')
     &              MESAGE,
     &              BASFIL (NUMCHR:LENCHR)
C
C1D----MODTOOLS parameter file
C
       MESAGE='COVERAGE PARAMETERS FILE NAME'
        NUMCHR=INDEX(PMRFIL,' ')-1
      IF(NUMCHR.LT.0) THEN
         NUMCHR=1
         LENCHR=48
      ELSE IF(NUMCHR.GT.MAXCHR) THEN
         NUMCHR=NUMCHR-MAXCHR+1
         LENCHR=NUMCHR+MAXCHR-1
      ELSE
         LENCHR=NUMCHR
         NUMCHR=1
      ENDIF
      WRITE(OUTUNT,'(10X,
     &                   A50,
     &                   A30)')
     &              MESAGE,
     &              PMRFIL (NUMCHR:LENCHR)
C
C1E----MODPATH output file
C
      IF(ICOVER.EQ.6) THEN
       IF(MODFLG.LT.2) THEN
          MODFIL=HCLFIL
          MESAGE='MODTOOLS HEAD CONTROL FILE NAME'
       ELSE IF(MODFLG.LT.3) THEN
          MODFIL=DCLFIL
          MESAGE='MODTOOLS DRAWDOWN CONTROL FILE NAME'
       ELSE IF(MODFLG.EQ.14) THEN
          MODFIL=ACLFIL
          MESAGE='MODTOOLS MISCELLANEOUS CONTROL FILE NAME'
       ELSE
          MODFIL=LVLFIL
          MESAGE='MODTOOLS CELL-BY-CELL CONTROL FILE'
       ENDIF
      ENDIF
      IF(ICOVER.EQ.7) THEN
         MESAGE='MODTOOLS CONTOUR CONTROL FILE NAME'
         NUMCHR=INDEX(LVLFIL,' ')-1
       IF(NUMCHR.LT.0) THEN
          NUMCHR=1
          LENCHR=48
       ELSE IF(NUMCHR.GT.MAXCHR) THEN
          NUMCHR=NUMCHR-MAXCHR+1
          LENCHR=NUMCHR+MAXCHR-1
       ELSE
          LENCHR=NUMCHR
          NUMCHR=1
       ENDIF
       WRITE(OUTUNT,'(10X,
     &                    A50,
     &                    A30)')
     &               MESAGE,
     &               LVLFIL (NUMCHR:LENCHR)
      ENDIF
C
C1E----MODPATH input file
C
       MESAGE='MODTOOLS INPUT DATA FILE NAME'
        NUMCHR=INDEX(MODFIL,' ')-1
      IF(NUMCHR.LT.0) THEN
         NUMCHR=1
         LENCHR=48
      ELSE IF(NUMCHR.GT.MAXCHR) THEN
         NUMCHR=NUMCHR-MAXCHR+1
         LENCHR=NUMCHR+MAXCHR-1
      ELSE
         LENCHR=NUMCHR
         NUMCHR=1
      ENDIF
      WRITE(OUTUNT,'(10X,
     &                   A50,
     &                   A30)')
     &              MESAGE,
     &              MODFIL (NUMCHR:LENCHR)
C
C1E----MODTOOLS listing file
C
       MESAGE='MODTOOLS LISTING FILE NAME'
        NUMCHR=INDEX(OUTFIL,' ')-1
      IF(NUMCHR.LT.0) THEN
         NUMCHR=1
         LENCHR=48
      ELSE IF(NUMCHR.GT.MAXCHR) THEN
         NUMCHR=NUMCHR-MAXCHR+1
         LENCHR=NUMCHR+MAXCHR-1
      ELSE
         LENCHR=NUMCHR
         NUMCHR=1
      ENDIF
      WRITE(OUTUNT,'(10X,
     &                   A50,
     &                   A30)')
     &              MESAGE,
     &              OUTFIL (NUMCHR:LENCHR)
C
      WRITE(OUTUNT,'(10X,85(''-''))')
C
C2----Modtools coverage parameters list
C
      WRITE(OUTUNT,'(//,36X,
     &             ''MODTOOLS COVERAGE PARAMETERS LIST'',
     &             /,10X,85(''-''))')
C
C3----Read MODPATH mode of operation
C
      IF(ICOVER.NE.6 .AND. ICOVER.NE.7) THEN
       IF(MODFLG.LE.1) THEN
          WRITE(OUTUNT,'(10X,
     &           ''MODPATH WAS RUN IN THE FORWARD MODE            '',
     &           10X,I15,'' COVPMR(1)'')')
     &              MODFLG
       ELSE
          WRITE(OUTUNT,'(10X,
     &           ''MODPATH WAS RUN IN THE BACKWARD MODE           '',
     &           10X,I15,'' COVPMR(1)'')')
     &              MODFLG
       ENDIF
      ENDIF
C
C3----Read coverage type
C
      IF(ICOVER.EQ.1) THEN
         WRITE(OUTUNT,'(10X,
     &          ''PATHLINE COVERAGE                              '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
      ELSE IF(ICOVER.EQ.2) THEN
       IF(MODFLG.LE.1) WRITE(OUTUNT,'(10X,
     &       ''MAPVIEW STARTING POINT COVERAGE (FORWARD TRACKING)'',
     &          6X,I15,'' COVPMR(2)'')')
     &             ICOVER
       IF(MODFLG.EQ.2) WRITE(OUTUNT,'(10X,
     &         ''MAPVIEW ENDING POINT COVERAGE (FORWARD TRACKING)  '',
     &          6X,I15,'' COVPMR(2)'')')
     &             ICOVER
       IF(MODFLG.EQ.3) WRITE(OUTUNT,'(10X,
     &         ''MAPVIEW ENDING POINT COVERAGE (BACKWARD TRACKING)'',
     &          9X,I15,'' COVPMR(2)'')')
     &             ICOVER
      ELSE IF(ICOVER.EQ.3) THEN
         WRITE(OUTUNT,'(10X,
     &          ''TIME-SERIES POINT COVERAGE                     '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
      ELSE IF(ICOVER.EQ.4) THEN
         WRITE(OUTUNT,'(10X,
     &          ''ZONES OF TRANSPORT COVERAGE (BACKWARD TRACKING)'',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
      ELSE IF(ICOVER.EQ.5) THEN
       IF(IVIEW.LE.0) WRITE(OUTUNT,'(10X,
     &          ''MODEL CELLS COVERAGE (MAPVIEW)                 '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
       IF(IVIEW.EQ.1) WRITE(OUTUNT,'(10X,
     &          ''VERTICAL ROW PROFILE COVERAGE                  '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
       IF(IVIEW.EQ.2) WRITE(OUTUNT,'(10X,
     &          ''VERTICAL COLUMN PROFILE COVERAGE               '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
       IF(IVIEW.EQ.3) WRITE(OUTUNT,'(10X,
     &          ''PARTICLE PATHLINE PROFILE COVERAGE             '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
      ELSE IF(ICOVER.EQ.6) THEN
         WRITE(OUTUNT,'(10X,
     &          ''CELL-BY-CELL TERM INFO FILE                    '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
      ELSE IF(ICOVER.EQ.7) THEN
         WRITE(OUTUNT,'(10X,
     &          ''CONTOUR LINE COVERAGE                          '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
      ELSE
         WRITE(OUTUNT,'(10X,
     &          ''FLOW VECTOR LINE COVERAGE                      '',
     &          10X,I15,'' COVPMR(2)'')')
     &             ICOVER
      ENDIF
C
C4----Read view orientation informatiom
C
      WRITE(OUTUNT,'(10X,
     &             ''MULTIPLIER FACTOR X AND Y DIRECTION            '',
     &             10X,F15.5,
     &             '' COVPMR('',I1,'')'',/,10X,
     &             ''MULTIPLIER FACTOR Z DIRECTION                  '',
     &             10X,F15.5,
     &             '' COVPMR('',I1,'')'',/,10X,
     &             ''ANGLE OF ROTATION (COUNTERCLOCKWISE DIRECTION) '',
     &             10X,F15.5,
     &             '' COVPMR('',I1,'')'',/,10X,
     &             ''X ORIGIN IN REAL-WORLD COORDINATES             '',
     &             10X,F15.5,
     &             '' COVPMR('',I1,'')'',/,10X,
     &             ''Y ORIGIN IN REAL-WORLD COORDINATES             '',
     &             10X,F15.5,
     &             '' COVPMR('',I1,'')'',/,10X,
     &             ''VERTICAL EXAGGERATION                          '',
     &             10X,F15.5,
     &             '' COVPMR('',I1,'')'',/,10X,
     &             ''HORIZONTAL MAPSCALE (1:XXXXXXXXX)              '',
     &             10X,F15.5,
     &             '' COVPMR('',I1,'')''))')
     &          (COVPMR(N),N, N=3,9)
C
C5----Read view orientation informatiom
C
      IF(IVIEW.LE.0) THEN
         WRITE(OUTUNT,'(10X,
     &          ''MAPVIEW ORIENTATION                                 '',
     &                10X,I10,'' COVPMR(10)'')')
     &             IVIEW
      ELSE IF(IVIEW.EQ.1) THEN
         WRITE(OUTUNT,'(10X,
     &          ''ROW ORIENTATION                                     '',
     &                10X,I10,'' COVPMR(10)'')')
     &             IVIEW
      ELSE IF(IVIEW.EQ.2) THEN
         WRITE(OUTUNT,'(10X,
     &          ''COLUMN ORIENTATION                                  '',
     &                10X,I10,'' COVPMR(10)'')')
     &             IVIEW
      ELSE IF(IVIEW.EQ.3) THEN
         WRITE(OUTUNT,'(10X,
     &          ''SINGLE PARTICLE ORIENTATION                         '',
     &                10X,I10,'' COVPMR(10)'')')
     &             IVIEW
      ELSE IF(IVIEW.EQ.4) THEN
         WRITE(OUTUNT,'(10X,
     &          ''USER SPECIFIED LAYER IN MAPVIEW ORIENTATION         '',
     &                10X,I10,'' COVPMR(10)'')')
     &             IVIEW
      ELSE IF(IVIEW.EQ.5) THEN
         WRITE(OUTUNT,'(10X,
     &          ''USER SPECIFIED IBOUND IN MAPVIEW ORIENTATION        '',
     &                10X,I10,'' COVPMR(10)'')')
     &             IVIEW
      ELSE
         WRITE(OUTUNT,'(10X,
     &          ''UPPERMOST ACTIVE LAYER IN MAPVIEW ORIENTATION       '',
     &                10X,I10,'' COVPMR(10)'')')
     &             IVIEW
      ENDIF
C
C6----Read tranverse informatiom
C
      IF(IVIEW.LE.0) THEN
         WRITE(OUTUNT,'(10X,
     &          ''MAPVIEW ORIENTATION (IRWCL NOT USED)           '',
     &           10X,I15,'' COVPMR(11)'')')
     &             IRWCL
      ELSE IF(IVIEW.EQ.1) THEN
         WRITE(OUTUNT,'(10X,
     &          ''VERTICAL PROFILE ALONG ROW                     '',
     &           10X,I15,'' COVPMR(11)'')')
     &             IRWCL
      ELSE IF(IVIEW.EQ.2) THEN
         WRITE(OUTUNT,'(10X,
     &          ''VERTICAL PROFILE ALONG COLUMN                  '',
     &           10X,I15,'' COVPMR(11)'')')
     &             IRWCL
      ELSE IF(IVIEW.EQ.3) THEN
         WRITE(OUTUNT,'(10X,
     &          ''VERTICAL PROFILE ALONG SINGLE PARTICLE PATH    '',
     &           10X,I15,'' COVPMR(11)'')')
     &             IRWCL
      ELSE IF(IVIEW.EQ.4) THEN
         WRITE(OUTUNT,'(10X,
     &          ''MAPVIEW ORIENTATION OF LAYER                   '',
     &           10X,I15,'' COVPMR(11)'')')
     &             IRWCL
      ELSE IF(IVIEW.EQ.5) THEN
         WRITE(OUTUNT,'(10X,
     &          ''MAPVIEW ORIENTATION OF IBOUND                  '',
     &           10X,I15,'' COVPMR(11)'')')
     &             IRWCL
      ELSE
         WRITE(OUTUNT,'(10X,
     &          ''MAPVIEW ORIENTATION OF UPPERMOST ACTIVE LAYER  '',
     &           10X,I15,'' COVPMR(11)'')')
     &             IRWCL
      ENDIF
C
C7----Read data array dimension and vector scaling information
C
      IF(ICOVER.EQ.7) THEN
       IF(IDARAY.LE.2) THEN
          WRITE(OUTUNT,'(10X,
     &          ''TWO-DIMENSIONAL ARRAY                          '',
     &           10X,I15,'' COVPMR(12)'')')
     &             IDARAY
       ELSE 
         WRITE(OUTUNT,'(10X,
     &          ''THREE-DIMENSIONAL ARRAY                        '',
     &           10X,I15,'' COVPMR(12)'')')
     &             IDARAY
       ENDIF
      ELSE IF(ICOVER.EQ.8) THEN
       IF(VECTOR.LT.0.0) THEN
          WRITE(OUTUNT,'(10X,
     &          ''VELOCITY VECTOR SCALING (LOGARITHMIC)          '',
     &           10X,G15.6,'' COVPMR(12)'')')
     &             VECTOR
       ELSE 
          WRITE(OUTUNT,'(10X,
     &          ''VELOCITY VECTOR SCALING (ARITHMETIC)           '',
     &           10X,G15.6,'' COVPMR(12)'')')
     &             VECTOR
       ENDIF
      ELSE
         WRITE(OUTUNT,'(10X,
     &          ''DIMENSION OF GRIDDED ARRAY                     '',
     &           10X,I15,'' COVPMR(12)'')')
     &             IDARAY
      ENDIF
C
C6----Read contour or Modflow stress period informatiom
C
      IF(ICOVER.EQ.7) THEN
         WRITE(OUTUNT,'(10X,
     &          ''CONTOUR INTERVAL                               '',
     &           10X,F15.5,'' COVPMR(1)'')')
     &             COVPMR(1)
      ENDIF
C 
      IF(ICOVER.GE.6) THEN
         WRITE(OUTUNT,'(10X,
     &          ''MODFLOW STRESS PERIOD                          '',
     &           10X,I15,'' COVPMR(13)'')')
     &             MODPER
      ELSE 
         WRITE(OUTUNT,'(10X,
     &          ''CONTOUR INTERVAL (NOT USED)                    '',
     &           10X,F15.5,'' COVPMR(13)'')')
     &             COVPMR(13)
      ENDIF
C
C7----Read number of equal arcs informatiom
C
      IF(ICOVER.EQ.4) THEN
         WRITE(OUTUNT,'(10X,
     &          ''NUMBER OF EQUAL ARCS                           '',
     &           10X,I15,'' COVPMR(14)'')')
     &             NUMARC
      ELSE IF(ICOVER.GE.6) THEN
         WRITE(OUTUNT,'(10X,
     &          ''MODFLOW TIME STEP                              '',
     &           10X,I15,'' COVPMR(14)'')')
     &             MODSTP
      ELSE 
         WRITE(OUTUNT,'(10X,
     &          ''NUMBER OF EQUAL ARCS (NOT USED)                '',
     &           10X,I15,'' COVPMR(14)'')')
     &             NUMARC
      ENDIF
C
C8----Hydraulic head assigned to noflow cells
C
      WRITE(OUTUNT,'(10X,
     &          ''HYDRAULIC HEAD ASSIGNED TO NOFLOW CELLS        '',
     &           10X,G15.6,'' COVPMR(15)'')')
     &             HNOFLO
C
C9----Hydraulic head assigned to dry cells
C
      WRITE(OUTUNT,'(10X,
     &          ''HYDRAULIC HEAD ASSIGNED TO DRY CELLS           '',
     &           10X,G15.6,'' COVPMR(16)'')')
     &             HDRY
C
      WRITE(OUTUNT,'(10X,85(''-''),//)')
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
C************* U.S. Geological Survey preliminary computer program ************
C******************************************************************************
C*************                 Pthrp1 version 6.0                 *************
C******************************************************************************
C**                          Language: Fortran 77                            **
C**   Program must be recompiled then link (no system libraries are needed)  **
C**                The source code is available from below:                  **
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C*     Author/Site,      Date,        Event
C*   --------------------------------------------------------------------------
C*   Leonard L. Orzol                                   Phone: (503) 251-3270
C*   U. S. Geological Survey - WRD                        FAX: (503) 251-3470
C*   10615 SE. Cherry Blossom Drive
C*   Portland, Oregon 97216 USA                    Internet: llorzol@usgs.gov
C*
C*=============================================================================
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*
C* Disclaimer: 
C            Although this program has been used by the U.S. Geological Survey,
C            no warranty, expressed or implied, is made by the USGS as to the
C            accuracy and functioning of the program and related program
C            material nor shall the fact of distribution constitute any such
C            warranty, and no responsibility is assumed by the USGS in
C            connection therewith.
C*
C*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C*=============================================================================
C
C---VERSION 6.0 PTHRP1 23JUNE1997
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Purpose:
C
C     Reads an user specifed MODPATH Main file for particle-tracking and
C      model cell information.
C
C:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
C
C .. Language: FORTRAN
C
C    Inputs:
C
C     OUTFIL  : OUTPUT FILE NAME DOCUMENTING PTHRP1 OPERATIONS.
C     OUTUNT  : FORTRAN UNIT NUMBER FOR OUTPUT DATA FILE
C     BASFIL  : INPUT MODPATH MAIN DATA FILE NAME.
C     BASUNT  : FORTRAN UNIT NUMBER FOR OUTPUT DATA FILE
C     HEDFIL  : FILE NAME FOR HEAD DATA
C     HEDUNT  : FORTRAN UNIT NUMBER FOR HEAD DATA FILE
C     CTLFIL  : FILE NAME FOR CONTROL LINES
C     CTLUNT  : FORTRAN UNIT NUMBER FOR CONTROL LINES FILE
C     ICOVER  : FLAG (TYPE OF COVERAGE)
C     IVIEW   : FLAG (ORIENTATION OF COVERAGE)
C     MODFLG  : FLAG (MODPATH TRACKING MODE AND OUTPUT FORMAT)
C     NLAY    : NUMBER OF LAYERS IN MODEL
C     NROW    : NUMBER OF ROWS IN GRID
C     NCOL    : NUMBER OF COLUMNS IN GRID
C     NCBL    : NUMBER OF QUASI-3D CONFINING LAYERS
C     IGRID   : GRID GEOMETRY CODE
C
C    Outputs:
C
C     LAYCON  : INTEGER FLAG LAYER ONE TYPE
C     DELX    : ARRAY FOR CELL WIDTHS IN ROW/COLUMN/PARTICLE DIRECTION
C     DELZ    : ARRAY FOR NUMBER MODEL LAYERS/UNITS THICKNESS
C     DELZCB  : ARRAY FOR CONFINING LAYERS/UNITS THICKNESS
C     IBOUND  : ARRAY FOR IBOUND ARRAY
C     ZTOP    : ARRAY FOR LAYER/UNIT TOP ELEVATIONS
C     ZBOT    : ARRAY FOR LAYER/UNIT BOTTOM ELEVATIONS
C     PORSTY  : ARRAY FOR CELL POROSITY
C
C
C-------------------------------------------------------------------------
      SUBROUTINE PTHRP1 (
     I                   OUTFIL,OUTUNT,
     I                   BASFIL,BASUNT,
     I                   HEDFIL,HEDUNT,
     I                   CTLFIL,CTLUNT,
     I                   ICOVER,IVIEW,
     I                   NLAY,NROW,NCOL,NCBL,IGRID,
     I                   MAXPMR,COVPMR,
     O                   LAYCON,
     O                   DELX,DELZ,DELZCB,
     O                   IBOUND,ZBOT,ZTOP,PORSTY,
     E                   *)
C-----------------------------------------------------------------------
C
C        SPECIFICATIONS:
C     ------------------------------------------------------------------
C
C:::::::::::::::::::::::  GLOBAL_VARIABLES  ::::::::::::::::::::::::::::
C
      DIMENSION 
     &          COVPMR(MAXPMR),
     &          LAYCON(NLAY),
     &          DELX(NCOL*NROW),
     &          DELZ(NLAY),
     &          DELZCB(NLAY),
     &          IBOUND(NCOL*NROW*NLAY),
     &          ZTOP(NCOL*NROW*NLAY),
     &          ZBOT(NCOL*NROW*NLAY),
     &          PORSTY(NCOL*NROW*NLAY)
C
      CHARACTER*(*) OUTFIL,BASFIL,HEDFIL,CTLFIL
C
      INTEGER BASUNT,HEDUNT,OUTUNT,CTLUNT
C
C::::::::::::::::::::::::  PROGRAM_VARIABLES  ::::::::::::::::::::::::::
C
      CHARACTER*132 BUFFER
      CHARACTER*80 VARNAM
      CHARACTER*16 TEXT
      CHARACTER*24 ANAME(9)
C
      INTEGER HEDFLG
C
      LOGICAL BOUND,COLUMN,ELEV,ROW,THICK,GRID,FLUX,HEAD,BUDGET,POR
C
      DATA ANAME(1) /'                    DELR'/
      DATA ANAME(2) /'                    DELC'/
      DATA ANAME(3) /'         LAYER THICKNESS'/
      DATA ANAME(4) /'CONFININGLAYER THICKNESS'/
      DATA ANAME(5) /'    TOP LAYER ELEVATIONS'/
      DATA ANAME(6) /' BOTTOM LAYER ELEVATIONS'/
      DATA ANAME(7) /' COMPUTED HYDRAULIC HEAD'/
      DATA ANAME(8) /'          BOUNDARY ARRAY'/
      DATA ANAME(9) /'          POROSITY ARRAY'/
C
      DATA POR /.FALSE./
      DATA BOUND /.TRUE./
C
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                 Reading basic model problem information
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CL*********************************************************************C
C
CH----Print Modtools header
C
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''       MODTOOLS GIS OUTPUT PACKAGE'')')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''          VERSION 6.0 23JUNE1997 '')')
      WRITE(OUTUNT,'(10X,85(''*''))')
      WRITE(OUTUNT,'(10X,85(''-''))')
      WRITE(OUTUNT,'(30X,
     &               ''             READ/PREPARE MODULE '')')
      WRITE(OUTUNT,'(10X,85(''=''))')
      WRITE(OUTUNT,'(//)')
C
CLA---Set local variables for ZTOP & ZBOT
C
      IF(IVIEW.GE.1 .AND. IVIEW.LE.3) THEN
       IF(IGRID.LE.0) THEN
          GRID=.FALSE.
          ELEV=.TRUE.
          THICK=.FALSE.
       ELSE
          GRID=.TRUE.
          ELEV=.FALSE.
          THICK=.TRUE.
       ENDIF
      ELSE IF(IVIEW.EQ.6) THEN
       IF(IGRID.LE.0) THEN
          GRID=.FALSE.
          ELEV=.TRUE.
          THICK=.FALSE.
       ELSE
          GRID=.TRUE.
          ELEV=.FALSE.
          THICK=.TRUE.
       ENDIF
      ELSE
       IF(IGRID.LE.0) THEN
          GRID=.FALSE.
       ELSE
          GRID=.TRUE.
       ENDIF
         ELEV=.FALSE.
         THICK=.FALSE.
      ENDIF
C
      IF(ICOVER.EQ.5 .AND. IVIEW.LE.0) THEN
         ELEV=.FALSE.
         THICK=.FALSE.
       IF(IGRID.LE.0) THEN
          ELEV=.TRUE.
       ELSE
          THICK=.TRUE.
       ENDIF
      ENDIF
C
C
      IF(ICOVER.EQ.6 .AND. IVIEW.EQ.5) THEN
         ELEV=.FALSE.
         THICK=.FALSE.
       IF(IGRID.LE.0) THEN
          ELEV=.TRUE.
       ELSE
          THICK=.TRUE.
       ENDIF
      ENDIF
C
      IF(ICOVER.EQ.6 .AND. (IVIEW.LE.0 .OR. IVIEW.GE.4)) THEN
         ELEV=.FALSE.
         THICK=.FALSE.
      ENDIF
C
      IF(ICOVER.EQ.5 .AND. IVIEW.LE.0) THEN
         POR=.FALSE.
         ELEV=.FALSE.
         THICK=.FALSE.
      ENDIF
C
      IF(ICOVER.EQ.8) THEN
         POR=.TRUE.
         ELEV=.FALSE.
         THICK=.FALSE.
       IF(IGRID.LE.0) THEN
          ELEV=.TRUE.
       ELSE
          THICK=.TRUE.
       ENDIF
      ENDIF
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                       Block-Centered Operations
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C1*********************************************************************C
C
C1----Open MODPATH Main file
C
      IF(BASUNT.GT.0) THEN
         NSTAT=1
         ITALK=1
         CALL OPEN_FILE (BASUNT,BASFIL,NSTAT,ITALK,*9998)
      ELSE
         WRITE(*,'(
     &             ''      .No Main file specified in MODPATH name '',
     &             ''file'')')
         WRITE(OUTUNT,'(
     &             ''      .No Main file specified in MODPATH name '',
     &             ''file'')')
         GO TO 9999
      ENDIF
C
C1A----Read MODPATH Main file [Item 1]
C
      VARNAM='MODPATH DATA ITEM 1'
       READ(BASUNT,'(A132)',ERR=9990,END=9991) BUFFER 
C
C1B----Read MODPATH output format information
C
      VARNAM='MODPATH DATA ITEM 2'
       READ(BASUNT,'(A132)',ERR=9990,END=9991) BUFFER
        MODFMT=0
      IF((INDEX(BUFFER,'XSECTION').NE.0) .OR.
     &   (INDEX(BUFFER,'xsection').NE.0) .OR.
     &   (INDEX(BUFFER,'Xsection').NE.0)) THEN
         MODFMT=MODFMT+1000
      ENDIF
C
      IF((INDEX(BUFFER,'COMPACT').NE.0) .OR.
     &   (INDEX(BUFFER,'compact').NE.0) .OR.
     &   (INDEX(BUFFER,'Compact').NE.0)) THEN
         MODFMT=MODFMT+100
      ENDIF
C
      IF((INDEX(BUFFER,'BINARY').NE.0) .OR.
     &   (INDEX(BUFFER,'binary').NE.0) .OR.
     &   (INDEX(BUFFER,'Binary').NE.0)) THEN
         MODFMT=MODFMT+200
      ENDIF
         COVPMR(MAXPMR-4)=MODFMT
C
C1C----Read MODPATH layer type codes
C
      VARNAM='MODPATH DATA ITEM 3'
       READ(BASUNT,*,ERR=9990,END=9991) (LAYCON(ILAY), ILAY=1,NLAY)
C
C1D----Read MODPATH confining layer type codes
C
      IF(NCBL.GT.0) THEN
         VARNAM='MODPATH DATA ITEM 4'
         READ(BASUNT,*,ERR=9990,END=9991)
     &        (DELZCB(ILAY), ILAY=1,NLAY)
         DO 100 ILAY=1,NLAY
            DELZCB(ILAY)=-1.0*DELZCB(ILAY)
  100    CONTINUE          
      ELSE
         DO 110 ILAY=1,NLAY
            DELZCB(ILAY)=0.0
  110    CONTINUE          
      ENDIF
C
C1----Read for row width (MODPATH x-direction)
C
      WRITE(*,'(''      .Processing for cell widths along '',
     &          ''rows (x-direction)'')')
      CALL U1DREL (DELX(1),ANAME(1),NCOL,BASUNT,OUTUNT)
C
C2----Read for column width (MODPATH y-direction)
C
      WRITE(*,'(''      .Processing for cell widths along '',
     &          ''columns (y-direction)'')')
      CALL U1DREL (DELX(NCOL+1),ANAME(2),NROW,BASUNT,OUTUNT)
C
C3----Cell Thickness or Elevations
C
C
C3A------Cell Thickness.
C
      IF(GRID) THEN
       IF(THICK) THEN
          WRITE(*,'(''      .Processing for Model Layer '',
     &                 ''and Confining Layer Thickness '')')
          CALL U1DREL (DELZ,ANAME(3),NLAY,BASUNT,OUTUNT)
        IF(NCBL.GT.0) THEN
           CALL U1DREL (DELZCB,ANAME(4),NLAY,BASUNT,OUTUNT)
        ELSE
           DO 300 K=1,NLAY
              KK=K
              DELZCB(KK)=0.0
  300      CONTINUE
        ENDIF
           VARNAM='ZBL1'
           READ(BASUNT,*,ERR=9990,END=9991) ZBL1
           DO 310 K=1,NLAY
              KK=K
            IF(KK.LE.1) THEN
               TOP=ZBL1+DELZ(KK)
               BOT=ZBL1
            ELSE
               TOP=BOT-DELZCB(KK-1)
               BOT=TOP-DELZ(KK)
            ENDIF
              DO 310 NN=1,NCOL*NROW
                 LOC=NN+(KK-1)*NCOL*NROW
                 ZTOP(LOC)=TOP
                 ZBOT(LOC)=BOT
  310      CONTINUE
C
        IF(LAYCON(1).EQ.1) THEN
           VARNAM='SIMULATED HEAD FOR LAYER 1'
         IF(HEDUNT.LT.0) THEN
            WRITE(*,'(
     &            ''        .Substituting cell hydraulic head '',
     &            ''for top of unconfined layer 1'')') 
            WRITE(OUTUNT,'(
     &            ''        .Substituting cell hydraulic head '',
     &            ''for top of unconfined layer 1'')')
            LOC=1
            KK=1
            NSTAT=1
            ITALK=1
            CALL OPEN_FILE (HEDUNT,HEDFIL,NSTAT,ITALK,*9998)
            HEDFLG=0
            HEDUNT=ABS(HEDUNT)
  302       READ(HEDUNT,ERR=9990,END=304) 
     &           KSTP,KPER,PERTIM,TOTIM,TEXT,ICOL,IROW,ILAY
            READ(HEDUNT,ERR=9990,END=9991) (ZTOP(N), N=1,NCOL*NROW)
          IF(TEXT.NE.'            HEAD') GO TO 302
            HEDFLG=HEDFLG+1
  304       HEDUNT=-ABS(HEDUNT)
            CALL CLOSE_FILE (HEDFIL,*9998)
          IF(HEDFLG.LE.0) THEN
             WRITE(*,'(
     &                 ''      .Did not find cell_by_cell '',
     &                 ''head terms in file '',A)')
     &                 HEDFIL (1:INDEX(HEDFIL,' ')-1)
             WRITE(OUTUNT,'(
     &                 ''      .Did not find cell_by_cell '',
     &                 ''head terms in file '',A)')
     &                 HEDFIL (1:INDEX(HEDFIL,' ')-1)
             GO TO 9999
          ENDIF
         ELSE IF(HEDUNT.GT.0) THEN
            LOC=1
            KK=1
          IF(CTLUNT.GT.0) THEN
             WRITE(*,'(
     &             ''        .Substituting cell hydraulic head '',
     &             ''for top of unconfined layer 1'')') 
             WRITE(OUTUNT,'(
     &             ''        .Substituting cell hydraulic head '',
     &             ''for top of unconfined layer 1'')')
             NSTAT=1
             ITALK=1
             CALL OPEN_FILE (CTLUNT,CTLFIL,NSTAT,ITALK,*9998)
             CALL OPEN_FILE (HEDUNT,HEDFIL,NSTAT,ITALK,*9998)
             CALL U2DREL (ZTOP(LOC),ANAME(7),NROW,NCOL,KK,CTLUNT,
     &                    OUTUNT)
             CALL CLOSE_FILE (CTLFIL,*9998)
             CALL CLOSE_FILE (HEDFIL,*9998)
          ELSE
             WRITE(*,'(
     &             ''        .Can not '',
     &             ''substitute cell hydraulic head '',
     &             ''for top of unconfined layer 1 '',/,
     &             ''        .Need U2DREL control lines for ASCII '',
     &             ''formatted cell-by-cell head file'')') 
             WRITE(OUTUNT,'(
     &             ''        .Can not '',
     &             ''substitute cell hydraulic head '',
     &             ''for top of unconfined layer 1 '',/,
     &             ''        .Need U2DREL control lines for ASCII '',
     &             ''formatted cell-by-cell head file'')') 
             GO TO 9998
          ENDIF
         ELSE
            WRITE(*,'(
     &            ''        .Can not '',
     &            ''substitute cell hydraulic head '',
     &            ''for top of unconfined layer 1 '')')
            WRITE(*,'(
     &            ''      .No file containing cell_by_cell '',
     &            ''head terms specified in MODTOOLS name file'')')
            WRITE(OUTUNT,'(
     &            ''        .Can not '',
     &            ''substitute cell hydraulic head '',
     &            ''for top of unconfined layer 1'')')
            WRITE(OUTUNT,'(
     &            ''      .No file containing cell_by_cell '',
     &            ''head terms specified in MODTOOLS name file'')')
            GO TO 9998
         ENDIF
        ENDIF
C
C3B------Omit Cell Thickness.
C
       ELSE
          WRITE(*,'(''      .Omitting for Model Layer '',
     &              ''and Confining Layer Thickness '')')
          CALL U1DRELOMIT (DELZ,ANAME(3),NLAY,BASUNT,OUTUNT,
     E                     *9998)
         IF(NCBL.GT.0) THEN
            CALL U1DRELOMIT (DELZCB,ANAME(4),NLAY,BASUNT,OUTUNT,
     E                      *9998)
         ENDIF
           VARNAM='ZBL1'
           READ(BASUNT,'(G10.0)',ERR=9990,END=9991) ZBL1
       ENDIF
C
C3C------Read Top and Bottom Elevations.
C
      ELSE
       IF(ELEV) THEN
          WRITE(*,'(''      .Processing Elevations....'')')
          DO 320 K=1,NLAY
             KK=K
             LOC=1+(K-1)*NCOL*NROW
           IF(LAYCON(1).EQ.1 .AND. KK.EQ.1) THEN
            IF(HEDUNT.EQ.0) THEN
               WRITE(*,'(
     &               ''        .Substituting cell hydraulic head '',
     &               ''for top of unconfined layer 1'')') 
               WRITE(OUTUNT,'(
     &               ''        .Substituting cell hydraulic head '',
     &               ''for top of unconfined layer 1'')') 
               WRITE(*,'(
     &               ''        .No cell hydraulic head file '',
     &               ''specified for top of unconfined layer 1'')') 
               WRITE(OUTUNT,'(
     &               ''        .No cell hydraulic head file '',
     &               ''specified for top of unconfined layer 1'')') 
                GO TO 9998
            ELSE IF(HEDUNT.LT.0) THEN
               WRITE(*,'(
     &               ''        .No cell hydraulic head file '',
     &               ''specified for top of unconfined layer 1'')') 
               WRITE(*,'(
     &               ''        .Substituting cell hydraulic head '',
     &               ''for top of unconfined layer 1'')') 
               WRITE(OUTUNT,'(
     &               ''        .Substituting cell hydraulic head '',
     &               ''for top of unconfined layer 1'')') 
               NSTAT=1
               ITALK=1
               CALL OPEN_FILE (HEDUNT,HEDFIL,NSTAT,ITALK,*9998)
               HEDUNT=ABS(HEDUNT)
               READ(HEDUNT) KSTP,KPER,PERTIM,TOTIM,TEXT,ICOL,IROW,ILAY
               READ(HEDUNT) (ZTOP(N), N=1,NCOL*NROW)
               HEDUNT=-ABS(HEDUNT)
               CALL CLOSE_FILE (HEDFIL,*9998)
            ELSE IF(HEDUNT.GT.0) THEN
             IF(CTLUNT.GT.0) THEN
                NSTAT=1
                ITALK=1
                CALL OPEN_FILE (CTLUNT,CTLFIL,NSTAT,ITALK,*9998)
                CALL OPEN_FILE (HEDUNT,HEDFIL,NSTAT,ITALK,*9998)
                WRITE(*,'(
     &                ''        .Substituting cell hydraulic head '',
     &                ''for top of unconfined layer 1'')') 
                WRITE(OUTUNT,'(
     &                ''        .Substituting cell hydraulic head '',
     &                ''for top of unconfined layer 1'')')
                CALL U2DREL (ZTOP(LOC),ANAME(7),NROW,NCOL,KK,CTLUNT,
     &                       OUTUNT)
                CALL CLOSE_FILE (CTLFIL,*9998)
                CALL CLOSE_FILE (HEDFIL,*9998)
             ELSE
                WRITE(*,'(
     &                ''        .Can not '',
     &                ''substitute cell hydraulic head '',
     &                ''for top of unconfined layer 1 '',/,
     &                ''        .Need U2DREL control lines for ASCII '',
     &                ''formatted cell-by-cell head file'')') 
                WRITE(OUTUNT,'(
     &                ''        .Can not '',
     &                ''substitute cell hydraulic head '',
     &                ''for top of unconfined layer 1 '',/,
     &                ''        .Need U2DREL control lines for ASCII '',
     &                ''formatted cell-by-cell head file'')') 
                GO TO 9998
             ENDIF
            ELSE
               WRITE(*,'(
     &               ''        .Can not '',
     &               ''substitute cell hydraulic head '',
     &               ''for top of unconfined layer 1 '',/,
     &               ''        .Cell-by-cell head file not open'')') 
               WRITE(OUTUNT,'(
     &               ''        .Can not '',
     &               ''substitute cell hydraulic head '',
     &               ''for top of unconfined layer 1'',/,
     &               ''        .Cell-by-cell head file not open'')') 
               GO TO 9998
            ENDIF
           ELSE
              CALL U2DREL (ZTOP(LOC),ANAME(5),NROW,NCOL,KK,BASUNT,
     &                     OUTUNT)
           ENDIF
             CALL U2DREL (ZBOT(LOC),ANAME(6),NROW,NCOL,KK,BASUNT,
     &                    OUTUNT)
  320     CONTINUE
C
C3D------Omit Cell Elevations.
C
       ELSE
          WRITE(*,'(''      .Omitting Elevations Arrays '')')
          DO 330 K=1,NLAY
             KK=K
             LOC=1+(K-1)*NCOL*NROW
           IF(LAYCON(1).EQ.1 .AND. KK.EQ.1) THEN
              GO TO 332
           ELSE
              CALL U2DRELOMIT (ZTOP(LOC),ANAME(5),NROW,NCOL,
     &                                                 KK,BASUNT,OUTUNT,
     E                        *9998)
           ENDIF
  332        CALL U2DRELOMIT (ZBOT(LOC),ANAME(6),NROW,NCOL,
     &                                                KK,BASUNT,OUTUNT,
     E                       *9998)
  330     CONTINUE
       ENDIF
      ENDIF
C
C4---Ibound Array File
C
      IF(BOUND) THEN
         WRITE(*,'(''      .Processing Ibound File '')')
C
C4A----Read values from Ibound File
C
         DO 400 LAYER=1,NLAY
            KK=LAYER
            LOC=1+(KK-1)*NCOL*NROW
C
C4B-----Tests Existence Of Info File And Item Name.
C
            CALL U2DINT (IBOUND(LOC),ANAME(8),NROW,NCOL,KK,BASUNT,
     &                   OUTUNT)
  400    CONTINUE
C
C4C-----Ommitting Ibound array.
C
      ELSE
         WRITE(*,'(''      .Omitting Ibound Array '')')
      ENDIF
C
C5---Porosity Array File
C
      IF(POR) THEN
         WRITE(*,'(''      .Processing Porosity '')')
C
C5A----Read values from MAIN File
C
         DO 500 LAYER=1,NLAY
            KK=LAYER
            LOC=1+(KK-1)*NCOL*NROW
C
C5B-----Tests Existence Of Info File And Item Name.
C
            CALL U2DREL (PORSTY(LOC),ANAME(9),NROW,NCOL,KK,BASUNT,
     &                   OUTUNT)
  500    CONTINUE
C
C5C-----Ommitting porosity array.
C
      ELSE
         WRITE(*,'(''      .Omitting Porosity Array '')')
      ENDIF
C
C6----Close MODPATH Main file
C
      CALL CLOSE_FILE (BASFIL,*9998)
       GO TO 1000
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                        Program Errors
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
CE*********************************************************************C
 9990 WRITE(*,'(//,'' Unable to read '',A,'' from file '',A)') 
     &          VARNAM,BASFIL (1:INDEX(BASFIL,' ')-1)
      WRITE(OUTUNT,'(//,'' Unable to read '',A,'' from file '',A)') 
     &          VARNAM,BASFIL (1:INDEX(BASFIL,' ')-1)
      GO TO 9998
 9991 WRITE(*,'(//,'' End-of-file; Unable to read '',A,
     &          '' from file '',A)') 
     &          VARNAM,BASFIL (1:INDEX(BASFIL,' ')-1)
      WRITE(OUTUNT,'(//,'' End-of-file; Unable to read '',A,
     &          '' from file '',A)') 
     &          VARNAM,BASFIL (1:INDEX(BASFIL,' ')-1)
 9998 CALL CLOSE_FILE (BASFIL,*9999)
 9999 WRITE(*,
     &      '(//,'' Abnormal Termination of Pthrp1_Subroutine'')')
      WRITE(OUTUNT,
     &      '(//,'' Abnormal Termination of Pthrp1_Subroutine'')')
      RETURN 1
C**********************************************************************C
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C                  Return to Calling Program
C<><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><><>C
C**********************************************************************C
 1000 RETURN
      END
